(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2480474,     100962]*)
(*NotebookOutlinePosition[   2509456,     102028]*)
(*  CellTagsIndexPosition[   2509412,     102024]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["The Quadrupole (Example #6  Revisited)",
  FontSize->24]], "Title",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["P. Elleaume, ESRF,   Version : 0.1", "Text",
  PageWidth->PaperWidth,
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
This is a new version of the quadrupole already presented in \
Example#6 of the distribution. The improvements are a a better organisation \
which allow a more complete systematic study. It also allows an easy study of \
the variation of any characteristics as a function of any input parameter \
(geometry, segmentation, current density,...). It makes use of more advanced \
mathematica programming. As a result, it makes this example is much more \
usefull for a systematic optimization. As in example#6, This quadrupole \
presents an hyperbolic pole face with  chamfer.
Note that no effort has been made in optimizing this quadrupole for a \
particular gradient and/or power consumption. This notebook should only be \
used as a template for designing and optimizing a quadrupole. Sometime, the \
quadrupole must be cut in the middle (to let space for beamline,...) and \
therefore have a second order symmetry (horizontal plane) rather than a 4th \
order symmetry (horizontal and vertical planes) as used in this notebook. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Load and Initialize Radia", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The following instruction loads the Radia package and returns the Radia  \
version number.It also turn off some warnings and load additionnal ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" packages used for plotting. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
<<Radia`;
Off[General::\"spell1\"];
<<Graphics`MultipleListPlot`;
<<Graphics`PlotField3D`;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining The Model", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
A routine to create the geometry ,  solve it and compute  the \
mulipoles\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \( (*\(\(--\(--\(--For\)\)\)\ the\ Harmonic\ \(\(\(\(Analysis--\)--\)--\)\
--\)\)\(-\)*) \[IndentingNewLine]\[IndentingNewLine]harm[Obj_, {y_, z_, ro_}, 
        Np_] := Module[{}, \[IndentingNewLine]{Np, ro, 
          Table[radFldInt[Obj, "\<inf\>", "\<ibz\>", 
                N[{\(-1\), y + ro*Cos[tet], z + ro*Sin[tet]}], 
                N[{1, y + ro*Cos[tet], z + ro*Sin[tet]}]] + 
              radFldInt[
                  Obj, "\<inf\>", "\<iby\>", {\(-1\), y + ro*Cos[tet], 
                    z + ro*Sin[tet]}, {1, y + ro*Cos[tet], z + ro*Sin[tet]}]*
                I, {tet, 0, 2*Pi*\((1 - 1/Np)\), 
              2*Pi/Np}]}]\), "\[IndentingNewLine]", 
    \(\(\(multipol[w_List, 
        q_]\)\(:=\)\((\(w[\([3]\)] . 
              Table[Exp[\(-2\)*I*Pi/w[\([1]\)]*q*p], {p, 0, w[\([1]\)] - 1}]/
            w[\([1]\)]\)/w[\([2]\)]^q)\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[{
    \(\(quad[radius_, thick_, width_, height_, chamfer_, hyp_, ns_seg, 
          CurDens_, ironmat_] := 
        Module[{n1, n2, np3, n4, np5, t0, t1, t2, dy, Bz, Iz, gap, nx, ny, 
            np, nb, na, nr3, nr5, Nn, depth, rap, ct, z0, y0, amax, dz, qq, 
            hh, g1, g2, gg, gp, g3, cy, tan, len, g4, g5, cyl, Rmax, coil1, 
            coil2, coilvol, g, gd, t, tc, w, mm, y, bp, CuResistivity, power, 
            volRaceTrk}, \[IndentingNewLine]\[IndentingNewLine] (*\ ___  ___  \
___  _\ Prepare\ the\ Geometry\ ___  ___  ___  __  ___  ___  ___  ___  _\
*) \[IndentingNewLine]\[IndentingNewLine]t0 = 
            AbsoluteTime[]; \
\[IndentingNewLine]\[IndentingNewLine]volRaceTrk[{rmin_, rmax_}, {lx_, ly_}, 
              h_]\  := \[IndentingNewLine]h*\((rmax - 
                  rmin)\)*\((2*\((lx + ly)\) + 
                  Pi*\((rmax + 
                        rmin)\))\); \[IndentingNewLine]\[IndentingNewLine]gap \
= 2*radius; \[IndentingNewLine]{nx, ny, np, nb, na} = 
            List @@ ns; \[IndentingNewLine]n1 = {nx, 
              ny, {3, 1}}; \[IndentingNewLine]n2 = {nx, 
              ny, {3, 1}}; \[IndentingNewLine]np3 = 
            na; \[IndentingNewLine]nr3 = 
            ny; \[IndentingNewLine]n4 = {nx, nb, 
              ny}; \[IndentingNewLine]np5 = 
            Ceiling[np3/2]; \[IndentingNewLine]nr5 = 
            ny; \[IndentingNewLine]Nn = 4; \[IndentingNewLine]depth = 
            1.2*width/2; \[IndentingNewLine]If[hyp < 0.1, 
            hyp = 0.2]; \[IndentingNewLine]rap = 
            0.5; \[IndentingNewLine]ct = {0, 0, 0}; \[IndentingNewLine]z0 = 
            gap/2; \[IndentingNewLine]y0 = width/2; \[IndentingNewLine]amax = 
            N[hyp*ArcSinh[y0/z0]]; \[IndentingNewLine]dz = 
            z0*\((Cosh[amax] - 1)\); \[IndentingNewLine]qq = 
            N[Table[{z0*Sinh[a/hyp], z0*Cosh[a]}, {a, 0, amax*\((1 + 2/np)\), 
                  amax/np}]]; \[IndentingNewLine]hh = \(qq[\([np + 
                      1]\)]\)[\([2]\)] + height*rap - 
              dz; \[IndentingNewLine]qq[\([np + 
                  2]\)] = {\(qq[\([np + 1]\)]\)[\([1]\)], 
              hh}; \[IndentingNewLine]qq[\([np + 3]\)] = {0, 
              hh}; \[IndentingNewLine]\[IndentingNewLine]g1 = 
            radObjThckPgn[thick/4, thick/2, 
              qq]; \[IndentingNewLine]\[IndentingNewLine]radObjDivMag[g1, 
            n1]; \[IndentingNewLine]g2 = 
            radObjRecMag[{thick/4, width/4, 
                gap/2 + height*\((1/2 + rap/2)\)}, {thick/2, width/2, 
                height*\((1 - rap)\)}]; \[IndentingNewLine]radObjDivMag[g2, 
            n2]; \[IndentingNewLine]gg = 
            radObjCnt[{g1, g2}]; \[IndentingNewLine]gp = \(radObjCutMag[
                gg, {thick/2 - chamfer - gap/2, 0, 0}, {1, 
                  0, \(-1\)}]\)[\([1]\)]; \[IndentingNewLine]g3 = 
            radObjRecMag[{thick/4, width/4, 
                gap/2 + height + depth/2}, {thick/2, width/2, 
                depth}]; \[IndentingNewLine]cy = {"\<cyl\>", {{0, width/2, 
                  gap/2 + height}, {1, 0, 0}}, {0, 0, gap/2 + height}, 
              2*depth/width}; \[IndentingNewLine]radObjDivMag[
            g3, {nr3, np3, nx}, cy]; \[IndentingNewLine]tan = 
            N[Tan[2*\(Pi/2\)/Nn]]; \[IndentingNewLine]len = 
            tan*\((height + gap/2)\) - width/2; \[IndentingNewLine]g4 = 
            radObjRecMag[{thick/4, width/2 + len/2, 
                gap/2 + height + depth/2}, {thick/2, len, 
                depth}]; \[IndentingNewLine]\[IndentingNewLine]radObjDivMag[
            g4, n4]; \[IndentingNewLine]posy = width/2 + len; 
          posz = posy/tan; \[IndentingNewLine]g5 = 
            radObjThckPgn[thick/4, 
              thick/2, {{posy, posz}, {posy, 
                  posz + depth}, {posy + depth*tan, 
                  posz + depth}}]; \[IndentingNewLine]cyl = {"\<cyl\>", {{0, 
                  posy, posz}, {1, 0, 0}}, {0, posy, posz + depth}, 
              1}; \[IndentingNewLine]radObjDivMag[g5, {nr5, np5, nx}, 
            cyl]; \[IndentingNewLine] (*\ \(===\)\(===\)\(===\)\(\ \
\)\(coils\)\(\ \)\(===\)\(===\)\(===\)\(===\)\(\[Equal]\)\
*) \[IndentingNewLine]Rmax = 
            rmin - width/2 + gap/2 + offset - 2; \[IndentingNewLine]coil1 = 
            radObjRaceTrk[{0, 0, 
                gap/2 + height/2 + offset/2}, \[IndentingNewLine]{rmin, 
                Rmax}, {thick, width - 2*rmin}, height - offset, 
              3, \(-CurDens\)]; \[IndentingNewLine]coilvol = 
            volRaceTrk[{rmin, Rmax}, {thick, width - 2*rmin}, 
              height - 
                offset]\ ; \[IndentingNewLine]\[IndentingNewLine]radObjDrwAtr[
            coil1, coilcolor]; \[IndentingNewLine]hh = \((height - offset)\)/
              2; \[IndentingNewLine]coil2 = 
            radObjRaceTrk[{0, 0, gap/2 + height - hh/2}, {Rmax, 
                Rmax + hh*0.8}, {thick, width - 2*rmin}, hh, 
              3, \(-CurDens\)]; \[IndentingNewLine]coilvol = 
            coilvol + 
              volRaceTrk[{Rmax, Rmax + hh*0.8}, {thick, width - 2*rmin}, 
                hh]\ ; \[IndentingNewLine]\[IndentingNewLine]radObjDrwAtr[
            coil2, coilcolor]; \[IndentingNewLine]g = 
            radObjCnt[{gp, g3, g4, g5}]; \[IndentingNewLine]radObjDrwAtr[g, 
            ironcolor]; \[IndentingNewLine]gd = 
            radObjCnt[{g}]; \[IndentingNewLine]RadTrfZerPerp[gd, 
            ct, {1, 0, 0}]; \[IndentingNewLine]RadTrfZerPerp[gd, 
            ct, {0, 1, 0}]; \[IndentingNewLine]t = 
            radObjCnt[{gd, coil1, coil2}]; \[IndentingNewLine]tc = 
            radObjDpl[
              t]; \[IndentingNewLine] (*\ \(===\)\(===\)\(===\)\(\ \)\(set\ \
quadrupole\ symmetries\)\(\ \)\(===\)\(===\)\(===\)\(===\)\(\[Equal]\)\
*) \[IndentingNewLine]RadTrfZerPara[t, 
            ct, {0, N[Cos[Pi/Nn]], 
              N[Sin[Pi/Nn]]}]; \[IndentingNewLine]radTrfMlt[t, 
            radTrfRot[ct, {1, 0, 0}, 4*Pi/Nn], 
            Nn/2]; \[IndentingNewLine]radMatApl[g, 
            ironmat]; \[IndentingNewLine]radTrfOrnt[t, 
            radTrfRot[{0, 0, 0}, {1, 0, 0}, 
              N[Pi/Nn]]]; \[IndentingNewLine]size = 
            radObjDegFre[
              t]; \[IndentingNewLine] (*\ ___  __Solve\ for\ the\ \
magnetization\ in\ the\ Iron\ ___  ___  ___  ___  __*) \[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]t1 = 
            AbsoluteTime[]; \[IndentingNewLine]{r1, r2, r3, r4} = 
            RadSolve[t, 0.0001, 1000]; \[IndentingNewLine]t2 = 
            AbsoluteTime[]; \[IndentingNewLine]\[IndentingNewLine] (*\ ___  \
__Compute\ Field\ , \ 
            Field\ Integral\ and\ Mulipoles\ ___  ___  \
_*) \[IndentingNewLine]\[IndentingNewLine]dy = 1; \[IndentingNewLine]Bz = 
            radFld[t, "\<Bz\>", {0, dy, 0}]*1000; \t
          Iz = radFldInt[
              t, "\<inf\>", "\<ibz\>", {\(-1\), dy, 0}, {1, dy, 
                0}]; \[IndentingNewLine]\[IndentingNewLine]ra = 2; \ \  (*\ 
            radius\ over\ which\ the\ harmonic\ decomposition\ is\ computed\ \
*) \[IndentingNewLine]nharm = 10; \[IndentingNewLine]w = 
            harm[t, {0, 0, ra}, nharm]; \[IndentingNewLine]mm = 
            Table[multipol[w, i], {i, 0, nharm - 1}]; \[IndentingNewLine]t3 = 
            AbsoluteTime[]; \[IndentingNewLine]\[IndentingNewLine]y = 
            radius*0.97; \[IndentingNewLine]bp = 
            Sqrt[2]*radFld[
                t, "\<Bz\>", {0, y*Cos[Pi/4], 
                  y*Sin[Pi/4]}]; \[IndentingNewLine]power = 
            coilvol*4*CurDens^2*1000*
              Resistivity; \[IndentingNewLine]\[IndentingNewLine] (*\ ___  \
___  ___  _Prepare\ Output\ ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\
\[IndentingNewLine]{AllObject \[Rule] 
              t, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              handle\ to\ the\ full\ quadrupole\ \
*) \[IndentingNewLine]PoleObject \[Rule] 
              g, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  (*\ handle\ to\ the\ fund . \ 
                  part\ of\ the\ yoke*) \[IndentingNewLine]PoleCoilObject \
\[Rule] tc, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \(handle\ a\ pole\  &\)\ \
coil\ assembly\ *) \[IndentingNewLine]PoleProfile \[Rule] 
              qq, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              2  D\ points\ of\ the\ pole\ profile\ \
*) \[IndentingNewLine]DegOfFreedom \[Rule] 
              size, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              degrees\ of\ freedom\ in\ solving\ \
*) \[IndentingNewLine]CreationCpuTime \[Rule] t1 - t0, \ \ \ \ \  (*\ 
              CPU\ time\ to\ create\ the\ geometry\ \
*) \[IndentingNewLine]SolvingCpuTime \[Rule] t2 - t1, \ \ \ \ \ \ \ \  (*\ 
              CPU\ time\ to\ solve\ *) \[IndentingNewLine]ProcessCpuTime \
\[Rule] t3 - t2, \ \ \ \ \ \ \ \  (*\ 
              CPU\ time\ to\ compute\ multipoles\ \
*) \[IndentingNewLine]MaxMag \[Rule] 
              r2, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
              Maximum\ Magnetizat . \ \([T]\)\ in\ yoke\ \
*) \[IndentingNewLine]MaxH \[Rule] 
              r3, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Maximum\ H\ vector\ [
                  T]\ in\ yoke\ *) \[IndentingNewLine]Niter \[Rule] 
              r4, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Numb . \ 
                  of\ iteration\ during\ solving\ \
*) \[IndentingNewLine]PoleField \[Rule] 
              bp, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  (*\ 
              Field\ in\ the\ centre\ of\ the\ pole\ \
*) \[IndentingNewLine]IntQuad \[Rule] 
              Iz/dy, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  (*\ Integrated\ Quadrupole\ [T]\ *) \[IndentingNewLine]PeakGrad \[Rule] 
              Bz/dy, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Max\ Gradient\ on\ axis\ [
                  T/m]\ *) \[IndentingNewLine]EffLength \[Rule] 
              Iz/Bz, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Effective\ Length\ of\ Quadrupole\ \
*) \[IndentingNewLine]IntMultipole \[Rule] 
              mm, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              List\ of\ multipoles\ {Norm, 
                  Skew}\ *) \[IndentingNewLine]CoilVolume \[Rule] 
              coilvol*4, \ \ \ \ \ \ \ \ \  (*\ 
              volume\ of\ coils\ [mm3]\ *) \[IndentingNewLine]CoilPower -> 
              power\ , \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              power\ in\ watts\ in\ coils\ [
                  W]\ *) \[IndentingNewLine]Debug \[Rule] 
              1\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              add\ here\ debugging\ informations\ *) \[IndentingNewLine]}\ \ \
\[IndentingNewLine]];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(SetAttributes[quad, Listable];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[seg, Listable];\)\), "\[IndentingNewLine]", 
    \(\(Resistivity = 1.7\ 10^\(-8\);\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      default\ to\ copper\ resistivity\ *) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(quad::usage = "\<To be written ...\>";\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating the Geometry and Solving", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Creating and solving the quadrupole with a complete output of \
multipole and postprocessing to plot the pole shape. The user should \
experience with varying the segmentation parameters to check the stability of \
the result and its precision.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(radius = 
        34;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ 
      radius\ of\ circle\ *) \t\t\t\t\t\), "\[IndentingNewLine]", 
    \(\(width = 
        60;\)\t\t\t\t\ \  (*\ \ pole\ width\ *) \), "\[IndentingNewLine]", 
    \(\(heigh = 80;\)\t\t\t\t (*\ 
      height\ of\ iron\ in\ coil\ *) \), "\[IndentingNewLine]", 
    \(\(length = 80;\)\t\t\t\t (*\ 
      length\ \ along\ beam\ *) \), "\[IndentingNewLine]", 
    \(\(chamfer = 
        16;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ chamfer\ of\ the\ pole\ *) \), "\[IndentingNewLine]", 
    \(\(curden = 2;\)\t\t\t\t (*\ 
      current\ density\ A/
          mm2\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(nx = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ beam\ *) \), \
"\[IndentingNewLine]", 
    \(\(ny = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ width\ *) \
\), "\[IndentingNewLine]", 
    \(\(nz = 
        4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ height\ *) \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nb = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ return\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(na = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ angular\ segmentation\ in\ the\ \
corner\ *) \[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(rmin = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
      minimum\ radius\ of\ the\ coil\ windings\ *) \), "\[IndentingNewLine]", 
  
    \(\(offset = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ 
      Vert . \ recess\ betw . \ 1  st\ and\ 2  
        nd\ coils*) \), "\[IndentingNewLine]", 
    \(\(hyp = 
        1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ pole\ profile\ 0.1 < \ hyp\  < 2, \ 
      1 : \ hyperbolic*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ironcolor = {0, 0.5, 
          1};\)\ \ \ \ \  (*\ \ Color\ of\ the\ yoke\ \ *) \), "\
\[IndentingNewLine]", 
    \(\(coilcolor = {1, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \  (*\ \ Color\ of\ the\ coi\
\[IndentingNewLine]l\ \ *) \), "\[IndentingNewLine]", 
    \(\(Resistivity = 1.7\ 10^\(-8\);\)\ \ \ \  (*\ 
      resistivity\ of\ the\ coil\ material[
          Ohm - m]\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(iron\  = RadMatSteel37[];\)\ \ \ \ \  (*\ 
      Material\ of\ the\ Yoke\ *) \), "\[IndentingNewLine]", 
    \(\(nseg = seg[nx, ny, nz, nb, na];\)\), "\[IndentingNewLine]", 
    \(res = 
      quad[radius, length, width, heigh, chamfer, hyp, nseg, curden, 
        iron]\)}], "Input"],

Cell[BoxData[
    \({AllObject \[Rule] 111, PoleObject \[Rule] 107, 
      PoleCoilObject \[Rule] 192, 
      PoleProfile \[Rule] {{0.`, 34.`}, {6.808077880157913`, 
            34.67491779979147`}, {13.886443580532603`, 
            36.726466142487965`}, {21.516115630807374`, 
            40.236093645361166`}, {30.`, 45.34313619501853`}, {30.`, 
            74.`}, {0, 74.`}}, DegOfFreedom \[Rule] 162, 
      CreationCpuTime \[Rule] 0``5.7196, SolvingCpuTime \[Rule] 3.`6.1967, 
      ProcessCpuTime \[Rule] 0``5.7196, MaxMag \[Rule] 0.9634781555475244`, 
      MaxH \[Rule] 0.0006966914128646796`, Niter \[Rule] 337, 
      PoleField \[Rule] 0.23579419778286417`, 
      IntQuad \[Rule] 0.7237264532278125`, 
      PeakGrad \[Rule] 7.289314388867081`, 
      EffLength \[Rule] 0.09928594304193475`, 
      IntMultipole \[Rule] {\(-2.478997229715674`*^-10\) - 
            1.7406542873743548`*^-11\ \[ImaginaryI], \
\(\(0.72372644321679`\)\(\[InvisibleSpace]\)\) - 
            4.573485614786793`*^-11\ \[ImaginaryI], 
          3.4574454410574164`*^-12 + 
            9.795025901482291`*^-13\ \[ImaginaryI], \
\(-1.3370995283201736`*^-11\) - 
            4.151165522436884`*^-12\ \[ImaginaryI], \
\(-1.683712926026093`*^-11\) + 7.000233726017768`*^-14\ \[ImaginaryI], 
          1.0195660820472297`*^-8 + 2.4070894583116955`*^-12\ \[ImaginaryI], 
          1.3770484752484436`*^-12 + 1.0143182384432311`*^-12\ \[ImaginaryI], 
          4.3151506673444473`*^-13 + 
            4.5352688618494066`*^-13\ \[ImaginaryI], \
\(-2.8340160079798337`*^-13\) + 
            2.1046870843366427`*^-13\ \[ImaginaryI], \
\(-2.078679025782626`*^-14\) - 1.390898247272121`*^-13\ \[ImaginaryI]}, 
      CoilVolume \[Rule] 2.8386944403730184`*^6, 
      CoilPower \[Rule] 193.03122194536527`, Debug \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      parse\ the\ information\ from\ res\ *) \[IndentingNewLine]\
\[IndentingNewLine]\(g = PoleObject /. res;\)\), "\[IndentingNewLine]", 
    \(\(t = AllObject /. res;\)\), "\[IndentingNewLine]", 
    \(\(p = 
        PoleProfile /. res;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ListPlot[p, 
        PlotJoined \[Rule] True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]PlotRange \[Rule] {{0, 80}, {0, 
              80}}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(RadPlot3DOptions[];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics3D[
          radObjDrw[
            g]], \[IndentingNewLine]ViewPoint -> {2.0, \ \(-1.5\), \ \
\(-2\)}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics3D[
          radObjDrw[
            PoleCoilObject /. 
              res]], \[IndentingNewLine]ViewPoint -> {2.0, \ \(-1.5\), \ \(-2\
\)}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(multi = IntMultipole /. res;\)\), "\[IndentingNewLine]", 
    \(TableForm[multi]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0125 0 0.0125 [
[.125 -0.0125 -8 -14 ]
[.125 -0.0125 8 0 ]
[.25 -0.0125 -8 -14 ]
[.25 -0.0125 8 0 ]
[.375 -0.0125 -8 -14 ]
[.375 -0.0125 8 0 ]
[.5 -0.0125 -8 -14 ]
[.5 -0.0125 8 0 ]
[.625 -0.0125 -8 -14 ]
[.625 -0.0125 8 0 ]
[.75 -0.0125 -8 -14 ]
[.75 -0.0125 8 0 ]
[.875 -0.0125 -8 -14 ]
[.875 -0.0125 8 0 ]
[1 -0.0125 -8 -14 ]
[1 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -16 -7 ]
[-0.0125 .125 0 7 ]
[-0.0125 .25 -16 -7 ]
[-0.0125 .25 0 7 ]
[-0.0125 .375 -16 -7 ]
[-0.0125 .375 0 7 ]
[-0.0125 .5 -16 -7 ]
[-0.0125 .5 0 7 ]
[-0.0125 .625 -16 -7 ]
[-0.0125 .625 0 7 ]
[-0.0125 .75 -16 -7 ]
[-0.0125 .75 0 7 ]
[-0.0125 .875 -16 -7 ]
[-0.0125 .875 0 7 ]
[-0.0125 1 -16 -7 ]
[-0.0125 1 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 1.0005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 1 L
s
.25 0 m
.25 1 L
s
.375 0 m
.375 1 L
s
.5 0 m
.5 1 L
s
.625 0 m
.625 1 L
s
.75 0 m
.75 1 L
s
.875 0 m
.875 1 L
s
0 .125 m
1 .125 L
s
0 .25 m
1 .25 L
s
0 .375 m
1 .375 L
s
0 .5 m
1 .5 L
s
0 .625 m
1 .625 L
s
0 .75 m
1 .75 L
s
0 .875 m
1 .875 L
s
0 g
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
gsave
-0.0125 .125 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .375 m
.00625 .375 L
s
gsave
-0.0125 .375 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .625 m
.00625 .625 L
s
gsave
-0.0125 .625 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .75 m
.00625 .75 L
s
gsave
-0.0125 .75 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .875 m
.00625 .875 L
s
gsave
-0.0125 .875 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
0 1 m
.00625 1 L
s
gsave
-0.0125 1 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
.001 w
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.002 w
0 .425 m
.0851 .43344 L
.17358 .45908 L
.26895 .50295 L
.375 .56679 L
.375 .925 L
0 .925 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00;`3oool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3o
ool0503oool4000000030;Zj^P3oool0V9RH00<0000000<0V9RH0?ooo`3oool04`3oool0100@4100
0000010@401gMgL20?ooo`0509RHV000000000000000002HV9P06@3oool010000000oooo0?ooo`2H
V9P30000000309RHV03oool0oooo01<0oooo00L0410@000000000000000009RHV03oool0V9RH00<0
000000<0V9RH0?ooo`3oool0503oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`000000
0`2HV9P0oooo0?ooo`0D0?ooo`0309RHV014A4@0oooo0080oooo00D0V9RH000000000000000009RH
V00F0?ooo`0709RHV000000000000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo0080
oooo000`0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000F0?ooo`0;0<c<c03^k^h0
oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000603oool0201gMgL0IVIV0?ooo`000000
V9RH0?ooo`2HV9P000006@3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000603oool0
202HV9P000000?ooo`000000V9RH0?ooo`2HV9P000005P3oool02`000000V9RH0?ooo`2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P0000001H0oooo00<0k^k^0000003^k^h00P3oool01@000000V9RH
0?ooo`2HV9P0000001H0oooo00/0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
000000040?ooo`00<03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo
00<0c<c<0>k^kP3oool00P3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0D0?ooo`L000000`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0503oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0E0?ooo`0504A4A02YZJT0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0D0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo000`0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool05P3oool01@2YZJT0k^k^0?ooo`3oool0000000<0oooo00<000000?ooo`3oool05@3oool01@3M
gMd0QhN70000003oool0000000<0oooo00<000000?ooo`3oool0503oool01014A4@0V9RH0?ooo`00
00020?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo000000030?ooo`030000
003oool0oooo01@0oooo00L000000<c<c03oool0V9RH0000003oool0000000<0oooo00<000000?oo
o`3oool05@3oool01@2HV9P0EEEE0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0503oool0
1`2HV9P0MgMg0;Zj^P2YZJT0EEEE0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`00<03o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01H0oooo00D0gMgM06IVIP3oool0
oooo000000030?ooo`030000003oool0oooo01@0oooo00H0EEEE010@40000000V9RH0?ooo`000003
0?ooo`030000003oool0oooo01@0oooo00@0k^k^010@403MgMd000000P3oool01@000000oooo0?oo
o`3oool0000001P0oooo00@0V9RH0000003oool000000`3oool00`000000oooo0?ooo`0D0?ooo`07
010@401EEED000000000002HV9P0oooo000000030?ooo`030000003oool0oooo01D0oooo00D0k^k^
0000003oool0oooo000000030?ooo`030000003oool0oooo01@0oooo00@0gMgM024Q8@14A4@0<S8b
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo000`0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0503oool0101gMgL0oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`000000603oool0102j^[X0V9RH0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<0
ZJVY038b<P0000000P3oool01@000000oooo0?ooo`3oool0000001D0oooo100000000`2HV9P0oooo
000000030?ooo`030000003oool0oooo01@0oooo00<0MgMg04A4A03oool00`3oool01@000000oooo
0?ooo`3oool0000001P0oooo00@08B4Q0:VYZ@3oool000000`3oool00`000000oooo0?ooo`0D0?oo
o`07024Q8@2YZJT0oooo0=gMg@0b<S80oooo000000030?ooo`030000003oool0oooo0080oooo000`
0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000F0?ooo`040000002HV9P0V9RH0000
0080oooo00D0000009RHV03oool0V9RH0000000E0?ooo`0;04A4A02j^[X0oooo0;Zj^P000000oooo
0000002HV9P0oooo09RHV0000000603oool02@1VIVH000000?ooo`3oool0000009RHV03oool0V9RH
0000000E0?ooo`0307MgM`1EEED0oooo00<0oooo00D0000009RHV03oool0V9RH0000000G0?ooo`03
05EEE@1gMgL0oooo0080oooo00D0000009RHV03oool0V9RH0000000E0?ooo`0;024Q8@2j^[X0oooo
08N7Q`1EEED0oooo0000002HV9P0oooo09RHV00000005P3oool02`000000V9RH0?ooo`2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P0000000@0oooo000_0?ooo`05024Q8@000000oooo0?ooo`2HV9P0
0`0000000`2HV9P0oooo0?ooo`0D0?ooo`0409RHV0000000000009RHV080oooo00D0V9RH00000000
0000000009RHV00E0?ooo`070>k^kP14A4@000000000002HV9P0oooo09RHV0030000000309RHV03o
ool0oooo01H0oooo00D0k^k^010@403oool0oooo09RHV0030000000309RHV03oool0oooo01@0oooo
00H0410@000000000000<S8b0?ooo`2HV9P30000000309RHV03oool0oooo01H0oooo00D0V9RH04A4
A027QhL0oooo09RHV0030000000309RHV03oool0oooo01<0oooo00L0MgMg0000000000000000010@
403oool0V9RH00<0000000<0V9RH0?ooo`3oool0503oool01`2HV9P00000000000000000V9RH0?oo
o`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`004`3ooooo000000H00000203oool001<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0
oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0
oooo000C0?ooo`8000007P3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0M0?ooo`800000203oool001<0oooo00<0
00000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3o
ool2000000P0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<00000
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`8000007P3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0M0?ooo`800000203oool001<0oooo00<000000?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000
003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3o
ool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3o
ool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0
oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
0000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0
oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo
0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
00000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`00103oool3000000030?ooo`2HV9P000000080
000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<000000?ooo`3oool01P3oool000D0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH
000000H0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0
oooo00H0oooo00050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool2
00000?l0001o0@0007l3000000P0oooo00050?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<00000
0?ooo`3oool01P3oool000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00050?oo
o`080000003oool0oooo0000002HV9P0oooo09RHV00000060?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00103oool01@0Q8B4000000?oo
o`3oool0V9RH00<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo0P00000N0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01d0oooo0P0000080?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<0
00000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`03
0000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00
4`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0
1P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003o
ool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0
oooo0P0000080?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000
003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3o
ool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0
oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0
oooo00020?ooo`@0000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`040?ooo`030000
003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`000P3o
ool02`3<c<`0k^k^0?ooo`3<c<`0EEEE0?ooo`000000V9RH0?ooo`2HV9P0000000H0oooo00<00000
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00030?oo
o`030<c<c03^k^h0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`800000o`0007l1
0000O`<00000203oool000@0oooo00D0ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0
oooo00H0oooo00040?ooo`050=gMg@1VIVH0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`000P3oool0101gMgL0oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3o
ool00080oooo00@0000009RHV02HV9P000000P3oool01@000000V9RH0?ooo`2HV9P0000000H0oooo
00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo
00020?ooo`0409RHV0000000000009RHV080oooo00D0V9RH000000000000000009RHV0060?ooo`03
0000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00
4`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0
1P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P0000080?ooo`004`3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool0
01<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`8000007P3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0M
0?ooo`800000203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0
oooo0P00000N0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P0000080?ooo`004`3oool00`000000oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<0
00000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`8000007P3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0M0?ooo`800000
203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003o
ool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00020?ooo`04010@40000000410@07MgM`80
oooo00D0V9RH000000000000000009RHV0060?ooo`030000003oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`001@3oool0201gMgL0IVIV0?ooo`000000V9RH
0?ooo`2HV9P000001P3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
00000?ooo`3oool01P3oool000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`800000o`0007l10000O`<00000203oool000@0oooo00D0gMgM08N7Q`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000003oool0oooo00H0oooo00030?ooo`0605EEE@0@4100000009RHV03oool000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`060?ooo`001@3oool0102j^[X0V9RH0?ooo`0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003o
ool0oooo00H0oooo00020?ooo`0;04A4A02j^[X0oooo0;Zj^P000000oooo0000002HV9P0oooo09RH
V00000001P3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool00080oooo00L0k^k^04A4A0000000000009RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<00000
0?ooo`3oool01P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P0000080?oo
o`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3o
ool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool7000001T0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`030000003oool0oooo00@0oooo2`00
000>0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<00000
0?ooo`3oool03`3oool7000000L0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool00`000000oooo0?ooo`0F0?ooo`@000000`3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01X0oooo1000000P0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00@0001o000000000000
00007@3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00@0001o0?ooo`3oool0
oooo1000000I0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0M0?ooo`800000203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo
0?ooo`050?ooo`@000005@3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?oo
o`0M0?ooo`030000O`3oool0oooo00T0oooo0`00000B0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0303oool200000100oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<00000
0?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0>0?oo
o`8000003P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo0100oooo0P00000<0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000
003oool0oooo01d0oooo00<0001o0?ooo`3oool04P3oool2000000X0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0
1P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01@0oooo0P0000080?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0M0?ooo`800000203o
ool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0F0?ooo`<000001@3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01T0oooo0P0000030?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool06`3oool2000000030?ooo`0007l0oooo01h0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00050?ooo`040000
003oool0oooo09RHV0<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01d0oooo0P00000O0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`060?ooo`001@3oool020000000oooo0?ooo`000000V9RH0?oo
o`2HV9P000001P3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0000000000007@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<00000
0?ooo`3oool01P3oool00080oooo1`0000030?ooo`030000003oool0oooo00@0oooo0P0000120000
O`800000_00007l3000000P0oooo00020?ooo`0404A4A02HV9P0oooo00000080oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`020?ooo`8000006@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00@0k^k^010@403MgMd000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo00@0oooo0P00000G0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`000`3oool00`2YZJT0<S8b00000002
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00103oool0
2@1VIVH000000?ooo`3oool0000009RHV03oool0V9RH000000060?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`070?ooo`800000503oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool000@0oooo
00D0k^k^010@403oool0oooo09RHV0030000000309RHV03oool0oooo00@0oooo00<000000?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo00T0oooo0P00000B0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00
4`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0<0?ooo`8000003`3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01d0oooo0P0000080?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool03P3oool2000000d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0A0?ooo`8000002P3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01<0oooo0P0000080?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?oo
o`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0F
0?ooo`8000001@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P000008
0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool0603oool2000000<0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0J0?ooo`040000003oool0oooo0000Ob00oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool06`3oool2000000030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<0
00000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
00000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`03
0000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00
4`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0
1P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003o
ool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0
oooo0P0000080?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00L0410@00000000
0000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool000D0oooo00P0V9RH0000
003oool0000009RHV03oool0V9RH000000H0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool2000005l0001o00<000000000O`0007l0WP0007l3000000P0oooo0006
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool000D0oooo00@0V9RH0000
003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`000P3oool40000000309RHV03oool00000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool00080oooo00<0MgMg05EEE@3oool00`3oool01@000000
V9RH0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000003oool0oooo00H0oooo00030?ooo`06010@400000000000038b<P3oool0V9RH0`000000
0`2HV9P0oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool20000
00P0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`800000
7P3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0M0?ooo`800000203oool001<0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0
oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0
oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo
0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`8000007P3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0M0?ooo`800000203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00L0V9RH
000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00/0
000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH000000060?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`800000G`00
07l00`000000001o0000O`2N0000O`<00000203oool00080oooo00L000000<c<c03oool0V9RH0000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00L0410@05EEE@0000000000
09RHV03oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00080oooo00<0MgMg04A4A03oool0
0`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00030?ooo`0305EEE@1gMgL0oooo0080oooo
00D0000009RHV03oool0V9RH000000060?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`060?ooo`00103oool01@2HV9P0A4A408N7Q`3oool0V9RH00<0
000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`8000007P3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0M0?ooo`800000203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3o
ool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool2
000001h0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`030000003oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo
00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo
000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?oo
o`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<00000
0?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?oo
o`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`8000007P3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0M0?ooo`80
0000203oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07@3oool2000000P0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`03
0000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00
0`3oool00`2HV9P0A4A40?ooo`020?ooo`0509RHV000000000000000002HV9P01P3oool00`000000
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`000000
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool000<0oooo
00<0k^k^0000003^k^h00P3oool01@000000V9RH0?ooo`2HV9P0000000H0oooo00<000000?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00040?ooo`0504A4
A02YZJT0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`800000G`0007l00`000000
001o0000O`2N0000O`<00000203oool000@0oooo00D0V9RH05EEE@3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo00040?ooo`050>k^kP000000oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`001@3oool0100Q8B40ZJVY0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0
oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0
oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0
oooo00020?ooo`0;024Q8@2j^[X0oooo08N7Q`1EEED0oooo0000002HV9P0oooo09RHV00000001P3o
ool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3o
ool00080oooo00L0MgMg0000000000000000010@403oool0V9RH00<0000000<0V9RH0?ooo`3oool0
103oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0
1P3oool001<0oooo0P00000N0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P0000080?ooo`004`3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool0
01<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo
00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?oo
o`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?oo
o`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o
0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3ooomR00000200oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07@3oool2000000P0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3o
ool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0
oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0
oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`00
07l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0
oooo0P00000N0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01d0oooo0P0000080?ooo`004`3oool00`000000oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo
0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo
0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<0
00000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0
001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0
001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M
0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N
0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?oo
o`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?oo
o`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool0
7@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`060?ooo`004`3oool2000001h0oooo00<0001o0?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07@3o
ool2000000P0oooo000C0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool0
0`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`004`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0oooo0?ooo`0N0?ooo`030000O`3oool0oooo
01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0oooo0?ooo`0M0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000O`3oool0oooo01d0oooo00<0001o0?ooo`3oool07P3oool00`0007l0
oooo0?ooo`0M0?ooo`030000O`3oool0oooo01h0oooo00<0001o0?ooo`3oool07@3oool00`0007l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00020?ooo`0709RHV000000000000000002H
V9P0oooo09RHV0030000000309RHV03oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00020?ooo`0;0000002HV9P0oooo09RH
V0000000oooo0000002HV9P0oooo09RHV00000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0ooooo`000006000000P0oooo00020?ooo`0709RHV01gMgL0^[Zj0:VYZ@1E
EED0oooo000000030?ooo`030000003oool0oooo0?l0oooo4P3oool00080oooo00@0gMgM024Q8@14
A4@0<S8b0P3oool01@000000oooo0?ooo`3oool000000?l0oooo503oool00080oooo00L08B4Q0:VY
Z@3oool0gMgM038b<P3oool0000000<0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`000P3oool0
2`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P000000?l0oooo503oool00080
oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0o`3ooolB
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.92821, -5.77422, 0.307988, \
0.307988}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.74095 .07767 -4.65143 -14 ]
[.74095 .07767 5.34857 0 ]
[.7726 .09647 -7.36557 -14 ]
[.7726 .09647 8.63443 0 ]
[.80504 .11573 -7.28606 -14 ]
[.80504 .11573 8.71394 0 ]
[.8383 .13548 -7.20362 -14 ]
[.8383 .13548 8.79638 0 ]
[.87241 .15574 -7.11808 -14 ]
[.87241 .15574 8.88192 0 ]
[.8106 .05348 -7.1153 -14 ]
[.8106 .05348 8.5097 0 ]
[.10176 .324 -5.62034 -14 ]
[.10176 .324 4.37966 0 ]
[.33015 .23485 -8.41188 -14 ]
[.33015 .23485 7.58812 0 ]
[.53671 .15425 -10.8805 -14 ]
[.53671 .15425 11.1195 0 ]
[.72443 .08104 -10.285 -14 ]
[.72443 .08104 11.715 0 ]
[.43476 .13107 -7.96228 -14 ]
[.43476 .13107 7.66272 0 ]
[.08448 .43115 -16 -4.12491 ]
[.08448 .43115 0 9.87509 ]
[.09801 .53467 -16 -3.95696 ]
[.09801 .53467 0 10.043 ]
[.11067 .63153 -22 -3.79891 ]
[.11067 .63153 0 10.2011 ]
[.12254 .72235 -22 -3.64991 ]
[.12254 .72235 0 10.3501 ]
[.1337 .80767 -22 -3.50921 ]
[.1337 .80767 0 10.4908 ]
[.04972 .62688 -14.3125 -3.84846 ]
[.04972 .62688 0 10.1515 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.73697 .08829 m
.87448 .17021 L
s
.25 Mabswid
.74008 .09014 m
.73964 .09638 L
s
gsave
.74095 .07767 -65.6514 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.77161 .10893 m
.77112 .11516 L
s
gsave
.7726 .09647 -68.3656 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80393 .12818 m
.80338 .13441 L
s
gsave
.80504 .11573 -68.2861 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83706 .14792 m
.83644 .15414 L
s
gsave
.8383 .13548 -68.2036 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.87104 .16816 m
.87035 .17437 L
s
gsave
.87241 .15574 -68.1181 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
.74632 .09386 m
.74606 .0976 L
s
.7526 .0976 m
.75232 .10134 L
s
.75891 .10136 m
.75862 .1051 L
s
.76524 .10513 m
.76496 .10887 L
s
.77801 .11274 m
.77771 .11648 L
s
.78445 .11657 m
.78413 .12031 L
s
.79091 .12042 m
.79059 .12416 L
s
.7974 .12429 m
.79708 .12803 L
s
.81049 .13209 m
.81015 .13582 L
s
.81708 .13602 m
.81674 .13975 L
s
.82371 .13997 m
.82335 .1437 L
s
.83037 .14393 m
.83001 .14766 L
s
.84379 .15193 m
.84341 .15566 L
s
.85055 .15595 m
.85016 .15968 L
s
.85734 .16 m
.85695 .16373 L
s
.86417 .16407 m
.86377 .1678 L
s
gsave
.8106 .05348 -68.1153 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.08526 .34347 m
.73697 .08829 L
s
.25 Mabswid
.1033 .33641 m
.10407 .34261 L
s
gsave
.10176 .324 -66.6203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.33079 .24733 m
.33111 .25357 L
s
gsave
.33015 .23485 -69.4119 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.53658 .16675 m
.53651 .173 L
s
gsave
.53671 .15425 -71.8805 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.72362 .09351 m
.72322 .09975 L
s
gsave
.72443 .08104 -71.285 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.1507 .31785 m
.1511 .32158 L
s
.19712 .29967 m
.19746 .30341 L
s
.24258 .28187 m
.24288 .28561 L
s
.28713 .26443 m
.28738 .26817 L
s
.37358 .23058 m
.37372 .23432 L
s
.41553 .21415 m
.41563 .2179 L
s
.45666 .19804 m
.45671 .20179 L
s
.49701 .18225 m
.49701 .186 L
s
.5754 .15155 m
.57532 .1553 L
s
.6135 .13663 m
.61337 .14038 L
s
.65089 .12199 m
.65072 .12574 L
s
.68759 .10762 m
.68738 .11137 L
s
gsave
.43476 .13107 -68.9623 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.08526 .34347 m
.14612 .81164 L
s
.25 Mabswid
.09605 .4264 m
.10183 .42402 L
s
gsave
.08448 .43115 -77 -8.12491 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.10947 .52969 m
.1152 .5272 L
s
gsave
.09801 .53467 -77 -7.95696 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.12204 .62633 m
.12772 .62373 L
s
gsave
.11067 .63153 -83 -7.79891 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.13382 .71695 m
.13945 .71425 L
s
gsave
.12254 .72235 -83 -7.64991 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.14488 .80209 m
.15048 .79931 L
s
gsave
.1337 .80767 -83 -7.50921 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.0988 .44762 m
.10227 .44618 L
s
.10153 .46856 m
.10498 .4671 L
s
.10421 .48921 m
.10766 .48774 L
s
.10686 .50958 m
.1103 .5081 L
s
.11205 .54953 m
.11548 .54802 L
s
.1146 .56911 m
.11802 .56759 L
s
.11711 .58843 m
.12053 .5869 L
s
.11959 .6075 m
.123 .60596 L
s
.12445 .64492 m
.12786 .64335 L
s
.12684 .66327 m
.13024 .66169 L
s
.12919 .68139 m
.13259 .6798 L
s
.13152 .69928 m
.13491 .69768 L
s
.13608 .7344 m
.13946 .73277 L
s
.13832 .75164 m
.1417 .75 L
s
.14054 .76866 m
.1439 .76701 L
s
.14272 .78548 m
.14608 .78382 L
s
.09325 .40488 m
.09672 .40347 L
s
.09041 .38307 m
.09389 .38167 L
s
.08754 .36094 m
.09102 .35956 L
s
gsave
.04972 .62688 -75.3125 -7.84846 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.08526 .34347 m
.14612 .81164 L
s
.14612 .81164 m
.70653 .53091 L
s
.70653 .53091 m
.73697 .08829 L
s
.73697 .08829 m
.08526 .34347 L
s
.20608 .45601 m
.87448 .17021 L
s
.87448 .17021 m
.82415 .62234 L
s
.82415 .62234 m
.25151 .93174 L
s
.25151 .93174 m
.20608 .45601 L
s
.08526 .34347 m
.14612 .81164 L
s
.14612 .81164 m
.25151 .93174 L
s
.25151 .93174 m
.20608 .45601 L
s
.20608 .45601 m
.08526 .34347 L
s
.73697 .08829 m
.87448 .17021 L
s
.87448 .17021 m
.82415 .62234 L
s
.82415 .62234 m
.70653 .53091 L
s
.70653 .53091 m
.73697 .08829 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.63553 .63324 m .75299 .57244 L .69809 .52965 L p 0 .234 .55 r
F P
0 g
s
.69809 .52965 m .58158 .58785 L .63553 .63324 L p 0 .234 .55 r
F P
0 g
s
.58158 .58785 m .69809 .52965 L .66655 .51222 L closepath p 0 .461 .92 r
F P
0 g
s
.66655 .51222 m .69809 .52965 L .75299 .57244 L p 0 .057 .1 r
F P
0 g
s
.75299 .57244 m .72187 .55549 L .66655 .51222 L p 0 .057 .1 r
F P
0 g
s
.58158 .58785 m .66655 .51222 L .62674 .49023 L p 0 .461 .92 r
F P
0 g
s
.62674 .49023 m .66655 .51222 L .72187 .55549 L p 0 .057 .1 r
F P
0 g
s
.81033 .61712 m .75299 .57244 L .63553 .63324 L p 0 .234 .55 r
F P
0 g
s
.77969 .60073 m .72187 .55549 L .75299 .57244 L p 0 .057 .1 r
F P
0 g
s
.75299 .57244 m .81033 .61712 L .77969 .60073 L p 0 .057 .1 r
F P
0 g
s
.62674 .49023 m .58321 .5287 L .58158 .58785 L p 0 .461 .92 r
F P
0 g
s
.63553 .63324 m .69194 .68069 L .81033 .61712 L p 0 .234 .55 r
F P
0 g
s
.62674 .49023 m .58492 .46712 L .58321 .5287 L closepath p 0 .461 .92 r
F P
0 g
s
.58492 .46712 m .58158 .58785 L .69194 .68069 L p 0 .245 .866 r
F P
0 g
s
.63831 .57366 m .63553 .63324 L .58158 .58785 L p 0 .245 .866 r
F P
0 g
s
.58158 .58785 m .58321 .5287 L .63831 .57366 L p 0 .245 .866 r
F P
0 g
s
.69194 .68069 m .58158 .58785 L .28097 .73802 L p 0 .234 .55 r
F P
0 g
s
.2713 .61459 m .28097 .73802 L .58158 .58785 L p 0 .461 .92 r
F P
0 g
s
.28097 .73802 m .38509 .84547 L .69194 .68069 L p 0 .234 .55 r
F P
0 g
s
.33177 .79046 m .32805 .72975 L .27624 .67764 L p 0 .202 .848 r
F P
0 g
s
.27624 .67764 m .28097 .73802 L .33177 .79046 L p 0 .202 .848 r
F P
0 g
s
.28097 .73802 m .27624 .67764 L .22833 .67742 L p 0 .461 .92 r
F P
0 g
s
.27624 .67764 m .32805 .72975 L .32416 .66629 L p 0 .202 .848 r
F P
0 g
s
.32416 .66629 m .2713 .61459 L .27624 .67764 L p 0 .202 .848 r
F P
0 g
s
.38248 .78448 m .32805 .72975 L .33177 .79046 L p 0 .202 .848 r
F P
0 g
s
.33177 .79046 m .38509 .84547 L .38248 .78448 L p 0 .202 .848 r
F P
0 g
s
.38509 .84547 m .28097 .73802 L .2713 .61459 L p 0 .202 .848 r
F P
0 g
s
.27624 .67764 m .2713 .61459 L .22833 .67742 L closepath p 0 .461 .92 r
F P
0 g
s
.32805 .72975 m .38248 .78448 L .37975 .72066 L p 0 .202 .848 r
F P
0 g
s
.37975 .72066 m .32416 .66629 L .32805 .72975 L p 0 .202 .848 r
F P
0 g
s
.2713 .61459 m .37975 .72066 L .37975 .72066 L p 0 .202 .848 r
F P
0 g
s
.37975 .72066 m .38509 .84547 L p .2713 .61459 L 0 .202 .848 r
F P
0 g
s
.2713 .61459 m .37975 .72066 L .2713 .61459 L 0 .202 .848 r
F
.31697 .7525 m .26218 .69654 L .32416 .66629 L p 0 .222 .522 r
F P
0 g
s
.58158 .58785 m .58492 .46712 L .2713 .61459 L p 0 .461 .92 r
F P
0 g
s
.69194 .68069 m .70019 .55819 L .58492 .46712 L p 0 .245 .866 r
F P
0 g
s
.64121 .51159 m .63831 .57366 L .58321 .5287 L p 0 .245 .866 r
F P
0 g
s
.69194 .68069 m .63553 .63324 L .63831 .57366 L p 0 .245 .866 r
F P
0 g
s
.63831 .57366 m .69598 .62073 L .69194 .68069 L p 0 .245 .866 r
F P
0 g
s
.69598 .62073 m .63831 .57366 L .64121 .51159 L p 0 .245 .866 r
F P
0 g
s
.64121 .51159 m .70019 .55819 L .69598 .62073 L p 0 .245 .866 r
F P
0 g
s
.37975 .72066 m .70019 .55819 L .69194 .68069 L p 0 .473 .927 r
F P
0 g
s
.70019 .55819 m .37975 .72066 L .2713 .61459 L p 0 .222 .522 r
F P
0 g
s
.58321 .5287 m .58492 .46712 L .64121 .51159 L p 0 .245 .866 r
F P
0 g
s
.2713 .61459 m .58492 .46712 L .70019 .55819 L p 0 .222 .522 r
F P
0 g
s
.2675 .56607 m .2713 .61459 L .32416 .66629 L p 0 .202 .848 r
F P
0 g
s
.32416 .66629 m .37975 .72066 L .31697 .7525 L p 0 .222 .522 r
F P
0 g
s
.32116 .61741 m .32416 .66629 L .37975 .72066 L p 0 .202 .848 r
F P
0 g
s
.37975 .72066 m .32416 .66629 L .26218 .69654 L p 0 .222 .522 r
F P
0 g
s
.37975 .72066 m .37765 .67145 L .32116 .61741 L p 0 .202 .848 r
F P
0 g
s
.31372 .70311 m .37765 .67145 L p .37975 .72066 L 0 .473 .927 r
F P
0 g
s
.37765 .67145 m .37765 .67145 L .37955 .71606 L p 0 .473 .927 r
F P
0 g
s
.37955 .71606 m .37975 .72066 L p .37765 .67145 L 0 .473 .927 r
F P
0 g
s
.2713 .61459 m .30154 .64417 L .26218 .69654 L p 0 .222 .522 r
F P
0 g
s
.74097 .58001 m .68256 .5341 L .72187 .55549 L p 0 .057 .1 r
F P
0 g
s
.72187 .55549 m .77969 .60073 L .74097 .58001 L p 0 .057 .1 r
F P
0 g
s
.72187 .55549 m .68256 .5341 L .62674 .49023 L p 0 .057 .1 r
F P
0 g
s
.77969 .60073 m .81033 .61712 L .69194 .68069 L closepath p 0 .473 .927 r
F P
0 g
s
.58492 .46712 m .62674 .49023 L .68256 .5341 L p 0 .057 .1 r
F P
0 g
s
0 0 0 r
.33177 .79046 m
.33177 .79046 L
s
.33177 .79046 m
.33177 .79046 L
s
.4855 .51387 m
.4855 .51387 L
s
.4855 .51387 m
.4855 .51387 L
s
.74097 .58001 m .77969 .60073 L .69194 .68069 L p 0 .473 .927 r
F P
0 g
s
.70019 .55819 m .64121 .51159 L .68256 .5341 L p 0 .057 .1 r
F P
0 g
s
.68256 .5341 m .74097 .58001 L .70019 .55819 L p 0 .057 .1 r
F P
0 g
s
.68256 .5341 m .64121 .51159 L .58492 .46712 L p 0 .057 .1 r
F P
0 g
s
0 0 0 r
.64121 .51159 m
.64121 .51159 L
s
.64121 .51159 m
.64121 .51159 L
s
.69194 .68069 m .69598 .62073 L .74097 .58001 L p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.69598 .62073 m
.69598 .62073 L
s
.69194 .68069 m .38509 .84547 L .37975 .72066 L p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.59469 .73292 m
.59469 .73292 L
s
.59469 .73292 m
.59469 .73292 L
s
.38109 .56297 m
.38109 .56297 L
s
.38109 .56297 m
.38109 .56297 L
s
.49253 .78778 m
.49253 .78778 L
s
.49253 .78778 m
.49253 .78778 L
s
.70019 .55819 m .74097 .58001 L .69598 .62073 L closepath p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.32416 .66629 m
.32416 .66629 L
s
.64121 .51159 m
.64121 .51159 L
s
.35602 .65075 m
.64121 .51159 L
s
.64121 .51159 m
.64121 .51159 L
s
.64121 .51159 m
.64121 .51159 L
s
.59886 .60956 m
.59886 .60956 L
s
.4855 .51387 m
.59886 .60956 L
s
.4855 .51387 m
.4855 .51387 L
s
.69598 .62073 m
.69598 .62073 L
s
.59886 .60956 m
.59886 .60956 L
s
.59469 .73292 m
.59886 .60956 L
s
.59469 .73292 m
.59469 .73292 L
s
.33177 .79046 m .28097 .73802 L .16253 .79719 L p 0 .234 .55 r
F P
0 g
s
0 0 0 r
.33177 .79046 m
.33177 .79046 L
s
.28097 .73802 m .18567 .7398 L .16007 .77724 L p 0 .461 .92 r
F P
0 g
s
.16007 .77724 m .16253 .79719 L .28097 .73802 L p 0 .461 .92 r
F P
0 g
s
.22833 .67742 m .18567 .7398 L .28097 .73802 L p 0 .461 .92 r
F P
0 g
s
0 0 0 r
.49219 .66365 m
.49219 .66365 L
s
.38109 .56297 m
.49219 .66365 L
s
.38109 .56297 m
.38109 .56297 L
s
.27632 .67773 m
.2843 .68575 L
s
.31958 .72123 m
.31958 .72123 L
s
.49219 .66365 m
.49219 .66365 L
s
.49219 .66365 m
.49253 .78778 L
s
.49253 .78778 m
.49253 .78778 L
s
.38509 .84547 m .33177 .79046 L .21182 .85254 L p 0 .234 .55 r
F P
0 g
s
.16253 .79719 m .21182 .85254 L .33177 .79046 L p 0 .234 .55 r
F P
0 g
s
0 0 0 r
.32907 .74636 m
.33177 .79046 L
s
.33177 .79046 m
.33177 .79046 L
s
.21182 .85254 m .16253 .79719 L .16007 .77724 L p 0 .178 .831 r
F P
0 g
s
.14721 .67294 m .16007 .77724 L .18567 .7398 L closepath p 0 .461 .92 r
F P
0 g
s
.20967 .83251 m .16007 .77724 L .14721 .67294 L p 0 .178 .831 r
F P
0 g
s
.16007 .77724 m .20967 .83251 L .21182 .85254 L p 0 .178 .831 r
F P
0 g
s
.14721 .67294 m .18567 .7398 L .22833 .67742 L p 0 .461 .92 r
F P
0 g
s
.22833 .67742 m .21012 .64336 L .14721 .67294 L p 0 .461 .92 r
F P
0 g
s
.22833 .67742 m .2713 .61459 L .21012 .64336 L closepath p 0 .461 .92 r
F P
0 g
s
.26218 .69654 m .21012 .64336 L .2713 .61459 L p 0 .222 .522 r
F P
0 g
s
.32416 .66629 m .2713 .61459 L .21012 .64336 L p 0 .222 .522 r
F P
0 g
s
.2713 .61459 m .2675 .56607 L .20524 .59463 L p 0 .461 .92 r
F P
0 g
s
.20524 .59463 m .21012 .64336 L .2713 .61459 L p 0 .461 .92 r
F P
0 g
s
.21182 .85254 m .26362 .9107 L .38509 .84547 L p 0 .234 .55 r
F P
0 g
s
.2618 .8906 m .28894 .8515 L .38509 .84547 L p 0 .473 .927 r
F P
0 g
s
.38509 .84547 m .26362 .9107 L .2618 .8906 L p 0 .473 .927 r
F P
0 g
s
.38248 .78448 m .38509 .84547 L .28894 .8515 L p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.33937 .74114 m
.38248 .78448 L
s
.38248 .78448 m
.69598 .62073 L
s
.38248 .78448 m
.38248 .78448 L
s
.38248 .78448 m
.38248 .78448 L
s
.21182 .85254 m .20967 .83251 L .2618 .8906 L p 0 .178 .831 r
F P
0 g
s
.2618 .8906 m .26362 .9107 L .21182 .85254 L p 0 .178 .831 r
F P
0 g
s
.21012 .64336 m .26218 .69654 L .1984 .72766 L p 0 .222 .522 r
F P
0 g
s
.1984 .72766 m .14721 .67294 L .21012 .64336 L p 0 .222 .522 r
F P
0 g
s
.21012 .64336 m .26218 .69654 L .32416 .66629 L p 0 .222 .522 r
F P
0 g
s
0 0 0 r
.32416 .66629 m
.32416 .66629 L
s
.32416 .66629 m
.32416 .66629 L
s
.26218 .69654 m .21012 .64336 L .14721 .67294 L p 0 .222 .522 r
F P
0 g
s
.21012 .64336 m .20524 .59463 L .14118 .62401 L p 0 .461 .92 r
F P
0 g
s
.14118 .62401 m .14721 .67294 L .21012 .64336 L p 0 .461 .92 r
F P
0 g
s
.2618 .8906 m .20967 .83251 L .1984 .72766 L p 0 .178 .831 r
F P
0 g
s
.14721 .67294 m .1984 .72766 L .20967 .83251 L p 0 .178 .831 r
F P
0 g
s
.32416 .66629 m .32116 .61741 L .2675 .56607 L p 0 .202 .848 r
F P
0 g
s
.26357 .5159 m .2675 .56607 L .32116 .61741 L p 0 .202 .848 r
F P
0 g
s
.2675 .56607 m .26357 .5159 L .20018 .54422 L p 0 .461 .92 r
F P
0 g
s
.20018 .54422 m .20524 .59463 L .2675 .56607 L p 0 .461 .92 r
F P
0 g
s
.28894 .8515 m .33418 .78633 L .38248 .78448 L p 0 .473 .927 r
F P
0 g
s
.37975 .72066 m .38248 .78448 L .33418 .78633 L closepath p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.38248 .78448 m
.38248 .78448 L
s
.14721 .67294 m .1984 .72766 L .26218 .69654 L p 0 .222 .522 r
F P
0 g
s
.1984 .72766 m .14721 .67294 L .14118 .62401 L p 0 .178 .831 r
F P
0 g
s
.20524 .59463 m .20018 .54422 L .13493 .57338 L p 0 .461 .92 r
F P
0 g
s
.13493 .57338 m .14118 .62401 L .20524 .59463 L p 0 .461 .92 r
F P
0 g
s
.32116 .61741 m .31806 .56683 L .26357 .5159 L p 0 .202 .848 r
F P
0 g
s
.2595 .46401 m .26357 .5159 L .31806 .56683 L p 0 .202 .848 r
F P
0 g
s
.26357 .5159 m .2595 .46401 L .19495 .49206 L p 0 .461 .92 r
F P
0 g
s
.19495 .49206 m .20018 .54422 L .26357 .5159 L p 0 .461 .92 r
F P
0 g
s
.31485 .51446 m .2595 .46401 L p .2595 .46401 L 0 .202 .848 r
F P
0 g
s
.31806 .56683 m .31485 .51446 L p .2595 .46401 L 0 .202 .848 r
F P
0 g
s
.31485 .51446 m .31485 .51446 L p .2595 .46401 L 0 .202 .848 r
F P
0 g
s
.31806 .56683 m .32116 .61741 L .37765 .67145 L p 0 .202 .848 r
F P
0 g
s
.37765 .67145 m .37547 .62047 L .31806 .56683 L p 0 .202 .848 r
F P
0 g
s
.31485 .51446 m .31806 .56683 L .37547 .62047 L p 0 .202 .848 r
F P
0 g
s
.37547 .62047 m .37321 .56765 L .31485 .51446 L p 0 .202 .848 r
F P
0 g
s
.30686 .59887 m .37321 .56765 L .31485 .51446 L p 0 .206 .483 r
F P
0 g
s
.31152 .46021 m .31485 .51446 L .37321 .56765 L p 0 .202 .848 r
F P
0 g
s
.31485 .51446 m .2494 .54403 L .30686 .59887 L p 0 .206 .483 r
F P
0 g
s
.30686 .59887 m .2494 .54403 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.2494 .54403 m .31485 .51446 L .37321 .56765 L p 0 .206 .483 r
F P
0 g
s
.37321 .56765 m .30686 .59887 L .2494 .54403 L p 0 .206 .483 r
F P
0 g
s
.37321 .56765 m .37087 .51288 L .31152 .46021 L p 0 .202 .848 r
F P
0 g
s
.30686 .59887 m .30324 .54382 L .37087 .51288 L p 0 .473 .927 r
F P
0 g
s
.2494 .54403 m .30686 .59887 L p .30686 .59887 L 0 .19 .841 r
F P
0 g
s
.2494 .54403 m .31485 .51446 L .2595 .46401 L p 0 .206 .483 r
F P
0 g
s
.2595 .46401 m .19495 .49206 L .2494 .54403 L p 0 .206 .483 r
F P
0 g
s
.19495 .49206 m .2595 .46401 L .31485 .51446 L p 0 .206 .483 r
F P
0 g
s
.2494 .54403 m .19495 .49206 L p .19495 .49206 L 0 .19 .841 r
F P
0 g
s
.31485 .51446 m .2494 .54403 L .19495 .49206 L p 0 .206 .483 r
F P
0 g
s
.19495 .49206 m .2494 .54403 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.18953 .43804 m .19495 .49206 L .2595 .46401 L p 0 .461 .92 r
F P
0 g
s
.18953 .43804 m .19495 .49206 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.19495 .49206 m .19495 .49206 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.24483 .48948 m .2494 .54403 L p .19495 .49206 L 0 .19 .841 r
F P
0 g
s
.2494 .54403 m .2494 .54403 L p .19495 .49206 L 0 .19 .841 r
F P
0 g
s
.24483 .48948 m .2494 .54403 L .31485 .51446 L p 0 .467 .923 r
F P
0 g
s
.25529 .4103 m .2595 .46401 L .31485 .51446 L p 0 .202 .848 r
F P
0 g
s
.31485 .51446 m .31152 .46021 L .25529 .4103 L p 0 .202 .848 r
F P
0 g
s
.31152 .46021 m .31485 .51446 L .2494 .54403 L p 0 .467 .923 r
F P
0 g
s
.2494 .54403 m .24483 .48948 L .31152 .46021 L p 0 .467 .923 r
F P
0 g
s
.24483 .48948 m .2494 .54403 L p .30686 .59887 L 0 .19 .841 r
F P
0 g
s
.2494 .54403 m .2494 .54403 L p .30686 .59887 L 0 .19 .841 r
F P
0 g
s
.30324 .54382 m .30686 .59887 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.30686 .59887 m .30686 .59887 L p .2494 .54403 L 0 .19 .841 r
F P
0 g
s
.37321 .56765 m .30686 .59887 L p .30686 .59887 L 0 .473 .927 r
F P
0 g
s
.37087 .51288 m .37321 .56765 L p .30686 .59887 L 0 .473 .927 r
F P
0 g
s
.37321 .56765 m .37321 .56765 L p .30686 .59887 L 0 .473 .927 r
F P
0 g
s
.1984 .72766 m .26218 .69654 L .31697 .7525 L p 0 .222 .522 r
F P
0 g
s
.26218 .69654 m .31697 .7525 L .37975 .72066 L p 0 .222 .522 r
F P
0 g
s
.31697 .7525 m .26218 .69654 L .1984 .72766 L p 0 .222 .522 r
F P
0 g
s
.25231 .78528 m .28894 .8515 L .2618 .8906 L closepath p 0 .473 .927 r
F P
0 g
s
.1984 .72766 m .25231 .78528 L .2618 .8906 L p 0 .178 .831 r
F P
0 g
s
.33418 .78633 m .28894 .8515 L .25231 .78528 L p 0 .473 .927 r
F P
0 g
s
.14118 .62401 m .19311 .6784 L .1984 .72766 L p 0 .178 .831 r
F P
0 g
s
.19311 .6784 m .14118 .62401 L .13493 .57338 L p 0 .178 .831 r
F P
0 g
s
.25231 .78528 m .31697 .7525 L .33418 .78633 L p 0 .473 .927 r
F P
0 g
s
.31697 .7525 m .37975 .72066 L .33418 .78633 L closepath p 0 .473 .927 r
F P
0 g
s
.20018 .54422 m .19495 .49206 L .12847 .52095 L p 0 .461 .92 r
F P
0 g
s
.12847 .52095 m .13493 .57338 L .20018 .54422 L p 0 .461 .92 r
F P
0 g
s
.2595 .46401 m .25529 .4103 L .18953 .43804 L p 0 .461 .92 r
F P
0 g
s
.37975 .72066 m .31697 .7525 L .31372 .70311 L p 0 .473 .927 r
F P
0 g
s
.31697 .7525 m .25231 .78528 L .1984 .72766 L p 0 .222 .522 r
F P
0 g
s
.1984 .72766 m .25231 .78528 L .31697 .7525 L p 0 .222 .522 r
F P
0 g
s
.25231 .78528 m .1984 .72766 L .19311 .6784 L p 0 .178 .831 r
F P
0 g
s
.13493 .57338 m .18763 .62738 L .19311 .6784 L p 0 .178 .831 r
F P
0 g
s
.18763 .62738 m .13493 .57338 L .12847 .52095 L p 0 .178 .831 r
F P
0 g
s
.19495 .49206 m .18953 .43804 L .24483 .48948 L p 0 .19 .841 r
F P
0 g
s
.18194 .57451 m .2494 .54403 L .19495 .49206 L p 0 .206 .483 r
F P
0 g
s
.19495 .49206 m .12847 .52095 L .18194 .57451 L p 0 .206 .483 r
F P
0 g
s
.12177 .46664 m .12847 .52095 L .19495 .49206 L p 0 .461 .92 r
F P
0 g
s
.19495 .49206 m .18953 .43804 L .12177 .46664 L p 0 .461 .92 r
F P
0 g
s
.12847 .52095 m .19495 .49206 L .2494 .54403 L p 0 .206 .483 r
F P
0 g
s
.31697 .7525 m .25231 .78528 L .24785 .73573 L p 0 .473 .927 r
F P
0 g
s
.24785 .73573 m .31372 .70311 L .31697 .7525 L p 0 .473 .927 r
F P
0 g
s
.18953 .43804 m .25529 .4103 L .31152 .46021 L p 0 .2 .467 r
F P
0 g
s
.24483 .48948 m .31152 .46021 L .25529 .4103 L p 0 .2 .467 r
F P
0 g
s
.25529 .4103 m .18953 .43804 L .24483 .48948 L p 0 .2 .467 r
F P
0 g
s
.25094 .35467 m .25529 .4103 L .31152 .46021 L p 0 .202 .848 r
F P
0 g
s
.18392 .38208 m .18953 .43804 L .25529 .4103 L p 0 .461 .92 r
F P
0 g
s
.25529 .4103 m .25094 .35467 L .18392 .38208 L p 0 .461 .92 r
F P
0 g
s
.37765 .67145 m .31372 .70311 L .31035 .65193 L p 0 .473 .927 r
F P
0 g
s
.31035 .65193 m .37547 .62047 L .37765 .67145 L p 0 .473 .927 r
F P
0 g
s
.19311 .6784 m .24785 .73573 L .25231 .78528 L p 0 .178 .831 r
F P
0 g
s
.24785 .73573 m .19311 .6784 L .18763 .62738 L p 0 .178 .831 r
F P
0 g
s
.31485 .51446 m .31152 .46021 L .24483 .48948 L p 0 .467 .923 r
F P
0 g
s
.2494 .54403 m .18194 .57451 L .12847 .52095 L p 0 .206 .483 r
F P
0 g
s
.17605 .51967 m .18194 .57451 L .12847 .52095 L p 0 .178 .831 r
F P
0 g
s
.12847 .52095 m .12177 .46664 L .17605 .51967 L p 0 .178 .831 r
F P
0 g
s
.12847 .52095 m .18194 .57451 L .18763 .62738 L p 0 .178 .831 r
F P
0 g
s
.31152 .46021 m .24483 .48948 L .18953 .43804 L p 0 .2 .467 r
F P
0 g
s
.24009 .43291 m .24483 .48948 L .18953 .43804 L p 0 .19 .841 r
F P
0 g
s
.18953 .43804 m .18392 .38208 L .24009 .43291 L p 0 .19 .841 r
F P
0 g
s
.2494 .54403 m .24483 .48948 L .18953 .43804 L p 0 .19 .841 r
F P
0 g
s
.17605 .51967 m .24483 .48948 L .18953 .43804 L p 0 .2 .467 r
F P
0 g
s
.18953 .43804 m .12177 .46664 L .17605 .51967 L p 0 .2 .467 r
F P
0 g
s
.18392 .38208 m .18953 .43804 L .24483 .48948 L p 0 .19 .841 r
F P
0 g
s
.11483 .41033 m .12177 .46664 L .18953 .43804 L p 0 .461 .92 r
F P
0 g
s
.18953 .43804 m .18392 .38208 L .11483 .41033 L p 0 .461 .92 r
F P
0 g
s
.12177 .46664 m .18953 .43804 L .24483 .48948 L p 0 .2 .467 r
F P
0 g
s
.31372 .70311 m .24785 .73573 L .24322 .68436 L p 0 .473 .927 r
F P
0 g
s
.24322 .68436 m .31035 .65193 L .31372 .70311 L p 0 .473 .927 r
F P
0 g
s
.31152 .46021 m .30807 .40397 L .25094 .35467 L p 0 .202 .848 r
F P
0 g
s
.18392 .38208 m .25094 .35467 L .30807 .40397 L p 0 .193 .451 r
F P
0 g
s
.24009 .43291 m .30807 .40397 L .25094 .35467 L p 0 .193 .451 r
F P
0 g
s
.25094 .35467 m .18392 .38208 L .24009 .43291 L p 0 .193 .451 r
F P
0 g
s
.17953 .33834 m .18392 .38208 L .25094 .35467 L p 0 .461 .92 r
F P
0 g
s
.21051 .33953 m .17953 .33834 L p .25094 .35467 L 0 .461 .92 r
F P
0 g
s
.25094 .35467 m .25027 .3462 L .21051 .33953 L p 0 .461 .92 r
F P
0 g
s
.25027 .3462 m .25094 .35467 L .30807 .40397 L p 0 .202 .848 r
F P
0 g
s
.37547 .62047 m .31035 .65193 L .30686 .59887 L p 0 .473 .927 r
F P
0 g
s
.30686 .59887 m .37321 .56765 L .37547 .62047 L p 0 .473 .927 r
F P
0 g
s
.30807 .40397 m .30755 .3954 L .25027 .3462 L p 0 .202 .848 r
F P
0 g
s
.21051 .33953 m .25027 .3462 L .30755 .3954 L p 0 .137 .1 r
F P
0 g
s
.18763 .62738 m .24322 .68436 L .24785 .73573 L p 0 .178 .831 r
F P
0 g
s
.24322 .68436 m .18763 .62738 L .18194 .57451 L p 0 .178 .831 r
F P
0 g
s
.2494 .54403 m .24483 .48948 L .30324 .54382 L p 0 .19 .841 r
F P
0 g
s
.23842 .63107 m .30686 .59887 L .2494 .54403 L p 0 .206 .483 r
F P
0 g
s
.2494 .54403 m .18194 .57451 L .23842 .63107 L p 0 .206 .483 r
F P
0 g
s
.17605 .51967 m .18194 .57451 L .2494 .54403 L p 0 .467 .923 r
F P
0 g
s
.2494 .54403 m .24483 .48948 L .17605 .51967 L p 0 .467 .923 r
F P
0 g
s
.24483 .48948 m .2494 .54403 L .18194 .57451 L p 0 .467 .923 r
F P
0 g
s
.30686 .59887 m .23842 .63107 L p .23842 .63107 L 0 .473 .927 r
F P
0 g
s
.18194 .57451 m .2494 .54403 L .30686 .59887 L p 0 .206 .483 r
F P
0 g
s
.30686 .59887 m .23842 .63107 L .18194 .57451 L p 0 .206 .483 r
F P
0 g
s
.30686 .59887 m .30324 .54382 L .24483 .48948 L p 0 .19 .841 r
F P
0 g
s
.23842 .63107 m .23343 .57575 L .30324 .54382 L p 0 .473 .927 r
F P
0 g
s
.30324 .54382 m .30686 .59887 L p .23842 .63107 L 0 .473 .927 r
F P
0 g
s
.30686 .59887 m .30686 .59887 L p .23842 .63107 L 0 .473 .927 r
F P
0 g
s
.24483 .48948 m .31152 .46021 L .37087 .51288 L p 0 .2 .467 r
F P
0 g
s
.30324 .54382 m .37087 .51288 L .31152 .46021 L p 0 .2 .467 r
F P
0 g
s
.31152 .46021 m .24483 .48948 L .30324 .54382 L p 0 .2 .467 r
F P
0 g
s
.30807 .40397 m .31152 .46021 L .37087 .51288 L p 0 .202 .848 r
F P
0 g
s
.24009 .43291 m .24483 .48948 L .31152 .46021 L p 0 .467 .923 r
F P
0 g
s
.31152 .46021 m .30807 .40397 L .24009 .43291 L p 0 .467 .923 r
F P
0 g
s
.30807 .40397 m .31152 .46021 L .24483 .48948 L p 0 .467 .923 r
F P
0 g
s
.24483 .48948 m .17605 .51967 L .12177 .46664 L p 0 .2 .467 r
F P
0 g
s
.16993 .46277 m .17605 .51967 L .12177 .46664 L p 0 .178 .831 r
F P
0 g
s
.12177 .46664 m .11483 .41033 L .16993 .46277 L p 0 .178 .831 r
F P
0 g
s
.30807 .40397 m .24009 .43291 L .18392 .38208 L p 0 .193 .451 r
F P
0 g
s
.23638 .38866 m .24009 .43291 L .18392 .38208 L p 0 .19 .841 r
F P
0 g
s
.18392 .38208 m .17953 .33834 L .23638 .38866 L p 0 .19 .841 r
F P
0 g
s
.24483 .48948 m .24009 .43291 L .18392 .38208 L p 0 .19 .841 r
F P
0 g
s
.11483 .41033 m .18392 .38208 L .24009 .43291 L p 0 .193 .451 r
F P
0 g
s
.16993 .46277 m .24009 .43291 L .18392 .38208 L p 0 .193 .451 r
F P
0 g
s
.18392 .38208 m .11483 .41033 L .16993 .46277 L p 0 .193 .451 r
F P
0 g
s
.17953 .33834 m .18392 .38208 L .24009 .43291 L p 0 .19 .841 r
F P
0 g
s
.10763 .35191 m .11483 .41033 L .18392 .38208 L p 0 .461 .92 r
F P
0 g
s
.14022 .34216 m .10763 .35191 L p .18392 .38208 L 0 .461 .92 r
F P
0 g
s
.17417 .33813 m .14022 .34216 L p .18392 .38208 L 0 .461 .92 r
F P
0 g
s
.18392 .38208 m .17953 .33834 L .17417 .33813 L p 0 .461 .92 r
F P
0 g
s
.31035 .65193 m .24322 .68436 L .23842 .63107 L p 0 .473 .927 r
F P
0 g
s
.23842 .63107 m .30686 .59887 L .31035 .65193 L p 0 .473 .927 r
F P
0 g
s
.30755 .3954 m .2676 .38934 L .21051 .33953 L p 0 .137 .1 r
F P
0 g
s
.17953 .33834 m .21051 .33953 L .2676 .38934 L p 0 .154 .185 r
F P
0 g
s
.23343 .57575 m .23842 .63107 L .18194 .57451 L p 0 .178 .831 r
F P
0 g
s
.18194 .57451 m .17605 .51967 L .24483 .48948 L p 0 .467 .923 r
F P
0 g
s
.18194 .57451 m .17605 .51967 L .23343 .57575 L p 0 .178 .831 r
F P
0 g
s
.18194 .57451 m .23842 .63107 L .24322 .68436 L p 0 .178 .831 r
F P
0 g
s
.37087 .51288 m .30324 .54382 L .24483 .48948 L p 0 .2 .467 r
F P
0 g
s
.30024 .49827 m .30324 .54382 L .24483 .48948 L p 0 .19 .841 r
F P
0 g
s
.29136 .47932 m .30024 .49827 L p .24483 .48948 L 0 .19 .841 r
F P
0 g
s
.24483 .48948 m .24009 .43291 L .30807 .40397 L p 0 .467 .923 r
F P
0 g
s
.24483 .48948 m .24009 .43291 L .29136 .47932 L p 0 .19 .841 r
F P
0 g
s
.17605 .51967 m .24483 .48948 L .30324 .54382 L p 0 .2 .467 r
F P
0 g
s
.23343 .57575 m .30324 .54382 L .24483 .48948 L p 0 .2 .467 r
F P
0 g
s
.24483 .48948 m .17605 .51967 L .23343 .57575 L p 0 .2 .467 r
F P
0 g
s
.24009 .43291 m .24483 .48948 L .30324 .54382 L p 0 .19 .841 r
F P
0 g
s
.16993 .46277 m .17605 .51967 L .24483 .48948 L p 0 .467 .923 r
F P
0 g
s
.24483 .48948 m .24009 .43291 L .16993 .46277 L p 0 .467 .923 r
F P
0 g
s
.24009 .43291 m .24483 .48948 L .17605 .51967 L p 0 .467 .923 r
F P
0 g
s
.36893 .46759 m .36019 .44894 L .30807 .40397 L p 0 .202 .848 r
F P
0 g
s
.37087 .51288 m .36893 .46759 L p .30807 .40397 L 0 .202 .848 r
F P
0 g
s
.24009 .43291 m .30807 .40397 L .36019 .44894 L p 0 .193 .451 r
F P
0 g
s
.29136 .47932 m .36019 .44894 L .30807 .40397 L p 0 .193 .451 r
F P
0 g
s
.30807 .40397 m .24009 .43291 L .29136 .47932 L p 0 .193 .451 r
F P
0 g
s
.23638 .38866 m .24009 .43291 L .30807 .40397 L p 0 .467 .923 r
F P
0 g
s
.2676 .38934 m .23638 .38866 L p .30807 .40397 L 0 .467 .923 r
F P
0 g
s
.30807 .40397 m .30755 .3954 L .2676 .38934 L p 0 .467 .923 r
F P
0 g
s
.30755 .3954 m .30807 .40397 L .24009 .43291 L p 0 .467 .923 r
F P
0 g
s
.30755 .3954 m .30807 .40397 L .36019 .44894 L p 0 .202 .848 r
F P
0 g
s
.2676 .38934 m .23638 .38866 L .17953 .33834 L p 0 .154 .185 r
F P
0 g
s
.24009 .43291 m .23638 .38866 L .17953 .33834 L p 0 .19 .841 r
F P
0 g
s
.17417 .33813 m .17953 .33834 L .23638 .38866 L p 0 .154 .185 r
F P
0 g
s
.2676 .38934 m .30755 .3954 L p .24009 .43291 L 0 .467 .923 r
F P
0 g
s
.36019 .44894 m .35367 .43502 L .30755 .3954 L p 0 .202 .848 r
F P
0 g
s
.2676 .38934 m .30755 .3954 L .35367 .43502 L p 0 .137 .1 r
F P
0 g
s
.24009 .43291 m .16993 .46277 L .11483 .41033 L p 0 .193 .451 r
F P
0 g
s
.16358 .40368 m .16993 .46277 L .11483 .41033 L p 0 .178 .831 r
F P
0 g
s
.11483 .41033 m .10763 .35191 L .16358 .40368 L p 0 .178 .831 r
F P
0 g
s
.23638 .38866 m .23097 .38855 L .17417 .33813 L p 0 .154 .185 r
F P
0 g
s
.14022 .34216 m .17417 .33813 L .23097 .38855 L p 0 .17 .292 r
F P
0 g
s
.36893 .46759 m .37087 .51288 L .30324 .54382 L p 0 .473 .927 r
F P
0 g
s
.30324 .54382 m .23343 .57575 L .17605 .51967 L p 0 .2 .467 r
F P
0 g
s
.2293 .52995 m .23343 .57575 L .17605 .51967 L p 0 .178 .831 r
F P
0 g
s
.22028 .51069 m .2293 .52995 L p .17605 .51967 L 0 .178 .831 r
F P
0 g
s
.17605 .51967 m .16993 .46277 L .24009 .43291 L p 0 .467 .923 r
F P
0 g
s
.17605 .51967 m .16993 .46277 L .22028 .51069 L p 0 .178 .831 r
F P
0 g
s
.23097 .38855 m .19665 .39322 L .14022 .34216 L p 0 .17 .292 r
F P
0 g
s
.10763 .35191 m .14022 .34216 L .19665 .39322 L p 0 .182 .39 r
F P
0 g
s
.36019 .44894 m .29136 .47932 L .24009 .43291 L p 0 .193 .451 r
F P
0 g
s
.25775 .40758 m .29136 .47932 L .24009 .43291 L p 0 .19 .841 r
F P
0 g
s
.24009 .43291 m .23638 .38866 L .2676 .38934 L p 0 .467 .923 r
F P
0 g
s
.24009 .43291 m .23638 .38866 L .25775 .40758 L p 0 .19 .841 r
F P
0 g
s
.30024 .49827 m .29136 .47932 L .24009 .43291 L p 0 .19 .841 r
F P
0 g
s
.30324 .54382 m .30024 .49827 L p .24009 .43291 L 0 .19 .841 r
F P
0 g
s
.16993 .46277 m .24009 .43291 L .29136 .47932 L p 0 .193 .451 r
F P
0 g
s
.22028 .51069 m .29136 .47932 L .24009 .43291 L p 0 .193 .451 r
F P
0 g
s
.24009 .43291 m .16993 .46277 L .22028 .51069 L p 0 .193 .451 r
F P
0 g
s
.23638 .38866 m .24009 .43291 L .29136 .47932 L p 0 .19 .841 r
F P
0 g
s
.16358 .40368 m .16993 .46277 L .24009 .43291 L p 0 .467 .923 r
F P
0 g
s
.19665 .39322 m .16358 .40368 L p .24009 .43291 L 0 .467 .923 r
F P
0 g
s
.23097 .38855 m .19665 .39322 L p .24009 .43291 L 0 .467 .923 r
F P
0 g
s
.24009 .43291 m .23638 .38866 L .23097 .38855 L p 0 .467 .923 r
F P
0 g
s
.23638 .38866 m .24009 .43291 L .16993 .46277 L p 0 .467 .923 r
F P
0 g
s
.35367 .43502 m .29807 .41592 L .2676 .38934 L p 0 .137 .1 r
F P
0 g
s
.23638 .38866 m .2676 .38934 L .29807 .41592 L p 0 .154 .185 r
F P
0 g
s
.19665 .39322 m .16358 .40368 L .10763 .35191 L p 0 .182 .39 r
F P
0 g
s
.29136 .47932 m .36019 .44894 L .36893 .46759 L p 0 .359 .741 r
F P
0 g
s
.36893 .46759 m .30024 .49827 L .29136 .47932 L p 0 .359 .741 r
F P
0 g
s
.30324 .54382 m .30024 .49827 L .36893 .46759 L p 0 .473 .927 r
F P
0 g
s
.35367 .43502 m .36019 .44894 L .29136 .47932 L p 0 .359 .741 r
F P
0 g
s
.29807 .41592 m .35367 .43502 L p .29136 .47932 L 0 .359 .741 r
F P
0 g
s
.30024 .49827 m .30324 .54382 L .23343 .57575 L p 0 .473 .927 r
F P
0 g
s
.29807 .41592 m .25775 .40758 L .23638 .38866 L p 0 .154 .185 r
F P
0 g
s
.29136 .47932 m .25775 .40758 L .23638 .38866 L p 0 .19 .841 r
F P
0 g
s
.23097 .38855 m .23638 .38866 L p .16993 .46277 L 0 .467 .923 r
F P
0 g
s
.23097 .38855 m .23638 .38866 L .25775 .40758 L p 0 .154 .185 r
F P
0 g
s
.29136 .47932 m .22028 .51069 L .16993 .46277 L p 0 .193 .451 r
F P
0 g
s
.19665 .39322 m .23097 .38855 L p .16993 .46277 L 0 .467 .923 r
F P
0 g
s
.16993 .46277 m .16358 .40368 L .19665 .39322 L p 0 .467 .923 r
F P
0 g
s
.17516 .41439 m .22028 .51069 L .16993 .46277 L p 0 .178 .831 r
F P
0 g
s
.16993 .46277 m .16358 .40368 L .17516 .41439 L p 0 .178 .831 r
F P
0 g
s
.25775 .40758 m .25081 .40615 L .23097 .38855 L p 0 .154 .185 r
F P
0 g
s
.19665 .39322 m .23097 .38855 L .25081 .40615 L p 0 .17 .292 r
F P
0 g
s
.29136 .47932 m .25775 .40758 L .29807 .41592 L p 0 .359 .741 r
F P
0 g
s
.22028 .51069 m .29136 .47932 L .30024 .49827 L p 0 .359 .741 r
F P
0 g
s
.30024 .49827 m .2293 .52995 L .22028 .51069 L p 0 .359 .741 r
F P
0 g
s
.23343 .57575 m .2293 .52995 L .30024 .49827 L p 0 .473 .927 r
F P
0 g
s
.25775 .40758 m .29136 .47932 L .22028 .51069 L p 0 .359 .741 r
F P
0 g
s
.25081 .40615 m .25775 .40758 L p .22028 .51069 L 0 .359 .741 r
F P
0 g
s
.21031 .40558 m .25081 .40615 L p .22028 .51069 L 0 .359 .741 r
F P
0 g
s
.25081 .40615 m .21031 .40558 L .19665 .39322 L p 0 .17 .292 r
F P
0 g
s
.16358 .40368 m .19665 .39322 L .21031 .40558 L p 0 .182 .39 r
F P
0 g
s
.22028 .51069 m .17516 .41439 L .21031 .40558 L p 0 .359 .741 r
F P
0 g
s
.21031 .40558 m .17516 .41439 L .16358 .40368 L p 0 .182 .39 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.20608 .45601 m
.87448 .17021 L
s
.87448 .17021 m
.82415 .62234 L
s
.82415 .62234 m
.25151 .93174 L
s
.25151 .93174 m
.20608 .45601 L
s
.08526 .34347 m
.14612 .81164 L
s
.14612 .81164 m
.25151 .93174 L
s
.25151 .93174 m
.20608 .45601 L
s
.20608 .45601 m
.08526 .34347 L
s
.003 w
[ ] 0 setdash
.08526 .34347 m
.73697 .08829 L
s
.25 Mabswid
.1033 .33641 m
.10407 .34261 L
s
gsave
.10176 .324 -66.6203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.33079 .24733 m
.33111 .25357 L
s
gsave
.33015 .23485 -69.4119 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.53658 .16675 m
.53651 .173 L
s
gsave
.53671 .15425 -71.8805 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.72362 .09351 m
.72322 .09975 L
s
gsave
.72443 .08104 -71.285 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.1507 .31785 m
.1511 .32158 L
s
.19712 .29967 m
.19746 .30341 L
s
.24258 .28187 m
.24288 .28561 L
s
.28713 .26443 m
.28738 .26817 L
s
.37358 .23058 m
.37372 .23432 L
s
.41553 .21415 m
.41563 .2179 L
s
.45666 .19804 m
.45671 .20179 L
s
.49701 .18225 m
.49701 .186 L
s
.5754 .15155 m
.57532 .1553 L
s
.6135 .13663 m
.61337 .14038 L
s
.65089 .12199 m
.65072 .12574 L
s
.68759 .10762 m
.68738 .11137 L
s
gsave
.43476 .13107 -68.9623 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00h`3oool3000000030?ooo`1gMgL0000000800000=@3oool00>@0oooo
00H0V9RH07MgM`3oool0oooo024Q8@2YZJTf0?ooo`00i@3oool0101EEED0V9RH07MgM`1VIVHg0?oo
o`00i@3oool00`3^k^h08B4Q038b<P0h0?ooo`00i@3oool00`3^k^h0410@038b<P0h0?ooo`00i@3o
ool0101VIVH0MgMg0:VYZ@1VIVHg0?ooo`00i03oool0102YZJT08B4Q0?ooo`3oool209RHV0030>k^
kP3oool0oooo03<0oooo003B0?ooo`0509RHV000000000000000002HV9P0303oool30000000307Mg
M`3oool0<S8b0080000000<0^[Zj0?ooo`3oool0<P3oool00<T0oooo0`0000000`3oool0410@0000
00020000000309RHV0000000V9RH00<0000000<0V9RH0?ooo`3oool0AP3oool00<X0oooo00<00000
0?ooo`3oool00`3oool01P2HV9P00000000000000000V9RH0?ooo`800000B03oool00<X0oooo00<0
00000?ooo`3oool0103oool300000080oooo0P0000180?ooo`00bP3oool00`000000oooo0?ooo`04
0?ooo`<000000P3oool2000004P0oooo003:0?ooo`030000003oool0oooo00<0oooo00@0V9RH0000
0000000000000P3oool200000080oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0
oooo03/0oooo003:0?ooo`030000003oool0oooo00@0000000D0V9RH000000000000oooo09RHV002
000000<0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000003d0oooo003:0?ooo`050000
003oool0oooo07MgM`1EEED00`3oool01P2HV9P00000000000000000V9RH000000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0k0?ooo`00b@3oool00`0Q8B4000000?ooo`02
0?ooo`06010@400000000000038b<P3oool0V9RH0`0000001@2HV9P0oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000m0?ooo`00f`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo03/0oooo003K0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0>`3oool00=/0oooo00H000000?ooo`3oool0000009RHV03oool4000000030;Zj^P3oool0
V9RH00<0000000<0V9RH0?ooo`3oool0<P3oool00=80oooo0`0000050?ooo`05024Q8@000000oooo
0?ooo`2HV9P00`0000002P2=SHd0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV000000d0?oo
o`00c`3oool3000000030?ooo`0000000000008000002`3oool00`3<c<`0k^k^0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000=03oool00<d0oooo0`0000040?ooo`040000003oool000000000
00/0oooo00D0ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo0380oooo001h0?oo
o`<00000C`3oool300000080oooo00<000000?ooo`3oool0103oool010000000oooo000000000009
0?ooo`050=gMg@1VIVH0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0b0?ooo`00N03oool0
0`3^k^h000000>k^kP1<0?ooo`<000002@3oool01P000000oooo0?ooo`3oool000000?ooo`<00000
1@3oool0101gMgL0oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`80000000D0410@07Mg
M`3oool0oooo09RHV0030000000309RHV03oool0oooo02P0oooo001i0?ooo`030000003oool0oooo
04T0oooo0P00000<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000103oool0
10000000V9RH09RHV00000020?ooo`050000002HV9P0oooo09RHV00000000P3oool0201gMgL0IVIV
0?ooo`000000V9RH0?ooo`2HV9P00000:P3oool007P0oooo00<0k^k^0000003^k^h0A`3oool40000
00d0oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000020?ooo`0409RHV0000000
000009RHV080oooo00D0V9RH000000000000000009RHV0030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0:03oool007P0oooo0`14A4A50?ooo`8000004@3oool00`000000oooo0?oo
o`070?ooo`040000003oool00000000000`0oooo00D0gMgM08N7Q`000000oooo000000030?ooo`03
0000003oool0oooo02P0oooo001g0?ooo`0508N7Q`14A4@0oooo038b<P2YZJT0@@3oool3000001d0
oooo00D000000?ooo`000000oooo0000000:0?ooo`0605EEE@0@4100000009RHV03oool000000`3o
ool00`000000oooo0?ooo`0X0?ooo`00MP3oool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`0
?P3oool2000002@0oooo0`00000:0?ooo`040;Zj^P2HV9P0oooo000000<0oooo00<000000?ooo`3o
ool0:03oool007H0oooo0P0000000`0b<S80oooo00000002000001H0oooo0`0000000`3oool0V9RH
000000020000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool04`3oool4000001L0oooo
00<000000?ooo`3oool03@3oool010000000oooo0000000000050?ooo`0;04A4A02j^[X0oooo0;Zj
^P000000oooo0000002HV9P0oooo09RHV00000000P3oool010000000oooo0?ooo`2HV9P300000003
09RHV03oool0oooo01h0oooo002D0?ooo`0>0000003oool0oooo0000002HV9P0oooo09RHV0000000
oooo0000002HV9P0oooo09RHV000000D0?ooo`8000000P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00l0oooo00@000000?ooo`00000000000`3oool01`3^k^h0A4A4000000000000
V9RH0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`0000020?ooo`050000002HV9P0oooo09RHV000
0000803oool009@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00h0oooo1000000L0?ooo`030000003oool0oooo0140oooo0`00000<0?ooo`L0
00000`3oool00`000000oooo0?ooo`0N0?ooo`00U03oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0303oool3000003<0oooo00<000000?ooo`00
00000P00000:0?ooo`0404A4A02HV9P0oooo00000080oooo00D000000?ooo`3oool0oooo0000000P
0?ooo`00U03oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool02P3oool3000003T0oooo0`0000080?ooo`040>k^kP0@4100gMgM00000080oooo00D0
00000?ooo`3oool0oooo0000000P0?ooo`00U03oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01`3oool4000000030?ooo`000000oooo0200oooo
00<000000?ooo`3oool05@3oool010000000oooo0000000000080?ooo`030:VYZ@0b<S8000000080
oooo00D000000?ooo`3oool0oooo0000000P0?ooo`00U03oool03P000000oooo0?ooo`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P000001`3oool4000002D0oooo00<000000?oo
o`3oool05`3oool010000000oooo0000000000070?ooo`0906IVIP000000oooo0?ooo`000000V9RH
0?ooo`2HV9P000000200oooo002C0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0
oooo09RHV0030000000309RHV03oool0oooo0080oooo0`00000Y0?ooo`030000003oool0oooo01T0
oooo00@000000?ooo`00000000001@3oool01@3^k^h0410@0?ooo`3oool0V9RH00<0000000<0V9RH
0?ooo`3oool07P3oool00:@0oooo0`00000[0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`000000;@3oool00:40oooo0`0000000`3oool000000?ooo`190?ooo`030000003oool000000080
0000:`3oool009h0oooo1000001B0?ooo`<00000:@3oool009`0oooo0`00000c0?ooo`030000003o
ool0oooo0240oooo0P00000X0?ooo`00V@3oool4000003D0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`02000002H0oooo002G0?ooo`80000000<0oooo0000003oool0=@3oool00`00
0000oooo0?ooo`0S0?ooo`040000003oool00000000002D0oooo002D0?ooo`<000000`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02D0oooo0P00000U0?ooo`00TP3oool200000640
oooo0P0000020?ooo`8000009@3oool008l0oooo0`00001Q0?ooo`8000001@3oool00`000000oooo
0?ooo`0S0?ooo`00S@3oool200000480oooo00<000000?ooo`3oool0C03oool008X0oooo0`000000
0`3oool000000?ooo`110?ooo`030000003oool0oooo01`0oooo0P00000^0?ooo`00Q`3oool30000
04L0oooo00<000000?ooo`3oool06P3oool2000000X0oooo00<000000?ooo`3oool08`3oool008D0
oooo0P00001:0?ooo`030000003oool0oooo01H0oooo0P00000>0?ooo`030000003oool0oooo02<0
oooo00220?ooo`<00000I03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo
00200?ooo`80000000<0oooo0000003oool0C03oool00`000000oooo0?ooo`0A0?ooo`8000004P3o
ool00`000000oooo0?ooo`0T0?ooo`00F03oool01`0@41000000000000000000V9RH0?ooo`2HV9P0
0`0000000`2HV9P0oooo0?ooo`0H0?ooo`<00000D@3oool00`000000oooo0?ooo`0?0?ooo`800000
>`3oool005/0oooo00P0V9RH0000003oool0000009RHV03oool0V9RH000001P0oooo0P00001D0?oo
o`030000003oool0oooo00`0oooo0P00000n0?ooo`00G03oool00`000000oooo000000030?ooo`03
0000003oool0oooo0180oooo1000001F0?ooo`030000003oool0oooo00X0oooo0P00000I0?ooo`03
0000003oool0oooo02@0oooo001L0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
403oool300000840oooo00<000000?ooo`3oool0903oool005/0oooo00@0V9RH0000003oool00000
0`3oool00`000000oooo0?ooo`0>0?ooo`<0000000<0oooo0000003oool0HP3oool2000001`0oooo
00<000000?ooo`3oool0903oool005P0oooo100000000`2HV9P0oooo000000030?ooo`030000003o
ool0oooo00/0oooo1000001L0?ooo`030000003oool0oooo00H0oooo0P00000N0?ooo`030000003o
ool0oooo02@0oooo001H0?ooo`0307MgM`1EEED0oooo00<0oooo00D0000009RHV03oool0V9RH0000
000;0?ooo`@00000GP3oool00`000000oooo0?ooo`020?ooo`800000B@3oool005T0oooo00H0410@
000000000000<S8b0?ooo`2HV9P30000000309RHV03oool0oooo00H0oooo0`00001R0?ooo`050000
003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`0T0?ooo`00J@3oool3000006@0oooo
0P00000W0?ooo`030000003oool0oooo02@0oooo001V0?ooo`<000000P3oool00`000000oooo0?oo
o`1P0?ooo`800000:03oool00`000000oooo0?ooo`0U0?ooo`00I03oool3000006@0oooo0P00000[
0?ooo`030000003oool0oooo02D0oooo001Q0?ooo`<00000I@3oool2000000D0oooo00<000000?oo
o`3oool0C@3oool005h0oooo1000001^0?ooo`030000003oool0oooo04d0oooo001L0?ooo`<00000
IP3oool2000000T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`00F@3o
ool3000000<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool09@3oool005L0oooo0P00001W0?ooo`800000=P3oool0
0`000000oooo0?ooo`0U0?ooo`00E03oool3000006P0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0U0?ooo`00DP3oool2000006L0oooo0P00000C0?ooo`030000003oool0oooo04d0
oooo001?0?ooo`@00000IP3oool2000001D0oooo00<000000?ooo`3oool0C@3oool004`0oooo0`00
001W0?ooo`8000005`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo001:
0?ooo`<00000J03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02H0oooo00170?oo
o`<00000JP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02H0oooo00150?ooo`80
0000J@3oool2000001d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`00
@P3oool4000006T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1>0?ooo`00@03o
ool2000006T0oooo0P00000R0?ooo`030000003oool0oooo04h0oooo000I0?ooo`0509RHV0000000
00000000002HV9P07`3oool3000006T0oooo0P00000T0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool09P3oool001T0oooo00D0000009RHV03oool0V9RH0000000M0?ooo`800000J@3o
ool2000004l0oooo00<000000?ooo`3oool09P3oool001T0oooo00D000000?ooo`3oool0oooo0000
000J0?ooo`@00000J03oool200000500oooo00<000000?ooo`3oool09`3oool001T0oooo00D00000
0?ooo`3oool0oooo0000000G0?ooo`@00000J03oool2000002`0oooo00<000000?ooo`3oool0CP3o
ool001T0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`@0000000<0oooo0000003oool0IP3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04h0oooo000I0?ooo`050000003oool0
oooo0?ooo`0000004P3oool4000006/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02L0oooo000I0?ooo`050000002HV9P0oooo09RHV0000000403o
ool4000006T0oooo0P00000b0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09`3o
ool001T0oooo00D0V9RH000000000000000009RHV00=0?ooo`<00000K03oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo02L0oooo000Y0?ooo`<00000JP3oool2000005h0oooo00<00000
0?ooo`3oool09`3oool002H0oooo0`0000020?ooo`030000003oool0oooo06H0oooo0P00000h0?oo
o`030000003oool0oooo04l0oooo000T0?ooo`<00000JP3oool2000003/0oooo00<000000?ooo`3o
ool0C`3oool00240oooo0`00001[0?ooo`800000?@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02P0oooo000N0?ooo`@00000JP3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0:03oool001`0oooo0P00001]0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0:03oool001T0oooo0`0000000`3oool000000?ooo`0>0?oo
oa<00000BP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0:03oool001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`L0
00001`00:dX2000000P002L_00<00000000S6@000000100000110?ooo`800000AP3oool00`000000
oooo0?ooo`1?0?ooo`00603oool2000000T0oooo0`000004000^H`0300000000:dX002]:00P002]:
0P000008000W;`03000000008aT002<I00<002<I1000000k0?ooo`800000B03oool00`000000oooo
0?ooo`1?0?ooo`00603oool00`000000oooo0?ooo`050?ooo`<000002000;V<00`00000002]:000[
BP08000[BP80000020009bl00`00000002<I000S6@06000S6@030000003oool0oooo03D0oooo0P00
001;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool001P0oooo00@00000
0?ooo`3oool000000P3oool2000000`002iS00<00000000[BP00:dX02000:dX2000000P002L_00<0
0000000S6@008aT01P008aT00`000000oooo0?ooo`0b0?ooo`800000M03oool00`000000oooo0?oo
o`0X0?ooo`00603oool02@000000oooo0?ooo`3oool000000?ooo`00000002gD0000000<000^H`03
00000000:dX002]:00P002]:0P000008000W;`03000000008aT002<I00H002<I00<000000?ooo`3o
ool0;P3oool2000007H0oooo00<000000?ooo`3oool0:@3oool001T0oooo0P0000020?ooo`800000
0P00;M@00`00000002iS000^H`0:000^H`0300000000:dX002]:00P002]:0P000008000W;`030000
00008aT002<I00H002<I00<000000?ooo`3oool0:`3oool200000580oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0Y0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`0500000000
;M@002gD000]e00000003000;V<00`00000002]:000[BP08000[BP<000001`009bl2000000L002<I
0P00000X0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0C`3oool001T0oooo00<0
00000?ooo`3oool00P3oool2000000<002gD00<00000000^H`00;V<02P00;V<2000000X002]:0P00
0008000W;`03000000008aT002<I00H002<I00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool001T0oooo00<00000
0?ooo`3oool00`3oool2000000<002gD00<00000000^H`00;V<02`00;V<00`00000002]:000[BP08
000[BP80000020009bl00`00000002<I000S6@06000S6@030000003oool0oooo0280oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo000I0?oo
o`030000003oool0oooo00<0oooo00<00000000]e00000000`00;M@00`00000002iS000^H`0;000^
H`0300000000:dX002]:00P002]:0P000008000W;`03000000008aT002<I00H002<I00<000000?oo
o`3oool07@3oool200000840oooo00<000000?ooo`3oool0:@3oool001T0oooo00<000000?ooo`3o
ool00`3oool00`00000002gD000]e004000]e08000003000;V<00`00000002]:000[BP08000[BP80
000020009bl00`00000002<I000S6@06000S6@8000006`3oool2000008<0oooo00<000000?ooo`3o
ool0:@3oool001T0oooo0P0000040?ooo`0300000000;M@002gD008002gD00D00000000]e000;M@0
02gD0000000<000^H`0300000000:dX002]:00P002]:0P000008000W;`03000000008aT002<I00L0
02<I00<000000?ooo`3oool05@3oool2000005l0oooo00<000000?ooo`3oool0D03oool001T0oooo
00<000000?ooo`3oool00`3oool00`00000002gD000]e003000]e00500000000;M@002gD000]e000
00003000;V<00`00000002]:000[BP08000[BP80000020009bl00`00000002<I000S6@07000S6@03
0000003oool0oooo0180oooo0P00001Q0?ooo`030000003oool0oooo0500oooo000I0?ooo`800000
103oool00`00000002gD000]e004000]e00500000000;M@002gD000]e00000003000;V<00`000000
02]:000[BP03000[BQ<000001P008aT00`000000oooo0?ooo`0=0?ooo`800000I@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo000J0?ooo`030000003oool0oooo0080oooo
00<00000000]e000;M@02@00;M@00`00000002iS000^H`08000^H`L000001`00:dX2000000P002L_
00<00000000S6@0000001@0000000`008aT000000?ooo`0<0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`006P3oool00`000000oooo0?oo
o`020?ooo`0300000000;M@002gD00H002gD00D00000000]e000;M@002gD00000006000^H`<00000
0`00;V<00`00000002]:000[BP09000[BP<000001`009bl00`00000002<I000S6@04000S6@@00000
V@3oool00`000000oooo0?ooo`0Z0?ooo`006P3oool00`000000oooo0?ooo`030?ooo`0300000000
;M@002gD00H002gD00D00000000]e000;M@002gD00000002000^H`<000001`00;V<00`00000002]:
000[BP09000[BP03000000009bl0000000L002L_00<00000000S6@008aT01`008aT00`000000oooo
0?ooo`040?ooo`800000T03oool00`000000oooo0?ooo`0Z0?ooo`006P3oool2000000@0oooo00<0
0000000]e000;M@01`00;M@01000000002gD000]e000;M@2000000/002iS00<00000000[BP00:dX0
2@00:dX00`00000002L_00000007000W;`03000000008aT002<I00L002<I00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0500oooo000J0?ooo`030000003o
ool0oooo00<0oooo00<00000000]e000;M@02`00;M@00`00000002gD00000009000^Ha<000001@00
9bl00`00000002<I000S6@07000S6@800000K`3oool00`000000oooo0?ooo`1@0?ooo`006P3oool2
000000@0oooo00<00000000]e000;M@02@00;M@00`00000002gD00000002000]e00400000000;V<0
02iS000^H`D000004000Fkd00`00000005^m001K_@040000008002L_00<00000000S6@008aT01000
8aT200000003000S6@000000oooo06h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0Z0?ooo`006P3oool2000000@0oooo00<00000000]e00000002P00;M@2000000<002gD0`00000F
001K_@0300000000Fkd005^m00<005^m10000002000S6@8000001@008aT2000006d0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`006`3oool00`000000oooo0?ooo`020?oo
o`0400000000;M@002gD000000X002gD00D00000000]e000;M@002gD0000000H001K_@0300000000
Fkd005^m00H005^m10000008000S6@030000003oool0oooo0900oooo00<000000?ooo`3oool0:P3o
ool001/0oooo00<000000?ooo`3oool00P3oool01@00000002gD000]e000;M@0000000X002gD00D0
0000000]e000;M@002gD0000000H001K_@0300000000Fkd005^m008005^m0P000005001K_@<00000
1P008aT00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
:P3oool001/0oooo0`0000020?ooo`0300000000;M@002gD008002gD00<00000000]e000;M@01`00
;M@20000008002gD00<00000001K_@00Fkd05P00Fkd01@00000005^m001K_@00Fkd0000000X005^m
0`000004000S6@030000003oool0oooo06L0oooo00<000000?ooo`3oool0D@3oool001/0oooo00<0
00000?ooo`3oool00`3oool00`00000002gD000]e002000]e00300000000;M@002gD00H002gD00<0
0000000]e00000000P00;M@00`00000005^m001K_@0E001K_@0300000000Fkd005^m00l005^m0`00
0002000S6@030000003oool0oooo06H0oooo00<000000?ooo`3oool0D@3oool001/0oooo00<00000
0?ooo`3oool00`3oool00`00000002gD000]e003000]e00300000000;M@002gD00D002gD00H00000
000]e000;M@00000000]e000000G001K_@8000004`00Fkd4000006L0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0[0?ooo`002P3oool01`0@41000000000000000000V9RH0?ooo`2H
V9P00`0000000`2HV9P0oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000000]e000
;M@01000;M@00`00000002gD000]e004000]e00300000000;M@002gD00<002gD00<00000001K_@00
Fkd04P00Fkd200000003001K_@00000005^m01D005^m0P00002<0?ooo`030000003oool0oooo02/0
oooo000=0?ooo`0809RHV0000000oooo0000002HV9P0oooo09RHV00000060?ooo`030000003oool0
oooo00<0oooo00<00000000]e000;M@01@00;M@00`00000002gD000]e003000]e00300000000;M@0
02gD008002gD0P00000A001K_@8000001@00Fkd00`00000005^m001K_@0D001K_@030000003oool0
oooo08X0oooo00<000000?ooo`3oool0:`3oool000h0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@01P00;M@00`00
000002gD000]e002000]e00300000000;M@002gD00<002gD00<00000001K_@00Fkd03@00Fkd20000
00L005^m00<00000001K_@00Fkd05@00Fkd00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0540oooo000>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`0300000000;M@002gD00L002gD00D00000000]e000;M@002gD00000006000]
e00300000000Fkd005^m00T005^m0P00000;001K_@0300000000Fkd005^m01@005^m00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`1A0?ooo`003@3oool0102HV9P000000?ooo`0000030?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`0300000000;M@002gD00P002gD00@00000000]
e000;M@000001P00;M@01000000005^m001K_@000006001K_@8000003@00Fkd00`00000005^m001K
_@0D001K_@800000I03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02/0oooo000:
0?ooo`@0000000<0V9RH0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<00000000]e000;M@02@00;M@01000000002gD000]e0000006000]e00500000000
Fkd005^m00000000Fkd00P00000A001K_@0300000000Fkd005^m018005^m0P0000000`00Fkd00000
0?ooo`1S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3oool000X0oooo00<0
MgMg05EEE@3oool00`3oool01@000000V9RH0?ooo`2HV9P0000000L0oooo00<000000?ooo`3oool0
0`3oool00`00000002gD000]e009000]e00300000000;M@0000000H002gD00D00000001K_@00Fkd0
05^m0000000D001K_@0300000000Fkd005^m00h005^m0`000004001K_@030000003oool0oooo08H0
oooo00<000000?ooo`3oool0;03oool000/0oooo00H0410@000000000000<S8b0?ooo`2HV9P30000
000309RHV03oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00000002gD000]e00:000]
e08000001`00;M@00`00000005^m001K_@0E001K_@0300000000Fkd005^m00`005^m0P000007001K
_@030000003oool0oooo08H0oooo00<000000?ooo`3oool0;03oool001`0oooo00<000000?ooo`3o
ool00`3oool00`00000002gD000]e00;000]e08000001P00;M@00`00000005^m001K_@0F001K_@03
00000000Fkd005^m00T005^m0P000009001K_@030000003oool0oooo0640oooo00<000000?ooo`3o
ool0D@3oool001`0oooo00<000000?ooo`3oool00`3oool00`00000002gD000]e00;000]e0030000
0000;M@0000000H002gD00<00000001K_@0000005@00Fkd00`00000005^m001K_@07001K_@800000
3000Fkd00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0540oooo000M0?ooo`8000000`3o
ool2000000`002gD00@00000000]e000;M@000001@00;M@00`00000005^m0000000F001K_@030000
0000Fkd005^m00@005^m0P00000=001K_@800000?03oool300000280oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0/0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`0300000000
;M@0000000/002gD00D00000000]e000;M@002gD00000005000]e08000005P00Fkd01000000005^m
001K_@00Fkd3000000d005^m0P0000000`00NNd000000?ooo`0i0?ooo`8000000`00>8D200000200
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0/0?ooo`007@3oool00`000000oooo
0?ooo`020?ooo`0400000000;M@002gD000000X002gD00<00000000]e000;M@00P00;M@00`000000
02gD000]e002000]e08000005P00Fkd01000000005^m001K_@00000>001K_@8000000`00NNd00`00
0000oooo0?ooo`0f0?ooo`8000001P00>8D3000004@0oooo00<000000?ooo`3oool0;03oool001d0
oooo00<000000?ooo`3oool00P3oool01@00000002gD000]e000;M@0000000X002gD00<00000000]
e000;M@00P00;M@00`00000002gD000]e002000]e00300000000Fkd005^m01@005^m0P00000>001K
_@8000001@00NNd00`000000oooo0?ooo`0c0?ooo`<000002@00>8D400000480oooo00<000000?oo
o`3oool0;03oool001d0oooo00<000000?ooo`3oool00`3oool01@00000002gD000]e000;M@00000
00T002gD00<00000000]e000;M@00`00;M@01@00000002gD000]e000;M@0000001@005^m0P000000
0`00Fkd00000001K_@0:001K_@<000001`00NNd00`000000oooo0?ooo`0a0?ooo`8000003@00>8D2
00000003000>6@000000000001X0oooo00<000000?ooo`3oool0DP3oool001d0oooo0P0000040?oo
o`0300000000;M@002gD008002gD00<00000000]e000;M@01P00;M@00`00000002gD000]e004000]
e00300000000;M@002gD008000004000Fkd3000000@005^m00<00000001K_@00Fkd01P00Fkd20000
00X007W]00<000000?ooo`3oool0;`3oool20000014003R50P0000000`003QT000000000000H0?oo
o`030000003oool0oooo0580oooo000M0?ooo`800000103oool00`00000002gD000]e003000]e003
00000000;M@002gD00D002gD00<00000000]e000;M@01@00;M@01000000002gD000]e000000>001K
_@8000001`00Fkd00`00000005^m001K_@04001K_@8000003000NNd00`000000oooo0?ooo`0]0?oo
o`8000005000>8D20000008000hI0P00000F0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0;@3oool001d0oooo0P0000040?ooo`0300000000;M@002gD00@002gD00<00000000]e000
;M@01000;M@00`00000002gD000]e006000]e00300000000;M@0000000`005^m0P00000:001K_@04
00000000Fkd005^m001K_@8000003`00NNd00`000000oooo0?ooo`0Z0?ooo`8000005`00>8D30000
008000hI0P00000i0?ooo`030000003oool0oooo02d0oooo000N0?ooo`030000003oool0oooo0080
oooo00<00000000]e000;M@01@00;M@00`00000002gD000]e003000]e00300000000;M@002gD00L0
02gD00<00000000]e00000002@00Fkd2000000`005^m00@00000001K_@00000000004@00NNd00`00
0000oooo0?ooo`0X0?ooo`8000006`00>8D20000008000hI0P00000h0?ooo`030000003oool0oooo
02d0oooo000N0?ooo`030000003oool0oooo0080oooo00<00000000]e000;M@01P00;M@00`000000
02gD000]e002000]e00300000000;M@002gD00P002gD0P000007001K_@8000003P00Fkd2000001<0
07W]00<000000?ooo`3oool09P3oool2000001h003R50P000002000>6@<000004@3oool00`000000
oooo0?ooo`1B0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`0300000000;M@002gD00L002gD
00D00000000]e000;M@002gD0000000:000]e0<000000`00Fkd3000000d005^m0`0000000`00NNd0
0000001ik@0B001ik@030000003oool0oooo02<0oooo0`00000Q000hQ@<0000000<000hI00000000
00000P00000?0?ooo`030000003oool0oooo0580oooo000N0?ooo`8000000`3oool00`00000002gD
000]e008000]e00400000000;M@002gD000000X002gD00@00000000]e000000005^m0P00000>001K
_@8000001000NNd00`00000007W]001ik@0A001ik@030000003oool0oooo0240oooo0P00000U000h
Q@<000000P003QT00`00000000hI0000000>0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0;@3oool001h0oooo00<000000?ooo`3oool00`3oool00`00000002gD000]e008000]e004
00000000;M@002gD000000T002gD00@00000000]e000;M@000003P00Fkd2000000H007W]00<00000
001ik@00NNd04@00NNd00`000000oooo0?ooo`0O0?ooo`800000:@00>8D300000003000>6@000000
00hI00800000303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02d0oooo000N0?oo
o`030000003oool0oooo00<0oooo00<00000000]e000;M@02@00;M@00`00000002gD00000009000]
e00400000000;M@002gD000000/005^m0`000008001ik@0300000000NNd007W]010007W]0P00000O
0?ooo`<00000:000>8D200000006000hQ@00000003kM000000003QT000000P003QT2000002h0oooo
00<000000?ooo`3oool0;P3oool001h0oooo00<000000?ooo`3oool00`3oool00`00000002gD000]
e00:000]e08000003@00;M@00`00000005^m001K_@06001K_@8000002`00NNd00`00000007W]001i
k@0>001ik@80000000<007W]0000003oool0703oool2000000<003R500<00000000hQ@00>8D08`00
>8D2000000@003R500<00000000ng@0000000P000003000>6@800000;03oool00`000000oooo0?oo
o`0^0?ooo`007P3oool2000000@0oooo0P00000<000]e00300000000;M@002gD00/002gD00<00000
001K_@00Fkd01000Fkd2000000d007W]00<00000001ik@00NNd03000NNd2000000<007W]00<00000
0?ooo`3oool06@3oool2000000H003R500<00000000hQ@00>8D08000>8D2000000L003R51P000002
000>6@<000001@3oool00`000000oooo0?ooo`1C0?ooo`007`3oool00`000000oooo0?ooo`020?oo
o`8002gD00<00000000]e000;M@02@00;M@00`00000002gD00000007000]e00500000000;M@002gD
000]e00000000`00Fkd30000010007W]00<00000001ik@00NNd02@00NNd2000000D007W]00<00000
0?ooo`3oool05`3oool2000000T003R500<00000000hQ@00>8D07@00>8D2000000/003R50P000000
0`003QT0000000000002000>6@<00000103oool00`000000oooo0?ooo`1C0?ooo`007`3oool30000
0080oooo00@00000000]e000;M@000002P00;M@01000000002gD000]e0000006000]e00300000000
;M@002gD008002gD0`00000C001ik@0300000000NNd007W]00H007W]0`000007001ik@030000003o
ool0oooo01@0oooo0`00000<000hQ@0300000000>8D003R501X003R50P00000>000hQ@80000000<0
00hI0000000000000`003QT300000080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0^0?ooo`007`3oool00`000000oooo0?ooo`020?ooo`0500000000;M@002gD000]e00000002@00
;M@01@00000002gD000]e000;M@0000000H002gD00D00000000]e000;M@002gD0000000E001ik@03
00000000NNd007W]00@007W]0P00000:001ik@030000003oool0oooo0180oooo0P00000@000hQ@80
00006000>8D20000014003R50P000002000>6@06000000003QT000hI000>6@00000000hI1000000S
0?ooo`030000003oool0oooo02h0oooo000O0?ooo`030000003oool0oooo0080oooo00<00000000]
e000;M@00P00;M@00`00000002gD000]e006000]e00300000000;M@002gD008002gD00<00000000]
e000;M@00`00;M@01@00000002gD000]e000;M@0000001D007W]00<00000001ik@00NNd00P00NNd2
000000`007W]00<000000?ooo`3oool0403oool2000001@003R500<00000000hQ@00>8D04`00>8D2
000001@003R50`0000000`003QT0000000000002000>6@80000000@000hI0000003oool000008P3o
ool00`000000oooo0?ooo`0^0?ooo`003`3oool00`2HV9P0A4A40?ooo`020?ooo`05010@40000000
00000000002HV9P01P3oool00`000000oooo0?ooo`030?ooo`0300000000;M@002gD008002gD00<0
0000000]e000;M@01P00;M@00`00000002gD000]e002000]e00300000000;M@002gD00H002gD00<0
0000001ik@00NNd04`00NNd00`00000007W]001ik@02000000h007W]00<000000?ooo`3oool03P3o
ool2000001L003R500<00000000hQ@00>8D04000>8D2000001P003R50P000002000>6@8000000P00
3QT00`00000000hI0000000S0?ooo`030000003oool0oooo02h0oooo000?0?ooo`030>k^kP000000
k^k^00D0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`030?ooo`0300000000;M@0
02gD00<002gD00<00000000]e000;M@01@00;M@00`00000002gD000]e003000]e00300000000;M@0
02gD00D002gD00<00000001ik@00NNd04`00NNd00`00000007W]0000000A001ik@030000003oool0
oooo00/0oooo0P00000J000hQ@0300000000>8D003R500d003R50P00000K000hQ@8000000P003QT3
00000003000>6@00000000hI0080000000<0oooo0000003oool0C`3oool00100oooo00<0A4A40:VY
Z@3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000000]
e000;M@01000;M@00`00000002gD000]e004000]e00300000000;M@002gD00@002gD00@00000000]
e000;M@000001000;M@00`00000007W]001ik@0A001ik@8000004`00NNd00`000000oooo0?ooo`09
0?ooo`8000007@00>8D00`00000003R5000hQ@09000hQ@<000007P00>8D20000008000hI1P000000
10003QT000000?ooo`00001?0?ooo`00403oool00`2HV9P0EEEE0?ooo`050?ooo`030000003oool0
oooo00@0oooo0`0000030?ooo`0300000000;M@002gD00D002gD00<00000000]e000;M@00`00;M@0
0`00000002gD000]e005000]e00300000000;M@0000000@002gD00<00000001ik@00NNd03`00NNd2
00000003001ik@00000007W]018007W]00<000000?ooo`3oool01`3oool20000020003R500<00000
000hQ@00>8D01P00>8D2000002<003R500H00000000>6@003QT000hI000000003QT300000004000>
6@000000oooo000001`0oooo00<000000?ooo`3oool0;`3oool00100oooo00<0k^k^0000003oool0
103oool00`2HV9P000000?ooo`060?ooo`030000003oool0oooo0080oooo00<00000000]e000;M@0
1P00;M@00`00000002gD000]e002000]e00300000000;M@002gD00H002gD0P000004000]e0030000
0000NNd007W]00`007W]0`000003001ik@0300000000NNd007W]014007W]00<000000?ooo`3oool0
103oool3000002<003R50P000004000hQ@8000009P00>8D4000>6@03000000003QT000hI00800000
00<000hI000000000000703oool00`000000oooo0?ooo`0_0?ooo`004@3oool00`0Q8B40ZJVY0?oo
o`040000000309RHV03oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00000002gD000]
e007000]e00500000000;M@002gD000]e00000002@00;M@00`00000002gD000]e002000]e0030000
0000NNd007W]00X007W]0P000006001ik@0300000000NNd007W]014007W]00<000000?ooo`3oool0
0P3oool2000002P003R500@00000000hQ@0000000000:@00>8D4000>6@8000000P003QT200000003
000>6@000000000001X0oooo00<000000?ooo`3oool0;`3oool000h0oooo00P08B4Q0;Zj^P3oool0
QhN705EEE@3oool0MgMg05EEE@X0oooo00<000000?ooo`3oool00P3oool00`00000002gD000]e008
000]e00400000000;M@002gD000000X002gD00D00000000]e000;M@002gD0000000:001ik@800000
2000NNd00`00000007W]001ik@0A001ik@030000003oool0oooo00800000:P00>8D2000002`003R5
0P000003000>6@04000000003QT000hI000>6@@000006@3oool00`000000oooo0?ooo`0_0?ooo`00
3P3oool01@1gMgL00000000000000000410@0080oooo00@0410@000000000000<S8b1`3oool00`00
0000oooo0?ooo`030?ooo`0300000000;M@002gD00P002gD00@00000000]e000;M@000002@00;M@2
0000008002gD00<00000001ik@00NNd01P00NNd2000000X007W]00<00000001ik@00NNd04@00NNd4
000002T003R50P000002000hQ@0300000000>8D003R502H003R50P0000000`00NNd00000001ik@02
0000008000hI00@00000000>6@003QT000hI1000001:0?ooo`00803oool2000000@0oooo00<00000
000]e000;M@02@00;M@00`00000002gD00000009000]e00500000000;M@00000000]e00000001P00
NNd2000000`007W]00<00000001ik@00NNd04000NNd2000000<003R500<00000000hQ@00>8D09000
>8D2000000D003R500<00000000hQ@00>8D08`00>8D2000000<007W]00@00000001ik@00NNd007W]
0P0000000`003QT00000000>6@02000>6@06000000003QT000000000003oool000005@3oool00`00
0000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`030?ooo`0300000000;M@002gD00X0
02gD0P000009000]e00600000000;M@002gD00000000;M@000000P00NNd3000000h007W]00<00000
001ik@00NNd03P00NNd200000003001ik@00000003R500<003R500<00000000hQ@00>8D08@00>8D2
000000P003R50P00000Q000hQ@8000001@00NNd00`00000007W]001ik@03001ik@@000000P003QT4
000000030?ooo`000000oooo01<0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?oo
o`3oool00`3oool00`00000002gD000]e00;000]e00300000000;M@002gD00L002gD00@00000000]
e000;M@002gD0P0000000`00NNd00000001ik@0A001ik@0300000000NNd007W]00/007W]0P000003
001ik@0300000000>8D003R500<003R500<00000000hQ@00>8D07P00>8D2000000`003R500<00000
000hQ@00>8D07000>8D2000000L007W]00<00000001ik@00NNd01@00NNd3000000<000hI00<00000
000>6@0000000P00000B0?ooo`030000003oool0oooo0300oooo000P0?ooo`030000003oool0oooo
00<0oooo00<00000000]e000;M@02`00;M@00`00000002gD000]e00<000]e00300000000NNd007W]
018007W]00<00000001ik@00NNd02@00NNd2000000D007W]00<00000000hQ@00>8D01000>8D00`00
000003R5000hQ@0K000hQ@8000003`00>8D00`00000003R5000hQ@0I000hQ@8000002@00NNd00`00
000007W]001ik@07001ik@8000000`003QT01000000000hI000>6@00000B0?ooo`030000003oool0
oooo0300oooo000Q0?ooo`030000003oool0oooo0080oooo0P00000<000]e08000003@00;M@00`00
000007W]001ik@0B001ik@0300000000NNd007W]00H007W]0`000007001ik@0300000000>8D003R5
00D003R500<00000000hQ@00>8D06000>8D20000018003R500<00000000hQ@00>8D05P00>8D20000
00/007W]00<00000001ik@00NNd02000NNd30000008000hI00<00000000>6@003QT00P0000130?oo
o`008@3oool00`000000oooo0?ooo`020?ooo`0300000000;M@0000000/002gD00<00000000]e000
00001`00;M@00`00000002gD000]e002000]e00300000000NNd007W]018007W]00<00000001ik@00
NNd01000NNd2000000X007W]00<00000000hQ@00>8D01P00>8D00`00000003R5000hQ@0E000hQ@80
00005@00>8D00`00000003R5000hQ@0C000hQ@8000003@00NNd00`00000007W]001ik@07001ik@04
00000000NNd007W]001ik@80000000@000hI000000003QT000hI0P0000120?ooo`008@3oool20000
00<0oooo00@00000000]e000;M@000002P00;M@01000000002gD000]e0000006000]e00300000000
;M@002gD008002gD00<00000001ik@00NNd04P00NNd00`00000007W]001ik@02001ik@8000003000
NNd00`00000003R5000hQ@07000hQ@0300000000>8D003R5018003R50P00000H000hQ@0300000000
>8D003R5010003R50P00000?001ik@0300000000NNd007W]00H007W]00<00000001ik@00NNd01000
NNd400000003000>6@000000000000h0oooo00<000000?ooo`3oool0<03oool00240oooo00<00000
0?ooo`3oool00`3oool01000000002gD000]e0000009000]e00500000000;M@002gD000]e0000000
1@00;M@00`00000002gD000]e002000]e00300000000NNd007W]018007W]00<00000001ik@00NNd0
0P00000>001ik@0300000000>8D003R500P003R500<00000000hQ@00>8D03`00>8D2000001/003R5
0P00000>000hQ@8000004@00NNd00`00000007W]001ik@05001ik@0300000000NNd007W]00L007W]
00<00000000>6@0000000P003QT00`000000oooo0000000;0?ooo`030000003oool0oooo0300oooo
000Q0?ooo`030000003oool0oooo00<0oooo00D00000000]e000;M@002gD00000008000]e0030000
0000;M@002gD008002gD00<00000000]e000;M@00P00;M@00`00000002gD000]e002000]e0030000
0000NNd007W]018007W]0`00000@001ik@0300000000>8D003R500T003R500<00000000hQ@00>8D0
3000>8D2000001l003R500<00000000hQ@00>8D02@00>8D20000018007W]00<00000001ik@00NNd0
1@00NNd00`00000007W]001ik@09001ik@<000000P003QT00`000000oooo0000000:0?ooo`030000
003oool0oooo0300oooo000Q0?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@00P00
;M@00`00000002gD000]e005000]e00300000000;M@002gD00<002gD00<00000000]e000;M@01P00
;M@00`00000007W]001ik@0A001ik@8000004P00NNd00`00000003R5000hQ@0:000hQ@8000002P00
>8D20000028003R500<00000000hQ@00>8D01P00>8D2000001@007W]00<00000001ik@00NNd01000
NNd00`00000007W]001ik@0<001ik@8000000P003QT00`000000oooo000000090?ooo`030000003o
ool0oooo0300oooo000Q0?ooo`800000103oool00`00000002gD000]e003000]e00300000000;M@0
02gD00@002gD00<00000000]e000;M@01000;M@00`00000002gD000]e005000]e00300000000NNd0
07W]00l007W]0P0000000`00NNd00000001ik@0A001ik@0300000000>8D003R500`003R500<00000
000hQ@00>8D01@00>8D2000002D003R500<00000000hQ@00>8D00`00>8D2000001H007W]00<00000
001ik@00NNd00`00NNd00`00000007W]001ik@0>001ik@<0000000<000hI0000003oool0?03oool0
0240oooo0`0000030?ooo`0300000000;M@002gD00@002gD00<00000000]e000;M@01000;M@00`00
000002gD000]e004000]e00400000000;M@002gD000000<002gD00<00000001ik@00NNd03@00NNd2
000000<007W]00<00000001ik@00NNd04000NNd00`00000003R5000hQ@0=000hQ@0300000000>8D0
03R5008003R50P00000X000hQ@0300000000>8D003R5008000006000NNd00`00000007W]001ik@02
001ik@0300000000NNd007W]00h007W]00@00000001ik@00NNd007W]1@00000j0?ooo`008P3oool0
0`000000oooo0?ooo`020?ooo`0300000000;M@002gD00D002gD00<00000000]e000;M@00`00;M@0
0`00000002gD000]e005000]e00300000000;M@0000000@002gD00<00000001ik@00NNd02P00NNd2
000000D007W]00<00000001ik@00NNd04000NNd00`00000003R5000hQ@0>000hQ@0400000000>8D0
0000000002/003R50P00000J001ik@0500000000NNd007W]001ik@0000004000NNd00`00000007W]
001ik@04001ik@@000001@3oool00`000000oooo0?ooo`0a0?ooo`008P3oool00`000000oooo0?oo
o`020?ooo`0300000000;M@002gD00H002gD00<00000000]e000;M@00P00;M@00`00000002gD000]
e006000]e08000001000;M@00`00000007W]001ik@08001ik@8000001`00NNd00`00000007W]001i
k@0@001ik@0300000000>8D003R500h003R50P00000[000hQ@<000006`00NNd01000000007W]001i
k@00000@001ik@0300000000NNd007W]00L007W]0`0000040?ooo`030000003oool0oooo0340oooo
000R0?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@01P00;M@01@00000002gD000]
e000;M@0000000T002gD00<00000000]e000;M@00P00;M@00`00000007W]001ik@06001ik@800000
2@00NNd00`00000007W]001ik@0@001ik@0300000000>8D003R500/003R50`000002000hQ@030000
0000>8D003R502H003R50P000002001ik@0300000000NNd007W]01T007W]00<00000001ik@000000
4000NNd00`00000007W]001ik@09001ik@8000000P3oool00`000000oooo0000000c0?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`0300000000;M@002gD00L002gD00@00000000]e000;M@00000
2P00;M@01@00000002gD000]e000;M@0000000H007W]0P00000;001ik@0300000000NNd007W]0100
07W]00<00000000hQ@00>8D02@00>8D2000000H003R500<00000000hQ@00>8D08`00>8D2000000@0
07W]00<00000001ik@00NNd06@00NNd20000010007W]00<00000001ik@00NNd02`00NNd200000080
oooo0P00000c0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`0300000000;M@002gD00P002gD
00<00000000]e00000002@00;M@00`00000002gD00000002000]e00300000000NNd007W]008007W]
0P00000=001ik@0300000000NNd007W]00l007W]0P000009000hQ@8000002@00>8D00`00000003R5
000hQ@0P000hQ@8000001P00NNd00`00000007W]001ik@0H001ik@8000004000NNd00`00000007W]
001ik@0:001ik@800000103oool2000003<0oooo000R0?ooo`<000000`3oool00`00000002gD000]
e00:000]e00300000000;M@002gD00L002gD00H00000000]e000;M@00000000]e0000002001ik@80
00003`00NNd00`00000007W]001ik@0=001ik@80000000<007W]00000000>8D01P00>8D2000000`0
03R500<00000000hQ@00>8D07@00>8D2000000P007W]00<00000001ik@00NNd05P00NNd200000003
001ik@00000007W]00h007W]00<00000001ik@00NNd02@00NNd2000000@0oooo0P00000e0?ooo`00
8P3oool2000000@0oooo00<002gD00000000;M@02P00;M@00`00000002gD000]e007000]e0040000
0000;M@002gD000]e0@000004P00NNd00`00000007W]001ik@0:001ik@8000000`00NNd00`000000
03R5000hQ@03000hQ@8000003`00>8D2000001/003R50P00000:001ik@0300000000NNd007W]01@0
07W]0P000003001ik@0300000000NNd007W]00`007W]00<00000001ik@00NNd02000NNd2000003d0
oooo00020?ooo`H000006P3oool2000000@0oooo00<00000000]e00000002`00;M@00`00000002gD
000]e006000]e00300000000;M@002gD008002gD00<00000001ik@00NNd04P00NNd00`00000007W]
001ik@08001ik@8000001@00NNd01000000003R5000hQ@00>8D2000001<003R500<00000000hQ@00
>8D05P00>8D2000000`007W]00<00000001ik@00NNd04P00NNd2000000D007W]00<00000001ik@00
NNd02`00NNd00`00000007W]001ik@07001ik@8000001@3oool2000003P0oooo00020?ooo`060:VY
Z@0b<S80oooo0?ooo`3^k^h0<S8b1@3oool3000000030?ooo`2HV9P000000080000000<0V9RH0?oo
o`2HV9P00`0000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000000]
e000;M@000002@00;M@00`00000002gD0000000<000]e00300000000NNd007W]018007W]00<00000
001ik@00NNd01P00NNd2000000L007W]00@00000000hQ@00000000005P00>8D00`00000003R5000h
Q@0C000hQ@8000003P00NNd00`00000007W]001ik@0@001ik@8000001`00NNd00`00000007W]001i
k@0:001ik@0300000000NNd007W]00L007W]00<000000?ooo`3oool00`3oool2000003X0oooo0003
0?ooo`0306IVIP1gMgL0oooo00P0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003o
ool0000009RHV03oool0V9RH000000L0oooo00<000000?ooo`3oool00`3oool01000000002gD000]
e0000008000]e00400000000;M@002gD000000/002gD00<00000001ik@00NNd04P00NNd00`000000
07W]001ik@04001ik@8000002@00NNd2000001T003R500<00000000hQ@00>8D04@00>8D00`000000
07W]001ik@0>001ik@0300000000NNd007W]00h007W]0P000009001ik@0300000000NNd007W]00P0
07W]0P000008001ik@800000@P3oool000<0oooo00<0k^k^024Q8@3<c<`0203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool2000000@0
oooo00D00000000]e000;M@002gD00000008000]e00400000000;M@002gD000000H002gD00D00000
000]e000;M@002gD0000000D001ik@0300000000NNd007W]008007W]0P00000;001ik@0300000000
>8D003R501T003R500<00000000hQ@00>8D03P00>8D20000014007W]00<00000001ik@00NNd03@00
NNd00`00000007W]001ik@09001ik@0300000000NNd007W]00L007W]00<00000001ik@00NNd01P00
NNd2000000D0oooo0P00000m0?ooo`00103oool00`3<c<`08B4Q0>k^kP070?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<00000000]e000;M@00P00;M@00`00000002gD000]e005000]e00500000000
;M@002gD000]e00000001@00;M@01@00000002gD000]e000;M@0000001@007W]00<00000001ik@00
NNd00P00000=001ik@0300000000>8D003R501X003R500<00000000hQ@00>8D02`00>8D2000001<0
07W]00<00000001ik@00NNd02`00NNd2000000`007W]00<00000001ik@00NNd01P00NNd00`000000
07W]001ik@05001ik@8000001@3oool2000003l0oooo00050?ooo`0307MgM`1VIVH0oooo00H0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`00000002gD000]e003000]e00300000000;M@002gD00@0
02gD00<00000000]e000;M@00P00;M@00`00000002gD000]e002000]e00500000000;M@002gD000]
e00000005000NNd30000010007W]00<00000000hQ@00>8D06P00>8D00`00000003R5000hQ@08000h
Q@8000005@00NNd00`00000007W]001ik@09001ik@8000003P00NNd00`00000007W]001ik@05001i
k@0300000000NNd007W]00@007W]0P0000040?ooo`800000@P3oool00080oooo00H0<S8b0>k^kP3o
ool0oooo038b<P2YZJT60?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@01000
;M@00`00000002gD000]e003000]e00300000000;M@002gD00<002gD00D00000000]e000;M@002gD
00000003000]e00300000000NNd007W]018007W]00<00000001ik@00NNd04000NNd00`00000003R5
000hQ@0K000hQ@0300000000>8D003R500D003R50P00000G001ik@0300000000NNd007W]00L007W]
0P00000?001ik@0300000000NNd007W]00D007W]00<00000001ik@00NNd00`00NNd2000000D0oooo
00<000000?ooo`3oool0@P3oool00080oooo1P0000060?ooo`0>0000003oool0oooo0000002HV9P0
oooo09RHV0000000oooo0000002HV9P0oooo09RHV00000070?ooo`030000003oool0oooo00<0oooo
00<00000000]e000;M@01@00;M@00`00000002gD000]e002000]e00300000000;M@002gD00@002gD
00<00000000]e000;M@01000;M@00`00000007W]001ik@0?001ik@80000000<007W]00000000NNd0
4@00NNd00`00000003R5000hQ@0L000hQ@0300000000>8D003R5008003R50P00000I001ik@030000
0000NNd007W]00D007W]0P00000A001ik@0300000000NNd007W]00@007W]00<00000001ik@00NNd0
0P00NNd2000000H0oooo00<000000?ooo`3oool0@`3oool000d0oooo00D08B4Q0000003oool0oooo
09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool01@3oool3000000<0oooo
00<00000000]e000;M@01P00;M@01@00000002gD000]e000;M@0000000L002gD00<00000000]e000
;M@01000;M@00`00000007W]001ik@0;001ik@<000000`00NNd00`00000007W]001ik@0@001ik@03
00000000>8D003R501d003R500@00000000hQ@00000000006`00NNd00`00000007W]001ik@03001i
k@8000004`00NNd00`00000007W]001ik@03001ik@0400000000NNd007W]001ik@8000001@3oool2
000004L0oooo000T0?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@01P00;M@01000
000002gD000]e0000008000]e08000001000;M@00`00000007W]001ik@09001ik@8000001P00NNd0
0`00000007W]001ik@0@001ik@0300000000>8D003R501d003R50P00000M001ik@0400000000NNd0
07W]001ik@8000005@00NNd00`00000007W]001ik@02001ik@0300000000NNd007W]008000001@3o
ool2000004T0oooo000T0?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@01`00;M@0
1000000002gD000]e0000008000]e00300000000;M@002gD008002gD00<00000001ik@00NNd01`00
NNd2000000P007W]00<00000001ik@00NNd04000NNd00`00000003R5000hQ@0K000hQ@80000000<0
07W]00000000NNd07000NNd01000000007W]00000000000G001ik@0500000000NNd007W]001ik@00
00000P00NNd00`000000oooo0?ooo`1@0?ooo`00903oool00`000000oooo0?ooo`030?ooo`030000
0000;M@002gD00P002gD00<00000000]e00000002@00;M@01@00000002gD000]e000;M@0000000L0
07W]0P00000:001ik@0300000000NNd007W]010007W]00<00000000hQ@00>8D06@00>8D2000000<0
07W]00<00000001ik@00NNd06`00NNd2000001T007W]00D00000001ik@00NNd00000001ik@020000
00D0oooo0P00001<0?ooo`00903oool00`000000oooo0?ooo`030?ooo`0300000000;M@002gD00X0
02gD00<00000000]e000;M@01`00;M@20000008002gD00<00000001ik@00NNd00`00NNd2000000`0
07W]00<00000001ik@00NNd03@00NNd200000003001ik@00000003R501P003R50P000005001ik@03
00000000NNd007W]01T007W]0P00000K001ik@0300000000NNd00000008000001@3oool2000004h0
oooo000T0?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@02P00;M@00`00000002gD
000]e009000]e00300000000;M@00000008007W]0`00000>001ik@0300000000NNd007W]00/007W]
0P000003001ik@0300000000>8D003R501D003R50P000007001ik@0300000000NNd007W]01L007W]
0P0000000`00NNd00000001ik@0J001ik@<00000103oool200000540oooo000T0?ooo`<000000`3o
ool2000000/002gD00<00000000]e000;M@02`00;M@30000018007W]00<00000001ik@00NNd02000
NNd2000000D007W]00<00000000hQ@00>8D04`00>8D2000000T007W]00<00000001ik@00NNd05@00
NNd2000000<007W]00<00000001ik@00NNd06000NNd2000000D0oooo00<000000?ooo`3oool0D@3o
ool002@0oooo0P0000040?ooo`0300000000;M@0000000X002gD0P000008000]e00500000000;M@0
02gD000]e00000005000NNd00`00000007W]001ik@06001ik@8000001`00NNd00`00000003R5000h
Q@0A000hQ@8000002`00NNd00`00000007W]001ik@0D001ik@0300000000NNd007W]00<007W]00<0
0000001ik@00NNd05P00NNd2000000H0oooo00<000000?ooo`3oool0DP3oool002@0oooo0P000004
0?ooo`0400000000;M@002gD000000T002gD00<00000000]e00000001`00;M@01@00000002gD000]
e000;M@0000001@007W]00<00000001ik@00NNd01000NNd2000000T007W]00<00000000hQ@00>8D0
3`00>8D2000000d007W]00<00000001ik@00NNd04P00NNd2000000H007W]00<00000001ik@00NNd0
5000NNd2000000D0oooo0P00001F0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`0500000000
;M@002gD000]e00000002000;M@01000000002gD000]e0000006000]e00500000000;M@002gD000]
e00000005000NNd00`00000007W]001ik@02001ik@8000002`00NNd00`00000003R5000hQ@0=000h
Q@8000003`00NNd00`00000007W]001ik@0@001ik@8000002000NNd00`00000007W]001ik@0B001i
k@8000001P3oool00`000000oooo0?ooo`1F0?ooo`009@3oool00`000000oooo0?ooo`030?ooo`05
00000000;M@002gD000]e00000001`00;M@01@00000002gD000]e000;M@0000000T002gD00<00000
001ik@00NNd04P00NNd00`00000007W]001ik@02000000d007W]00<00000000hQ@00>8D02`00>8D2
0000014007W]00<00000001ik@00NNd03P00NNd2000000X007W]00<00000001ik@00NNd04@00NNd0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05L0oooo000U0?ooo`800000103oool00`00
000002gD000]e002000]e00300000000;M@002gD00@002gD00<00000000]e000;M@00P00;M@00`00
000002gD000]e006000]e00300000000NNd007W]018007W]0`00000@001ik@0300000000>8D003R5
00P003R50P00000C001ik@0300000000NNd007W]00`007W]0P00000<001ik@0300000000NNd007W]
00l007W]0P0000050?ooo`800000F`3oool002D0oooo00<000000?ooo`3oool00`3oool00`000000
02gD000]e003000]e00300000000;M@002gD00<002gD00<00000000]e000;M@00`00;M@01@000000
02gD000]e000;M@0000000@002gD00<00000001ik@00NNd04@00NNd00`00000007W]001ik@0@001i
k@0300000000>8D003R500H003R50P00000E001ik@0300000000NNd007W]00X007W]0P00000>001i
k@0300000000NNd007W]00d007W]0P0000050?ooo`800000G@3oool002D0oooo00<000000?ooo`3o
ool00`3oool00`00000002gD000]e004000]e00300000000;M@002gD00<002gD00<00000000]e000
;M@00`00;M@01000000002gD000]e0000004000]e00300000000NNd007W]00h007W]0P0000000`00
NNd00000001ik@0A001ik@0300000000>8D003R500@003R50P00000G001ik@0300000000NNd007W]
00P007W]0P00000@001ik@0300000000NNd007W]00/007W]0P00001V0?ooo`009@3oool2000000@0
oooo00<00000000]e000;M@01@00;M@00`00000002gD000]e002000]e00300000000;M@002gD00@0
02gD00@00000000]e000;M@000000`00;M@00`00000007W]001ik@0<001ik@8000000`00NNd00`00
000007W]001ik@0@001ik@0300000000>8D003R5008003R50P00000I001ik@0300000000NNd007W]
00H007W]0P00000B001ik@0300000000NNd007W]00T007W]0P0000060?ooo`800000H03oool002D0
oooo00@000000?ooo`00000000000P3oool00`00000002gD000]e006000]e00500000000;M@002gD
000]e00000001`00;M@00`00000002gD00000003000]e00300000000NNd007W]00X007W]0P000005
001ik@0300000000NNd007W]010007W]00<00000000hQ@00>8D00P00000K001ik@0300000000NNd0
07W]00@007W]0P00000D001ik@0300000000NNd007W]00L007W]0P0000060?ooo`800000HP3oool0
02H0oooo00<000000?ooo`3oool00P3oool00`00000002gD000]e007000]e00400000000;M@002gD
000000P002gD00<00000000]e000;M@00P00;M@00`00000007W]001ik@08001ik@8000001`00NNd0
0`00000007W]001ik@0?001ik@@000007@00NNd00`00000007W]001ik@02001ik@8000005P00NNd0
0`00000007W]001ik@05001ik@8000001@3oool2000006D0oooo000V0?ooo`030000003oool0oooo
0080oooo00<00000000]e000;M@02000;M@00`00000002gD00000009000]e00500000000;M@002gD
000]e00000002@00NNd00`00000007W]001ik@07001ik@0300000000NNd007W]00l007W]0P00000O
001ik@0300000000NNd007W]008000006000NNd00`00000007W]001ik@03001ik@8000001P3oool0
0`000000oooo0?ooo`1U0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`0300000000;M@002gD
00X002gD00<00000000]e000;M@01`00;M@20000008002gD00<00000001ik@00NNd01@00NNd20000
00X007W]00<00000001ik@00NNd03@00NNd200000003001ik@00000007W]01h007W]00<00000001i
k@0000006P00NNd00`00000007W]001ik@02001ik@030000003oool0oooo00D0oooo00<000000?oo
o`3oool0IP3oool00140oooo0`0000000`3oool0000000000002000000030;Zj^P3oool0410@00<0
000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`0300000000;M@002gD00X0
02gD00<00000000]e000;M@01`00;M@00`00000002gD00000002000]e00300000000NNd007W]0080
07W]0P00000<001ik@0300000000NNd007W]00/007W]0P000002001ik@8000007`00NNd2000001/0
07W]00<00000001ik@00NNd00P0000050?ooo`030000003oool0oooo06T0oooo000B0?ooo`080000
003oool0oooo0<c<c03^k^h0oooo0<c<c01EEED40?ooo`0309RHV0000000oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`00000002gD000]e009000]e00300000000;M@002gD00L002gD00H00000
000]e000;M@00000000]e0000002001ik@8000003`00NNd00`00000007W]001ik@08001ik@800000
0`00NNd00`00000007W]0000000M001ik@<000007000NNd3000000H0oooo00<000000?ooo`3oool0
JP3oool00180oooo00H000000?ooo`3oool0oooo0<c<c03^k^h70?ooo`030000003oool0oooo00@0
oooo0`0000030?ooo`0300000000;M@002gD00T002gD0P000008000]e00300000000;M@002gD0080
02gD0`00000A001ik@0300000000NNd007W]00H007W]0P000004001ik@0400000000NNd007W]0000
01/007W]0P000002001ik@0300000000NNd007W]01T007W]0P0000070?ooo`030000003oool0oooo
06/0oooo000B0?ooo`030000003oool0oooo0080oooo00<0ZJVY0>k^kP3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000000]e000;M@02@00;M@00`000000
02gD0000000<000]e00300000000NNd007W]014007W]00<00000001ik@00NNd01000NNd2000000H0
07W]00@00000001ik@00NNd000006@00NNd2000000@007W]00<00000001ik@00NNd05`00NNd20000
00D0oooo0P00001`0?ooo`004P3oool00`000000oooo0?ooo`020?ooo`030=gMg@1VIVH0oooo00@0
oooo00<0V9RH0000003oool01@3oool2000000@0oooo00<00000000]e000;M@02@00;M@010000000
02gD000]e000000;000]e00300000000NNd007W]014007W]00<00000001ik@00NNd00P00NNd20000
00L007W]00D00000001ik@00NNd007W]0000000G001ik@8000001P00NNd00`00000007W]001ik@0E
001ik@8000001P3oool00`000000oooo0?ooo`1`0?ooo`004P3oool010000000oooo0?ooo`1gMgL2
0?ooo`030000003oool0oooo00@0000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`0300000000;M@002gD00X002gD00@00000000]e000;M@000001@00;M@00`00000002gD000]
e002000]e00300000000NNd007W]014007W]00<00000001ik@00NNd00P000008001ik@0300000000
NNd007W]008007W]00<00000001ik@00NNd04`00NNd2000000P007W]00<00000001ik@00NNd04`00
NNd2000007/0oooo000B0?ooo`040000003oool0oooo00000080V9RH00D000000?ooo`3oool0MgMg
05EEE@0:0?ooo`030000003oool0oooo0080oooo00<00000000]e000;M@02P00;M@01@00000002gD
000]e000;M@0000000@002gD00<00000000]e000;M@00P00;M@00`00000007W]001ik@0A001ik@<0
00002@00NNd00`00000007W]001ik@03001ik@0300000000NNd007W]014007W]0P00000:001ik@03
00000000NNd007W]014007W]0P0000060?ooo`800000M@3oool00140oooo00D08B4Q0000003oool0
oooo09RHV0020000000509RHV03oool0oooo0?ooo`0@41000P0000000`0b<S80oooo0?ooo`050?oo
o`8000000`3oool00`00000002gD000]e00:000]e00300000000;M@002gD008002gD00<00000000]
e000;M@00P00;M@01@00000002gD000]e000;M@0000001<007W]00<00000001ik@00NNd02@00NNd0
0`00000007W]001ik@03001ik@0300000000NNd007W]00l007W]0P00000<001ik@0300000000NNd0
07W]010007W]00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1e0?ooo`009`3oool00`00
0000oooo0?ooo`020?ooo`0300000000;M@002gD00X002gD00<00000000]e000;M@00`00;M@01@00
000002gD000]e000;M@0000000<002gD00<00000001ik@00NNd03P00NNd200000003001ik@000000
07W]00T007W]00<00000001ik@00NNd01000NNd00`00000007W]001ik@0=001ik@8000003P00NNd0
0`00000007W]001ik@0>001ik@8000001@3oool00`000000oooo0?ooo`1h0?ooo`009`3oool00`00
0000oooo0?ooo`020?ooo`0300000000;M@002gD00X002gD00<00000000]e000;M@01000;M@00`00
000002gD000]e004000]e00300000000NNd007W]00`007W]0P000004001ik@0300000000NNd007W]
00H007W]00<00000001ik@00NNd01@00NNd00`00000007W]001ik@0;001ik@8000004000NNd00`00
000007W]001ik@0<001ik@8000001P3oool00`000000oooo0?ooo`1i0?ooo`009`3oool2000000<0
oooo00<00000000]e000;M@02P00;M@00`00000002gD000]e005000]e00300000000;M@0000000<0
02gD00<00000001ik@00NNd02P00NNd2000000H007W]00<00000001ik@00NNd01P00NNd00`000000
07W]001ik@05001ik@0300000000NNd007W]00T007W]0P00000B001ik@0300000000NNd007W]00X0
07W]0P0000070?ooo`030000003oool0oooo07X0oooo000W0?ooo`800000103oool00`00000002gD
000]e009000]e00300000000;M@002gD00H002gD0P000004000]e00300000000NNd007W]00L007W]
0P000008001ik@0300000000NNd007W]00D007W]00<00000001ik@00NNd01P00NNd00`00000007W]
001ik@08001ik@0300000000NNd007W]018007W]00<00000001ik@00NNd02000NNd2000000D0oooo
0P00001o0?ooo`009`3oool3000000<0oooo00<00000000]e000;M@02P00;M@00`00000002gD000]
e006000]e00300000000;M@002gD008002gD00<00000001ik@00NNd01P00NNd00`00000007W]001i
k@09001ik@0300000000NNd007W]00<007W]00<00000001ik@00NNd01`00NNd00`00000007W]001i
k@06001ik@8000005@00NNd00`00000007W]001ik@06001ik@8000001P3oool00`000000oooo0?oo
o`1o0?ooo`00:03oool00`000000oooo0?ooo`020?ooo`0300000000;M@002gD00X002gD00<00000
000]e000;M@01P00;M@2000000<002gD00<00000001ik@00NNd01000NNd2000000`007W]00<00000
001ik@00NNd00P00NNd00`00000007W]001ik@08001ik@0300000000NNd007W]00@007W]0P00000G
001ik@0300000000NNd007W]00@007W]0P00002:0?ooo`00:03oool00`000000oooo0?ooo`020?oo
o`0300000000;M@002gD00X002gD00<00000000]e000;M@02000;M@01000000002gD000]e0000004
001ik@8000003`00NNd01@00000007W]001ik@00NNd0000000X007W]00<00000001ik@00NNd00P00
NNd2000001T007W]00<00000001ik@00NNd00`00NNd00`000000oooo0?ooo`040?ooo`800000Q03o
ool002P0oooo00<000000?ooo`3oool00P3oool00`00000002gD000]e00:000]e00300000000;M@0
02gD00T002gD00<00000000]e00000000P00NNd20000014007W]00@00000001ik@00NNd000002`00
NNd00`00000007W]001ik@02000001/007W]00@00000001ik@00NNd007W]0P0000060?ooo`030000
003oool0oooo08@0oooo000X0?ooo`8000000`3oool00`00;M@00000000]e00:000]e00300000000
;M@002gD00L002gD00@00000000]e000;M@002gD0`00000C001ik@0300000000NNd0000000`007W]
0`00000M001ik@0400000000NNd00000000008l0oooo000X0?ooo`8000000`3oool00`00000002gD
0000000:000]e00300000000;M@002gD00L002gD00D00000000]e000;M@002gD0000000F001ikA00
00007P00NNd2000000H0oooo0P0000290?ooo`00:03oool2000000@0oooo00<00000000]e0000000
2@00;M@00`00000002gD000]e007000]e00500000000;M@002gD000]e00000005P00NNd00`000000
07W]001ik@0;001ik@8000007000NNd3000000H0oooo00<000000?ooo`3oool0R@3oool002P0oooo
00<000000?ooo`3oool00`3oool01000000002gD000]e0000008000]e00300000000;M@002gD00L0
02gD00@00000000]e000;M@002gD0P00000D001ik@0300000000NNd007W]00`007W]0P00000J001i
k@8000001P3oool00`000000oooo0?ooo`2<0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`05
00000000;M@002gD000]e00000002000;M@00`00000002gD000]e00:000]e08000004`00NNd00`00
000007W]001ik@0=001ik@8000006000NNd2000000L0oooo00<000000?ooo`3oool0S@3oool002T0
oooo0`0000020?ooo`0300000000;M@002gD008002gD00<00000000]e000;M@01@00;M@00`000000
02gD000]e00:000]e00300000000NNd00000018007W]00<00000001ik@00NNd03@00NNd2000001H0
07W]0P0000080?ooo`030000003oool0oooo08h0oooo000Y0?ooo`030000003oool0oooo00<0oooo
00<00000000]e000;M@00P00;M@00`00000002gD000]e004000]e00300000000;M@002gD00H002gD
00L00000000]e000;M@002gD00000000NNd00000014007W]00<00000001ik@00NNd03P00NNd20000
01D007W]00<000000?ooo`3oool0103oool2000009<0oooo000Y0?ooo`040000003oool000000000
00<0oooo00<00000000]e000;M@00P00;M@00`00000002gD000]e003000]e00300000000;M@002gD
00H002gD00<00000000]e000;M@00P00;M@00`00000007W]0000000?001ik@0300000000NNd007W]
00l007W]0P00000C001ik@8000001P3oool00`000000oooo0?ooo`2C0?ooo`00:@3oool2000000H0
oooo00<00000000]e000;M@00P00;M@00`00000002gD000]e002000]e00300000000;M@002gD00H0
02gD00<00000000]e000;M@00P00;M@00`00000007W]0000000?001ik@0300000000NNd007W]00l0
07W]0P00000A001ik@800000WP3oool001@0oooo0`0000000`3oool0410@000000020000000309RH
V03oool0V9RH00<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
0000;M@002gD008002gD00D00000000]e000;M@002gD00000008000]e00300000000;M@002gD0080
02gD00@00000001ik@00NNd000003@00NNd00`00000007W]001ik@0@001ik@8000003`00NNd20000
00H0oooo0P00002H0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`0809RHV0000000oooo0000
002HV9P0oooo09RHV00000070?ooo`030000003oool0oooo00H0oooo00<00000000]e000;M@00P00
;M@01000000002gD000]e000000=000]e00400000000NNd007W]000000`007W]00<00000001ik@00
NNd04P00NNd00`00000007W]001ik@0;001ik@8000001`3oool00`000000oooo0?ooo`2H0?ooo`00
5@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`0300000000;M@002gD008002gD00@00000000]e000;M@0
00003000;M@01@00000007W]001ik@00NNd0000000X007W]00<00000001ik@00NNd04`00NNd00`00
000007W]001ik@09001ik@8000001@3oool2000009d0oooo000E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0@0?ooo`0300000000;M@002gD0080
02gD00<00000000]e00000002000;M@01@00000002gD000]e000;M@0000000@007W]00<00000001i
k@00NNd01`00NNd00`00000007W]001ik@0C001ik@0300000000NNd007W]00L007W]0P0000060?oo
o`030000003oool0oooo09d0oooo000E0?ooo`030000003oool0oooo00<0oooo00@0V9RH0000003o
ool000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000000]
e000;M@01000;M@00`00000002gD000]e006000]e00500000000;M@002gD000]e00000001000NNd0
0`00000007W]001ik@06001ik@0300000000NNd007W]01@007W]00<00000001ik@00NNd01@00NNd2
000000L0oooo00<000000?ooo`3oool0WP3oool001D0oooo00<000000?ooo`3oool0100000000`2H
V9P0oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`00
000002gD000]e003000]e00300000000;M@002gD00H002gD00D00000000]e000;M@002gD00000005
001ik@0300000000NNd007W]00@007W]00<00000001ik@00NNd05@00NNd00`00000007W]001ik@04
001ik@030000003oool0oooo00@0oooo0P00002R0?ooo`005@3oool01@000000oooo0?ooo`1gMgL0
EEEE00@0oooo00D0000009RHV03oool0V9RH0000000<0?ooo`030000003oool0oooo00D0oooo00<0
0000000]e000;M@00P00;M@00`00000002gD000]e00:000]e00300000000NNd007W]00<007W]00<0
0000001ik@00NNd01000NNd00`00000007W]001ik@0E001ik@0300000000NNd007W]008007W]0P00
00060?ooo`030000003oool0oooo0:80oooo000D0?ooo`03024Q8@000000oooo0080oooo00H0410@
000000000000<S8b0?ooo`2HV9P30000000309RHV03oool0oooo01<0oooo00@00000000]e000;M@0
02gD0P00000;000]e00300000000NNd007W]00@007W]00<00000001ik@00NNd00P00NNd00`000000
07W]001ik@0F001ik@0300000000NNd007W]008000001`3oool00`000000oooo0?ooo`2S0?ooo`00
<@3oool00`000000oooo0?ooo`050?ooo`0600000000;M@002gD00000000;M@000001P00;M@00`00
000002gD000]e002000]e00300000000NNd007W]00<007W]00D00000001ik@00NNd007W]0000000I
001ik@<000001P3oool200000:L0oooo000b0?ooo`030000003oool0oooo00D0oooo0P00;M@01000
000002gD000]e0000005000]e00300000000;M@002gD008002gD00<00000001ik@00NNd01000NNd0
1000000007W]001ik@00000B001ik@P000001P3oool200000:T0oooo000c0?ooo`030000003oool0
oooo00D0oooo00<002gD00000000;M@00P00;M@00`00000002gD000]e003000]e00500000000;M@0
02gD000]e00000001P00NNd00`00000007W]00000005001ik@h000001000NNd200000;<0oooo000l
0?ooo`0300000000;M@002gD008002gD00<00000000]e000;M@00P00;M@01@00000002gD000]e000
;M@0000000L007W]1`00000@001ik@8000001`3oool200000:`0oooo000e0?ooo`030000003oool0
oooo00@0oooo00<00000000]e000;M@00`00;M@00`00000002gD000]e005000]e00300000000NNd0
07W]00D007W]00<00000001ik@00NNd04`00NNd00`000000oooo0?ooo`050?ooo`800000[P3oool0
03D0oooo00<000000?ooo`3oool01@3oool00`00000002gD000]e003000]e00300000000;M@002gD
00@002gD00<00000001ik@00NNd01000NNd00`00000007W]001ik@0B001ik@8000001@3oool20000
0;40oooo000f0?ooo`030000003oool0oooo00D0oooo00<00000000]e000;M@00`00;M@00`000000
02gD00000003000]e00300000000NNd007W]00<007W]00<00000001ik@00NNd04@00NNd2000000H0
oooo00<000000?ooo`3oool0/@3oool003L0oooo00<000000?ooo`3oool01@3oool00`00000002gD
000]e002000]e00300000000;M@0000000<002gD00<00000001ik@00NNd00`00NNd00`00000007W]
001ik@0?001ik@8000001`3oool00`000000oooo0?ooo`2b0?ooo`00@03oool00`00000002gD000]
e002000]e08000000`00;M@00`00000007W]001ik@02001ik@0300000000NNd007W]00h007W]0P00
00060?ooo`800000]P3oool003T0oooo00<000000?ooo`3oool01@3oool00`00000002gD000]e002
000]e00500000000;M@002gD000]e00000000`00NNd00`00000007W]001ik@0=001ik@8000001P3o
ool200000;P0oooo000i0?ooo`030000003oool0oooo00H0oooo00<00000000]e000;M@00P00;M@0
1@00000002gD000]e000;M@00000008007W]00<00000001ik@00NNd02`00NNd200000<80oooo000j
0?ooo`030000003oool0oooo00H0oooo00<00000000]e000;M@00P00;M@01P00000002gD000]e000
000007W]000000d007W]00<000000?ooo`3oool01@3oool200000;/0oooo00140?ooo`0300000000
;M@00000008002gD00D00000000]e000000007W]0000000;001ik@8000001P3oool200000;d0oooo
000l0?ooo`030000003oool0oooo00D0oooo00<00000000]e00000001000;M@2000000X007W]0P00
00370?ooo`00?@3oool00`000000oooo0?ooo`050?ooo`0300000000;M@0000000<002gD00<00000
001ik@00NNd01`00NNd2000000L0oooo0P0000300?ooo`00?P3oool00`000000oooo0?ooo`050?oo
o`8000000`00;M@00`00000007W]001ik@05001ik@8000001`3oool200000<80oooo00170?ooo`05
00000000;M@002gD000]e00000001@00NNd2000000H0oooo0P0000350?ooo`00@03oool00`000000
oooo0?ooo`040?ooo`8000000P00;M@00`00000007W]001ik@02001ik@030000003oool0oooo00D0
oooo00<000000?ooo`3oool0a@3oool00440oooo00<000000?ooo`3oool00`3oool01@000000oooo
00000000;M@00000008007W]0P0000070?ooo`030000003oool0oooo0<H0oooo00120?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0100000060?ooo`800000bP3oool004L0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`800000c03oool00?l0oooo8@3oool004@0oooo00<00000
0?ooo`3oool01`3oool200000=00oooo00150?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0d03oool004H0oooo0P0000020?ooo`030000003oool0oooo0=<0oooo00180?ooo`800000
eP3oool004P0oooo00<000000?ooo`3oool0e@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.000162426, -8.3589*^-5, \
0.0034849, 0.0034849}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.08271 .71771 -24.25 -3.68849 ]
[.08271 .71771 0 10.3115 ]
[.15035 .79185 -10 -3.53407 ]
[.15035 .79185 0 10.4659 ]
[.22249 .87091 -16 -3.36453 ]
[.22249 .87091 0 10.6355 ]
[.09434 .81958 -15.625 -3.53407 ]
[.09434 .81958 0 10.4659 ]
[.43053 .86262 -0.07895 0 ]
[.43053 .86262 30.1711 14 ]
[.64535 .74667 0 -0.83834 ]
[.64535 .74667 10 13.1617 ]
[.84075 .64117 0 -1.51984 ]
[.84075 .64117 22 12.4802 ]
[.69226 .78797 0 -0.83834 ]
[.69226 .78797 15.625 13.1617 ]
[.00604 .45918 -16 -4.10493 ]
[.00604 .45918 0 9.89507 ]
[.01379 .51218 -16 -4.02541 ]
[.01379 .51218 0 9.97459 ]
[.0213 .56352 -22 -3.94815 ]
[.0213 .56352 0 10.0518 ]
[.02857 .61326 -22 -3.87306 ]
[.02857 .61326 0 10.1269 ]
[.03563 .66149 -22 -3.80004 ]
[.03563 .66149 0 10.2 ]
[-0.03844 .57208 -14.3125 -3.97263 ]
[-0.03844 .57208 0 10.0274 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.0478 .66178 m
.28863 .9254 L
s
.25 Mabswid
.09401 .71237 m
.09966 .70969 L
s
gsave
.08271 .71771 -85.25 -7.68849 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.16156 .7863 m
.16716 .78353 L
s
gsave
.15035 .79185 -71 -7.53407 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.23358 .86515 m
.23913 .86227 L
s
gsave
.22249 .87091 -77 -7.36453 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.10718 .72678 m
.11057 .72517 L
s
.12052 .74138 m
.1239 .73975 L
s
.13402 .75617 m
.1374 .75453 L
s
.1477 .77114 m
.15107 .76949 L
s
.17559 .80166 m
.17894 .79999 L
s
.1898 .81723 m
.19315 .81554 L
s
.20421 .83299 m
.20755 .83129 L
s
.2188 .84896 m
.22213 .84725 L
s
.081 .69813 m
.0844 .69653 L
s
.06815 .68406 m
.07156 .68248 L
s
.05546 .67017 m
.05887 .6686 L
s
.24857 .88155 m
.25189 .87981 L
s
.26375 .89817 m
.26706 .89641 L
s
.27914 .91502 m
.28245 .91325 L
s
gsave
.09434 .81958 -76.625 -7.53407 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.28863 .9254 m
.93524 .57729 L
s
.25 Mabswid
.42172 .85376 m
.41731 .84932 L
s
gsave
.43053 .86262 -61.0789 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.63597 .73841 m
.63127 .73428 L
s
gsave
.64535 .74667 -61 -4.83834 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.8309 .63346 m
.82598 .62961 L
s
gsave
.84075 .64117 -61 -5.51984 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.46625 .82978 m
.46357 .82716 L
s
.50991 .80627 m
.5072 .80369 L
s
.55274 .78322 m
.54999 .78067 L
s
.59475 .7606 m
.59197 .75809 L
s
.67641 .71664 m
.67357 .71419 L
s
.71611 .69526 m
.71323 .69286 L
s
.75508 .67429 m
.75217 .67191 L
s
.79333 .65369 m
.79041 .65135 L
s
.37629 .87821 m
.37369 .87551 L
s
.32995 .90316 m
.32739 .90042 L
s
.8678 .6136 m
.86482 .61132 L
s
.90405 .59409 m
.90105 .59184 L
s
gsave
.69226 .78797 -61 -4.83834 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.0116 .41327 m
.0478 .66178 L
s
.25 Mabswid
.01759 .4544 m
.02336 .45202 L
s
gsave
.00604 .45918 -77 -8.10493 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.02529 .50729 m
.03105 .50485 L
s
gsave
.01379 .51218 -77 -8.02541 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.03276 .55852 m
.03849 .55602 L
s
gsave
.0213 .56352 -83 -7.94815 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.03999 .60816 m
.04569 .60561 L
s
gsave
.02857 .61326 -83 -7.87306 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.047 .65629 m
.05268 .65369 L
s
gsave
.03563 .66149 -83 -7.80004 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.01915 .46512 m
.02261 .46368 L
s
.0207 .47576 m
.02416 .47432 L
s
.02224 .48634 m
.0257 .48489 L
s
.02377 .49685 m
.02723 .49539 L
s
.02681 .51767 m
.03025 .5162 L
s
.02831 .52798 m
.03175 .5265 L
s
.0298 .53823 m
.03324 .53674 L
s
.03128 .54841 m
.03472 .54691 L
s
.03422 .56857 m
.03766 .56707 L
s
.03568 .57856 m
.03911 .57705 L
s
.03712 .58849 m
.04055 .58697 L
s
.03856 .59836 m
.04199 .59683 L
s
.04141 .61791 m
.04483 .61637 L
s
.04282 .62759 m
.04624 .62605 L
s
.04422 .63722 m
.04764 .63567 L
s
.04561 .64678 m
.04903 .64523 L
s
.01602 .44362 m
.01949 .44219 L
s
.01444 .43276 m
.01791 .43134 L
s
.01285 .42184 m
.01632 .42043 L
s
gsave
-0.03844 .57208 -75.3125 -7.97263 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.0116 .41327 m
.0478 .66178 L
s
.0478 .66178 m
.66543 .3787 L
s
.66543 .3787 m
.6769 .14397 L
s
.6769 .14397 m
.0116 .41327 L
s
.26955 .66897 m
.96867 .33233 L
s
.96867 .33233 m
.93524 .57729 L
s
.93524 .57729 m
.28863 .9254 L
s
.28863 .9254 m
.26955 .66897 L
s
.0116 .41327 m
.0478 .66178 L
s
.0478 .66178 m
.28863 .9254 L
s
.28863 .9254 m
.26955 .66897 L
s
.26955 .66897 m
.0116 .41327 L
s
.6769 .14397 m
.96867 .33233 L
s
.96867 .33233 m
.93524 .57729 L
s
.93524 .57729 m
.66543 .3787 L
s
.66543 .3787 m
.6769 .14397 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.75028 .4515 m .72003 .42913 L .65634 .45945 L p 0 .225 .528 r
F P
0 g
s
.72003 .42913 m .75028 .4515 L .73311 .44098 L p 0 .05 .1 r
F P
0 g
s
.65634 .45945 m .72003 .42913 L .70275 .41849 L closepath p 0 .461 .92 r
F P
0 g
s
.73311 .44098 m .70275 .41849 L .72003 .42913 L p 0 .05 .1 r
F P
0 g
s
.70275 .41849 m .73311 .44098 L .71192 .42798 L p 0 .05 .1 r
F P
0 g
s
.70275 .41849 m .68141 .40536 L .65792 .42601 L p 0 .461 .92 r
F P
0 g
s
.65792 .42601 m .65634 .45945 L .70275 .41849 L p 0 .461 .92 r
F P
0 g
s
.71192 .42798 m .68141 .40536 L .70275 .41849 L p 0 .05 .1 r
F P
0 g
s
.65634 .45945 m .68632 .48251 L .75028 .4515 L p 0 .225 .528 r
F P
0 g
s
.717 .50609 m .7812 .47438 L .75028 .4515 L p 0 .225 .528 r
F P
0 g
s
.75028 .4515 m .68632 .48251 L .717 .50609 L p 0 .225 .528 r
F P
0 g
s
.73311 .44098 m .75028 .4515 L .7812 .47438 L p 0 .05 .1 r
F P
0 g
s
.68632 .48251 m .65634 .45945 L .65792 .42601 L p 0 .251 .867 r
F P
0 g
s
.65634 .45945 m .65953 .39189 L .5 .4654 L p 0 .461 .92 r
F P
0 g
s
.5 .4654 m .5 .53389 L .65634 .45945 L p 0 .461 .92 r
F P
0 g
s
.65634 .45945 m .717 .50609 L .72153 .43794 L p 0 .251 .867 r
F P
0 g
s
.65792 .42601 m .68141 .40536 L .65953 .39189 L closepath p 0 .461 .92 r
F P
0 g
s
.72153 .43794 m .65953 .39189 L .65634 .45945 L p 0 .251 .867 r
F P
0 g
s
.65634 .45945 m .5 .53389 L .55923 .58402 L p 0 .225 .528 r
F P
0 g
s
.55923 .58402 m .717 .50609 L .65634 .45945 L p 0 .225 .528 r
F P
0 g
s
.7812 .47438 m .76417 .46398 L .73311 .44098 L p 0 .05 .1 r
F P
0 g
s
.71192 .42798 m .73311 .44098 L .76417 .46398 L p 0 .05 .1 r
F P
0 g
s
.76417 .46398 m .7812 .47438 L .717 .50609 L closepath p 0 .467 .923 r
F P
0 g
s
.74837 .53022 m .81283 .49778 L .7812 .47438 L p 0 .225 .528 r
F P
0 g
s
.7812 .47438 m .717 .50609 L .74837 .53022 L p 0 .225 .528 r
F P
0 g
s
.717 .50609 m .7812 .47438 L .76417 .46398 L closepath p 0 .467 .923 r
F P
0 g
s
.76417 .46398 m .7812 .47438 L .81283 .49778 L p 0 .05 .1 r
F P
0 g
s
.68141 .40536 m .71192 .42798 L .69018 .41465 L p 0 .05 .1 r
F P
0 g
s
.69018 .41465 m .65953 .39189 L .68141 .40536 L p 0 .05 .1 r
F P
0 g
s
.65792 .42601 m .68823 .44893 L .68632 .48251 L p 0 .251 .867 r
F P
0 g
s
.68823 .44893 m .65792 .42601 L .65953 .39189 L p 0 .251 .867 r
F P
0 g
s
.71924 .47237 m .717 .50609 L .68632 .48251 L p 0 .251 .867 r
F P
0 g
s
.68632 .48251 m .68823 .44893 L .71924 .47237 L p 0 .251 .867 r
F P
0 g
s
.76417 .46398 m .74312 .45112 L .71192 .42798 L p 0 .05 .1 r
F P
0 g
s
.76417 .46398 m .717 .50609 L .71924 .47237 L p 0 .467 .923 r
F P
0 g
s
.71924 .47237 m .74312 .45112 L .76417 .46398 L p 0 .467 .923 r
F P
0 g
s
.81283 .49778 m .79593 .4875 L .76417 .46398 L p 0 .05 .1 r
F P
0 g
s
.717 .50609 m .76417 .46398 L .74312 .45112 L p 0 .467 .923 r
F P
0 g
s
.74312 .45112 m .76417 .46398 L .79593 .4875 L p 0 .05 .1 r
F P
0 g
s
.84518 .52171 m .81283 .49778 L .74837 .53022 L p 0 .225 .528 r
F P
0 g
s
.82843 .51157 m .79593 .4875 L .81283 .49778 L p 0 .05 .1 r
F P
0 g
s
.81283 .49778 m .84518 .52171 L .82843 .51157 L p 0 .05 .1 r
F P
0 g
s
.69018 .41465 m .71192 .42798 L .74312 .45112 L p 0 .05 .1 r
F P
0 g
s
.65953 .39189 m .69018 .41465 L .68823 .44893 L p 0 .251 .867 r
F P
0 g
s
.72153 .43794 m .71924 .47237 L .68823 .44893 L p 0 .251 .867 r
F P
0 g
s
.68823 .44893 m .69018 .41465 L .72153 .43794 L p 0 .251 .867 r
F P
0 g
s
.52351 .45456 m .58426 .5036 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.57742 .42972 m .57742 .42972 L p .63869 .47757 L .437 0 0 r
F P
0 g
s
.63729 .51061 m .63729 .51061 L .63579 .5462 L 0 .467 .923 r
F
.717 .50609 m .63579 .5462 L p .63729 .51061 L F P
0 g
s
.57742 .42972 m .52351 .45456 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.72153 .43794 m .717 .50609 L p .63729 .51061 L 0 .467 .923 r
F P
0 g
s
.63843 .48368 m .72153 .43794 L .63729 .51061 L 0 .467 .923 r
F
.58426 .5036 m .72153 .43794 L .584 .51363 L F
.63869 .47757 m .72153 .43794 L .72153 .43794 L p F P
0 g
s
.57742 .42972 m .65953 .39189 L p .60915 .45451 L 0 .218 .512 r
F P
0 g
s
.60915 .45451 m .65953 .39189 L .63869 .47757 L 0 .218 .512 r
F
.64014 .44314 m .64014 .44314 L .64162 .40797 L .437 0 0 r
F
.56051 .51496 m .63869 .47757 L .56051 .51496 L 0 .467 .923 r
F
.584 .51363 m .63843 .48368 L .63729 .51061 L F
.78048 .55491 m .717 .50609 L .55923 .58402 L p 0 .225 .528 r
F P
0 g
s
.717 .50609 m .72153 .43794 L p .63869 .47757 L 0 .467 .923 r
F P
0 g
s
.58426 .5036 m .63755 .5046 L .63869 .47757 L 0 .467 .923 r
F
.63755 .5046 m .717 .50609 L .63869 .47757 L F
.584 .51363 m .63729 .51061 L .58426 .5036 L F
.63729 .51061 m .717 .50609 L .63755 .5046 L F
.63729 .51061 m .63755 .5046 L .58426 .5036 L F
.63729 .51061 m .63729 .51061 L .63579 .5462 L F
.63579 .5462 m .63579 .5462 L p .63729 .51061 L F P
0 g
s
.63579 .5462 m .63579 .5462 L p .63729 .51061 L 0 .467 .923 r
F P
0 g
s
.584 .51363 m .63729 .51061 L .58275 .5619 L 0 .467 .923 r
F
.63579 .5462 m .55923 .58402 L p .63729 .51061 L F P
0 g
s
.58248 .57253 m .717 .50609 L p .584 .51363 L 0 .467 .923 r
F P
0 g
s
.58426 .5036 m .648 .55505 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.63869 .47757 m .70293 .52773 L p .70293 .52773 L .437 0 0 r
F P
0 g
s
.70293 .52773 m .63869 .47757 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.74312 .45112 m .71924 .47237 L .717 .50609 L p 0 .467 .923 r
F P
0 g
s
.717 .50609 m .71924 .47237 L .75097 .49635 L p 0 .251 .867 r
F P
0 g
s
.74837 .53022 m .78048 .55491 L .84518 .52171 L p 0 .225 .528 r
F P
0 g
s
.71924 .47237 m .72153 .43794 L .74312 .45112 L closepath p 0 .467 .923 r
F P
0 g
s
.74312 .45112 m .72153 .43794 L .71924 .47237 L closepath p 0 .467 .923 r
F P
0 g
s
.72153 .43794 m .717 .50609 L .78048 .55491 L p 0 .251 .867 r
F P
0 g
s
.75363 .46177 m .75097 .49635 L .71924 .47237 L p 0 .251 .867 r
F P
0 g
s
.71924 .47237 m .72153 .43794 L .75363 .46177 L p 0 .251 .867 r
F P
0 g
s
.78048 .55491 m .78649 .48617 L .72153 .43794 L p 0 .251 .867 r
F P
0 g
s
.78345 .5209 m .75097 .49635 L .75363 .46177 L p 0 .251 .867 r
F P
0 g
s
.75363 .46177 m .78649 .48617 L .78345 .5209 L p 0 .251 .867 r
F P
0 g
s
.72153 .43794 m .78649 .48617 L p .6689 .50115 L 0 .218 .512 r
F P
0 g
s
.648 .55505 m .70293 .52773 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.59318 .5108 m .64417 .48185 L .6689 .50115 L 0 .218 .512 r
F
.64417 .48185 m .72153 .43794 L .6689 .50115 L F
.72153 .43794 m .72153 .43794 L p .63869 .47757 L 0 .467 .923 r
F P
0 g
s
.58426 .5036 m .63869 .47757 L p .59318 .5108 L 0 .218 .512 r
F P
0 g
s
.63869 .47757 m .72153 .43794 L p .64417 .48185 L 0 .218 .512 r
F P
0 g
s
.63869 .47757 m .64417 .48185 L .59318 .5108 L 0 .218 .512 r
F
.63869 .47757 m .56051 .51496 L p .56051 .51496 L 0 .467 .923 r
F P
0 g
s
.55923 .58402 m .56051 .51496 L p .584 .51363 L 0 .467 .923 r
F P
0 g
s
.584 .51363 m .58275 .5619 L .55923 .58402 L 0 .467 .923 r
F
.56051 .51496 m .58248 .57253 L .584 .51363 L F
.56051 .51496 m .58426 .5036 L .584 .51363 L F
.56051 .51496 m .584 .51363 L .58426 .5036 L F
.62402 .56698 m .648 .55505 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.56051 .51496 m .62402 .56698 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.648 .55505 m .58426 .5036 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.56051 .51496 m .58426 .5036 L p .59318 .5108 L 0 .218 .512 r
F P
0 g
s
.5 .4654 m .56051 .51496 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.52351 .45456 m .5 .4654 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.58426 .5036 m .52351 .45456 L p .57242 .50927 L .762 0 0 r
F P
0 g
s
.62402 .56698 m .56051 .51496 L p .59318 .5108 L 0 .218 .512 r
F P
0 g
s
.75097 .49635 m .74837 .53022 L .717 .50609 L p 0 .251 .867 r
F P
0 g
s
.78048 .55491 m .74837 .53022 L .75097 .49635 L p 0 .251 .867 r
F P
0 g
s
.75097 .49635 m .78345 .5209 L .78048 .55491 L p 0 .251 .867 r
F P
0 g
s
.6689 .50115 m .68229 .49945 L .70293 .52773 L 0 .218 .512 r
F
.78649 .48617 m .70293 .52773 L p .68229 .49945 L F P
0 g
s
.55923 .58402 m .62132 .63657 L .78048 .55491 L p 0 .225 .528 r
F P
0 g
s
.62132 .63657 m .62402 .56698 L p .64753 .56517 L 0 .473 .927 r
F P
0 g
s
.62402 .56698 m .78649 .48617 L .78649 .48617 L p 0 .473 .927 r
F P
0 g
s
.78649 .48617 m .78048 .55491 L p .62402 .56698 L 0 .473 .927 r
F P
0 g
s
.62402 .56698 m .78649 .48617 L .62402 .56698 L 0 .473 .927 r
F
.78048 .55491 m .64479 .62453 L p .64753 .56517 L F P
0 g
s
.64479 .62453 m .62132 .63657 L p .64753 .56517 L 0 .473 .927 r
F P
0 g
s
.6251 .56858 m .65574 .56619 L .648 .55505 L .762 0 0 r
F
.6251 .56858 m .648 .55505 L .62402 .56698 L F
.61528 .50799 m .6689 .50115 L .648 .55505 L 0 .218 .512 r
F
.65953 .39189 m .72153 .43794 L .63869 .47757 L p F P
0 g
s
.70293 .52773 m .70733 .4575 L .64162 .40797 L p .437 0 0 r
F P
0 g
s
.64014 .44314 m .63869 .47757 L .70293 .52773 L .437 0 0 r
F
.64014 .44314 m .70293 .52773 L .64162 .40797 L F
.64014 .44314 m .64014 .44314 L .64162 .40797 L F
.64014 .44314 m .64162 .40797 L .64162 .40797 L F
.64014 .44314 m .64162 .40797 L .64162 .40797 L F
.64162 .40797 m .57902 .36079 L p .64014 .44314 L F P
0 g
s
.57902 .36079 m .57742 .42972 L p .63869 .47757 L .437 0 0 r
F P
0 g
s
.57902 .36079 m .63869 .47757 L .64014 .44314 L .437 0 0 r
F
.59318 .5108 m .61528 .50799 L .648 .55505 L 0 .218 .512 r
F
.57902 .36079 m .66936 .42888 L p .60188 .41596 L .757 0 0 r
F P
0 g
s
.66936 .42888 m .70733 .4575 L p .66739 .44177 L .757 0 0 r
F P
0 g
s
.60188 .41596 m .66936 .42888 L .66739 .44177 L .757 0 0 r
F
.70293 .52773 m .648 .55505 L p .6689 .50115 L 0 .218 .512 r
F P
0 g
s
.65125 .4845 m .648 .55505 L .70293 .52773 L .962 0 0 r
F
.70293 .52773 m .648 .55505 L .65125 .4845 L p F P
0 g
s
.64014 .44314 m .63869 .47757 L .64014 .44314 L .437 0 0 r
F
.64014 .44314 m .63875 .47619 L .64014 .44314 L F
.63875 .47619 m .63869 .47757 L .64014 .44314 L F
.6341 .4607 m .66739 .44177 L .65125 .4845 L .757 0 0 r
F
.60188 .41596 m .63914 .43064 L .6341 .4607 L F
.63914 .43064 m .66739 .44177 L .6341 .4607 L F
.63869 .47757 m .57742 .42972 L p .61164 .4905 L .762 0 0 r
F P
0 g
s
.5754 .49645 m .57742 .42972 L .60915 .45451 L 0 .218 .512 r
F
.53643 .34165 m .48416 .40591 L .5357 .41031 L .754 0 0 r
F
.57902 .36079 m .5357 .41031 L .57742 .42972 L .58 0 0 r
F
.57902 .36079 m .53643 .34165 L .5357 .41031 L F
.57742 .42972 m .57902 .36079 L .524 .38528 L p .951 0 0 r
F P
0 g
s
.524 .38528 m .57902 .36079 L .57742 .42972 L .951 0 0 r
F
.57848 .42776 m .524 .38528 L p .55799 .39867 L .757 0 0 r
F P
0 g
s
.524 .38528 m .56624 .36647 L p .60188 .41596 L .757 0 0 r
F P
0 g
s
.52351 .45456 m .57742 .42972 L p .5754 .49645 L 0 .218 .512 r
F P
0 g
s
.63869 .47757 m .58426 .5036 L p .60915 .45451 L 0 .218 .512 r
F P
0 g
s
.58426 .5036 m .56051 .51496 L p .5754 .49645 L 0 .218 .512 r
F P
0 g
s
.5754 .49645 m .60915 .45451 L .58426 .5036 L 0 .218 .512 r
F
.58607 .43367 m .58426 .5036 L .58607 .43367 L .417 0 0 r
F
.52351 .45456 m .57742 .42972 L .5357 .41031 L .762 0 0 r
F
.50952 .44789 m .5357 .41031 L .48416 .40591 L F
.52351 .45456 m .5357 .41031 L .50952 .44789 L F
.524 .38528 m .52351 .45456 L .57742 .42972 L p .951 0 0 r
F P
0 g
s
.524 .38528 m .57742 .42972 L .52351 .45456 L .951 0 0 r
F
.52351 .45456 m .58426 .5036 L p .55466 .40918 L .417 0 0 r
F P
0 g
s
.53643 .34165 m .48384 .33732 L .48416 .40591 L .754 0 0 r
F
.51468 .37181 m .48384 .33732 L .53643 .34165 L .757 0 0 r
F
.50972 .3787 m .5066 .37371 L .51468 .37181 L F
.5066 .37371 m .48384 .33732 L .51468 .37181 L F
.49201 .44636 m .48416 .40591 L .43556 .41753 L .762 0 0 r
F
.50952 .44789 m .48416 .40591 L .49201 .44636 L F
.49201 .44636 m .43556 .41753 L .47556 .45038 L F
.49185 .37719 m .49201 .44636 L .47556 .45038 L .883 0 0 r
F
.49185 .37719 m .47556 .45038 L .49201 .44636 L F
.48384 .33732 m .43556 .41753 L .48416 .40591 L .882 0 0 r
F
.48384 .33732 m .43423 .34877 L .43556 .41753 L F
.49122 .37405 m .43423 .34877 L .48384 .33732 L .757 0 0 r
F
.49185 .37719 m .48818 .37538 L .49122 .37405 L F
.48818 .37538 m .43423 .34877 L .49122 .37405 L F
.43423 .34877 m .43556 .41753 L .47556 .45038 L p .407 0 0 r
F P
0 g
s
.43556 .41753 m .43423 .34877 L .31985 .39776 L p .946 0 0 r
F P
0 g
s
.47505 .38115 m .43556 .41753 L .43423 .34877 L .407 0 0 r
F
.47556 .45038 m .47505 .38115 L .43423 .34877 L p F P
0 g
s
.31985 .39776 m .43423 .34877 L .45301 .36366 L p .757 0 0 r
F P
0 g
s
.45301 .36366 m .47505 .38115 L p .42119 .38692 L .757 0 0 r
F P
0 g
s
.31985 .39776 m .45301 .36366 L .42119 .38692 L .757 0 0 r
F
.47556 .45038 m .43556 .41753 L .32357 .46721 L p .762 0 0 r
F P
0 g
s
.31985 .39776 m .32357 .46721 L .43556 .41753 L p .946 0 0 r
F P
0 g
s
.32357 .46721 m .3627 .50172 L .47556 .45038 L p .762 0 0 r
F P
0 g
s
.3627 .50172 m .32357 .46721 L .31985 .39776 L p .36 0 0 r
F P
0 g
s
.3627 .50172 m .32357 .46721 L .28782 .49345 L .762 0 0 r
F
.35976 .43182 m .32357 .46721 L .3627 .50172 L .36 0 0 r
F
.3627 .50172 m .28782 .49345 L .35085 .51069 L .762 0 0 r
F
.31985 .39776 m .35976 .43182 L .3627 .50172 L p .36 0 0 r
F P
0 g
s
.35976 .43182 m .3627 .50172 L .35085 .51069 L 1 0 0 r
F
.35976 .43182 m .35085 .51069 L .3627 .50172 L F
.35976 .43182 m .31985 .39776 L .32357 .46721 L .36 0 0 r
F
.35235 .4255 m .31985 .39776 L p .36237 .39321 L .757 0 0 r
F P
0 g
s
.31985 .39776 m .28782 .49345 L .32357 .46721 L 1 0 0 r
F
.31985 .39776 m .28329 .42365 L .28782 .49345 L F
.35235 .4255 m .33065 .42871 L .31985 .39776 L .757 0 0 r
F
.35069 .43085 m .33065 .42871 L .35235 .4255 L F
.28329 .42365 m .27656 .52745 L .28782 .49345 L 1 0 0 r
F
.28329 .42365 m .27171 .45722 L .27656 .52745 L F
.33578 .43754 m .27171 .45722 L .28329 .42365 L .757 0 0 r
F
.34764 .44067 m .33874 .44261 L .33578 .43754 L F
.33874 .44261 m .27171 .45722 L .33578 .43754 L F
.35976 .43182 m .34764 .44067 L .31533 .43213 L F
.30871 .42637 m .31533 .43213 L .28329 .42365 L F
.35976 .43182 m .31533 .43213 L .30871 .42637 L F
.35976 .43182 m .35085 .51069 L .34764 .44067 L 1 0 0 r
F
.35371 .43623 m .34764 .44067 L .35085 .51069 L F
.35371 .43623 m .35085 .51069 L .35976 .43182 L F
.47034 .58723 m .44138 .5618 L .3812 .59045 L p 0 .225 .528 r
F P
0 g
s
.3812 .59045 m .44138 .5618 L .44117 .55053 L p 0 .461 .92 r
F P
0 g
s
.47556 .45038 m .3627 .50172 L .35976 .43182 L p .949 0 0 r
F P
0 g
s
.49311 .46479 m .47556 .45038 L .3627 .50172 L p .762 0 0 r
F P
0 g
s
.35976 .43182 m .35235 .4255 L p .35918 .42303 L .757 0 0 r
F P
0 g
s
.35918 .42303 m .38411 .41402 L .36301 .42944 L .757 0 0 r
F
.35918 .42303 m .36301 .42944 L .35976 .43182 L F
.38411 .41402 m .3858 .41341 L .36304 .4295 L F
.36301 .42944 m .36304 .4295 L .35976 .43182 L F
.38411 .41402 m .36304 .4295 L .36301 .42944 L F
.3858 .41341 m .45708 .38765 L .38355 .42102 L F
.3858 .41341 m .38355 .42102 L .35976 .43182 L F
.45242 .3911 m .38343 .42141 L p .45708 .38765 L F P
0 g
s
.38343 .42141 m .35976 .43182 L p .38355 .42102 L .757 0 0 r
F P
0 g
s
.45708 .38765 m .38343 .42141 L .38355 .42102 L .757 0 0 r
F
.36237 .39321 m .46429 .38231 L .35235 .4255 L F
.46429 .38231 m .47505 .38115 L .45708 .38765 L F
.46429 .38231 m .45708 .38765 L .35235 .4255 L F
.47505 .38115 m .47556 .45038 L .43556 .41753 L .407 0 0 r
F
.35976 .43182 m .47505 .38115 L .47556 .45038 L p .949 0 0 r
F P
0 g
s
.36631 .50008 m .4534 .46046 L p .36066 .36191 L .949 0 0 r
F P
0 g
s
.4534 .46046 m .47556 .45038 L p .45302 .43302 L .949 0 0 r
F P
0 g
s
.36066 .36191 m .4534 .46046 L .45302 .43302 L .949 0 0 r
F
.35669 .35885 m .3627 .50172 L .36631 .50008 L p F P
0 g
s
.35669 .35885 m .36631 .50008 L .36066 .36191 L .949 0 0 r
F
.3627 .50172 m .37988 .51687 L .49311 .46479 L p .762 0 0 r
F P
0 g
s
.3769 .43651 m .3627 .50172 L .37988 .51687 L .36 0 0 r
F
.49311 .46479 m .37988 .51687 L .37458 .37359 L p .951 0 0 r
F P
0 g
s
.47556 .45038 m .47505 .38115 L p .41814 .40616 L .949 0 0 r
F P
0 g
s
.47505 .38115 m .45242 .3911 L p .45708 .38765 L .757 0 0 r
F P
0 g
s
.49185 .37719 m .47505 .38115 L .43423 .34877 L .757 0 0 r
F
.47452 .30898 m .35669 .35885 L p .41814 .40616 L .949 0 0 r
F P
0 g
s
.47505 .38115 m .47452 .30898 L p .41814 .40616 L .949 0 0 r
F P
0 g
s
.5066 .37371 m .49185 .37719 L .48384 .33732 L .757 0 0 r
F
.50972 .3787 m .49185 .37719 L .5066 .37371 L F
.49167 .30508 m .47452 .30898 L .47505 .38115 L .883 0 0 r
F
.49185 .37719 m .47556 .45038 L .47505 .38115 L F
.48346 .37917 m .47505 .38115 L .47556 .45038 L F
.49167 .30508 m .47505 .38115 L .48346 .37917 L F
.49167 .30508 m .48346 .37917 L .49185 .37719 L F
.48346 .37917 m .47556 .45038 L .49185 .37719 L F
.50972 .3787 m .49201 .44636 L .49185 .37719 L .752 0 0 r
F
.50972 .3787 m .50952 .44789 L .49201 .44636 L F
.49547 .46421 m .49201 .44636 L .47556 .45038 L .762 0 0 r
F
.50992 .30656 m .49201 .44636 L .50952 .44789 L .752 0 0 r
F
.50992 .30656 m .49167 .30508 L .49201 .44636 L F
.498 .46443 m .49201 .44636 L .49547 .46421 L .762 0 0 r
F
.498 .46443 m .50952 .44789 L .49201 .44636 L F
.49547 .46421 m .47556 .45038 L .49311 .46479 L F
.47556 .45038 m .49311 .46479 L p .48264 .37708 L .407 0 0 r
F P
0 g
s
.524 .38528 m .53643 .34165 L .57902 .36079 L .757 0 0 r
F
.524 .38528 m .50972 .3787 L .53643 .34165 L F
.52452 .31303 m .524 .38528 L p .55466 .40918 L .417 0 0 r
F P
0 g
s
.524 .38528 m .52351 .45456 L p .55466 .40918 L .417 0 0 r
F P
0 g
s
.58607 .43367 m .648 .55505 L .58607 .43367 L .417 0 0 r
F
.648 .55505 m .65125 .4845 L p .58607 .43367 L F P
0 g
s
.57848 .42776 m .60188 .41596 L .6341 .4607 L .757 0 0 r
F
.65125 .4845 m .63256 .46992 L p .6341 .4607 L F P
0 g
s
.63256 .46992 m .57848 .42776 L p .6341 .4607 L .757 0 0 r
F P
0 g
s
.648 .55505 m .62402 .56698 L p .59318 .5108 L 0 .218 .512 r
F P
0 g
s
.58607 .43367 m .58435 .50032 L .648 .55505 L .417 0 0 r
F
.58426 .5036 m .58426 .5036 L p .58435 .50032 L F P
0 g
s
.58426 .5036 m .648 .55505 L p .58435 .50032 L .417 0 0 r
F P
0 g
s
.58515 .46901 m .648 .55505 L .58426 .5036 L .417 0 0 r
F
.648 .55505 m .58426 .5036 L p .58426 .5036 L F P
0 g
s
.58426 .5036 m .6389 .54771 L .58426 .5036 L .417 0 0 r
F
.6389 .54771 m .648 .55505 L .58426 .5036 L F
.65125 .4845 m .648 .55505 L p .58515 .46901 L F P
0 g
s
.65125 .4845 m .648 .55505 L p .63904 .49038 L .962 0 0 r
F P
0 g
s
.648 .55505 m .62402 .56698 L .62676 .49629 L p .962 0 0 r
F P
0 g
s
.63904 .49038 m .648 .55505 L .62676 .49629 L .962 0 0 r
F
.65125 .4845 m .65465 .41077 L p .58607 .43367 L .417 0 0 r
F P
0 g
s
.58607 .43367 m .65125 .4845 L p .58515 .46901 L .417 0 0 r
F P
0 g
s
.62962 .4224 m .62402 .56698 L .648 .55505 L .962 0 0 r
F
.62731 .49708 m .6251 .56858 L .62402 .56698 L .164 0 0 r
F
.62787 .49787 m .6251 .56858 L .62731 .49708 L F
.62773 .49872 m .62482 .57029 L .6251 .56858 L .927 0 0 r
F
.62962 .4224 m .65465 .41077 L p .65125 .4845 L .962 0 0 r
F P
0 g
s
.62962 .4224 m .65125 .4845 L .63904 .49038 L .962 0 0 r
F
.62676 .49629 m .62962 .4224 L p .63904 .49038 L F P
0 g
s
.62962 .4224 m .648 .55505 L .65465 .41077 L .962 0 0 r
F
.63076 .42396 m .62787 .49787 L .62731 .49708 L .164 0 0 r
F
.63076 .42396 m .62731 .49708 L .62962 .4224 L F
.62731 .49708 m .62402 .56698 L .62676 .49629 L F
.62731 .49708 m .62676 .49629 L .62962 .4224 L F
.65574 .56619 m .70293 .52773 L .648 .55505 L .762 0 0 r
F
.65918 .49551 m .648 .55505 L .65574 .56619 L .18 0 0 r
F
.65918 .49551 m .65574 .56619 L .648 .55505 L F
.65827 .50143 m .65918 .49551 L .65574 .56619 L .907 0 0 r
F
.6552 .48999 m .65125 .4845 L .648 .55505 L .18 0 0 r
F
.6552 .48999 m .648 .55505 L .65918 .49551 L F
.62482 .57029 m .65574 .56619 L .6251 .56858 L .762 0 0 r
F
.62482 .57029 m .65394 .5782 L .65574 .56619 L F
.65736 .50738 m .65574 .56619 L .65394 .5782 L .907 0 0 r
F
.65827 .50143 m .65574 .56619 L .65736 .50738 L F
.65918 .49551 m .648 .55505 L .65125 .4845 L .18 0 0 r
F
.65574 .56619 m .72695 .56063 L .70293 .52773 L .762 0 0 r
F
.65736 .50738 m .65574 .56619 L .65918 .49551 L .907 0 0 r
F
.65736 .50738 m .65394 .5782 L .65574 .56619 L F
.64614 .51691 m .65394 .5782 L .65736 .50738 L 1 0 0 r
F
.56051 .51496 m .55936 .57674 L .58248 .57253 L p 0 .467 .923 r
F P
0 g
s
.55986 .54986 m .59088 .57569 L .59188 .54065 L p 0 .235 .864 r
F P
0 g
s
.59188 .54065 m .56051 .51496 L .55986 .54986 L p 0 .235 .864 r
F P
0 g
s
.62265 .60216 m .59088 .57569 L .5899 .60998 L p 0 .235 .864 r
F P
0 g
s
.5899 .60998 m .62132 .63657 L .62265 .60216 L p 0 .235 .864 r
F P
0 g
s
.59088 .57569 m .62265 .60216 L .62402 .56698 L p 0 .235 .864 r
F P
0 g
s
.62402 .56698 m .59188 .54065 L .59088 .57569 L p 0 .235 .864 r
F P
0 g
s
.56051 .51496 m .62402 .56698 L .62132 .63657 L p 0 .235 .864 r
F P
0 g
s
.55986 .54986 m .55923 .58402 L .5899 .60998 L p 0 .235 .864 r
F P
0 g
s
.5899 .60998 m .59088 .57569 L .55986 .54986 L p 0 .235 .864 r
F P
0 g
s
.62132 .63657 m .55923 .58402 L .56051 .51496 L p 0 .235 .864 r
F P
0 g
s
.5 .53389 m .52927 .55866 L .52958 .52464 L p 0 .235 .864 r
F P
0 g
s
.52958 .52464 m .52927 .55866 L .55923 .58402 L p 0 .235 .864 r
F P
0 g
s
.55923 .58402 m .55986 .54986 L .52958 .52464 L p 0 .235 .864 r
F P
0 g
s
.52958 .52464 m .55986 .54986 L .56051 .51496 L p 0 .235 .864 r
F P
0 g
s
.56051 .51496 m .55923 .58402 L .5 .53389 L p 0 .235 .864 r
F P
0 g
s
.52958 .52464 m .5 .5 L .5 .53389 L p 0 .235 .864 r
F P
0 g
s
.5299 .48988 m .5 .4654 L .5 .5 L p 0 .235 .864 r
F P
0 g
s
.5 .5 m .52958 .52464 L .5299 .48988 L p 0 .235 .864 r
F P
0 g
s
.56051 .51496 m .5299 .48988 L .52958 .52464 L p 0 .235 .864 r
F P
0 g
s
.5 .53389 m .5 .4654 L .56051 .51496 L p 0 .235 .864 r
F P
0 g
s
.5 .4654 m .5299 .48988 L .5 .50392 L p 0 .218 .512 r
F P
0 g
s
.5299 .48988 m .56051 .51496 L .53046 .52934 L p 0 .218 .512 r
F P
0 g
s
.55923 .58402 m .55986 .54986 L .5372 .54846 L p 0 .467 .923 r
F P
0 g
s
.55923 .58402 m .52927 .55866 L .47034 .58723 L p 0 .225 .528 r
F P
0 g
s
.5372 .54846 m .51398 .58183 L .55923 .58402 L p 0 .467 .923 r
F P
0 g
s
.55986 .54986 m .55923 .58402 L .51398 .58183 L p 0 .467 .923 r
F P
0 g
s
.55986 .54986 m .56051 .51496 L .5372 .54846 L closepath p 0 .467 .923 r
F P
0 g
s
.51398 .58183 m .5372 .54846 L .55986 .54986 L p 0 .467 .923 r
F P
0 g
s
.5372 .54846 m .56051 .51496 L .55986 .54986 L closepath p 0 .467 .923 r
F P
0 g
s
.5372 .54846 m .56051 .51496 L .53046 .52934 L closepath p 0 .467 .923 r
F P
0 g
s
.53046 .52934 m .56051 .51496 L .5372 .54846 L closepath p 0 .467 .923 r
F P
0 g
s
.56167 .55538 m .53046 .52934 L .56051 .51496 L p 0 .218 .512 r
F P
0 g
s
.56051 .51496 m .59188 .54065 L .56167 .55538 L p 0 .218 .512 r
F P
0 g
s
.62402 .56698 m .62265 .60216 L .60002 .60121 L closepath p 0 .473 .927 r
F P
0 g
s
.62325 .57165 m .65394 .5782 L .62482 .57029 L .762 0 0 r
F
.62325 .57165 m .64295 .58784 L .65394 .5782 L F
.64614 .51691 m .65394 .5782 L .64295 .58784 L 1 0 0 r
F
.64948 .44275 m .65176 .51213 L .64614 .51691 L F
.65176 .51213 m .65394 .5782 L .64614 .51691 L F
.62759 .49956 m .62482 .57029 L .62773 .49872 L .927 0 0 r
F
.62773 .49872 m .6251 .56858 L .62787 .49787 L F
.62035 .56398 m .56051 .51496 L p .56051 .51496 L .408 0 0 r
F P
0 g
s
.57231 .46549 m .58426 .5036 L .58462 .48965 L .417 0 0 r
F
.57231 .46549 m .58462 .48965 L .58607 .43367 L F
.55799 .39867 m .60188 .41596 L .57848 .42776 L .757 0 0 r
F
.52452 .31303 m .57231 .46549 L .58607 .43367 L .417 0 0 r
F
.58515 .46901 m .58515 .46901 L .58426 .5036 L F
.52351 .45456 m .524 .38528 L p .58515 .46901 L F P
0 g
s
.56051 .51496 m .52351 .45456 L .5754 .49645 L 0 .218 .512 r
F
.524 .38528 m .58607 .43367 L p .58515 .46901 L .417 0 0 r
F P
0 g
s
.56051 .51496 m .5 .4654 L .52351 .45456 L p 0 .218 .512 r
F P
0 g
s
.58426 .5036 m .52351 .45456 L p .58515 .46901 L .417 0 0 r
F P
0 g
s
.56051 .51496 m .5 .4654 L p .56182 .44489 L .408 0 0 r
F P
0 g
s
.524 .38528 m .50952 .44789 L .50972 .3787 L .571 0 0 r
F
.524 .38528 m .52351 .45456 L .50952 .44789 L F
.52452 .31303 m .50952 .44789 L .52351 .45456 L F
.52452 .31303 m .50992 .30656 L .50952 .44789 L F
.5 .4654 m .50952 .44789 L .498 .46443 L .762 0 0 r
F
.5 .4654 m .52351 .45456 L .50952 .44789 L F
.52452 .31303 m .5 .32355 L p .5021 .33528 L .951 0 0 r
F P
0 g
s
.5021 .33528 m .51775 .32852 L .52452 .31303 L .951 0 0 r
F
.5021 .33528 m .5058 .35588 L .51775 .32852 L F
.5058 .35588 m .51035 .38122 L .52427 .34782 L F
.52351 .45456 m .52407 .37514 L p .51035 .38122 L F P
0 g
s
.52407 .37514 m .52427 .34782 L p .51035 .38122 L .951 0 0 r
F P
0 g
s
.5 .4654 m .52351 .45456 L p .51035 .38122 L .951 0 0 r
F P
0 g
s
.50432 .38389 m .5 .4654 L .51035 .38122 L .951 0 0 r
F
.5 .35842 m .5 .4654 L p .5058 .35588 L F P
0 g
s
.5 .35842 m .52351 .45456 L .5 .4654 L .951 0 0 r
F
.5 .32355 m .5021 .33528 L .5 .33618 L F
.5 .32355 m .5 .35842 L p .5058 .35588 L F P
0 g
s
.5 .33618 m .5058 .35588 L .5 .35842 L .951 0 0 r
F
.5021 .33528 m .5058 .35588 L .5 .33618 L F
.5058 .35588 m .52351 .45456 L .5 .35842 L F
.5058 .35588 m .50432 .38389 L .51035 .38122 L F
.52427 .34782 m .52452 .31303 L p .5058 .35588 L F P
0 g
s
.5 .32355 m .52452 .31303 L .52427 .34782 L .951 0 0 r
F
.5058 .35588 m .52427 .34782 L .52351 .45456 L F
.5 .32355 m .52427 .34782 L .5058 .35588 L F
.5 .38581 m .5 .35842 L p .55296 .42751 L .408 0 0 r
F P
0 g
s
.5 .35842 m .5 .32355 L p .52939 .38124 L .408 0 0 r
F P
0 g
s
.52939 .38124 m .55296 .42751 L .5 .35842 L .408 0 0 r
F
.5 .39614 m .5 .38581 L p .50738 .39286 L F P
0 g
s
.50738 .39286 m .56182 .44489 L .5 .39614 L .408 0 0 r
F
.5 .4654 m .5 .39614 L p .56182 .44489 L F P
0 g
s
.55296 .42751 m .56182 .44489 L .5 .38581 L .408 0 0 r
F
.53038 .43701 m .5 .41276 L .5 .43929 L p 0 .235 .864 r
F P
0 g
s
.5 .41276 m .53038 .43701 L .53063 .40992 L p 0 .235 .864 r
F P
0 g
s
.53063 .40992 m .5 .38581 L .5 .41276 L p 0 .235 .864 r
F P
0 g
s
.5 .42375 m .53063 .40992 L .5 .38581 L p 0 .21 .492 r
F P
0 g
s
.5 .38581 m .53063 .40992 L .5 .42375 L p 0 .21 .492 r
F P
0 g
s
.5 .35842 m .5 .38581 L .53063 .40992 L p 0 .235 .864 r
F P
0 g
s
.56624 .36647 m .57902 .36079 L p .60188 .41596 L .757 0 0 r
F P
0 g
s
.65465 .41077 m .52452 .31303 L p .58607 .43367 L .417 0 0 r
F P
0 g
s
.5 .32355 m .62962 .4224 L .62402 .56698 L p .408 0 0 r
F P
0 g
s
.53063 .40992 m .53088 .38239 L .5 .35842 L p 0 .235 .864 r
F P
0 g
s
.5 .39614 m .53088 .38239 L .5 .35842 L p 0 .207 .485 r
F P
0 g
s
.47452 .30898 m .47477 .34373 L p .47906 .34707 L .407 0 0 r
F P
0 g
s
.47477 .34373 m .47498 .37103 L p .47906 .34707 L .407 0 0 r
F P
0 g
s
.53088 .38239 m .53113 .35441 L .50411 .33372 L p 0 .235 .864 r
F P
0 g
s
.50411 .33372 m .53113 .35441 L p .52337 .35343 L 0 .204 .478 r
F P
0 g
s
.49195 .32932 m .49033 .3413 L .47998 .32013 L .407 0 0 r
F
.47978 .34762 m .48521 .37911 L .47482 .35059 L F
.48855 .35445 m .48521 .37911 L .47978 .34762 L F
.48521 .37911 m .47556 .45038 L .47498 .37103 L F
.48521 .37911 m .47498 .37103 L .47482 .35059 L F
.49033 .3413 m .48855 .35445 L .47978 .34762 L F
.49033 .3413 m .47482 .35059 L .47452 .30898 L F
.47906 .34707 m .47498 .37103 L .48264 .37708 L F
.47498 .37103 m .47556 .45038 L p .48264 .37708 L F P
0 g
s
.49033 .3413 m .49311 .46479 L .47556 .45038 L .407 0 0 r
F
.49285 .33979 m .49311 .46479 L .49033 .3413 L F
.49195 .32932 m .49285 .33979 L .49033 .3413 L F
.49283 .32999 m .49285 .33979 L .49195 .32932 L F
.49281 .32296 m .49283 .32999 L .49195 .32932 L F
.49281 .32296 m .49195 .32932 L .47452 .30898 L F
.49195 .32932 m .47998 .32013 L .47452 .30898 L F
.49281 .32296 m .47452 .30898 L p .47906 .34707 L F P
0 g
s
.49311 .46479 m .49289 .35783 L p .47906 .34707 L .407 0 0 r
F P
0 g
s
.47906 .34707 m .47978 .34762 L .49281 .32296 L .407 0 0 r
F
.49285 .33979 m .49281 .32296 L p .47978 .34762 L F P
0 g
s
.37458 .37359 m .49281 .32296 L .49285 .33979 L p .951 0 0 r
F P
0 g
s
.48863 .33774 m .4784 .34392 L p .49284 .33691 L 0 .48 .858 r
F P
0 g
s
.37458 .37359 m .49285 .33979 L .38896 .38466 L .951 0 0 r
F
.4784 .34392 m .47312 .3471 L p .49284 .33691 L 0 .48 .858 r
F P
0 g
s
.49528 .3224 m .49547 .46421 L .49311 .46479 L .884 0 0 r
F
.49791 .32261 m .49547 .46421 L .49528 .3224 L .751 0 0 r
F
.49791 .32261 m .498 .46443 L .49547 .46421 L F
.5 .32355 m .498 .46443 L .49791 .32261 L .566 0 0 r
F
.5 .32355 m .5 .4654 L .498 .46443 L F
.49528 .3224 m .49311 .46479 L .49281 .32296 L .884 0 0 r
F
.47312 .3471 m .5 .3355 L p .49284 .33691 L 0 .48 .858 r
F P
0 g
s
.5 .3355 m .50411 .33372 L p .50208 .33425 L 0 .48 .858 r
F P
0 g
s
.50208 .33425 m .48863 .33774 L .5 .3355 L 0 .48 .858 r
F
.49289 .35783 m .49285 .33979 L p .47978 .34762 L .407 0 0 r
F P
0 g
s
.49285 .33979 m .49289 .35783 L p .38896 .38466 L .951 0 0 r
F P
0 g
s
.49289 .35783 m .49311 .46479 L p .40429 .39645 L .951 0 0 r
F P
0 g
s
.38896 .38466 m .49289 .35783 L .40429 .39645 L .951 0 0 r
F
.5 .43929 m .5 .41276 L .46978 .42633 L p 0 .461 .92 r
F P
0 g
s
.5 .41276 m .5 .38581 L .46954 .3993 L p 0 .461 .92 r
F P
0 g
s
.46954 .3993 m .46978 .42633 L .5 .41276 L p 0 .461 .92 r
F P
0 g
s
.46954 .3993 m .5 .42375 L p .5 .39078 L 0 .21 .492 r
F P
0 g
s
.49596 .3876 m .46954 .3993 L p .5 .39078 L 0 .21 .492 r
F P
0 g
s
.49163 .38952 m .49596 .3876 L p .49662 .39346 L 0 .21 .492 r
F P
0 g
s
.5 .42375 m .49163 .38952 L .49662 .39346 L 0 .21 .492 r
F
.5 .42375 m .46954 .3993 L .49163 .38952 L p F P
0 g
s
.5 .38581 m .49596 .3876 L p .5 .39078 L 0 .21 .492 r
F P
0 g
s
.49596 .3876 m .5 .38581 L p .5 .39078 L 0 .21 .492 r
F P
0 g
s
.5 .42375 m .49596 .3876 L .5 .39078 L 0 .21 .492 r
F
.46929 .37183 m .46954 .3993 L .5 .38581 L p 0 .461 .92 r
F P
0 g
s
.5 .38581 m .5 .35842 L .46929 .37183 L p 0 .461 .92 r
F P
0 g
s
.5 .39614 m .46929 .37183 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.53088 .38239 m .52678 .38422 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.52678 .38422 m .5 .39614 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.46909 .34953 m .4959 .33795 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.46929 .37183 m .5 .39614 L p .5 .36336 L 0 .207 .485 r
F P
0 g
s
.5 .35842 m .49593 .3602 L p .5 .36336 L 0 .207 .485 r
F P
0 g
s
.49593 .3602 m .46929 .37183 L p .5 .36336 L 0 .207 .485 r
F P
0 g
s
.47312 .3471 m .46909 .34953 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.49593 .3602 m .5 .35842 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.46929 .37183 m .49593 .3602 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.5 .35842 m .53088 .38239 L p .52263 .38098 L 0 .207 .485 r
F P
0 g
s
.5 .35842 m .53088 .38239 L p .50411 .33372 L 0 .235 .864 r
F P
0 g
s
.50411 .33372 m .5 .33618 L .5 .35842 L p 0 .235 .864 r
F P
0 g
s
.46909 .34953 m .46929 .37183 L .5 .35842 L p 0 .461 .92 r
F P
0 g
s
.5 .35842 m .5 .33618 L .46909 .34953 L p 0 .461 .92 r
F P
0 g
s
.47312 .3471 m .5 .36808 L p .50357 .33823 L 0 .204 .478 r
F P
0 g
s
.5 .33618 m .50411 .33372 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.50411 .33372 m .5 .3355 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.50411 .33372 m .5 .3355 L p .50357 .33823 L 0 .204 .478 r
F P
0 g
s
.4959 .33795 m .5 .33618 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.5 .3355 m .47312 .3471 L p .49945 .33583 L 0 .48 .858 r
F P
0 g
s
.5 .3355 m .47312 .3471 L p .50357 .33823 L 0 .204 .478 r
F P
0 g
s
.47312 .3471 m .5 .3355 L p .52337 .35343 L 0 .204 .478 r
F P
0 g
s
.5 .3355 m .50411 .33372 L p .52337 .35343 L 0 .204 .478 r
F P
0 g
s
.56182 .44489 m .62402 .56698 L .56051 .51496 L .408 0 0 r
F
.5899 .60998 m .55923 .58402 L .5 .61327 L p 0 .225 .528 r
F P
0 g
s
.47034 .58723 m .5 .61327 L .55923 .58402 L p 0 .225 .528 r
F P
0 g
s
.55923 .58402 m .51398 .58183 L .5 .60192 L p 0 .467 .923 r
F P
0 g
s
.5 .60192 m .5 .61327 L .55923 .58402 L p 0 .467 .923 r
F P
0 g
s
.51398 .58183 m .55923 .58402 L .5 .61327 L p 0 .467 .923 r
F P
0 g
s
.5 .61327 m .53038 .63994 L .5899 .60998 L p 0 .225 .528 r
F P
0 g
s
.5 .61327 m .5 .60192 L .51398 .58183 L p 0 .467 .923 r
F P
0 g
s
.52927 .55866 m .5 .53389 L .44138 .5618 L p 0 .225 .528 r
F P
0 g
s
.44138 .5618 m .47034 .58723 L .52927 .55866 L p 0 .225 .528 r
F P
0 g
s
.5 .54391 m .5 .60192 L .51398 .58183 L closepath p 0 .467 .923 r
F P
0 g
s
.51398 .58183 m .5 .60192 L .5 .54391 L closepath p 0 .467 .923 r
F P
0 g
s
.53049 .62855 m .5 .60192 L .5 .54391 L p 0 .228 .862 r
F P
0 g
s
.5 .54391 m .51398 .58183 L .5372 .54846 L p 0 .467 .923 r
F P
0 g
s
.5372 .54846 m .53046 .52934 L .5 .54391 L p 0 .467 .923 r
F P
0 g
s
.51398 .58183 m .5 .54391 L .53046 .52934 L p 0 .467 .923 r
F P
0 g
s
.53046 .52934 m .5372 .54846 L .51398 .58183 L p 0 .467 .923 r
F P
0 g
s
.5 .54391 m .53105 .57032 L .53049 .62855 L p 0 .228 .862 r
F P
0 g
s
.5 .60192 m .53049 .62855 L .53105 .57032 L p 0 .228 .862 r
F P
0 g
s
.62132 .63657 m .5899 .60998 L .53038 .63994 L p 0 .225 .528 r
F P
0 g
s
.53038 .63994 m .56149 .66727 L .62132 .63657 L p 0 .225 .528 r
F P
0 g
s
.56172 .65584 m .53049 .62855 L .53105 .57032 L p 0 .228 .862 r
F P
0 g
s
.53105 .57032 m .56288 .59739 L .56172 .65584 L p 0 .228 .862 r
F P
0 g
s
.62265 .60216 m .62132 .63657 L .57611 .63531 L p 0 .473 .927 r
F P
0 g
s
.57611 .63531 m .60002 .60121 L .62265 .60216 L p 0 .473 .927 r
F P
0 g
s
.60002 .60121 m .57611 .63531 L .56288 .59739 L p 0 .473 .927 r
F P
0 g
s
.6901 .62655 m .64295 .58784 L .58564 .61674 L p .762 0 0 r
F P
0 g
s
.56172 .65584 m .57611 .63531 L .62132 .63657 L p 0 .473 .927 r
F P
0 g
s
.53038 .63994 m .53049 .62855 L .56172 .65584 L p 0 .228 .862 r
F P
0 g
s
.56172 .65584 m .56149 .66727 L .53038 .63994 L p 0 .228 .862 r
F P
0 g
s
.56149 .66727 m .53038 .63994 L .46921 .67073 L p 0 .225 .528 r
F P
0 g
s
.53049 .62855 m .53038 .63994 L .56149 .66727 L p 0 .228 .862 r
F P
0 g
s
.53049 .62855 m .56172 .65584 L .56288 .59739 L p 0 .228 .862 r
F P
0 g
s
.56149 .66727 m .56172 .65584 L .53049 .62855 L p 0 .228 .862 r
F P
0 g
s
.56288 .59739 m .57611 .63531 L .56172 .65584 L closepath p 0 .473 .927 r
F P
0 g
s
.56172 .65584 m .54777 .64969 L .56288 .59739 L closepath p 0 .473 .927 r
F P
0 g
s
.53038 .63994 m .5 .61327 L .43916 .64332 L p 0 .225 .528 r
F P
0 g
s
.43916 .64332 m .46921 .67073 L .53038 .63994 L p 0 .225 .528 r
F P
0 g
s
.46921 .67073 m .5 .69882 L .56149 .66727 L p 0 .225 .528 r
F P
0 g
s
.52419 .63931 m .54777 .64969 L .5 .69882 L p 0 .473 .927 r
F P
0 g
s
.56288 .59739 m .53105 .57032 L .53049 .62855 L p 0 .228 .862 r
F P
0 g
s
.53166 .61291 m .56288 .59739 L p .53613 .62312 L 0 .473 .927 r
F P
0 g
s
.56288 .59739 m .54777 .64969 L p .53613 .62312 L 0 .473 .927 r
F P
0 g
s
.53038 .63994 m .5 .61327 L .5 .60192 L p 0 .228 .862 r
F P
0 g
s
.5 .60192 m .53049 .62855 L .53038 .63994 L p 0 .228 .862 r
F P
0 g
s
.5 .61327 m .53038 .63994 L .53049 .62855 L p 0 .228 .862 r
F P
0 g
s
.53049 .62855 m .5 .60192 L .5 .61327 L p 0 .228 .862 r
F P
0 g
s
.54777 .64969 m .52419 .63931 L .53166 .61291 L p 0 .473 .927 r
F P
0 g
s
.58564 .61674 m .52679 .64643 L p .60881 .63644 L .762 0 0 r
F P
0 g
s
.60881 .63644 m .6901 .62655 L .58564 .61674 L .762 0 0 r
F
.59366 .58208 m .56167 .55538 L .59188 .54065 L p 0 .218 .512 r
F P
0 g
s
.59188 .54065 m .62402 .56698 L .59366 .58208 L p 0 .218 .512 r
F P
0 g
s
.59263 .5142 m .59188 .54065 L .62402 .56698 L p 0 .235 .864 r
F P
0 g
s
.62402 .56698 m .59188 .54065 L .56167 .55538 L p 0 .218 .512 r
F P
0 g
s
.53105 .57032 m .56167 .55538 L .59366 .58208 L p 0 .218 .512 r
F P
0 g
s
.56167 .55538 m .59366 .58208 L .61999 .56898 L p 0 .218 .512 r
F P
0 g
s
.61999 .56898 m .62402 .56698 L p .61566 .56543 L 0 .218 .512 r
F P
0 g
s
.56167 .55538 m .61999 .56898 L .61566 .56543 L 0 .218 .512 r
F
.63047 .42563 m .62759 .49956 L .62773 .49872 L .927 0 0 r
F
.63047 .42563 m .62773 .49872 L .63076 .42396 L F
.62773 .49872 m .62787 .49787 L .63076 .42396 L F
.62402 .56698 m .62504 .54041 L .59263 .5142 L p 0 .235 .864 r
F P
0 g
s
.5934 .4873 m .59263 .5142 L .62504 .54041 L p 0 .235 .864 r
F P
0 g
s
.59366 .58208 m .62402 .56698 L .60002 .60121 L closepath p 0 .473 .927 r
F P
0 g
s
.62402 .56698 m .59366 .58208 L .59445 .55545 L p 0 .473 .927 r
F P
0 g
s
.59445 .55545 m .62504 .54041 L .62402 .56698 L p 0 .473 .927 r
F P
0 g
s
.62716 .48593 m .62824 .458 L .59497 .43216 L p 0 .235 .864 r
F P
0 g
s
.59497 .43216 m .62824 .458 L p .6196 .45647 L 0 .207 .485 r
F P
0 g
s
.56182 .44489 m .56182 .44489 L .56051 .51496 L .408 0 0 r
F
.56201 .43463 m .5615 .46185 L .5934 .4873 L p 0 .235 .864 r
F P
0 g
s
.5615 .46185 m .561 .48862 L .59263 .5142 L p 0 .235 .864 r
F P
0 g
s
.59263 .5142 m .5934 .4873 L .5615 .46185 L p 0 .235 .864 r
F P
0 g
s
.5934 .4873 m .59417 .45996 L .56201 .43463 L p 0 .235 .864 r
F P
0 g
s
.56323 .47449 m .59417 .45996 L .56201 .43463 L p 0 .21 .492 r
F P
0 g
s
.56252 .40697 m .56201 .43463 L .59417 .45996 L p 0 .235 .864 r
F P
0 g
s
.5615 .46185 m .53038 .43701 L .53014 .46366 L p 0 .235 .864 r
F P
0 g
s
.53038 .43701 m .5615 .46185 L .56201 .43463 L p 0 .235 .864 r
F P
0 g
s
.56201 .43463 m .53063 .40992 L .53038 .43701 L p 0 .235 .864 r
F P
0 g
s
.53122 .4488 m .56201 .43463 L .53063 .40992 L p 0 .21 .492 r
F P
0 g
s
.53088 .38239 m .53063 .40992 L .56201 .43463 L p 0 .235 .864 r
F P
0 g
s
.53063 .40992 m .56201 .43463 L .53122 .4488 L p 0 .21 .492 r
F P
0 g
s
.56201 .43463 m .56252 .40697 L .53088 .38239 L p 0 .235 .864 r
F P
0 g
s
.56201 .43463 m .56252 .40697 L .53148 .42106 L p 0 .467 .923 r
F P
0 g
s
.56252 .40697 m .56201 .43463 L .53122 .4488 L p 0 .467 .923 r
F P
0 g
s
.5615 .46185 m .56201 .43463 L .53122 .4488 L p 0 .467 .923 r
F P
0 g
s
.53122 .4488 m .56201 .43463 L .5615 .46185 L p 0 .467 .923 r
F P
0 g
s
.53014 .46366 m .561 .48862 L .5615 .46185 L p 0 .235 .864 r
F P
0 g
s
.561 .48862 m .53014 .46366 L .5299 .48988 L p 0 .235 .864 r
F P
0 g
s
.561 .48862 m .5615 .46185 L .53096 .47609 L p 0 .467 .923 r
F P
0 g
s
.53096 .47609 m .5615 .46185 L .561 .48862 L p 0 .467 .923 r
F P
0 g
s
.53122 .4488 m .53096 .47609 L .5615 .46185 L p 0 .467 .923 r
F P
0 g
s
.5615 .46185 m .53096 .47609 L .53122 .4488 L p 0 .467 .923 r
F P
0 g
s
.5299 .48988 m .56051 .51496 L .561 .48862 L p 0 .235 .864 r
F P
0 g
s
.53046 .52934 m .56051 .51496 L .5299 .48988 L p 0 .218 .512 r
F P
0 g
s
.53096 .47609 m .53071 .50293 L .561 .48862 L p 0 .467 .923 r
F P
0 g
s
.561 .48862 m .53071 .50293 L .53096 .47609 L p 0 .467 .923 r
F P
0 g
s
.53184 .48923 m .56323 .47449 L .53122 .4488 L p 0 .21 .492 r
F P
0 g
s
.56201 .43463 m .53122 .4488 L .56323 .47449 L p 0 .21 .492 r
F P
0 g
s
.53122 .4488 m .56201 .43463 L .59417 .45996 L p 0 .21 .492 r
F P
0 g
s
.59417 .45996 m .59497 .43216 L .56252 .40697 L p 0 .235 .864 r
F P
0 g
s
.59497 .43216 m .59417 .45996 L .62716 .48593 L p 0 .235 .864 r
F P
0 g
s
.59417 .45996 m .59497 .43216 L .56376 .44661 L p 0 .47 .925 r
F P
0 g
s
.59417 .45996 m .56323 .47449 L .53122 .4488 L p 0 .21 .492 r
F P
0 g
s
.59497 .43216 m .59417 .45996 L .56323 .47449 L p 0 .47 .925 r
F P
0 g
s
.56323 .47449 m .56376 .44661 L .59497 .43216 L p 0 .47 .925 r
F P
0 g
s
.56376 .44661 m .59083 .43408 L p .6196 .45647 L 0 .207 .485 r
F P
0 g
s
.59083 .43408 m .59497 .43216 L p .6196 .45647 L 0 .207 .485 r
F P
0 g
s
.62678 .50024 m .62482 .57029 L .62759 .49956 L 1 0 0 r
F
.62504 .54041 m .62609 .5134 L .5934 .4873 L p 0 .235 .864 r
F P
0 g
s
.62504 .54041 m .59445 .55545 L .59524 .52837 L p 0 .473 .927 r
F P
0 g
s
.59524 .52837 m .62609 .5134 L .62504 .54041 L p 0 .473 .927 r
F P
0 g
s
.62678 .50024 m .62325 .57165 L .62482 .57029 L 1 0 0 r
F
.59417 .45996 m .5934 .4873 L .62609 .5134 L p 0 .235 .864 r
F P
0 g
s
.62609 .5134 m .62716 .48593 L .59417 .45996 L p 0 .235 .864 r
F P
0 g
s
.62304 .48791 m .62716 .48593 L p .59442 .46532 L 0 .21 .492 r
F P
0 g
s
.62716 .48593 m .59417 .45996 L p .59442 .46532 L 0 .21 .492 r
F P
0 g
s
.59605 .50083 m .62304 .48791 L p .59442 .46532 L 0 .21 .492 r
F P
0 g
s
.59417 .45996 m .62716 .48593 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.59417 .45996 m .56323 .47449 L .59605 .50083 L p 0 .21 .492 r
F P
0 g
s
.56323 .47449 m .59007 .46189 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.59007 .46189 m .59417 .45996 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.59605 .50083 m .62716 .48593 L .62609 .5134 L p 0 .473 .927 r
F P
0 g
s
.62696 .49396 m .62598 .50091 L .62678 .50024 L 1 0 0 r
F
.59605 .50083 m .56323 .47449 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.62716 .48593 m .62304 .48791 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.62304 .48791 m .59605 .50083 L p .61859 .4844 L 0 .21 .492 r
F P
0 g
s
.62824 .458 m .59497 .43216 L p .59522 .43749 L 0 .207 .485 r
F P
0 g
s
.59688 .47282 m .62408 .45996 L p .59522 .43749 L 0 .207 .485 r
F P
0 g
s
.62408 .45996 m .62824 .458 L p .59522 .43749 L 0 .207 .485 r
F P
0 g
s
.59577 .40389 m .59497 .43216 L .62824 .458 L p 0 .235 .864 r
F P
0 g
s
.62824 .458 m .62716 .48593 L .59605 .50083 L p 0 .473 .927 r
F P
0 g
s
.56376 .44661 m .56323 .47449 L .59417 .45996 L p 0 .47 .925 r
F P
0 g
s
.62824 .458 m .59688 .47282 L .56376 .44661 L p 0 .207 .485 r
F P
0 g
s
.62912 .4353 m .62482 .42612 L .59577 .40389 L p 0 .235 .864 r
F P
0 g
s
.62824 .458 m .62912 .4353 L p .59577 .40389 L 0 .235 .864 r
F P
0 g
s
.59605 .50083 m .59688 .47282 L .62824 .458 L p 0 .473 .927 r
F P
0 g
s
.62912 .4353 m .62824 .458 L .59688 .47282 L p 0 .473 .927 r
F P
0 g
s
.62482 .42612 m .62912 .4353 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.59497 .43216 m .56376 .44661 L .59688 .47282 L p 0 .207 .485 r
F P
0 g
s
.59321 .44081 m .62063 .42806 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.62063 .42806 m .62482 .42612 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.59755 .45007 m .59321 .44081 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.62912 .4353 m .62494 .43726 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.62494 .43726 m .59755 .45007 L p .62436 .43603 L 0 .358 .744 r
F P
0 g
s
.59688 .47282 m .59755 .45007 L .62912 .4353 L p 0 .473 .927 r
F P
0 g
s
.62883 .42696 m .62746 .46259 L .62788 .461 L 1 0 0 r
F
.62783 .46288 m .62746 .46259 L .62779 .46413 L F
.62883 .42696 m .62678 .50024 L .63047 .42563 L F
.62678 .50024 m .62759 .49956 L .63047 .42563 L F
.63084 .44986 m .62746 .46259 L .63229 .46635 L .407 0 0 r
F
.62883 .42696 m .62817 .44416 L p .63084 .44986 L F P
0 g
s
.62817 .44416 m .62746 .46259 L p .63084 .44986 L .407 0 0 r
F P
0 g
s
.62817 .44416 m .63229 .46635 L .62746 .46259 L .407 0 0 r
F
.62883 .42696 m .63084 .44986 L .62817 .44416 L F
.63084 .44986 m .63229 .46635 L .62817 .44416 L F
.62746 .46259 m .62598 .50091 L .62779 .46413 L 1 0 0 r
F
.62779 .46413 m .62598 .50091 L .62696 .49396 L F
.62746 .46259 m .63501 .49736 L .62638 .49055 L .407 0 0 r
F
.63229 .46635 m .63501 .49736 L .62746 .46259 L F
.62746 .46259 m .62638 .49055 L p .63229 .46635 L F P
0 g
s
.62609 .5134 m .59524 .52837 L .59605 .50083 L p 0 .473 .927 r
F P
0 g
s
.62598 .50091 m .62325 .57165 L .62678 .50024 L 1 0 0 r
F
.62638 .49055 m .64295 .58784 L .62325 .57165 L .407 0 0 r
F
.63501 .49736 m .64295 .58784 L .62638 .49055 L F
.62638 .49055 m .62325 .57165 L p .62997 .49338 L F P
0 g
s
.62638 .49055 m .62997 .49338 L .63229 .46635 L .407 0 0 r
F
.62325 .57165 m .64295 .58784 L p .63229 .46635 L F P
0 g
s
.59366 .58208 m .56167 .55538 L .53105 .57032 L p 0 .218 .512 r
F P
0 g
s
.59366 .58208 m .56288 .59739 L .53105 .57032 L p 0 .218 .512 r
F P
0 g
s
.53046 .52934 m .56167 .55538 L .53105 .57032 L p 0 .218 .512 r
F P
0 g
s
.53105 .57032 m .5 .54391 L .53046 .52934 L p 0 .218 .512 r
F P
0 g
s
.56167 .55538 m .53046 .52934 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.5 .54391 m .53105 .57032 L .56167 .55538 L p 0 .218 .512 r
F P
0 g
s
.53105 .57032 m .56288 .59739 L .59366 .58208 L p 0 .218 .512 r
F P
0 g
s
.53131 .54374 m .53105 .57032 L .56288 .59739 L p 0 .228 .862 r
F P
0 g
s
.56288 .59739 m .53105 .57032 L .53131 .54374 L p 0 .228 .862 r
F P
0 g
s
.56051 .51496 m .59188 .54065 L p .561 .48862 L 0 .235 .864 r
F P
0 g
s
.561 .48862 m .56051 .51496 L p .561 .48862 L 0 .235 .864 r
F P
0 g
s
.5 .4654 m .5299 .48988 L .53014 .46366 L p 0 .235 .864 r
F P
0 g
s
.5 .50392 m .5299 .48988 L .5 .4654 L p 0 .218 .512 r
F P
0 g
s
.53046 .52934 m .5 .50392 L .5299 .48988 L p 0 .218 .512 r
F P
0 g
s
.5299 .48988 m .5 .50392 L .53046 .52934 L p 0 .218 .512 r
F P
0 g
s
.59188 .54065 m .56051 .51496 L .53046 .52934 L p 0 .218 .512 r
F P
0 g
s
.56051 .51496 m .561 .48862 L .53071 .50293 L p 0 .467 .923 r
F P
0 g
s
.53071 .50293 m .53046 .52934 L .56051 .51496 L p 0 .467 .923 r
F P
0 g
s
.56051 .51496 m .53046 .52934 L .53071 .50293 L p 0 .467 .923 r
F P
0 g
s
.53071 .50293 m .561 .48862 L .56051 .51496 L p 0 .467 .923 r
F P
0 g
s
.53046 .52934 m .56167 .55538 L .59188 .54065 L p 0 .218 .512 r
F P
0 g
s
.59188 .54065 m .59263 .5142 L .561 .48862 L p 0 .235 .864 r
F P
0 g
s
.53071 .50293 m .53096 .47609 L .5 .49053 L p 0 .467 .923 r
F P
0 g
s
.5 .49053 m .53096 .47609 L .53071 .50293 L p 0 .467 .923 r
F P
0 g
s
.53014 .46366 m .5 .43929 L .5 .4654 L p 0 .235 .864 r
F P
0 g
s
.5 .43929 m .53014 .46366 L .53038 .43701 L p 0 .235 .864 r
F P
0 g
s
.53096 .47609 m .53122 .4488 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .5 .49053 L .53096 .47609 L p 0 .467 .923 r
F P
0 g
s
.53096 .47609 m .5 .49053 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .53122 .4488 L .53096 .47609 L p 0 .467 .923 r
F P
0 g
s
.53122 .4488 m .5 .46317 L .53184 .48923 L p 0 .21 .492 r
F P
0 g
s
.5 .50392 m .53046 .52934 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.5 .54391 m .53046 .52934 L .5 .50392 L p 0 .218 .512 r
F P
0 g
s
.53046 .52934 m .53071 .50293 L .5 .51744 L p 0 .467 .923 r
F P
0 g
s
.5 .51744 m .53071 .50293 L .53046 .52934 L p 0 .467 .923 r
F P
0 g
s
.5 .49053 m .5 .51744 L .53071 .50293 L p 0 .467 .923 r
F P
0 g
s
.53071 .50293 m .5 .51744 L .5 .49053 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .5 .49053 L .53157 .51671 L p 0 .228 .862 r
F P
0 g
s
.53157 .51671 m .5 .49053 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.56376 .44661 m .56323 .47449 L .53122 .4488 L p 0 .232 .863 r
F P
0 g
s
.53148 .42106 m .53122 .4488 L .56201 .43463 L p 0 .467 .923 r
F P
0 g
s
.53122 .4488 m .53148 .42106 L .56252 .40697 L p 0 .467 .923 r
F P
0 g
s
.53148 .42106 m .53122 .4488 L .56323 .47449 L p 0 .232 .863 r
F P
0 g
s
.5 .46317 m .53122 .4488 L .56323 .47449 L p 0 .21 .492 r
F P
0 g
s
.5 .51744 m .5 .54391 L .53046 .52934 L p 0 .467 .923 r
F P
0 g
s
.53046 .52934 m .5 .54391 L .5 .51744 L p 0 .467 .923 r
F P
0 g
s
.5 .49053 m .5 .51744 L .53131 .54374 L p 0 .228 .862 r
F P
0 g
s
.53131 .54374 m .5 .51744 L .5 .49053 L p 0 .228 .862 r
F P
0 g
s
.53131 .54374 m .53157 .51671 L .5 .49053 L p 0 .228 .862 r
F P
0 g
s
.5 .49053 m .53157 .51671 L .53131 .54374 L p 0 .228 .862 r
F P
0 g
s
.53157 .51671 m .53184 .48923 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.5 .46317 m .53184 .48923 L .53157 .51671 L p 0 .228 .862 r
F P
0 g
s
.5 .50417 m .53184 .48923 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.5 .46317 m .53122 .4488 L .5 .42375 L p 0 .21 .492 r
F P
0 g
s
.5 .42375 m .53122 .4488 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.53063 .40992 m .5 .42375 L .53122 .4488 L p 0 .21 .492 r
F P
0 g
s
.53122 .4488 m .5 .42375 L .53063 .40992 L p 0 .21 .492 r
F P
0 g
s
.53148 .42106 m .53122 .4488 L .5 .42375 L p 0 .232 .863 r
F P
0 g
s
.53088 .38239 m .53063 .40992 L .5 .42375 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .5 .42375 L .53063 .40992 L p 0 .464 .922 r
F P
0 g
s
.5 .42375 m .5 .39614 L .53088 .38239 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .5 .42375 L .53122 .4488 L p 0 .232 .863 r
F P
0 g
s
.53122 .4488 m .53148 .42106 L .5 .39614 L p 0 .232 .863 r
F P
0 g
s
.53122 .4488 m .53148 .42106 L .5 .43535 L p 0 .467 .923 r
F P
0 g
s
.53148 .42106 m .53122 .4488 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.5 .43535 m .5 .46317 L .53122 .4488 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .5 .43535 L .53148 .42106 L p 0 .467 .923 r
F P
0 g
s
.56323 .47449 m .53184 .48923 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.5 .43535 m .5 .46317 L .53184 .48923 L p 0 .228 .862 r
F P
0 g
s
.53211 .46127 m .53184 .48923 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.5 .46317 m .53184 .48923 L .5 .50417 L p 0 .21 .492 r
F P
0 g
s
.56323 .47449 m .56376 .44661 L .53148 .42106 L p 0 .232 .863 r
F P
0 g
s
.56395 .54356 m .59524 .52837 L .59445 .55545 L p 0 .473 .927 r
F P
0 g
s
.53184 .48923 m .53157 .51671 L .56395 .54356 L p 0 .228 .862 r
F P
0 g
s
.56395 .54356 m .53157 .51671 L .53184 .48923 L p 0 .228 .862 r
F P
0 g
s
.59688 .47282 m .59605 .50083 L .56323 .47449 L p 0 .232 .863 r
F P
0 g
s
.56323 .47449 m .56376 .44661 L .59688 .47282 L p 0 .232 .863 r
F P
0 g
s
.5645 .51595 m .59605 .50083 L .56323 .47449 L p 0 .21 .492 r
F P
0 g
s
.56323 .47449 m .53184 .48923 L .5645 .51595 L p 0 .21 .492 r
F P
0 g
s
.56376 .44661 m .56323 .47449 L .59605 .50083 L p 0 .232 .863 r
F P
0 g
s
.53211 .46127 m .53184 .48923 L .56323 .47449 L p 0 .47 .925 r
F P
0 g
s
.56323 .47449 m .56376 .44661 L .53211 .46127 L p 0 .47 .925 r
F P
0 g
s
.56376 .44661 m .56323 .47449 L .53184 .48923 L p 0 .47 .925 r
F P
0 g
s
.53184 .48923 m .56323 .47449 L .59605 .50083 L p 0 .21 .492 r
F P
0 g
s
.53184 .48923 m .53211 .46127 L .5 .43535 L p 0 .228 .862 r
F P
0 g
s
.59524 .52837 m .56395 .54356 L .5645 .51595 L p 0 .473 .927 r
F P
0 g
s
.5645 .51595 m .59605 .50083 L .59524 .52837 L p 0 .473 .927 r
F P
0 g
s
.53157 .51671 m .53131 .54374 L .56341 .5707 L p 0 .228 .862 r
F P
0 g
s
.56341 .5707 m .53131 .54374 L .53157 .51671 L p 0 .228 .862 r
F P
0 g
s
.56341 .5707 m .56395 .54356 L .53157 .51671 L p 0 .228 .862 r
F P
0 g
s
.53157 .51671 m .56395 .54356 L .56341 .5707 L p 0 .228 .862 r
F P
0 g
s
.53184 .48923 m .5 .50417 L .53248 .53128 L p 0 .21 .492 r
F P
0 g
s
.56395 .54356 m .5645 .51595 L .53184 .48923 L p 0 .228 .862 r
F P
0 g
s
.53184 .48923 m .5645 .51595 L .56395 .54356 L p 0 .228 .862 r
F P
0 g
s
.53248 .53128 m .5645 .51595 L .53184 .48923 L p 0 .21 .492 r
F P
0 g
s
.53184 .48923 m .53211 .46127 L .56376 .44661 L p 0 .47 .925 r
F P
0 g
s
.59605 .50083 m .5645 .51595 L .53184 .48923 L p 0 .21 .492 r
F P
0 g
s
.53211 .46127 m .53184 .48923 L .5645 .51595 L p 0 .228 .862 r
F P
0 g
s
.5 .47615 m .5 .50417 L .53184 .48923 L p 0 .47 .925 r
F P
0 g
s
.53184 .48923 m .53211 .46127 L .5 .47615 L p 0 .47 .925 r
F P
0 g
s
.53211 .46127 m .53184 .48923 L .5 .50417 L p 0 .47 .925 r
F P
0 g
s
.56505 .48786 m .5645 .51595 L .53184 .48923 L p 0 .228 .862 r
F P
0 g
s
.53184 .48923 m .53211 .46127 L .56505 .48786 L p 0 .228 .862 r
F P
0 g
s
.53248 .53128 m .5 .50417 L .53184 .48923 L p 0 .21 .492 r
F P
0 g
s
.53184 .48923 m .5645 .51595 L .53248 .53128 L p 0 .21 .492 r
F P
0 g
s
.59755 .45007 m .59688 .47282 L .56376 .44661 L p 0 .232 .863 r
F P
0 g
s
.59321 .44081 m .59755 .45007 L p .56376 .44661 L 0 .232 .863 r
F P
0 g
s
.59605 .50083 m .59688 .47282 L .56376 .44661 L p 0 .232 .863 r
F P
0 g
s
.56505 .48786 m .59688 .47282 L .56376 .44661 L p 0 .207 .485 r
F P
0 g
s
.56376 .44661 m .53211 .46127 L .56505 .48786 L p 0 .207 .485 r
F P
0 g
s
.53148 .42106 m .56252 .40697 L .59497 .43216 L p 0 .207 .485 r
F P
0 g
s
.56376 .44661 m .59497 .43216 L .56252 .40697 L p 0 .207 .485 r
F P
0 g
s
.59497 .43216 m .56376 .44661 L .53148 .42106 L p 0 .207 .485 r
F P
0 g
s
.56431 .41826 m .56376 .44661 L .59497 .43216 L p 0 .47 .925 r
F P
0 g
s
.56305 .37884 m .56252 .40697 L .59497 .43216 L p 0 .235 .864 r
F P
0 g
s
.59497 .43216 m .59577 .40389 L .56305 .37884 L p 0 .235 .864 r
F P
0 g
s
.59577 .40389 m .59497 .43216 L .56376 .44661 L p 0 .47 .925 r
F P
0 g
s
.56376 .44661 m .56431 .41826 L .59577 .40389 L p 0 .47 .925 r
F P
0 g
s
.56431 .41826 m .56376 .44661 L .59688 .47282 L p 0 .232 .863 r
F P
0 g
s
.53211 .46127 m .56376 .44661 L .59688 .47282 L p 0 .207 .485 r
F P
0 g
s
.56288 .59739 m .56341 .5707 L .53131 .54374 L p 0 .228 .862 r
F P
0 g
s
.53131 .54374 m .56341 .5707 L .56288 .59739 L p 0 .228 .862 r
F P
0 g
s
.5645 .51595 m .56395 .54356 L .53221 .55896 L p 0 .473 .927 r
F P
0 g
s
.59688 .47282 m .59605 .50083 L .5645 .51595 L p 0 .473 .927 r
F P
0 g
s
.5 .50417 m .5 .47615 L .53211 .46127 L p 0 .47 .925 r
F P
0 g
s
.5 .50417 m .5 .47615 L .53277 .50313 L p 0 .224 .86 r
F P
0 g
s
.5645 .51595 m .56505 .48786 L .53211 .46127 L p 0 .228 .862 r
F P
0 g
s
.5 .47615 m .53211 .46127 L .56505 .48786 L p 0 .207 .485 r
F P
0 g
s
.53211 .46127 m .5 .47615 L .53277 .50313 L p 0 .207 .485 r
F P
0 g
s
.53277 .50313 m .56505 .48786 L .53211 .46127 L p 0 .207 .485 r
F P
0 g
s
.53122 .4488 m .53148 .42106 L .56376 .44661 L p 0 .232 .863 r
F P
0 g
s
.5 .43535 m .53148 .42106 L .56376 .44661 L p 0 .207 .485 r
F P
0 g
s
.53211 .46127 m .56376 .44661 L .53148 .42106 L p 0 .207 .485 r
F P
0 g
s
.56376 .44661 m .53211 .46127 L .5 .43535 L p 0 .207 .485 r
F P
0 g
s
.53239 .43284 m .53211 .46127 L .56376 .44661 L p 0 .47 .925 r
F P
0 g
s
.56252 .40697 m .53148 .42106 L .56376 .44661 L p 0 .207 .485 r
F P
0 g
s
.56431 .41826 m .56376 .44661 L .53148 .42106 L p 0 .232 .863 r
F P
0 g
s
.53063 .40992 m .53088 .38239 L .5 .39614 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .53088 .38239 L .56252 .40697 L p 0 .207 .485 r
F P
0 g
s
.53148 .42106 m .56252 .40697 L .53088 .38239 L p 0 .207 .485 r
F P
0 g
s
.56252 .40697 m .53148 .42106 L .5 .39614 L p 0 .207 .485 r
F P
0 g
s
.53113 .35441 m .53088 .38239 L .56252 .40697 L p 0 .235 .864 r
F P
0 g
s
.56252 .40697 m .56305 .37884 L .53113 .35441 L p 0 .235 .864 r
F P
0 g
s
.56305 .37884 m .56252 .40697 L .53148 .42106 L p 0 .467 .923 r
F P
0 g
s
.53175 .39285 m .53148 .42106 L .56252 .40697 L p 0 .467 .923 r
F P
0 g
s
.53148 .42106 m .53175 .39285 L .56305 .37884 L p 0 .467 .923 r
F P
0 g
s
.53175 .39285 m .53148 .42106 L .56376 .44661 L p 0 .232 .863 r
F P
0 g
s
.56376 .44661 m .56431 .41826 L .53175 .39285 L p 0 .232 .863 r
F P
0 g
s
.56431 .41826 m .56376 .44661 L .53211 .46127 L p 0 .47 .925 r
F P
0 g
s
.59688 .47282 m .56505 .48786 L .53211 .46127 L p 0 .207 .485 r
F P
0 g
s
.53211 .46127 m .53239 .43284 L .56431 .41826 L p 0 .47 .925 r
F P
0 g
s
.53239 .43284 m .53211 .46127 L .56505 .48786 L p 0 .228 .862 r
F P
0 g
s
.56551 .46505 m .56505 .48786 L .53211 .46127 L p 0 .228 .862 r
F P
0 g
s
.56114 .45572 m .56551 .46505 L p .53211 .46127 L 0 .228 .862 r
F P
0 g
s
.59755 .45007 m .59321 .44081 L .56431 .41826 L p 0 .232 .863 r
F P
0 g
s
.59688 .47282 m .59755 .45007 L p .56431 .41826 L 0 .232 .863 r
F P
0 g
s
.53221 .55896 m .53248 .53128 L .5645 .51595 L p 0 .473 .927 r
F P
0 g
s
.56505 .48786 m .5645 .51595 L .53248 .53128 L p 0 .473 .927 r
F P
0 g
s
.5645 .51595 m .56505 .48786 L .59688 .47282 L p 0 .473 .927 r
F P
0 g
s
.59755 .45007 m .59688 .47282 L .56505 .48786 L p 0 .473 .927 r
F P
0 g
s
.47734 .49819 m .5 .5 L .5 .4654 L closepath p 0 .461 .92 r
F P
0 g
s
.45476 .53086 m .47734 .49819 L .47026 .4791 L p 0 .461 .92 r
F P
0 g
s
.47734 .49819 m .5 .4654 L .47026 .4791 L closepath p 0 .461 .92 r
F P
0 g
s
.5 .53389 m .5 .5 L .47734 .49819 L p 0 .461 .92 r
F P
0 g
s
.5 .50392 m .47026 .4791 L .5 .4654 L p 0 .218 .512 r
F P
0 g
s
.5 .4654 m .47026 .4791 L .5 .50392 L p 0 .218 .512 r
F P
0 g
s
.47734 .49819 m .45476 .53086 L .5 .53389 L p 0 .461 .92 r
F P
0 g
s
.47026 .4791 m .44012 .49299 L .45476 .53086 L p 0 .461 .92 r
F P
0 g
s
.44012 .49299 m .47026 .4791 L .5 .50392 L p 0 .218 .512 r
F P
0 g
s
.5 .50392 m .4697 .51814 L .44012 .49299 L p 0 .218 .512 r
F P
0 g
s
.47026 .4791 m .44012 .49299 L .4697 .51814 L p 0 .218 .512 r
F P
0 g
s
.4697 .51814 m .5 .50392 L .47026 .4791 L p 0 .218 .512 r
F P
0 g
s
.43964 .46674 m .44012 .49299 L .47026 .4791 L p 0 .461 .92 r
F P
0 g
s
.46945 .49178 m .43964 .46674 L .44012 .49299 L p 0 .228 .862 r
F P
0 g
s
.44012 .49299 m .43964 .46674 L .46945 .49178 L p 0 .228 .862 r
F P
0 g
s
.47026 .4791 m .47002 .45292 L .43964 .46674 L p 0 .461 .92 r
F P
0 g
s
.43964 .46674 m .46945 .49178 L .4692 .465 L p 0 .228 .862 r
F P
0 g
s
.4692 .465 m .46945 .49178 L .43964 .46674 L p 0 .228 .862 r
F P
0 g
s
.44138 .5618 m .5 .53389 L .45476 .53086 L p 0 .461 .92 r
F P
0 g
s
.5 .54391 m .4697 .51814 L .5 .50392 L p 0 .218 .512 r
F P
0 g
s
.5 .50392 m .4697 .51814 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.46945 .49178 m .5 .51744 L .5 .49053 L p 0 .228 .862 r
F P
0 g
s
.47002 .45292 m .47026 .4791 L .5 .4654 L p 0 .461 .92 r
F P
0 g
s
.5 .49053 m .4692 .465 L .46945 .49178 L p 0 .228 .862 r
F P
0 g
s
.46945 .49178 m .4692 .465 L .5 .49053 L p 0 .228 .862 r
F P
0 g
s
.5 .49053 m .5 .51744 L .46945 .49178 L p 0 .228 .862 r
F P
0 g
s
.5 .4654 m .5 .43929 L .47002 .45292 L p 0 .461 .92 r
F P
0 g
s
.4692 .465 m .5 .49053 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.5 .46317 m .5 .49053 L .4692 .465 L p 0 .228 .862 r
F P
0 g
s
.45476 .53086 m .44117 .55053 L .44138 .5618 L p 0 .461 .92 r
F P
0 g
s
.44117 .55053 m .45476 .53086 L .44012 .49299 L closepath p 0 .461 .92 r
F P
0 g
s
.47024 .57592 m .44117 .55053 L .44012 .49299 L p 0 .228 .862 r
F P
0 g
s
.44012 .49299 m .4697 .51814 L .47024 .57592 L p 0 .228 .862 r
F P
0 g
s
.44117 .55053 m .47024 .57592 L .4697 .51814 L p 0 .228 .862 r
F P
0 g
s
.5 .60192 m .47024 .57592 L .4697 .51814 L p 0 .228 .862 r
F P
0 g
s
.4697 .51814 m .5 .54391 L .5 .60192 L p 0 .228 .862 r
F P
0 g
s
.5 .54391 m .4697 .51814 L .47024 .57592 L p 0 .228 .862 r
F P
0 g
s
.4697 .51814 m .5 .54391 L .46912 .55868 L p 0 .218 .512 r
F P
0 g
s
.44012 .49299 m .42702 .54392 L .44117 .55053 L closepath p 0 .461 .92 r
F P
0 g
s
.4697 .51814 m .44012 .49299 L .44117 .55053 L p 0 .228 .862 r
F P
0 g
s
.46912 .55868 m .43898 .53256 L .4697 .51814 L p 0 .218 .512 r
F P
0 g
s
.5 .54391 m .4697 .51814 L .43898 .53256 L p 0 .218 .512 r
F P
0 g
s
.4697 .51814 m .5 .54391 L .5 .51744 L p 0 .228 .862 r
F P
0 g
s
.5 .51744 m .5 .54391 L .4697 .51814 L p 0 .228 .862 r
F P
0 g
s
.43898 .53256 m .46912 .55868 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.46912 .55868 m .5 .54391 L .5 .51744 L p 0 .467 .923 r
F P
0 g
s
.5 .51744 m .46945 .49178 L .4697 .51814 L p 0 .228 .862 r
F P
0 g
s
.4697 .51814 m .46945 .49178 L .5 .51744 L p 0 .228 .862 r
F P
0 g
s
.46886 .53215 m .5 .51744 L .5 .49053 L p 0 .467 .923 r
F P
0 g
s
.5 .49053 m .5 .51744 L .46886 .53215 L p 0 .467 .923 r
F P
0 g
s
.4031 .53276 m .42702 .54392 L .44012 .49299 L p 0 .461 .92 r
F P
0 g
s
.44012 .49299 m .40957 .50706 L .4031 .53276 L p 0 .461 .92 r
F P
0 g
s
.40957 .50706 m .44012 .49299 L .4697 .51814 L p 0 .218 .512 r
F P
0 g
s
.4697 .51814 m .44012 .49299 L .40957 .50706 L p 0 .218 .512 r
F P
0 g
s
.44012 .49299 m .4697 .51814 L .46945 .49178 L p 0 .228 .862 r
F P
0 g
s
.46945 .49178 m .4697 .51814 L .44012 .49299 L p 0 .228 .862 r
F P
0 g
s
.4697 .51814 m .43898 .53256 L .40957 .50706 L p 0 .218 .512 r
F P
0 g
s
.40957 .50706 m .43898 .53256 L .4697 .51814 L p 0 .218 .512 r
F P
0 g
s
.5 .49053 m .4686 .50518 L .46886 .53215 L p 0 .467 .923 r
F P
0 g
s
.46886 .53215 m .4686 .50518 L .5 .49053 L p 0 .467 .923 r
F P
0 g
s
.4686 .50518 m .5 .49053 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .5 .49053 L .4686 .50518 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .46834 .47775 L .4686 .50518 L p 0 .467 .923 r
F P
0 g
s
.4686 .50518 m .46834 .47775 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.44138 .5618 m .44117 .55053 L .47024 .57592 L p 0 .228 .862 r
F P
0 g
s
.47024 .57592 m .47034 .58723 L .44138 .5618 L p 0 .228 .862 r
F P
0 g
s
.44117 .55053 m .44138 .5618 L .47034 .58723 L p 0 .228 .862 r
F P
0 g
s
.44117 .55053 m .42702 .54392 L .3812 .59045 L p 0 .461 .92 r
F P
0 g
s
.47034 .58723 m .47024 .57592 L .44117 .55053 L p 0 .228 .862 r
F P
0 g
s
.43898 .53256 m .46912 .55868 L .4378 .57366 L p 0 .218 .512 r
F P
0 g
s
.42702 .54392 m .4031 .53276 L .37992 .55626 L p 0 .461 .92 r
F P
0 g
s
.37992 .55626 m .3812 .59045 L .42702 .54392 L p 0 .461 .92 r
F P
0 g
s
.4378 .57366 m .40784 .54718 L .43898 .53256 L p 0 .218 .512 r
F P
0 g
s
.46912 .55868 m .43898 .53256 L .40784 .54718 L p 0 .218 .512 r
F P
0 g
s
.43728 .54707 m .46886 .53215 L .4686 .50518 L p 0 .467 .923 r
F P
0 g
s
.4686 .50518 m .46886 .53215 L .43728 .54707 L p 0 .467 .923 r
F P
0 g
s
.40957 .50706 m .43898 .53256 L .40784 .54718 L p 0 .218 .512 r
F P
0 g
s
.40957 .50706 m .37861 .52133 L .4031 .53276 L closepath p 0 .461 .92 r
F P
0 g
s
.37861 .52133 m .37992 .55626 L .4031 .53276 L closepath p 0 .461 .92 r
F P
0 g
s
.40784 .54718 m .37861 .52133 L .40957 .50706 L p 0 .218 .512 r
F P
0 g
s
.43898 .53256 m .40957 .50706 L .37861 .52133 L p 0 .218 .512 r
F P
0 g
s
.37861 .52133 m .40784 .54718 L .43898 .53256 L p 0 .218 .512 r
F P
0 g
s
.4686 .50518 m .43676 .52003 L .43728 .54707 L p 0 .467 .923 r
F P
0 g
s
.43728 .54707 m .43676 .52003 L .4686 .50518 L p 0 .467 .923 r
F P
0 g
s
.43676 .52003 m .4686 .50518 L .46834 .47775 L p 0 .467 .923 r
F P
0 g
s
.46834 .47775 m .4686 .50518 L .43676 .52003 L p 0 .467 .923 r
F P
0 g
s
.40957 .50706 m .44012 .49299 L .43964 .46674 L p 0 .461 .92 r
F P
0 g
s
.46834 .47775 m .43622 .49253 L .43676 .52003 L p 0 .467 .923 r
F P
0 g
s
.43676 .52003 m .43622 .49253 L .46834 .47775 L p 0 .467 .923 r
F P
0 g
s
.46834 .47775 m .43622 .49253 L .4677 .51934 L p 0 .21 .492 r
F P
0 g
s
.4677 .51934 m .5 .50417 L .46834 .47775 L p 0 .21 .492 r
F P
0 g
s
.5 .46317 m .46834 .47775 L .5 .50417 L p 0 .21 .492 r
F P
0 g
s
.5 .50417 m .46834 .47775 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.47002 .45292 m .46978 .42633 L .43915 .44008 L p 0 .461 .92 r
F P
0 g
s
.43915 .44008 m .43964 .46674 L .47002 .45292 L p 0 .461 .92 r
F P
0 g
s
.4692 .465 m .43915 .44008 L .43964 .46674 L p 0 .228 .862 r
F P
0 g
s
.43964 .46674 m .43915 .44008 L .4692 .465 L p 0 .228 .862 r
F P
0 g
s
.43915 .44008 m .4692 .465 L .46895 .43777 L p 0 .228 .862 r
F P
0 g
s
.46895 .43777 m .4692 .465 L .43915 .44008 L p 0 .228 .862 r
F P
0 g
s
.46978 .42633 m .47002 .45292 L .5 .43929 L p 0 .461 .92 r
F P
0 g
s
.5 .46317 m .46895 .43777 L .4692 .465 L p 0 .228 .862 r
F P
0 g
s
.4692 .465 m .46895 .43777 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.40884 .48075 m .43964 .46674 L .43915 .44008 L p 0 .461 .92 r
F P
0 g
s
.46895 .43777 m .43746 .45198 L .46834 .47775 L p 0 .21 .492 r
F P
0 g
s
.46834 .47775 m .5 .46317 L .46895 .43777 L p 0 .21 .492 r
F P
0 g
s
.43746 .45198 m .46895 .43777 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.5 .42375 m .46895 .43777 L .5 .46317 L p 0 .21 .492 r
F P
0 g
s
.5 .46317 m .46895 .43777 L .5 .42375 L p 0 .21 .492 r
F P
0 g
s
.46978 .42633 m .46954 .3993 L .43866 .41298 L p 0 .461 .92 r
F P
0 g
s
.43866 .41298 m .43915 .44008 L .46978 .42633 L p 0 .461 .92 r
F P
0 g
s
.46895 .43777 m .5 .42375 L .46954 .3993 L p 0 .21 .492 r
F P
0 g
s
.46954 .3993 m .43866 .41298 L .46895 .43777 L p 0 .21 .492 r
F P
0 g
s
.46954 .3993 m .5 .42375 L .46895 .43777 L p 0 .21 .492 r
F P
0 g
s
.46895 .43777 m .43866 .41298 L .46954 .3993 L p 0 .21 .492 r
F P
0 g
s
.5 .39614 m .5 .42375 L .46954 .3993 L p 0 .232 .863 r
F P
0 g
s
.46929 .37183 m .46954 .3993 L .5 .42375 L p 0 .232 .863 r
F P
0 g
s
.5 .42375 m .5 .39614 L .46929 .37183 L p 0 .232 .863 r
F P
0 g
s
.5 .39614 m .5 .42375 L .46895 .43777 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .46895 .43777 L .5 .42375 L p 0 .464 .922 r
F P
0 g
s
.46895 .43777 m .46869 .41008 L .5 .39614 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .46895 .43777 L .5 .46317 L p 0 .228 .862 r
F P
0 g
s
.5 .43535 m .5 .46317 L .46895 .43777 L p 0 .228 .862 r
F P
0 g
s
.5 .46317 m .5 .43535 L .46869 .41008 L p 0 .228 .862 r
F P
0 g
s
.5 .46317 m .5 .43535 L .46807 .44985 L p 0 .467 .923 r
F P
0 g
s
.5 .46317 m .46834 .47775 L .43746 .45198 L p 0 .21 .492 r
F P
0 g
s
.46807 .44985 m .46834 .47775 L .5 .46317 L p 0 .467 .923 r
F P
0 g
s
.5 .43535 m .5 .46317 L .46834 .47775 L p 0 .467 .923 r
F P
0 g
s
.46834 .47775 m .46807 .44985 L .5 .43535 L p 0 .467 .923 r
F P
0 g
s
.46807 .44985 m .46834 .47775 L .5 .50417 L p 0 .224 .86 r
F P
0 g
s
.5 .47615 m .5 .50417 L .46834 .47775 L p 0 .224 .86 r
F P
0 g
s
.4677 .51934 m .43622 .49253 L .46834 .47775 L p 0 .21 .492 r
F P
0 g
s
.46834 .47775 m .5 .50417 L .4677 .51934 L p 0 .21 .492 r
F P
0 g
s
.5 .50417 m .5 .47615 L .46807 .44985 L p 0 .224 .86 r
F P
0 g
s
.5 .47615 m .5 .50417 L .53248 .53128 L p 0 .224 .86 r
F P
0 g
s
.5 .50417 m .5 .47615 L .46742 .49124 L p 0 .47 .925 r
F P
0 g
s
.5 .47615 m .5 .50417 L .4677 .51934 L p 0 .47 .925 r
F P
0 g
s
.4677 .51934 m .46742 .49124 L .5 .47615 L p 0 .47 .925 r
F P
0 g
s
.53248 .53128 m .53277 .50313 L .5 .47615 L p 0 .224 .86 r
F P
0 g
s
.5 .47615 m .53277 .50313 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.46742 .49124 m .47179 .48921 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.47179 .48921 m .5 .47615 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.53105 .57032 m .5 .54391 L .5 .60192 L p 0 .228 .862 r
F P
0 g
s
.5 .54391 m .53105 .57032 L .5 .58546 L p 0 .218 .512 r
F P
0 g
s
.5 .58546 m .53105 .57032 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.5 .51744 m .5 .54391 L .53105 .57032 L p 0 .228 .862 r
F P
0 g
s
.53105 .57032 m .5 .54391 L .5 .51744 L p 0 .228 .862 r
F P
0 g
s
.53105 .57032 m .53131 .54374 L .5 .51744 L p 0 .228 .862 r
F P
0 g
s
.5 .51744 m .53131 .54374 L .53105 .57032 L p 0 .228 .862 r
F P
0 g
s
.5 .58546 m .53105 .57032 L .56288 .59739 L p 0 .218 .512 r
F P
0 g
s
.56288 .59739 m .53166 .61291 L .5 .58546 L p 0 .218 .512 r
F P
0 g
s
.53105 .57032 m .5 .58546 L .53166 .61291 L p 0 .218 .512 r
F P
0 g
s
.56288 .59739 m .59366 .58208 L .60002 .60121 L p 0 .473 .927 r
F P
0 g
s
.52419 .63931 m .5 .62866 L .53166 .61291 L closepath p 0 .473 .927 r
F P
0 g
s
.64295 .58784 m .62325 .57165 L .50744 .62937 L p .762 0 0 r
F P
0 g
s
.53166 .61291 m .56288 .59739 L .53105 .57032 L p 0 .218 .512 r
F P
0 g
s
.59366 .58208 m .56288 .59739 L .56341 .5707 L p 0 .473 .927 r
F P
0 g
s
.56341 .5707 m .59445 .55545 L .59366 .58208 L p 0 .473 .927 r
F P
0 g
s
.5 .58546 m .53166 .61291 L .5 .62866 L p 0 .218 .512 r
F P
0 g
s
.5 .62866 m .53166 .61291 L .5 .58546 L p 0 .218 .512 r
F P
0 g
s
.56341 .5707 m .56288 .59739 L .53166 .61291 L p 0 .473 .927 r
F P
0 g
s
.59445 .55545 m .56341 .5707 L .56395 .54356 L p 0 .473 .927 r
F P
0 g
s
.53193 .58616 m .53166 .61291 L .5 .62866 L p 0 .473 .927 r
F P
0 g
s
.53166 .61291 m .53193 .58616 L .56341 .5707 L p 0 .473 .927 r
F P
0 g
s
.56395 .54356 m .56341 .5707 L .53193 .58616 L p 0 .473 .927 r
F P
0 g
s
.5 .62866 m .5 .60185 L .53193 .58616 L p 0 .473 .927 r
F P
0 g
s
.53221 .55896 m .53193 .58616 L .5 .60185 L p 0 .473 .927 r
F P
0 g
s
.53193 .58616 m .53221 .55896 L .56395 .54356 L p 0 .473 .927 r
F P
0 g
s
.53248 .53128 m .5 .50417 L p .5 .54105 L 0 .21 .492 r
F P
0 g
s
.5 .54684 m .50436 .54476 L p .5 .54105 L 0 .21 .492 r
F P
0 g
s
.50436 .54476 m .53248 .53128 L p .5 .54105 L 0 .21 .492 r
F P
0 g
s
.53277 .50313 m .53248 .53128 L .5 .50417 L p 0 .224 .86 r
F P
0 g
s
.5 .50417 m .53248 .53128 L .50436 .54476 L p 0 .21 .492 r
F P
0 g
s
.50436 .54476 m .5 .54684 L p .5 .54105 L 0 .21 .492 r
F P
0 g
s
.5 .50417 m .50436 .54476 L .5 .54105 L 0 .21 .492 r
F
.5 .60185 m .5 .57459 L .53221 .55896 L p 0 .473 .927 r
F P
0 g
s
.53248 .53128 m .53221 .55896 L .5 .57459 L p 0 .473 .927 r
F P
0 g
s
.53277 .50313 m .5 .47615 L p .5 .51285 L 0 .207 .485 r
F P
0 g
s
.5 .51862 m .5044 .51654 L p .5 .51285 L 0 .207 .485 r
F P
0 g
s
.5044 .51654 m .53277 .50313 L p .5 .51285 L 0 .207 .485 r
F P
0 g
s
.5 .46317 m .5 .43535 L .53211 .46127 L p 0 .228 .862 r
F P
0 g
s
.46807 .44985 m .5 .43535 L .53211 .46127 L p 0 .207 .485 r
F P
0 g
s
.5 .47615 m .53211 .46127 L .5 .43535 L p 0 .207 .485 r
F P
0 g
s
.53211 .46127 m .5 .47615 L .46807 .44985 L p 0 .207 .485 r
F P
0 g
s
.5 .44763 m .5 .47615 L .53211 .46127 L p 0 .47 .925 r
F P
0 g
s
.53148 .42106 m .5 .43535 L .53211 .46127 L p 0 .207 .485 r
F P
0 g
s
.5 .42375 m .5 .39614 L .53148 .42106 L p 0 .232 .863 r
F P
0 g
s
.5 .42375 m .5 .39614 L .46869 .41008 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .5 .39614 L .53148 .42106 L p 0 .207 .485 r
F P
0 g
s
.5 .43535 m .53148 .42106 L .5 .39614 L p 0 .207 .485 r
F P
0 g
s
.53148 .42106 m .5 .43535 L .46869 .41008 L p 0 .207 .485 r
F P
0 g
s
.53088 .38239 m .5 .39614 L .53148 .42106 L p 0 .207 .485 r
F P
0 g
s
.53175 .39285 m .53148 .42106 L .5 .39614 L p 0 .232 .863 r
F P
0 g
s
.53113 .35441 m .53088 .38239 L .5 .39614 L p 0 .464 .922 r
F P
0 g
s
.5 .36808 m .5 .39614 L .53088 .38239 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .5 .36808 L .53113 .35441 L p 0 .464 .922 r
F P
0 g
s
.5 .36808 m .5 .39614 L .53148 .42106 L p 0 .232 .863 r
F P
0 g
s
.53148 .42106 m .53175 .39285 L .5 .36808 L p 0 .232 .863 r
F P
0 g
s
.53175 .39285 m .53148 .42106 L .5 .43535 L p 0 .467 .923 r
F P
0 g
s
.5 .40706 m .5 .43535 L .53148 .42106 L p 0 .467 .923 r
F P
0 g
s
.5 .43535 m .5 .40706 L .53175 .39285 L p 0 .467 .923 r
F P
0 g
s
.5 .40706 m .5 .43535 L .53211 .46127 L p 0 .228 .862 r
F P
0 g
s
.53239 .43284 m .53211 .46127 L .5 .43535 L p 0 .228 .862 r
F P
0 g
s
.53211 .46127 m .53239 .43284 L .5 .40706 L p 0 .228 .862 r
F P
0 g
s
.53239 .43284 m .53211 .46127 L .5 .47615 L p 0 .47 .925 r
F P
0 g
s
.56505 .48786 m .53277 .50313 L .5 .47615 L p 0 .207 .485 r
F P
0 g
s
.5 .47615 m .5 .44763 L .53239 .43284 L p 0 .47 .925 r
F P
0 g
s
.5 .44763 m .5 .47615 L .53277 .50313 L p 0 .224 .86 r
F P
0 g
s
.53277 .50313 m .5 .47615 L p .5286 .47086 L 0 .224 .86 r
F P
0 g
s
.5 .57459 m .5 .54684 L .53248 .53128 L p 0 .473 .927 r
F P
0 g
s
.53277 .50313 m .53248 .53128 L .5 .54684 L p 0 .473 .927 r
F P
0 g
s
.53248 .53128 m .53277 .50313 L .56505 .48786 L p 0 .473 .927 r
F P
0 g
s
.56114 .45572 m .53239 .43284 L p .56505 .48786 L 0 .228 .862 r
F P
0 g
s
.56505 .48786 m .56551 .46505 L .56114 .45572 L p 0 .228 .862 r
F P
0 g
s
.56551 .46505 m .56505 .48786 L .53277 .50313 L p 0 .473 .927 r
F P
0 g
s
.5 .51744 m .5 .54391 L .46912 .55868 L p 0 .467 .923 r
F P
0 g
s
.5 .51744 m .46886 .53215 L .46912 .55868 L p 0 .467 .923 r
F P
0 g
s
.46912 .55868 m .46886 .53215 L .5 .51744 L p 0 .467 .923 r
F P
0 g
s
.47024 .57592 m .5 .60192 L .5 .54391 L p 0 .228 .862 r
F P
0 g
s
.5 .61327 m .47034 .58723 L .47024 .57592 L p 0 .228 .862 r
F P
0 g
s
.47024 .57592 m .5 .60192 L .5 .61327 L p 0 .228 .862 r
F P
0 g
s
.5 .60192 m .47024 .57592 L .47034 .58723 L p 0 .228 .862 r
F P
0 g
s
.47034 .58723 m .5 .61327 L .5 .60192 L p 0 .228 .862 r
F P
0 g
s
.48593 .59553 m .5 .60192 L .5 .54391 L closepath p 0 .467 .923 r
F P
0 g
s
.5 .54391 m .5 .60192 L .48593 .59553 L closepath p 0 .467 .923 r
F P
0 g
s
.48593 .59553 m .5 .54391 L .46912 .55868 L p 0 .467 .923 r
F P
0 g
s
.3812 .59045 m .40983 .61657 L .47034 .58723 L p 0 .225 .528 r
F P
0 g
s
.5 .61327 m .47034 .58723 L .40983 .61657 L p 0 .225 .528 r
F P
0 g
s
.46912 .55868 m .46216 .58473 L .48593 .59553 L p 0 .467 .923 r
F P
0 g
s
.5 .54391 m .48593 .59553 L .46216 .58473 L p 0 .467 .923 r
F P
0 g
s
.46216 .58473 m .46912 .55868 L .5 .54391 L p 0 .467 .923 r
F P
0 g
s
.5 .58546 m .46912 .55868 L .5 .54391 L p 0 .218 .512 r
F P
0 g
s
.5 .54391 m .46912 .55868 L .5 .58546 L p 0 .218 .512 r
F P
0 g
s
.5 .50417 m .4677 .51934 L .5 .54684 L p 0 .21 .492 r
F P
0 g
s
.46742 .49124 m .4677 .51934 L .5 .50417 L p 0 .47 .925 r
F P
0 g
s
.5 .54684 m .4677 .51934 L .5 .50417 L p 0 .21 .492 r
F P
0 g
s
.5 .61327 m .5 .60192 L .48593 .59553 L p 0 .467 .923 r
F P
0 g
s
.40983 .61657 m .43916 .64332 L .5 .61327 L p 0 .225 .528 r
F P
0 g
s
.48593 .59553 m .43916 .64332 L .5 .61327 L p 0 .467 .923 r
F P
0 g
s
.5 .60192 m .5 .61327 L .43916 .64332 L p 0 .467 .923 r
F P
0 g
s
.43916 .64332 m .48593 .59553 L .5 .60192 L p 0 .467 .923 r
F P
0 g
s
.43849 .60888 m .43916 .64332 L .48593 .59553 L p 0 .467 .923 r
F P
0 g
s
.48593 .59553 m .46216 .58473 L .43849 .60888 L p 0 .467 .923 r
F P
0 g
s
.46216 .58473 m .48593 .59553 L .43916 .64332 L p 0 .467 .923 r
F P
0 g
s
.4081 .45402 m .41104 .4527 L p .41025 .45113 L 0 .461 .92 r
F P
0 g
s
.41104 .4527 m .43915 .44008 L p .41025 .45113 L 0 .461 .92 r
F P
0 g
s
.43915 .44008 m .43866 .41298 L p .41025 .45113 L 0 .461 .92 r
F P
0 g
s
.43866 .41298 m .40735 .42685 L .4081 .45402 L p 0 .461 .92 r
F P
0 g
s
.43915 .44008 m .4081 .45402 L .40884 .48075 L p 0 .461 .92 r
F P
0 g
s
.43866 .41298 m .40735 .42685 L .43746 .45198 L p 0 .21 .492 r
F P
0 g
s
.40658 .39922 m .40735 .42685 L .43866 .41298 L p 0 .461 .92 r
F P
0 g
s
.46895 .43777 m .43866 .41298 L .43915 .44008 L p 0 .228 .862 r
F P
0 g
s
.43915 .44008 m .43866 .41298 L .46895 .43777 L p 0 .228 .862 r
F P
0 g
s
.43746 .45198 m .46895 .43777 L .43866 .41298 L p 0 .21 .492 r
F P
0 g
s
.40735 .42685 m .43866 .41298 L .46895 .43777 L p 0 .21 .492 r
F P
0 g
s
.46895 .43777 m .43746 .45198 L .40735 .42685 L p 0 .21 .492 r
F P
0 g
s
.40658 .39922 m .40735 .42685 L .43746 .45198 L p 0 .224 .86 r
F P
0 g
s
.37588 .40883 m .36934 .43009 L .3769 .43651 L .36 0 0 r
F
.37521 .3906 m .37164 .40528 L .37588 .40883 L F
.37458 .37359 m .37287 .39204 L .37521 .3906 L F
.37287 .39204 m .37164 .40528 L .37521 .3906 L F
.40596 .37679 m .40984 .37442 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.37458 .37359 m .35669 .35885 L .3627 .50172 L .36 0 0 r
F
.37588 .40883 m .3769 .43651 L p .36798 .40221 L F P
0 g
s
.3769 .43651 m .37988 .51687 L p .36683 .42795 L .36 0 0 r
F P
0 g
s
.37988 .51687 m .3627 .50172 L .35669 .35885 L p .36 0 0 r
F P
0 g
s
.37988 .51687 m .3627 .50172 L .35085 .51069 L .762 0 0 r
F
.37988 .51687 m .35085 .51069 L .37819 .51816 L F
.37642 .44741 m .37988 .51687 L .37819 .51816 L 1 0 0 r
F
.37728 .44677 m .37988 .51687 L .37642 .44741 L F
.37762 .49496 m .40884 .48075 L .4081 .45402 L p 0 .461 .92 r
F P
0 g
s
.37642 .44741 m .37819 .51816 L .37556 .44805 L 1 0 0 r
F
.4081 .45402 m .37662 .46815 L .37762 .49496 L p 0 .461 .92 r
F P
0 g
s
.37662 .46815 m .4081 .45402 L .40735 .42685 L p 0 .461 .92 r
F P
0 g
s
.35669 .35885 m .37458 .37359 L .37521 .3906 L p .36 0 0 r
F P
0 g
s
.37521 .3906 m .37588 .40883 L p .37009 .39375 L .36 0 0 r
F P
0 g
s
.35669 .35885 m .37521 .3906 L .37009 .39375 L .36 0 0 r
F
.37458 .37359 m .375 .39068 L .37281 .37485 L 1 0 0 r
F
.375 .39068 m .37363 .39122 L .37281 .37485 L F
.35669 .35885 m .37588 .40883 L .36798 .40221 L .36 0 0 r
F
.35669 .35885 m .3769 .43651 L .36683 .42795 L F
.37164 .40528 m .36934 .43009 L .37588 .40883 L F
.36934 .43009 m .3627 .50172 L .3769 .43651 L F
.37458 .37359 m .37728 .44677 L .37642 .44741 L 1 0 0 r
F
.37752 .38837 m .37372 .39071 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.40984 .37442 m .38186 .38649 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.38186 .38649 m .37752 .38837 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.375 .39068 m .37642 .44741 L .37363 .39122 L 1 0 0 r
F
.37642 .44741 m .37556 .44805 L .37281 .37485 L F
.40735 .42685 m .3756 .44091 L .37662 .46815 L p 0 .461 .92 r
F P
0 g
s
.40735 .42685 m .37986 .43902 L p .40578 .46103 L 0 .21 .492 r
F P
0 g
s
.40553 .46639 m .43746 .45198 L .40735 .42685 L p 0 .21 .492 r
F P
0 g
s
.40735 .42685 m .43746 .45198 L p .38381 .44238 L 0 .21 .492 r
F P
0 g
s
.37986 .43902 m .40735 .42685 L p .38381 .44238 L 0 .21 .492 r
F P
0 g
s
.37456 .41321 m .3756 .44091 L .40735 .42685 L p 0 .461 .92 r
F P
0 g
s
.37456 .41321 m .40473 .43856 L p .40498 .43322 L 0 .207 .485 r
F P
0 g
s
.40658 .39922 m .40532 .426 L p .40735 .42685 L 0 .461 .92 r
F P
0 g
s
.38754 .4186 m .37886 .41133 L .37456 .41321 L p 0 .461 .92 r
F P
0 g
s
.40658 .39922 m .37886 .41133 L p .40498 .43322 L 0 .207 .485 r
F P
0 g
s
.37886 .41133 m .37456 .41321 L p .40498 .43322 L 0 .207 .485 r
F P
0 g
s
.37986 .43902 m .3756 .44091 L p .40578 .46103 L 0 .21 .492 r
F P
0 g
s
.3756 .44091 m .37986 .43902 L p .38381 .44238 L 0 .21 .492 r
F P
0 g
s
.37372 .39071 m .37805 .38884 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.37805 .38884 m .40596 .37679 L p .37855 .38853 L 0 .48 .858 r
F P
0 g
s
.40735 .42685 m .40658 .39922 L .43694 .42422 L p 0 .224 .86 r
F P
0 g
s
.43746 .45198 m .43694 .42422 L .40658 .39922 L p 0 .224 .86 r
F P
0 g
s
.40658 .39922 m .43694 .42422 L p .38284 .41467 L 0 .207 .485 r
F P
0 g
s
.37456 .41321 m .37886 .41133 L p .38284 .41467 L 0 .207 .485 r
F P
0 g
s
.37886 .41133 m .40658 .39922 L p .38284 .41467 L 0 .207 .485 r
F P
0 g
s
.3756 .44091 m .40553 .46639 L p .40578 .46103 L 0 .21 .492 r
F P
0 g
s
.37861 .52133 m .40957 .50706 L .40884 .48075 L p 0 .461 .92 r
F P
0 g
s
.43964 .46674 m .40884 .48075 L .40957 .50706 L p 0 .461 .92 r
F P
0 g
s
.40884 .48075 m .37762 .49496 L .37861 .52133 L p 0 .461 .92 r
F P
0 g
s
.37861 .52133 m .37762 .49496 L .40708 .52069 L p 0 .22 .858 r
F P
0 g
s
.40708 .52069 m .40784 .54718 L .37861 .52133 L p 0 .22 .858 r
F P
0 g
s
.43916 .64332 m .43849 .60888 L .46216 .58473 L p 0 .467 .923 r
F P
0 g
s
.37762 .49496 m .37662 .46815 L .40631 .49377 L p 0 .22 .858 r
F P
0 g
s
.40631 .49377 m .40708 .52069 L .37762 .49496 L p 0 .22 .858 r
F P
0 g
s
.46216 .58473 m .4378 .57366 L .43849 .60888 L closepath p 0 .467 .923 r
F P
0 g
s
.46912 .55868 m .4378 .57366 L .46216 .58473 L closepath p 0 .467 .923 r
F P
0 g
s
.43849 .60888 m .4378 .57366 L .46216 .58473 L closepath p 0 .467 .923 r
F P
0 g
s
.46216 .58473 m .4378 .57366 L .46912 .55868 L closepath p 0 .467 .923 r
F P
0 g
s
.40784 .54718 m .40708 .52069 L .43728 .54707 L p 0 .22 .858 r
F P
0 g
s
.40784 .54718 m .4378 .57366 L .46912 .55868 L p 0 .218 .512 r
F P
0 g
s
.43728 .54707 m .4378 .57366 L .40784 .54718 L p 0 .22 .858 r
F P
0 g
s
.37662 .46815 m .3756 .44091 L .40553 .46639 L p 0 .22 .858 r
F P
0 g
s
.40553 .46639 m .40631 .49377 L .37662 .46815 L p 0 .22 .858 r
F P
0 g
s
.46851 .60082 m .4378 .57366 L .46912 .55868 L p 0 .218 .512 r
F P
0 g
s
.46912 .55868 m .5 .58546 L .46851 .60082 L p 0 .218 .512 r
F P
0 g
s
.46851 .60082 m .5 .58546 L .46912 .55868 L p 0 .218 .512 r
F P
0 g
s
.46912 .55868 m .4378 .57366 L .46851 .60082 L p 0 .218 .512 r
F P
0 g
s
.4378 .57366 m .46912 .55868 L .46886 .53215 L p 0 .467 .923 r
F P
0 g
s
.46886 .53215 m .46912 .55868 L .4378 .57366 L p 0 .467 .923 r
F P
0 g
s
.40708 .52069 m .40631 .49377 L .43676 .52003 L p 0 .22 .858 r
F P
0 g
s
.43676 .52003 m .43728 .54707 L .40708 .52069 L p 0 .22 .858 r
F P
0 g
s
.3756 .44091 m .37456 .41321 L .40473 .43856 L p 0 .22 .858 r
F P
0 g
s
.43746 .45198 m .40553 .46639 L .3756 .44091 L p 0 .21 .492 r
F P
0 g
s
.40473 .43856 m .40553 .46639 L .3756 .44091 L p 0 .22 .858 r
F P
0 g
s
.46886 .53215 m .43728 .54707 L .4378 .57366 L p 0 .467 .923 r
F P
0 g
s
.4378 .57366 m .43728 .54707 L .46886 .53215 L p 0 .467 .923 r
F P
0 g
s
.46851 .60082 m .4378 .57366 L .43728 .54707 L p 0 .22 .858 r
F P
0 g
s
.37372 .39071 m .37456 .41321 L .40658 .39922 L p 0 .461 .92 r
F P
0 g
s
.40658 .39922 m .40596 .37679 L .37372 .39071 L p 0 .461 .92 r
F P
0 g
s
.40631 .49377 m .40553 .46639 L .43622 .49253 L p 0 .22 .858 r
F P
0 g
s
.43622 .49253 m .43676 .52003 L .40631 .49377 L p 0 .22 .858 r
F P
0 g
s
.5 .62866 m .46851 .60082 L .5 .58546 L p 0 .218 .512 r
F P
0 g
s
.43694 .42422 m .43746 .45198 L .40735 .42685 L p 0 .224 .86 r
F P
0 g
s
.43694 .42422 m .43746 .45198 L .40553 .46639 L p 0 .464 .922 r
F P
0 g
s
.43746 .45198 m .40553 .46639 L .43622 .49253 L p 0 .21 .492 r
F P
0 g
s
.40473 .43856 m .40553 .46639 L .43746 .45198 L p 0 .464 .922 r
F P
0 g
s
.5 .58546 m .46851 .60082 L .5 .62866 L p 0 .218 .512 r
F P
0 g
s
.43622 .49253 m .46834 .47775 L .43746 .45198 L p 0 .21 .492 r
F P
0 g
s
.40553 .46639 m .43746 .45198 L .46834 .47775 L p 0 .21 .492 r
F P
0 g
s
.43815 .38543 m .43866 .41298 L .46954 .3993 L p 0 .461 .92 r
F P
0 g
s
.43815 .38543 m .43866 .41298 L .46895 .43777 L p 0 .228 .862 r
F P
0 g
s
.46869 .41008 m .46895 .43777 L .43866 .41298 L p 0 .228 .862 r
F P
0 g
s
.46895 .43777 m .46869 .41008 L .43815 .38543 L p 0 .228 .862 r
F P
0 g
s
.46869 .41008 m .46895 .43777 L .43746 .45198 L p 0 .464 .922 r
F P
0 g
s
.43694 .42422 m .43746 .45198 L .46895 .43777 L p 0 .464 .922 r
F P
0 g
s
.43746 .45198 m .43694 .42422 L .46869 .41008 L p 0 .464 .922 r
F P
0 g
s
.43694 .42422 m .43746 .45198 L .46834 .47775 L p 0 .224 .86 r
F P
0 g
s
.46807 .44985 m .46834 .47775 L .43746 .45198 L p 0 .224 .86 r
F P
0 g
s
.46834 .47775 m .43622 .49253 L .40553 .46639 L p 0 .21 .492 r
F P
0 g
s
.43567 .46456 m .43622 .49253 L .46834 .47775 L p 0 .467 .923 r
F P
0 g
s
.46834 .47775 m .46807 .44985 L .43694 .42422 L p 0 .224 .86 r
F P
0 g
s
.46807 .44985 m .46834 .47775 L .43622 .49253 L p 0 .467 .923 r
F P
0 g
s
.43694 .42422 m .40473 .43856 L .37456 .41321 L p 0 .207 .485 r
F P
0 g
s
.37456 .41321 m .37372 .39071 L p .40392 .41025 L 0 .22 .858 r
F P
0 g
s
.40392 .41025 m .40473 .43856 L .37456 .41321 L p 0 .22 .858 r
F P
0 g
s
.43728 .54707 m .46824 .57412 L .46851 .60082 L p 0 .22 .858 r
F P
0 g
s
.46824 .57412 m .43728 .54707 L .43676 .52003 L p 0 .22 .858 r
F P
0 g
s
.38037 .3866 m .37752 .38837 L .40984 .37442 L p 0 .48 .858 r
F P
0 g
s
.43866 .41298 m .43815 .38543 L .40658 .39922 L p 0 .461 .92 r
F P
0 g
s
.43866 .41298 m .43815 .38543 L .46869 .41008 L p 0 .228 .862 r
F P
0 g
s
.40658 .39922 m .43815 .38543 L .46869 .41008 L p 0 .207 .485 r
F P
0 g
s
.43815 .38543 m .40658 .39922 L .43694 .42422 L p 0 .207 .485 r
F P
0 g
s
.40596 .37679 m .40658 .39922 L .43815 .38543 L p 0 .461 .92 r
F P
0 g
s
.43815 .38543 m .43774 .36307 L .40596 .37679 L p 0 .461 .92 r
F P
0 g
s
.40596 .37679 m .43774 .36307 L .4417 .36066 L p 0 .48 .858 r
F P
0 g
s
.46869 .41008 m .43694 .42422 L .40658 .39922 L p 0 .207 .485 r
F P
0 g
s
.40596 .37679 m .40658 .39922 L .43694 .42422 L p 0 .224 .86 r
F P
0 g
s
.40658 .39922 m .40596 .37679 L p .4364 .39599 L 0 .224 .86 r
F P
0 g
s
.4417 .36066 m .40984 .37442 L .40596 .37679 L p 0 .48 .858 r
F P
0 g
s
.40984 .37442 m .40596 .37679 L p .43694 .42422 L 0 .224 .86 r
F P
0 g
s
.40596 .37679 m .40984 .37442 L .4364 .39599 L p 0 .224 .86 r
F P
0 g
s
.43694 .42422 m .4364 .39599 L .40984 .37442 L p 0 .224 .86 r
F P
0 g
s
.37752 .38837 m .40984 .37442 L .4364 .39599 L p 0 .204 .478 r
F P
0 g
s
.40984 .37442 m .37752 .38837 L .40392 .41025 L p 0 .204 .478 r
F P
0 g
s
.40553 .46639 m .40473 .43856 L .43694 .42422 L p 0 .464 .922 r
F P
0 g
s
.40553 .46639 m .40473 .43856 L .43567 .46456 L p 0 .22 .858 r
F P
0 g
s
.43567 .46456 m .43622 .49253 L .40553 .46639 L p 0 .22 .858 r
F P
0 g
s
.5 .62866 m .46851 .60082 L .46824 .57412 L p 0 .22 .858 r
F P
0 g
s
.37372 .39071 m .37752 .38837 L .40392 .41025 L p 0 .22 .858 r
F P
0 g
s
.43676 .52003 m .46797 .54696 L .46824 .57412 L p 0 .22 .858 r
F P
0 g
s
.46797 .54696 m .43676 .52003 L .43622 .49253 L p 0 .22 .858 r
F P
0 g
s
.40473 .43856 m .43694 .42422 L .40658 .39922 L p 0 .207 .485 r
F P
0 g
s
.4364 .39599 m .43694 .42422 L .40658 .39922 L p 0 .224 .86 r
F P
0 g
s
.4364 .39599 m .40392 .41025 L .37752 .38837 L p 0 .204 .478 r
F P
0 g
s
.37752 .38837 m .38037 .3866 L .4038 .40598 L p 0 .22 .858 r
F P
0 g
s
.4038 .40598 m .40392 .41025 L .37752 .38837 L p 0 .22 .858 r
F P
0 g
s
.46824 .57412 m .5 .60185 L .5 .62866 L p 0 .22 .858 r
F P
0 g
s
.5 .60185 m .46824 .57412 L .46797 .54696 L p 0 .22 .858 r
F P
0 g
s
.37324 .37793 m .37861 .52133 L .5 .62866 L p .358 0 0 r
F P
0 g
s
.20383 .6749 m .3812 .59045 L .37861 .52133 L p 0 .461 .92 r
F P
0 g
s
.43916 .64332 m .3812 .59045 L .20383 .6749 L p 0 .225 .528 r
F P
0 g
s
.37861 .52133 m .19713 .60495 L .20383 .6749 L p 0 .461 .92 r
F P
0 g
s
.20051 .64032 m .22833 .66839 L .22522 .6329 L p 0 .193 .843 r
F P
0 g
s
.22833 .66839 m .20051 .64032 L .20383 .6749 L p 0 .193 .843 r
F P
0 g
s
.20383 .6749 m .20051 .64032 L .17101 .64334 L p 0 .461 .92 r
F P
0 g
s
.17101 .64334 m .145 .68157 L .20383 .6749 L p 0 .461 .92 r
F P
0 g
s
.22522 .6329 m .19713 .60495 L .20051 .64032 L p 0 .193 .843 r
F P
0 g
s
.20383 .6749 m .25962 .732 L .43916 .64332 L p 0 .225 .528 r
F P
0 g
s
.20383 .6749 m .23138 .70309 L .22833 .66839 L p 0 .193 .843 r
F P
0 g
s
.22522 .6329 m .22833 .66839 L .25686 .69719 L p 0 .193 .843 r
F P
0 g
s
.25686 .69719 m .25404 .66157 L .22522 .6329 L p 0 .193 .843 r
F P
0 g
s
.20383 .6749 m .19713 .60495 L .25404 .66157 L p 0 .193 .843 r
F P
0 g
s
.19713 .60495 m .17101 .64334 L .20051 .64032 L closepath p 0 .461 .92 r
F P
0 g
s
.19713 .60495 m .22522 .6329 L .19872 .67172 L p 0 .223 .695 r
F P
0 g
s
.3812 .59045 m .43916 .64332 L .4378 .57366 L p 0 .22 .858 r
F P
0 g
s
.4378 .57366 m .37861 .52133 L .3812 .59045 L p 0 .22 .858 r
F P
0 g
s
.40885 .58225 m .37992 .55626 L .37861 .52133 L p 0 .22 .858 r
F P
0 g
s
.37861 .52133 m .40784 .54718 L .40885 .58225 L p 0 .22 .858 r
F P
0 g
s
.43849 .60888 m .40885 .58225 L .40784 .54718 L p 0 .22 .858 r
F P
0 g
s
.40784 .54718 m .4378 .57366 L .43849 .60888 L p 0 .22 .858 r
F P
0 g
s
.37861 .52133 m .35353 .53288 L p .42515 .57971 L .762 0 0 r
F P
0 g
s
.4378 .57366 m .37861 .52133 L p .42515 .57971 L .762 0 0 r
F P
0 g
s
.37819 .51816 m .35085 .51069 L .34745 .52209 L .762 0 0 r
F
.37819 .51816 m .34745 .52209 L .37772 .5198 L F
.37532 .44886 m .37772 .5198 L .37508 .44966 L 1 0 0 r
F
.37556 .44805 m .37819 .51816 L .37532 .44886 L F
.37553 .45042 m .37861 .52133 L .37598 .45118 L .1 0 0 r
F
.37532 .44886 m .37819 .51816 L .37772 .5198 L 1 0 0 r
F
.37553 .45042 m .37772 .5198 L .37861 .52133 L .1 0 0 r
F
.37508 .44966 m .37772 .5198 L .37553 .45042 L F
.37772 .5198 m .35353 .53288 L .37861 .52133 L .762 0 0 r
F
.37772 .5198 m .34745 .52209 L .35353 .53288 L F
.35085 .51069 m .28782 .49345 L .27656 .52745 L F
.35085 .51069 m .27656 .52745 L .34745 .52209 L F
.34764 .44067 m .35085 .51069 L .34745 .52209 L 1 0 0 r
F
.34764 .44067 m .34745 .52209 L .35085 .51069 L F
.34764 .44067 m .34745 .52209 L .34415 .45193 L F
.3459 .44628 m .34745 .52209 L .34764 .44067 L F
.34724 .45724 m .35035 .46259 L .35353 .53288 L .1 0 0 r
F
.3459 .44628 m .34415 .45193 L .34745 .52209 L 1 0 0 r
F
.34415 .45193 m .35353 .53288 L .34745 .52209 L .1 0 0 r
F
.34724 .45724 m .35353 .53288 L .34415 .45193 L F
.34415 .45193 m .34745 .52209 L .35353 .53288 L F
.34745 .52209 m .29394 .56034 L .35353 .53288 L .762 0 0 r
F
.34745 .52209 m .27656 .52745 L .29394 .56034 L F
.34415 .45193 m .35353 .53288 L .35035 .46259 L .1 0 0 r
F
.35353 .53288 m .35035 .46259 L .28941 .48972 L p .951 0 0 r
F P
0 g
s
.37992 .55626 m .40885 .58225 L .40983 .61657 L p 0 .22 .858 r
F P
0 g
s
.40983 .61657 m .40885 .58225 L .43849 .60888 L p 0 .22 .858 r
F P
0 g
s
.41243 .5858 m .4378 .57366 L p .41271 .59596 L 0 .467 .923 r
F P
0 g
s
.35353 .53288 m .29394 .56034 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.40983 .61657 m .3812 .59045 L .37992 .55626 L p 0 .22 .858 r
F P
0 g
s
.29394 .56034 m .35212 .61465 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.41243 .5858 m .35353 .53288 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.40384 .57808 m .32405 .58845 L .35353 .53288 L 0 .218 .512 r
F
.19713 .60495 m .29394 .56034 L p .32405 .58845 L F P
0 g
s
.29394 .56034 m .35353 .53288 L p .32405 .58845 L 0 .218 .512 r
F P
0 g
s
.28941 .48972 m .29394 .56034 L .35353 .53288 L p .951 0 0 r
F P
0 g
s
.35035 .46259 m .35353 .53288 L .29394 .56034 L .951 0 0 r
F
.35035 .46259 m .29394 .56034 L .28941 .48972 L F
.29394 .56034 m .28941 .48972 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.41243 .5858 m .41243 .5858 L .35212 .61465 L 0 .467 .923 r
F
.25962 .732 m .25404 .66157 L p .35212 .61465 L F P
0 g
s
.41243 .5858 m .35341 .64226 L .35212 .61465 L 0 .467 .923 r
F
.35341 .64226 m .25962 .732 L .35212 .61465 L F
.25404 .66157 m .25404 .66157 L p .35212 .61465 L F P
0 g
s
.41271 .59596 m .25962 .732 L .41243 .5858 L 0 .467 .923 r
F
.43849 .60888 m .43916 .64332 L .40983 .61657 L p 0 .22 .858 r
F P
0 g
s
.4378 .57366 m .43916 .64332 L .41435 .65557 L p 0 .467 .923 r
F P
0 g
s
.41435 .65557 m .25962 .732 L p .41271 .59596 L 0 .467 .923 r
F P
0 g
s
.4378 .57366 m .41435 .65557 L .41271 .59596 L 0 .467 .923 r
F
.43916 .64332 m .4378 .57366 L p .41271 .59596 L F P
0 g
s
.25962 .732 m .41435 .65557 L p .41271 .59596 L 0 .467 .923 r
F P
0 g
s
.43916 .64332 m .25962 .732 L .3183 .79205 L p 0 .225 .528 r
F P
0 g
s
.25404 .66157 m .25962 .732 L p .3537 .64839 L 0 .467 .923 r
F P
0 g
s
.28858 .76164 m .28613 .72672 L .25686 .69719 L p 0 .193 .843 r
F P
0 g
s
.4378 .57366 m .41243 .5858 L .41271 .59596 L 0 .467 .923 r
F
.34878 .54344 m .34878 .54344 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.41271 .59596 m .35212 .61465 L .3537 .64839 L 0 .467 .923 r
F
.41243 .5858 m .35212 .61465 L .41271 .59596 L F
.35353 .53288 m .41243 .5858 L p .42515 .57971 L .762 0 0 r
F P
0 g
s
.37861 .52133 m .4378 .57366 L p .40384 .57808 L 0 .218 .512 r
F P
0 g
s
.35353 .53288 m .37861 .52133 L p .40384 .57808 L 0 .218 .512 r
F P
0 g
s
.37281 .37485 m .37532 .44886 L .37232 .37643 L 1 0 0 r
F
.37532 .44886 m .37508 .44966 L .37232 .37643 L F
.37281 .37485 m .37556 .44805 L .37532 .44886 L F
.37232 .37643 m .37553 .45042 L .37324 .37793 L .1 0 0 r
F
.37553 .45042 m .37598 .45118 L .37324 .37793 L F
.37232 .37643 m .37508 .44966 L .37553 .45042 L F
.35976 .43182 m .35069 .43085 L .35235 .4255 L .757 0 0 r
F
.35669 .35885 m .34429 .36757 L .34764 .44067 L 1 0 0 r
F
.35669 .35885 m .34764 .44067 L .35371 .43623 L F
.35669 .35885 m .35371 .43623 L .35976 .43182 L F
.37324 .37793 m .34702 .38917 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.37861 .52133 m .37598 .45118 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.37598 .45118 m .37324 .37793 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.35353 .53288 m .37861 .52133 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.34702 .38917 m .35035 .46259 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.35035 .46259 m .35353 .53288 L p .3632 .45687 L .951 0 0 r
F P
0 g
s
.37324 .37793 m .37861 .52133 L .35353 .53288 L .951 0 0 r
F
.37324 .37793 m .35353 .53288 L .34702 .38917 L F
.35035 .46259 m .35283 .51732 L p .38498 .53131 L .346 0 0 r
F P
0 g
s
.35283 .51732 m .35353 .53288 L p .38498 .53131 L .346 0 0 r
F P
0 g
s
.41331 .67178 m .35212 .61465 L p .35212 .61465 L .317 0 0 r
F P
0 g
s
.40384 .57808 m .34692 .6098 L .32405 .58845 L 0 .218 .512 r
F
.41243 .5858 m .35212 .61465 L p .40384 .57808 L F P
0 g
s
.35212 .61465 m .25404 .66157 L p .34692 .6098 L 0 .218 .512 r
F P
0 g
s
.35212 .61465 m .34692 .6098 L .40384 .57808 L 0 .218 .512 r
F
.4378 .57366 m .43916 .64332 L .5 .69882 L p 0 .22 .858 r
F P
0 g
s
.46886 .63616 m .43849 .60888 L .4378 .57366 L p 0 .22 .858 r
F P
0 g
s
.5 .69882 m .5 .62866 L .4378 .57366 L p 0 .22 .858 r
F P
0 g
s
.5 .66414 m .46886 .63616 L .46851 .60082 L p 0 .22 .858 r
F P
0 g
s
.46886 .63616 m .46921 .67073 L .43916 .64332 L p 0 .22 .858 r
F P
0 g
s
.3183 .79205 m .5 .69882 L .43916 .64332 L p 0 .225 .528 r
F P
0 g
s
.5 .69882 m .46921 .67073 L .46886 .63616 L p 0 .22 .858 r
F P
0 g
s
.46886 .63616 m .5 .66414 L .5 .69882 L p 0 .22 .858 r
F P
0 g
s
.46851 .60082 m .5 .62866 L .5 .66414 L p 0 .22 .858 r
F P
0 g
s
.5 .62866 m .47492 .71169 L .47443 .65166 L 0 .473 .927 r
F
.48797 .63464 m .5 .62866 L p .48639 .61976 L .762 0 0 r
F P
0 g
s
.46868 .61778 m .46886 .63616 L p .45284 .60393 L 0 .22 .858 r
F P
0 g
s
.45284 .60393 m .4378 .57366 L .46868 .61778 L 0 .22 .858 r
F
.4378 .57366 m .46851 .60082 L .46868 .61778 L p F P
0 g
s
.42515 .57971 m .48797 .63464 L .48639 .61976 L .762 0 0 r
F
.47434 .64142 m .48797 .63464 L p .42515 .57971 L F P
0 g
s
.5 .62866 m .4378 .57366 L p .42515 .57971 L .762 0 0 r
F P
0 g
s
.4378 .57366 m .5 .62866 L .47434 .64142 L p 0 .218 .512 r
F P
0 g
s
.53277 .50313 m .5044 .51654 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.5286 .47086 m .5 .44763 L p .53277 .50313 L 0 .224 .86 r
F P
0 g
s
.5 .54684 m .5 .51862 L .53277 .50313 L p 0 .473 .927 r
F P
0 g
s
.53277 .50313 m .533 .48025 L .56551 .46505 L p 0 .473 .927 r
F P
0 g
s
.53277 .50313 m .533 .48025 L .5286 .47086 L p 0 .224 .86 r
F P
0 g
s
.5044 .51654 m .5 .51862 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.5286 .47086 m .533 .48025 L .53277 .50313 L p 0 .224 .86 r
F P
0 g
s
.533 .48025 m .53277 .50313 L .5 .51862 L p 0 .473 .927 r
F P
0 g
s
.5 .47615 m .46742 .49124 L .5 .51862 L p 0 .207 .485 r
F P
0 g
s
.5 .49567 m .49557 .48621 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.533 .48025 m .50443 .4936 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.50443 .4936 m .5 .49567 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.5286 .47086 m .533 .48025 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.49557 .48621 m .5 .48415 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.5 .48415 m .5286 .47086 L p .50059 .48541 L 0 .358 .744 r
F P
0 g
s
.5 .51862 m .5 .49567 L .533 .48025 L p 0 .473 .927 r
F P
0 g
s
.50779 .48332 m .50744 .62937 L p .62325 .57165 L .962 0 0 r
F P
0 g
s
.5105 .50656 m .5077 .51931 L .51245 .52328 L .36 0 0 r
F
.50779 .48332 m .50775 .50069 L .5105 .50656 L F
.50775 .50069 m .5077 .51931 L .5105 .50656 L F
.50779 .48332 m .52774 .5361 L .52214 .53141 L F
.5105 .50656 m .52214 .53141 L .51245 .52328 L F
.50779 .48332 m .52214 .53141 L .5105 .50656 L F
.50779 .48332 m .52805 .5 L .52774 .5361 L p F P
0 g
s
.5 .69882 m .5 .66414 L .52419 .63931 L p 0 .473 .927 r
F P
0 g
s
.52419 .63931 m .5 .66414 L .5 .62866 L closepath p 0 .473 .927 r
F P
0 g
s
.50744 .62937 m .52679 .64643 L .64295 .58784 L p .762 0 0 r
F P
0 g
s
.52774 .5361 m .52679 .64643 L p .51245 .52328 L .36 0 0 r
F P
0 g
s
.5 .51862 m .46742 .49124 L p .47609 .49281 L 0 .207 .485 r
F P
0 g
s
.43746 .45198 m .43694 .42422 L .40473 .43856 L p 0 .464 .922 r
F P
0 g
s
.43746 .45198 m .43694 .42422 L .46807 .44985 L p 0 .224 .86 r
F P
0 g
s
.40984 .37442 m .40815 .37426 L .38037 .3866 L 0 .48 .858 r
F
.40621 .37408 m .38716 .38332 L p .40815 .37426 L F P
0 g
s
.38716 .38332 m .38037 .3866 L p .40815 .37426 L 0 .48 .858 r
F P
0 g
s
.40392 .41025 m .4364 .39599 L .40984 .37442 L p 0 .204 .478 r
F P
0 g
s
.40473 .43856 m .43694 .42422 L .46807 .44985 L p 0 .207 .485 r
F P
0 g
s
.4364 .39599 m .43694 .42422 L .40473 .43856 L p 0 .464 .922 r
F P
0 g
s
.43694 .42422 m .40473 .43856 L .43567 .46456 L p 0 .207 .485 r
F P
0 g
s
.43567 .46456 m .46807 .44985 L .43694 .42422 L p 0 .207 .485 r
F P
0 g
s
.40392 .41025 m .40473 .43856 L .43694 .42422 L p 0 .464 .922 r
F P
0 g
s
.43694 .42422 m .4364 .39599 L .40392 .41025 L p 0 .464 .922 r
F P
0 g
s
.46834 .47775 m .46807 .44985 L .43567 .46456 L p 0 .467 .923 r
F P
0 g
s
.46834 .47775 m .46807 .44985 L .5 .47615 L p 0 .224 .86 r
F P
0 g
s
.38037 .3866 m .40621 .37408 L .422 .38692 L p 0 .221 .642 r
F P
0 g
s
.422 .38692 m .4038 .40598 L .38037 .3866 L p 0 .221 .642 r
F P
0 g
s
.46807 .44985 m .43567 .46456 L .40473 .43856 L p 0 .207 .485 r
F P
0 g
s
.40473 .43856 m .40392 .41025 L .4364 .39599 L p 0 .464 .922 r
F P
0 g
s
.40473 .43856 m .40392 .41025 L .43512 .43611 L p 0 .22 .858 r
F P
0 g
s
.43512 .43611 m .43567 .46456 L .40473 .43856 L p 0 .22 .858 r
F P
0 g
s
.43694 .42422 m .46869 .41008 L .43815 .38543 L p 0 .207 .485 r
F P
0 g
s
.46895 .43777 m .46869 .41008 L .43694 .42422 L p 0 .464 .922 r
F P
0 g
s
.46895 .43777 m .46869 .41008 L .5 .43535 L p 0 .228 .862 r
F P
0 g
s
.43694 .42422 m .46869 .41008 L .5 .43535 L p 0 .207 .485 r
F P
0 g
s
.46954 .3993 m .46929 .37183 L .43815 .38543 L p 0 .461 .92 r
F P
0 g
s
.46954 .3993 m .46929 .37183 L .5 .39614 L p 0 .232 .863 r
F P
0 g
s
.43815 .38543 m .46929 .37183 L .5 .39614 L p 0 .207 .485 r
F P
0 g
s
.46929 .37183 m .43815 .38543 L .46869 .41008 L p 0 .207 .485 r
F P
0 g
s
.43774 .36307 m .43815 .38543 L .46929 .37183 L p 0 .461 .92 r
F P
0 g
s
.5 .39614 m .46869 .41008 L .43815 .38543 L p 0 .207 .485 r
F P
0 g
s
.43774 .36307 m .43815 .38543 L .46869 .41008 L p 0 .228 .862 r
F P
0 g
s
.46843 .38193 m .46869 .41008 L .43815 .38543 L p 0 .228 .862 r
F P
0 g
s
.46929 .37183 m .46909 .34953 L .43774 .36307 L p 0 .461 .92 r
F P
0 g
s
.43774 .36307 m .46909 .34953 L .47312 .3471 L p 0 .48 .858 r
F P
0 g
s
.47312 .3471 m .4417 .36066 L .43774 .36307 L p 0 .48 .858 r
F P
0 g
s
.4417 .36066 m .43774 .36307 L p .46869 .41008 L 0 .228 .862 r
F P
0 g
s
.46869 .41008 m .46843 .38193 L .4417 .36066 L p 0 .228 .862 r
F P
0 g
s
.46843 .38193 m .46869 .41008 L .43694 .42422 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .43694 .42422 L .46807 .44985 L p 0 .207 .485 r
F P
0 g
s
.4364 .39599 m .43694 .42422 L .46869 .41008 L p 0 .464 .922 r
F P
0 g
s
.43694 .42422 m .4364 .39599 L .46843 .38193 L p 0 .464 .922 r
F P
0 g
s
.5 .43535 m .46807 .44985 L .43694 .42422 L p 0 .207 .485 r
F P
0 g
s
.4364 .39599 m .43694 .42422 L .46807 .44985 L p 0 .224 .86 r
F P
0 g
s
.43694 .42422 m .4364 .39599 L .46779 .42148 L p 0 .224 .86 r
F P
0 g
s
.46807 .44985 m .46779 .42148 L .4364 .39599 L p 0 .224 .86 r
F P
0 g
s
.40392 .41025 m .4364 .39599 L .46779 .42148 L p 0 .204 .478 r
F P
0 g
s
.4364 .39599 m .40392 .41025 L p .41452 .39837 L 0 .464 .922 r
F P
0 g
s
.4417 .36066 m .46843 .38193 L p .43815 .38543 L 0 .228 .862 r
F P
0 g
s
.43815 .38543 m .43774 .36307 L .4417 .36066 L p 0 .228 .862 r
F P
0 g
s
.40984 .37442 m .4417 .36066 L .46843 .38193 L p 0 .204 .478 r
F P
0 g
s
.4417 .36066 m .40984 .37442 L .4364 .39599 L p 0 .204 .478 r
F P
0 g
s
.42476 .36527 m .40984 .37442 L .4417 .36066 L p 0 .48 .858 r
F P
0 g
s
.46843 .38193 m .4364 .39599 L .40984 .37442 L p 0 .204 .478 r
F P
0 g
s
.42476 .36527 m .40984 .37442 L .4364 .39599 L p 0 .224 .86 r
F P
0 g
s
.436 .3743 m .4364 .39599 L .40984 .37442 L p 0 .224 .86 r
F P
0 g
s
.4364 .39599 m .436 .3743 L .42476 .36527 L p 0 .224 .86 r
F P
0 g
s
.436 .3743 m .43627 .38886 L p .41452 .39837 L 0 .464 .922 r
F P
0 g
s
.43627 .38886 m .4364 .39599 L p .41452 .39837 L 0 .464 .922 r
F P
0 g
s
.4364 .39599 m .40392 .41025 L .43512 .43611 L p 0 .204 .478 r
F P
0 g
s
.46779 .42148 m .46807 .44985 L .43694 .42422 L p 0 .224 .86 r
F P
0 g
s
.43512 .43611 m .46779 .42148 L .4364 .39599 L p 0 .204 .478 r
F P
0 g
s
.4038 .40598 m .40392 .41025 L .4364 .39599 L p 0 .464 .922 r
F P
0 g
s
.422 .38692 m .4038 .40598 L p .4364 .39599 L 0 .464 .922 r
F P
0 g
s
.43622 .49253 m .43567 .46456 L .46807 .44985 L p 0 .467 .923 r
F P
0 g
s
.43622 .49253 m .43567 .46456 L .46742 .49124 L p 0 .22 .858 r
F P
0 g
s
.46742 .49124 m .4677 .51934 L .43622 .49253 L p 0 .22 .858 r
F P
0 g
s
.43622 .49253 m .4677 .51934 L .46797 .54696 L p 0 .22 .858 r
F P
0 g
s
.46779 .42148 m .46807 .44985 L .43567 .46456 L p 0 .467 .923 r
F P
0 g
s
.43567 .46456 m .46807 .44985 L .5 .47615 L p 0 .207 .485 r
F P
0 g
s
.46807 .44985 m .43567 .46456 L .46742 .49124 L p 0 .207 .485 r
F P
0 g
s
.46742 .49124 m .5 .47615 L .46807 .44985 L p 0 .207 .485 r
F P
0 g
s
.43512 .43611 m .43567 .46456 L .46807 .44985 L p 0 .467 .923 r
F P
0 g
s
.46807 .44985 m .46779 .42148 L .43512 .43611 L p 0 .467 .923 r
F P
0 g
s
.422 .38692 m .436 .3743 L p .40392 .41025 L 0 .464 .922 r
F P
0 g
s
.46779 .42148 m .43512 .43611 L .40392 .41025 L p 0 .204 .478 r
F P
0 g
s
.40392 .41025 m .4038 .40598 L .422 .38692 L p 0 .464 .922 r
F P
0 g
s
.40392 .41025 m .4038 .40598 L .43504 .43182 L p 0 .22 .858 r
F P
0 g
s
.43504 .43182 m .43512 .43611 L .40392 .41025 L p 0 .22 .858 r
F P
0 g
s
.46797 .54696 m .5 .57459 L .5 .60185 L p 0 .22 .858 r
F P
0 g
s
.5 .57459 m .46797 .54696 L .4677 .51934 L p 0 .22 .858 r
F P
0 g
s
.4038 .40598 m .422 .38692 L .45345 .41249 L p 0 .221 .642 r
F P
0 g
s
.45345 .41249 m .43504 .43182 L .4038 .40598 L p 0 .221 .642 r
F P
0 g
s
.43567 .46456 m .43512 .43611 L .46779 .42148 L p 0 .467 .923 r
F P
0 g
s
.5 .47615 m .46742 .49124 L .43567 .46456 L p 0 .207 .485 r
F P
0 g
s
.43567 .46456 m .43512 .43611 L .46714 .46265 L p 0 .22 .858 r
F P
0 g
s
.46714 .46265 m .46742 .49124 L .43567 .46456 L p 0 .22 .858 r
F P
0 g
s
.46779 .42148 m .43512 .43611 L p .44585 .42407 L 0 .467 .923 r
F P
0 g
s
.46869 .41008 m .46843 .38193 L .4364 .39599 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .5 .39614 L .46929 .37183 L p 0 .207 .485 r
F P
0 g
s
.5 .36808 m .5 .39614 L .46929 .37183 L p 0 .232 .863 r
F P
0 g
s
.46929 .37183 m .5 .39614 L p .47312 .3471 L 0 .232 .863 r
F P
0 g
s
.5 .39614 m .5 .36808 L .47312 .3471 L p 0 .232 .863 r
F P
0 g
s
.5 .36808 m .5 .39614 L .46869 .41008 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .46869 .41008 L .5 .43535 L p 0 .207 .485 r
F P
0 g
s
.46843 .38193 m .46869 .41008 L .5 .39614 L p 0 .464 .922 r
F P
0 g
s
.46869 .41008 m .46843 .38193 L .5 .36808 L p 0 .464 .922 r
F P
0 g
s
.46843 .38193 m .46869 .41008 L .5 .43535 L p 0 .228 .862 r
F P
0 g
s
.46869 .41008 m .46843 .38193 L .5 .40706 L p 0 .228 .862 r
F P
0 g
s
.5 .43535 m .5 .40706 L .46843 .38193 L p 0 .228 .862 r
F P
0 g
s
.4364 .39599 m .46843 .38193 L .5 .40706 L p 0 .204 .478 r
F P
0 g
s
.46843 .38193 m .4364 .39599 L .46779 .42148 L p 0 .204 .478 r
F P
0 g
s
.4364 .39599 m .46843 .38193 L .4417 .36066 L p 0 .204 .478 r
F P
0 g
s
.47312 .3471 m .5 .36808 L p .46929 .37183 L 0 .232 .863 r
F P
0 g
s
.46929 .37183 m .46909 .34953 L .47312 .3471 L p 0 .232 .863 r
F P
0 g
s
.47312 .3471 m .46909 .34953 L .46929 .37183 L p 0 .232 .863 r
F P
0 g
s
.4417 .36066 m .47312 .3471 L .5 .36808 L p 0 .204 .478 r
F P
0 g
s
.47312 .3471 m .4417 .36066 L .46843 .38193 L p 0 .204 .478 r
F P
0 g
s
.46189 .34839 m .4417 .36066 L .47312 .3471 L p 0 .48 .858 r
F P
0 g
s
.5 .36808 m .46843 .38193 L .4417 .36066 L p 0 .204 .478 r
F P
0 g
s
.46189 .34839 m .4417 .36066 L .46843 .38193 L p 0 .228 .862 r
F P
0 g
s
.46816 .35331 m .46843 .38193 L .4417 .36066 L p 0 .228 .862 r
F P
0 g
s
.46843 .38193 m .46816 .35331 L .46189 .34839 L p 0 .228 .862 r
F P
0 g
s
.46816 .35331 m .46843 .38193 L .4364 .39599 L p 0 .464 .922 r
F P
0 g
s
.436 .3743 m .4364 .39599 L .46843 .38193 L p 0 .464 .922 r
F P
0 g
s
.46807 .44985 m .5 .43535 L .46869 .41008 L p 0 .207 .485 r
F P
0 g
s
.5 .40706 m .5 .43535 L .46869 .41008 L p 0 .228 .862 r
F P
0 g
s
.5 .40706 m .46779 .42148 L .4364 .39599 L p 0 .204 .478 r
F P
0 g
s
.45358 .36109 m .46816 .35331 L p .4364 .39599 L 0 .464 .922 r
F P
0 g
s
.43838 .37215 m .45358 .36109 L p .4364 .39599 L 0 .464 .922 r
F P
0 g
s
.4364 .39599 m .436 .3743 L .43838 .37215 L p 0 .464 .922 r
F P
0 g
s
.436 .3743 m .4364 .39599 L .46779 .42148 L p 0 .224 .86 r
F P
0 g
s
.46758 .39968 m .46779 .42148 L .4364 .39599 L p 0 .224 .86 r
F P
0 g
s
.46779 .42148 m .46758 .39968 L .436 .3743 L p 0 .224 .86 r
F P
0 g
s
.46758 .39968 m .46773 .41431 L p .44585 .42407 L 0 .467 .923 r
F P
0 g
s
.46773 .41431 m .46779 .42148 L p .44585 .42407 L 0 .467 .923 r
F P
0 g
s
.40372 .4031 m .37324 .37793 L p .38918 .40945 L .358 0 0 r
F P
0 g
s
.38918 .40945 m .5 .62866 L .40372 .4031 L .358 0 0 r
F
.5 .40706 m .5 .43535 L .46807 .44985 L p 0 .467 .923 r
F P
0 g
s
.5 .43535 m .46807 .44985 L .5 .47615 L p 0 .207 .485 r
F P
0 g
s
.46779 .42148 m .46807 .44985 L .5 .43535 L p 0 .467 .923 r
F P
0 g
s
.46807 .44985 m .46779 .42148 L .5 .40706 L p 0 .467 .923 r
F P
0 g
s
.46779 .42148 m .46807 .44985 L .5 .47615 L p 0 .224 .86 r
F P
0 g
s
.46807 .44985 m .46779 .42148 L .5 .44763 L p 0 .224 .86 r
F P
0 g
s
.5 .47615 m .5 .44763 L .46779 .42148 L p 0 .224 .86 r
F P
0 g
s
.43512 .43611 m .46779 .42148 L .5 .44763 L p 0 .204 .478 r
F P
0 g
s
.46779 .42148 m .43512 .43611 L .46714 .46265 L p 0 .204 .478 r
F P
0 g
s
.5 .44763 m .5 .47615 L .46807 .44985 L p 0 .224 .86 r
F P
0 g
s
.46714 .46265 m .5 .44763 L .46779 .42148 L p 0 .204 .478 r
F P
0 g
s
.43504 .43182 m .43512 .43611 L .46779 .42148 L p 0 .467 .923 r
F P
0 g
s
.45345 .41249 m .43504 .43182 L p .46779 .42148 L 0 .467 .923 r
F P
0 g
s
.4677 .51934 m .46742 .49124 L .5 .51862 L p 0 .22 .858 r
F P
0 g
s
.5 .51862 m .5 .54684 L .4677 .51934 L p 0 .22 .858 r
F P
0 g
s
.4677 .51934 m .5 .54684 L .5 .57459 L p 0 .22 .858 r
F P
0 g
s
.46714 .46265 m .46742 .49124 L .5 .47615 L p 0 .47 .925 r
F P
0 g
s
.5 .47615 m .5 .44763 L .46714 .46265 L p 0 .47 .925 r
F P
0 g
s
.5 .44763 m .5 .47615 L .46742 .49124 L p 0 .47 .925 r
F P
0 g
s
.45345 .41249 m .46758 .39968 L p .43512 .43611 L 0 .467 .923 r
F P
0 g
s
.43512 .43611 m .43504 .43182 L .45345 .41249 L p 0 .467 .923 r
F P
0 g
s
.5 .44763 m .46714 .46265 L .43512 .43611 L p 0 .204 .478 r
F P
0 g
s
.43512 .43611 m .43504 .43182 L .46709 .45834 L p 0 .22 .858 r
F P
0 g
s
.46709 .45834 m .46714 .46265 L .43512 .43611 L p 0 .22 .858 r
F P
0 g
s
.43504 .43182 m .45345 .41249 L .48572 .43873 L p 0 .221 .642 r
F P
0 g
s
.48572 .43873 m .46709 .45834 L .43504 .43182 L p 0 .221 .642 r
F P
0 g
s
.46742 .49124 m .46714 .46265 L .5 .44763 L p 0 .47 .925 r
F P
0 g
s
.46742 .49124 m .46714 .46265 L .49557 .48621 L p 0 .22 .858 r
F P
0 g
s
.5 .51862 m .46742 .49124 L p .49557 .48621 L 0 .22 .858 r
F P
0 g
s
.5 .47615 m .5 .44763 L .5286 .47086 L p 0 .224 .86 r
F P
0 g
s
.46714 .46265 m .5 .44763 L .5286 .47086 L p 0 .204 .478 r
F P
0 g
s
.5 .44763 m .46714 .46265 L .49557 .48621 L p 0 .204 .478 r
F P
0 g
s
.49557 .48621 m .5286 .47086 L .5 .44763 L p 0 .204 .478 r
F P
0 g
s
.46709 .45834 m .46714 .46265 L .5 .44763 L p 0 .47 .925 r
F P
0 g
s
.5 .44763 m .49332 .44347 L .46709 .45834 L 0 .47 .925 r
F
.48572 .43873 m .47199 .45318 L p .49332 .44347 L F P
0 g
s
.47199 .45318 m .46709 .45834 L p .49332 .44347 L 0 .47 .925 r
F P
0 g
s
.5 .43535 m .5 .40706 L .46779 .42148 L p 0 .467 .923 r
F P
0 g
s
.5 .44763 m .46714 .46265 L p .47799 .45045 L 0 .47 .925 r
F P
0 g
s
.5 .43535 m .5 .40706 L .53239 .43284 L p 0 .228 .862 r
F P
0 g
s
.46779 .42148 m .5 .40706 L .53239 .43284 L p 0 .204 .478 r
F P
0 g
s
.5 .40706 m .46779 .42148 L .5 .44763 L p 0 .204 .478 r
F P
0 g
s
.46779 .42148 m .5 .40706 L .46843 .38193 L p 0 .204 .478 r
F P
0 g
s
.5 .39614 m .5 .36808 L .46843 .38193 L p 0 .464 .922 r
F P
0 g
s
.5 .39614 m .5 .36808 L .53175 .39285 L p 0 .232 .863 r
F P
0 g
s
.46843 .38193 m .5 .36808 L .53175 .39285 L p 0 .204 .478 r
F P
0 g
s
.5 .36808 m .46843 .38193 L .5 .40706 L p 0 .204 .478 r
F P
0 g
s
.46843 .38193 m .5 .36808 L .47312 .3471 L p 0 .204 .478 r
F P
0 g
s
.53113 .35441 m .5 .36808 L .47312 .3471 L p 0 .204 .478 r
F P
0 g
s
.5 .34651 m .5 .36808 L .47312 .3471 L p 0 .232 .863 r
F P
0 g
s
.48863 .33774 m .47312 .3471 L .5 .36808 L p 0 .232 .863 r
F P
0 g
s
.5 .36808 m .5 .34651 L .48863 .33774 L p 0 .232 .863 r
F P
0 g
s
.5 .34651 m .5 .36808 L .46843 .38193 L p 0 .464 .922 r
F P
0 g
s
.46816 .35331 m .46843 .38193 L .5 .36808 L p 0 .464 .922 r
F P
0 g
s
.47312 .3471 m .48863 .33774 L .5 .34651 L p 0 .232 .863 r
F P
0 g
s
.49766 .34643 m .5 .34651 L p .46843 .38193 L 0 .464 .922 r
F P
0 g
s
.53175 .39285 m .5 .40706 L .46843 .38193 L p 0 .204 .478 r
F P
0 g
s
.48268 .34849 m .49766 .34643 L p .46843 .38193 L 0 .464 .922 r
F P
0 g
s
.46843 .38193 m .46816 .35331 L .48268 .34849 L p 0 .464 .922 r
F P
0 g
s
.46816 .35331 m .46843 .38193 L .5 .40706 L p 0 .228 .862 r
F P
0 g
s
.5 .37829 m .5 .40706 L .46843 .38193 L p 0 .228 .862 r
F P
0 g
s
.5 .40706 m .5 .37829 L .46816 .35331 L p 0 .228 .862 r
F P
0 g
s
.5 .37829 m .5 .40706 L .46779 .42148 L p 0 .467 .923 r
F P
0 g
s
.46758 .39968 m .46779 .42148 L .5 .40706 L p 0 .467 .923 r
F P
0 g
s
.48532 .38624 m .5 .37829 L p .46779 .42148 L 0 .467 .923 r
F P
0 g
s
.47 .39749 m .48532 .38624 L p .46779 .42148 L 0 .467 .923 r
F P
0 g
s
.46779 .42148 m .46758 .39968 L .47 .39749 L p 0 .467 .923 r
F P
0 g
s
.53239 .43284 m .5 .44763 L .46779 .42148 L p 0 .204 .478 r
F P
0 g
s
.46758 .39968 m .46779 .42148 L .5 .44763 L p 0 .224 .86 r
F P
0 g
s
.5 .42572 m .5 .44763 L .46779 .42148 L p 0 .224 .86 r
F P
0 g
s
.5 .44763 m .5 .42572 L .46758 .39968 L p 0 .224 .86 r
F P
0 g
s
.5 .42572 m .5 .44043 L p .47799 .45045 L 0 .47 .925 r
F P
0 g
s
.5 .44043 m .5 .44763 L p .47799 .45045 L 0 .47 .925 r
F P
0 g
s
.48572 .43873 m .5 .42572 L p .46714 .46265 L 0 .47 .925 r
F P
0 g
s
.5286 .47086 m .49557 .48621 L .46714 .46265 L p 0 .204 .478 r
F P
0 g
s
.46714 .46265 m .46709 .45834 L .48572 .43873 L p 0 .47 .925 r
F P
0 g
s
.46714 .46265 m .46709 .45834 L .49226 .47915 L p 0 .22 .858 r
F P
0 g
s
.49226 .47915 m .49557 .48621 L .46714 .46265 L p 0 .22 .858 r
F P
0 g
s
.46709 .45834 m .48572 .43873 L .50256 .45243 L p 0 .221 .642 r
F P
0 g
s
.50256 .45243 m .49226 .47915 L .46709 .45834 L p 0 .221 .642 r
F P
0 g
s
.5286 .47086 m .49557 .48621 L p .501 .46932 L 0 .358 .744 r
F P
0 g
s
.5 .44763 m .53239 .43284 L .5 .40706 L p 0 .204 .478 r
F P
0 g
s
.53211 .46127 m .53239 .43284 L .5 .44763 L p 0 .47 .925 r
F P
0 g
s
.53211 .46127 m .53239 .43284 L .56114 .45572 L p 0 .228 .862 r
F P
0 g
s
.5 .44763 m .53239 .43284 L .56114 .45572 L p 0 .204 .478 r
F P
0 g
s
.53239 .43284 m .5 .44763 L .5286 .47086 L p 0 .204 .478 r
F P
0 g
s
.5 .42572 m .5 .44763 L .53239 .43284 L p 0 .47 .925 r
F P
0 g
s
.53148 .42106 m .53175 .39285 L .56431 .41826 L p 0 .232 .863 r
F P
0 g
s
.53148 .42106 m .53175 .39285 L .5 .40706 L p 0 .467 .923 r
F P
0 g
s
.5 .40706 m .53175 .39285 L .56431 .41826 L p 0 .204 .478 r
F P
0 g
s
.53239 .43284 m .56431 .41826 L .53175 .39285 L p 0 .204 .478 r
F P
0 g
s
.53175 .39285 m .5 .40706 L .53239 .43284 L p 0 .204 .478 r
F P
0 g
s
.5 .40706 m .53175 .39285 L .5 .36808 L p 0 .204 .478 r
F P
0 g
s
.53088 .38239 m .53113 .35441 L .5 .36808 L p 0 .464 .922 r
F P
0 g
s
.5 .36808 m .53113 .35441 L .56305 .37884 L p 0 .204 .478 r
F P
0 g
s
.53175 .39285 m .56305 .37884 L .53113 .35441 L p 0 .204 .478 r
F P
0 g
s
.53113 .35441 m .5 .36808 L .53175 .39285 L p 0 .204 .478 r
F P
0 g
s
.56305 .37884 m .53175 .39285 L .5 .36808 L p 0 .204 .478 r
F P
0 g
s
.53195 .37117 m .53175 .39285 L .5 .36808 L p 0 .232 .863 r
F P
0 g
s
.5 .36808 m .53113 .35441 L .50411 .33372 L p 0 .204 .478 r
F P
0 g
s
.50719 .33188 m .50411 .33372 L .53113 .35441 L p 0 .235 .864 r
F P
0 g
s
.53113 .35441 m .53117 .35019 L .50719 .33188 L p 0 .235 .864 r
F P
0 g
s
.53117 .35019 m .53113 .35441 L .5 .36808 L p 0 .464 .922 r
F P
0 g
s
.5 .34651 m .5 .36808 L .53113 .35441 L p 0 .464 .922 r
F P
0 g
s
.51364 .347 m .53117 .35019 L p .5 .36808 L 0 .464 .922 r
F P
0 g
s
.5 .36808 m .5 .34651 L .51364 .347 L p 0 .464 .922 r
F P
0 g
s
.5 .34651 m .5 .36808 L .53175 .39285 L p 0 .232 .863 r
F P
0 g
s
.53175 .39285 m .53195 .37117 L .5 .34651 L p 0 .232 .863 r
F P
0 g
s
.53195 .37117 m .53175 .39285 L .5 .40706 L p 0 .467 .923 r
F P
0 g
s
.5 .37829 m .5 .40706 L .53175 .39285 L p 0 .467 .923 r
F P
0 g
s
.5296 .37111 m .53195 .37117 L p .5 .40706 L 0 .467 .923 r
F P
0 g
s
.51458 .37332 m .5296 .37111 L p .5 .40706 L 0 .467 .923 r
F P
0 g
s
.5 .40706 m .5 .37829 L .51458 .37332 L p 0 .467 .923 r
F P
0 g
s
.56431 .41826 m .53239 .43284 L .5 .40706 L p 0 .204 .478 r
F P
0 g
s
.5 .37829 m .5 .40706 L .53239 .43284 L p 0 .228 .862 r
F P
0 g
s
.53267 .40391 m .53239 .43284 L .5 .40706 L p 0 .228 .862 r
F P
0 g
s
.53239 .43284 m .53267 .40391 L .5 .37829 L p 0 .228 .862 r
F P
0 g
s
.53267 .40391 m .53239 .43284 L .5 .44763 L p 0 .47 .925 r
F P
0 g
s
.56114 .45572 m .5286 .47086 L .5 .44763 L p 0 .204 .478 r
F P
0 g
s
.51789 .41204 m .53267 .40391 L p .5 .44763 L 0 .47 .925 r
F P
0 g
s
.50244 .4235 m .51789 .41204 L p .5 .44763 L 0 .47 .925 r
F P
0 g
s
.5 .44763 m .5 .42572 L .50244 .4235 L p 0 .47 .925 r
F P
0 g
s
.5 .42572 m .5 .44763 L .5286 .47086 L p 0 .224 .86 r
F P
0 g
s
.51194 .43531 m .5286 .47086 L .5 .44763 L p 0 .224 .86 r
F P
0 g
s
.5286 .47086 m .51194 .43531 L .5 .42572 L p 0 .224 .86 r
F P
0 g
s
.51194 .43531 m .5231 .45912 L p .501 .46932 L 0 .358 .744 r
F P
0 g
s
.5231 .45912 m .5286 .47086 L p .501 .46932 L 0 .358 .744 r
F P
0 g
s
.50256 .45243 m .51194 .43531 L p .501 .46932 L 0 .358 .744 r
F P
0 g
s
.49557 .48621 m .49886 .47031 L .501 .46932 L 0 .358 .744 r
F
.49886 .47031 m .50256 .45243 L .501 .46932 L F
.49557 .48621 m .5 .49567 L .5 .51862 L p 0 .22 .858 r
F P
0 g
s
.49557 .48621 m .49226 .47915 L .49498 .4721 L p 0 .358 .744 r
F P
0 g
s
.49498 .4721 m .50256 .45243 L p .49886 .47031 L 0 .358 .744 r
F P
0 g
s
.49557 .48621 m .49498 .4721 L .49886 .47031 L 0 .358 .744 r
F
.5 .62866 m .5 .48263 L .40372 .4031 L p .358 0 0 r
F P
0 g
s
.46706 .45542 m .49003 .47439 L p .46042 .45845 L .751 0 0 r
F P
0 g
s
.49003 .47439 m .5 .48263 L p .48803 .47531 L .751 0 0 r
F P
0 g
s
.46042 .45845 m .49003 .47439 L .48803 .47531 L .751 0 0 r
F
.46042 .45845 m .48803 .47531 L .44036 .46757 L F
.48803 .47531 m .5 .48263 L .48202 .47809 L F
.48803 .47531 m .48202 .47809 L .44036 .46757 L F
.47314 .49511 m .46321 .48677 L p .5 .48263 L F P
0 g
s
.46321 .48677 m .44036 .46757 L p .48202 .47809 L .751 0 0 r
F P
0 g
s
.48202 .47809 m .5 .48263 L .46321 .48677 L .751 0 0 r
F
.44036 .46757 m .34702 .38917 L p .46042 .45845 L F P
0 g
s
.43498 .42892 m .46706 .45542 L p .42175 .43482 L .751 0 0 r
F P
0 g
s
.42175 .43482 m .46706 .45542 L .46042 .45845 L .751 0 0 r
F
.40372 .4031 m .43498 .42892 L p .38396 .41174 L F P
0 g
s
.38396 .41174 m .43498 .42892 L .42175 .43482 L .751 0 0 r
F
.38231 .38541 m .40372 .4031 L p .35802 .39589 L F P
0 g
s
.35802 .39589 m .40372 .4031 L .38396 .41174 L .751 0 0 r
F
.34702 .38917 m .37324 .37793 L .38231 .38541 L p F P
0 g
s
.34702 .38917 m .38231 .38541 L .35802 .39589 L .751 0 0 r
F
.5 .51862 m .47434 .64142 L .5 .62866 L .962 0 0 r
F
.5 .48263 m .4937 .52159 L .5 .51862 L F
.4937 .52159 m .47434 .64142 L .5 .51862 L F
.41331 .67178 m .41331 .67178 L .35212 .61465 L .317 0 0 r
F
.41435 .65557 m .43916 .64332 L p .41271 .59596 L 0 .467 .923 r
F P
0 g
s
.43916 .64332 m .43849 .60888 L .46886 .63616 L p 0 .22 .858 r
F P
0 g
s
.41331 .67178 m .47434 .64142 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.35212 .61465 m .41331 .67178 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.47434 .64142 m .41243 .5858 L p .38247 .60013 L .762 0 0 r
F P
0 g
s
.47434 .64142 m .41331 .67178 L p .40956 .6073 L 0 .218 .512 r
F P
0 g
s
.42109 .59358 m .47434 .64142 L .40956 .6073 L 0 .218 .512 r
F
.41243 .5858 m .47434 .64142 L p .42515 .57971 L .762 0 0 r
F P
0 g
s
.4378 .57366 m .47434 .64142 L .42109 .59358 L 0 .218 .512 r
F
.4378 .57366 m .36895 .6066 L .4378 .57366 L 0 .467 .923 r
F
.4378 .57366 m .41243 .5858 L p .40384 .57808 L 0 .218 .512 r
F P
0 g
s
.35212 .61465 m .25404 .66157 L .25404 .66157 L p 0 .467 .923 r
F P
0 g
s
.35212 .61465 m .25404 .66157 L .3537 .64839 L 0 .467 .923 r
F
.31397 .72119 m .25404 .66157 L .41243 .5858 L p 0 .218 .512 r
F P
0 g
s
.41243 .5858 m .4378 .57366 L p .42109 .59358 L 0 .218 .512 r
F P
0 g
s
.42109 .59358 m .37353 .65023 L .41243 .5858 L 0 .218 .512 r
F
.41243 .5858 m .47434 .64142 L p .47434 .64142 L .346 0 0 r
F P
0 g
s
.41147 .55074 m .41243 .5858 L .47434 .64142 L .346 0 0 r
F
.41243 .5858 m .41243 .5858 L .47434 .64142 L F
.47492 .71169 m .3183 .79205 L p .47443 .65166 L 0 .473 .927 r
F P
0 g
s
.47434 .64142 m .41243 .5858 L p .41147 .55074 L .346 0 0 r
F P
0 g
s
.3183 .79205 m .31397 .72119 L p .47434 .64142 L 0 .473 .927 r
F P
0 g
s
.5 .62866 m .47443 .65166 L .47434 .64142 L 0 .473 .927 r
F
.47443 .65166 m .3183 .79205 L .47434 .64142 L F
.47434 .64142 m .41331 .67178 L .4113 .6 L p .962 0 0 r
F P
0 g
s
.41147 .55074 m .47434 .64142 L .41048 .5149 L .346 0 0 r
F
.47434 .64142 m .47375 .56994 L .41048 .5149 L p F P
0 g
s
.41048 .5149 m .47434 .64142 L .41147 .55074 L .346 0 0 r
F
.34702 .38917 m .47314 .49511 L .47375 .56994 L p F P
0 g
s
.47375 .56994 m .47434 .64142 L p .41048 .5149 L .346 0 0 r
F P
0 g
s
.34702 .38917 m .47375 .56994 L .41048 .5149 L .346 0 0 r
F
.47375 .56994 m .4113 .6 L .41331 .67178 L .962 0 0 r
F
.41322 .66882 m .41325 .66965 L .41331 .67178 L .512 0 0 r
F
.31397 .72119 m .5 .62866 L p .5 .62866 L 0 .473 .927 r
F P
0 g
s
.5 .62866 m .47434 .64142 L .48954 .64943 L .762 0 0 r
F
.5 .62866 m .47434 .64142 L .47367 .55946 L p .962 0 0 r
F P
0 g
s
.5 .48263 m .47314 .49511 L .47434 .64142 L .962 0 0 r
F
.47375 .56994 m .48673 .63526 L .47859 .57241 L .526 0 0 r
F
.48673 .63526 m .48954 .64943 L .47859 .57241 L F
.48499 .55403 m .5 .62866 L .47367 .55946 L .962 0 0 r
F
.47859 .57241 m .48954 .64943 L .4893 .57786 L .526 0 0 r
F
.47375 .56994 m .47434 .64142 L .48954 .64943 L F
.47375 .56994 m .47434 .64142 L .47375 .56994 L F
.47434 .64142 m .48954 .64943 L .47434 .64142 L F
.47367 .55946 m .47314 .49511 L p .48499 .55403 L .962 0 0 r
F P
0 g
s
.47314 .49511 m .48954 .64943 L .47434 .64142 L .526 0 0 r
F
.47314 .49511 m .5 .48263 L .5 .62866 L p .962 0 0 r
F P
0 g
s
.47314 .49511 m .48905 .50294 L .48954 .64943 L .526 0 0 r
F
.47375 .56994 m .4893 .57786 L .48694 .58141 L .757 0 0 r
F
.47314 .49511 m .47314 .49511 L .47375 .56994 L .526 0 0 r
F
.47375 .56994 m .47375 .56994 L .47434 .64142 L F
.47314 .49511 m .47375 .56994 L .47375 .56994 L F
.41261 .64702 m .41331 .67178 L .41331 .67178 L .512 0 0 r
F
.31397 .72119 m .31397 .72119 L p .47434 .64142 L 0 .473 .927 r
F P
0 g
s
.47434 .64142 m .41331 .67178 L .41336 .67181 L .762 0 0 r
F
.45919 .69663 m .41336 .67181 L .45919 .69663 L F
.47434 .64142 m .41336 .67181 L .45919 .69663 L F
.47375 .56994 m .41331 .67178 L .47434 .64142 L .962 0 0 r
F
.4113 .6 m .41331 .67178 L .41261 .64702 L .512 0 0 r
F
.4113 .6 m .45919 .69663 L .41331 .67178 L F
.4113 .6 m .47375 .56994 L .47434 .64142 L p .962 0 0 r
F P
0 g
s
.47375 .56994 m .48694 .58141 L .45824 .62463 L .757 0 0 r
F
.4113 .6 m .4113 .6 L .41325 .66965 L .512 0 0 r
F
.4113 .6 m .41325 .66965 L .41322 .66882 L F
.41331 .67178 m .45919 .69663 L .41331 .67178 L F
.4113 .6 m .45824 .62463 L .45919 .69663 L F
.37353 .65023 m .31397 .72119 L .36782 .64714 L 0 .218 .512 r
F
.37353 .65023 m .36782 .64714 L .41243 .5858 L F
.41331 .67178 m .31397 .72119 L p .37353 .65023 L F P
0 g
s
.40956 .6073 m .41331 .67178 L .37353 .65023 L 0 .218 .512 r
F
.5 .62866 m .5 .69882 L .47492 .71169 L p 0 .473 .927 r
F P
0 g
s
.5 .62866 m .48954 .64943 L .50184 .63029 L .762 0 0 r
F
.5 .62866 m .50184 .63029 L .50217 .62979 L F
.41048 .5149 m .35035 .46259 L p .41147 .55074 L .346 0 0 r
F P
0 g
s
.4113 .6 m .41331 .67178 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.35047 .57944 m .41331 .67178 L .35212 .61465 L .317 0 0 r
F
.25404 .66157 m .19713 .60495 L p .32405 .58845 L 0 .218 .512 r
F P
0 g
s
.34692 .6098 m .25404 .66157 L .32405 .58845 L 0 .218 .512 r
F
.35353 .53288 m .41243 .5858 L p .41243 .5858 L .346 0 0 r
F P
0 g
s
.38498 .53131 m .35353 .53288 L .41243 .5858 L .346 0 0 r
F
.35353 .53288 m .35353 .53288 L .41243 .5858 L F
.35035 .46259 m .41243 .5858 L .41147 .55074 L F
.41147 .55074 m .41147 .55074 L .41243 .5858 L F
.41048 .5149 m .41147 .55074 L .35035 .46259 L F
.35353 .53288 m .35035 .46259 L p .41147 .55074 L F P
0 g
s
.41243 .5858 m .35353 .53288 L p .41147 .55074 L .346 0 0 r
F P
0 g
s
.47375 .56994 m .4113 .6 L .28941 .48972 L p .757 0 0 r
F P
0 g
s
.28941 .48972 m .35035 .46259 L .47375 .56994 L p .757 0 0 r
F P
0 g
s
.34878 .54344 m .4113 .6 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.34878 .54344 m .35047 .57944 L .35047 .57944 L .317 0 0 r
F
.25686 .69719 m .25962 .732 L .28858 .76164 L p 0 .193 .843 r
F P
0 g
s
.28941 .48972 m .34878 .54344 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.35212 .61465 m .29394 .56034 L p .35047 .57944 L .317 0 0 r
F P
0 g
s
.25404 .66157 m .35212 .61465 L p .35212 .61465 L 0 .467 .923 r
F P
0 g
s
.51245 .52328 m .50744 .62937 L .52385 .62119 L .36 0 0 r
F
.52385 .62119 m .50744 .62937 L .52679 .64643 L F
.5077 .51931 m .50744 .62937 L .51245 .52328 L F
.51245 .52328 m .51611 .55474 L .5077 .51931 L F
.51611 .55474 m .52679 .64643 L .51257 .55173 L F
.51611 .55474 m .51257 .55173 L .5077 .51931 L F
.52679 .64643 m .50744 .62937 L .50764 .54754 L p F P
0 g
s
.50764 .54754 m .5077 .51931 L p .51257 .55173 L .36 0 0 r
F P
0 g
s
.51257 .55173 m .52679 .64643 L .50764 .54754 L .36 0 0 r
F
.5077 .51931 m .50779 .48332 L p .51245 .52328 L F P
0 g
s
.56114 .45572 m .59321 .44081 L .59755 .45007 L p 0 .358 .744 r
F P
0 g
s
.59755 .45007 m .56551 .46505 L .56114 .45572 L p 0 .358 .744 r
F P
0 g
s
.56505 .48786 m .56551 .46505 L .59755 .45007 L p 0 .473 .927 r
F P
0 g
s
.56551 .46505 m .533 .48025 L .5286 .47086 L p 0 .358 .744 r
F P
0 g
s
.5286 .47086 m .56114 .45572 L .56551 .46505 L p 0 .358 .744 r
F P
0 g
s
.62325 .57165 m .62883 .42696 L .50779 .48332 L p .962 0 0 r
F P
0 g
s
.64295 .58784 m .64948 .44275 L .62883 .42696 L p .407 0 0 r
F P
0 g
s
.62883 .42696 m .64948 .44275 L .64295 .58784 L .407 0 0 r
F
.64295 .58784 m .64614 .51691 L .5274 .57489 L p .964 0 0 r
F P
0 g
s
.64295 .58784 m .52679 .64643 L .5274 .57489 L p .964 0 0 r
F P
0 g
s
.5274 .57489 m .52805 .5 L p .58758 .54551 L .964 0 0 r
F P
0 g
s
.58758 .54551 m .64295 .58784 L .5274 .57489 L .964 0 0 r
F
.5274 .57489 m .52679 .64643 L .64295 .58784 L p F P
0 g
s
.62132 .63657 m .56149 .66727 L .56172 .65584 L p 0 .473 .927 r
F P
0 g
s
.56149 .66727 m .5 .69882 L .54777 .64969 L p 0 .473 .927 r
F P
0 g
s
.54777 .64969 m .56172 .65584 L .56149 .66727 L p 0 .473 .927 r
F P
0 g
s
.52679 .64643 m .5731 .68727 L .6901 .62655 L p .762 0 0 r
F P
0 g
s
.5731 .68727 m .52679 .64643 L .5274 .57489 L p .36 0 0 r
F P
0 g
s
.5274 .57489 m .52679 .64643 L .5731 .68727 L .36 0 0 r
F
.50779 .48332 m .52679 .64643 L .52805 .5 L F
.50899 .57969 m .52679 .64643 L .5274 .57489 L .89 0 0 r
F
.50489 .63005 m .52679 .64643 L .50744 .62937 L .762 0 0 r
F
.50489 .63005 m .50879 .65127 L .52679 .64643 L F
.50899 .57969 m .52679 .64643 L .50879 .65127 L .89 0 0 r
F
.5092 .50474 m .51821 .57729 L .50899 .57969 L F
.51821 .57729 m .52679 .64643 L .50899 .57969 L F
.5 .48263 m .5 .62866 L .50217 .62979 L .532 0 0 r
F
.50512 .48398 m .50744 .62937 L .50779 .48332 L .89 0 0 r
F
.50512 .48398 m .50489 .63005 L .50744 .62937 L F
.50227 .48373 m .50217 .62979 L .50489 .63005 L .74 0 0 r
F
.5 .48263 m .50217 .62979 L .50227 .48373 L .532 0 0 r
F
.50227 .48373 m .50489 .63005 L .50512 .48398 L .74 0 0 r
F
.50899 .57969 m .50879 .65127 L .52679 .64643 L .89 0 0 r
F
.50217 .62979 m .50879 .65127 L .50489 .63005 L .762 0 0 r
F
.50217 .62979 m .48954 .64943 L .50879 .65127 L F
.4893 .57786 m .48954 .64943 L .50879 .65127 L .739 0 0 r
F
.48905 .50294 m .50879 .65127 L .48954 .64943 L F
.4893 .57786 m .50879 .65127 L .50899 .57969 L F
.48905 .50294 m .5092 .50474 L .50879 .65127 L F
.48371 .58628 m .51862 .63035 L .45824 .62463 L .757 0 0 r
F
.4893 .57786 m .49269 .58394 L .48371 .58628 L F
.49269 .58394 m .51862 .63035 L .48371 .58628 L F
.5092 .50474 m .52805 .5 L .52679 .64643 L .89 0 0 r
F
.5274 .57489 m .57481 .61535 L .5731 .68727 L p .36 0 0 r
F P
0 g
s
.5274 .57489 m .5731 .68727 L .57481 .61535 L .36 0 0 r
F
.51306 .58189 m .5274 .57489 L .57481 .61535 L .757 0 0 r
F
.50899 .57969 m .5274 .57489 L .51306 .58189 L F
.52805 .5 m .64948 .44275 L .64295 .58784 L p .964 0 0 r
F P
0 g
s
.53917 .5735 m .6431 .51949 L .58602 .56798 L .757 0 0 r
F
.5274 .57489 m .55106 .56356 L .53917 .5735 L F
.55106 .56356 m .6431 .51949 L .53917 .5735 L F
.55106 .56356 m .64253 .51868 L .6431 .51949 L F
.5274 .57489 m .5517 .56302 L p .55106 .56356 L F P
0 g
s
.5517 .56302 m .64253 .51868 L p .55106 .56356 L .757 0 0 r
F P
0 g
s
.64614 .51691 m .64295 .58784 L .65394 .5782 L 1 0 0 r
F
.66162 .4795 m .65125 .4845 L p .66739 .44177 L .757 0 0 r
F P
0 g
s
.65125 .4845 m .70293 .52773 L .70733 .4575 L .962 0 0 r
F
.65125 .4845 m .70733 .4575 L .70293 .52773 L p F P
0 g
s
.65918 .49551 m .65125 .4845 L .70733 .4575 L .757 0 0 r
F
.66277 .42163 m .65125 .4845 L .6552 .48999 L .18 0 0 r
F
.66277 .42163 m .6552 .48999 L .65918 .49551 L F
.66277 .42163 m .65465 .41077 L .65125 .4845 L F
.64948 .44275 m .66094 .43334 L .65736 .50738 L 1 0 0 r
F
.65176 .51213 m .65736 .50738 L .65394 .5782 L F
.64948 .44275 m .65736 .50738 L .65176 .51213 L F
.65394 .5782 m .72695 .56063 L .65574 .56619 L .762 0 0 r
F
.65394 .5782 m .72272 .59687 L .72695 .56063 L F
.64295 .58784 m .72272 .59687 L .65394 .5782 L F
.64295 .58784 m .6901 .62655 L .72272 .59687 L F
.64614 .51691 m .64295 .58784 L .6901 .62655 L p .407 0 0 r
F P
0 g
s
.64614 .51691 m .6901 .62655 L .64295 .58784 L .407 0 0 r
F
.6901 .62655 m .69442 .55521 L .64614 .51691 L p F P
0 g
s
.64614 .51691 m .69442 .55521 L .6901 .62655 L .407 0 0 r
F
.6431 .51949 m .64614 .51691 L .67027 .55806 L .757 0 0 r
F
.64253 .51868 m .64614 .51691 L p .6431 .51949 L F P
0 g
s
.58602 .56798 m .6431 .51949 L .67027 .55806 L .757 0 0 r
F
.64614 .51691 m .69442 .55521 L p .67027 .55806 L F P
0 g
s
.35035 .46259 m .34702 .38917 L p .41048 .5149 L .346 0 0 r
F P
0 g
s
.34764 .44067 m .34415 .45193 L .27171 .45722 L .757 0 0 r
F
.34429 .36757 m .34071 .37866 L .34415 .45193 L 1 0 0 r
F
.34429 .36757 m .34415 .45193 L .3459 .44628 L F
.34429 .36757 m .3459 .44628 L .34764 .44067 L F
.34071 .37866 m .34702 .38917 L .35035 .46259 L .1 0 0 r
F
.34071 .37866 m .35035 .46259 L .34724 .45724 L F
.33065 .42871 m .28329 .42365 L .31476 .40137 L .757 0 0 r
F
.33065 .42871 m .31476 .40137 L .31985 .39776 L F
.34071 .37866 m .34724 .45724 L .34415 .45193 L .1 0 0 r
F
.66094 .43334 m .66277 .42163 L .65918 .49551 L .907 0 0 r
F
.66094 .43334 m .65918 .49551 L .65827 .50143 L F
.70733 .4575 m .66162 .4795 L p .66739 .44177 L .757 0 0 r
F P
0 g
s
.66094 .43334 m .65827 .50143 L .65736 .50738 L .907 0 0 r
F
.73195 .49001 m .70293 .52773 L .72695 .56063 L .217 0 0 r
F
0 0 0 r
.69018 .41465 m
.69018 .41465 L
s
.80773 .49904 m .77505 .4748 L .79593 .4875 L p 0 .05 .1 r
F P
0 g
s
.79593 .4875 m .82843 .51157 L .80773 .49904 L p 0 .05 .1 r
F P
0 g
s
.79593 .4875 m .77505 .4748 L .74312 .45112 L p 0 .05 .1 r
F P
0 g
s
.82843 .51157 m .84518 .52171 L .78048 .55491 L closepath p 0 .473 .927 r
F P
0 g
s
.74312 .45112 m .72153 .43794 L .69018 .41465 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.69018 .41465 m
.69018 .41465 L
s
.72153 .43794 m .74312 .45112 L .77505 .4748 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.69018 .41465 m
.69018 .41465 L
s
.66571 .42613 m
.69018 .41465 L
s
.69018 .41465 m
.69018 .41465 L
s
.72874 .58146 m
.72874 .58146 L
s
.72874 .58146 m
.72874 .58146 L
s
.80773 .49904 m .82843 .51157 L .78048 .55491 L p 0 .473 .927 r
F P
0 g
s
.78649 .48617 m .75363 .46177 L .77505 .4748 L p 0 .05 .1 r
F P
0 g
s
.77505 .4748 m .80773 .49904 L .78649 .48617 L p 0 .05 .1 r
F P
0 g
s
.77505 .4748 m .75363 .46177 L .72153 .43794 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.75363 .46177 m
.75363 .46177 L
s
.75363 .46177 m
.75363 .46177 L
s
.78048 .55491 m .78345 .5209 L .80773 .49904 L p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.78345 .5209 m
.78345 .5209 L
s
.78649 .48617 m .80773 .49904 L .78345 .5209 L closepath p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.75363 .46177 m
.75363 .46177 L
s
.7056 .4852 m
.75363 .46177 L
s
.75363 .46177 m
.75363 .46177 L
s
.7337 .51243 m
.7337 .51243 L
s
.7337 .51243 m
.7337 .51243 L
s
.70526 .49063 m
.72175 .50327 L
s
.73053 .51 m
.7337 .51243 L
s
.72099 .55247 m
.72099 .55247 L
s
.72777 .54904 m
.78345 .5209 L
s
.78345 .5209 m
.78345 .5209 L
s
0 g
.49283 .32999 m
.49284 .33665 L
s
.28782 .49345 m
.28956 .49217 L
s
.29829 .48577 m
.32357 .46721 L
s
.32283 .45348 m
.32357 .46721 L
s
.32357 .46721 m
.32907 .47206 L
s
0 0 0 r
.7337 .51243 m
.7337 .51243 L
s
.73324 .51881 m
.7337 .51243 L
s
.72874 .58146 m
.73324 .51881 L
s
.72874 .58146 m
.72874 .58146 L
s
.67956 .53936 m
.67956 .53936 L
s
.67956 .53936 m
.67956 .53936 L
s
.67956 .53936 m
.67956 .53936 L
s
0 g
.28329 .42365 m
.31985 .39776 L
s
.31985 .39776 m
.34251 .4171 L
s
.27171 .45722 m .29394 .56034 L .27656 .52745 L .1 0 0 r
F
0 g
.27656 .52745 m
.29394 .56034 L
s
.28279 .50862 m
.28782 .49345 L
s
.73195 .49001 m .70733 .4575 L .70293 .52773 L .217 0 0 r
F
0 g
.70293 .52773 m
.7038 .51387 L
s
0 0 0 r
.2592 .57635 m
.2592 .57635 L
s
.2592 .57635 m
.2592 .57635 L
s
.49528 .3224 m .47452 .30898 L .49167 .30508 L .751 0 0 r
F
.49791 .32261 m .49167 .30508 L .50992 .30656 L F
.49791 .32261 m .49528 .3224 L .49167 .30508 L F
.5 .32355 m .50992 .30656 L .52452 .31303 L F
0 g
.52431 .34209 m
.52447 .32005 L
s
.5 .32355 m .49791 .32261 L .50992 .30656 L .751 0 0 r
F
0 g
.49167 .30508 m
.50992 .30656 L
s
.35669 .35885 m .47452 .30898 L .49281 .32296 L p .751 0 0 r
F P
0 g
s
.47466 .32775 m
.47468 .33073 L
s
.49528 .3224 m .49281 .32296 L .47452 .30898 L .751 0 0 r
F
0 g
.47452 .30898 m
.49167 .30508 L
s
.5 .32355 m .52452 .31303 L .65465 .41077 L p .751 0 0 r
F P
0 g
s
.50992 .30656 m
.52452 .31303 L
s
.5 .33058 m
.5 .33479 L
s
0 0 0 r
.22522 .6329 m
.22522 .6329 L
s
.22522 .6329 m
.22522 .6329 L
s
.22522 .6329 m
.22522 .6329 L
s
.22522 .6329 m
.32267 .58716 L
s
.35509 .581 m
.35509 .581 L
s
.5 .66414 m
.5 .66414 L
s
0 g
.49528 .3224 m
.49791 .32261 L
s
.49759 .33468 m .48863 .33774 L p .50411 .33372 L 0 .48 .858 r
F P
0 g
s
.50411 .33372 m .50719 .33188 L .49759 .33468 L p 0 .48 .858 r
F P
0 g
s
.49281 .32296 m .37458 .37359 L .35669 .35885 L p .751 0 0 r
F P
0 g
s
.49281 .32296 m
.49528 .3224 L
s
.49281 .32296 m
.49283 .32999 L
s
.47452 .30898 m
.49281 .32296 L
s
0 0 0 r
.44103 .72907 m
.44103 .72907 L
s
.44103 .72907 m
.44103 .72907 L
s
.65465 .41077 m .62962 .4224 L .5 .32355 L p .751 0 0 r
F P
0 g
s
.49791 .32261 m
.5 .32355 L
s
.5 .32355 m
.52452 .31303 L
s
.5 .32355 m
.5 .33058 L
s
.23138 .70309 m .20383 .6749 L .12354 .71313 L p 0 .225 .528 r
F P
0 g
s
.145 .68157 m .12354 .71313 L .20383 .6749 L closepath p 0 .461 .92 r
F P
0 g
s
.22833 .66839 m .23138 .70309 L .25962 .732 L p 0 .193 .843 r
F P
0 g
s
.25962 .732 m .25686 .69719 L .22833 .66839 L p 0 .193 .843 r
F P
0 g
s
.25404 .66157 m .25962 .732 L .20383 .6749 L p 0 .193 .843 r
F P
0 g
s
.25404 .66157 m .22714 .70083 L .19872 .67172 L p 0 .223 .695 r
F P
0 g
s
0 0 0 r
.23138 .70309 m
.23138 .70309 L
s
.23138 .70309 m
.23138 .70309 L
s
.23138 .70309 m
.23138 .70309 L
s
.49759 .33468 m .50719 .33188 L .53117 .35019 L p 0 .124 .1 r
F P
0 g
s
.27171 .45722 m .28941 .48972 L .29394 .56034 L .1 0 0 r
F
.72771 .52585 m .72695 .56063 L .72272 .59687 L .854 0 0 r
F
0 g
.70293 .52773 m
.72541 .55853 L
s
.72771 .52585 m .73195 .49001 L .72695 .56063 L .854 0 0 r
F
.47533 .34278 m .46189 .34839 L p .47312 .3471 L 0 .48 .858 r
F P
0 g
s
.48709 .33827 m .47533 .34278 L p .47312 .3471 L 0 .48 .858 r
F P
0 g
s
.47312 .3471 m .48863 .33774 L .48709 .33827 L p 0 .48 .858 r
F P
0 g
s
.34415 .45193 m .28941 .48972 L .27171 .45722 L .757 0 0 r
F
0 g
.27171 .45722 m
.28329 .42365 L
s
.34415 .45193 m .35035 .46259 L .28941 .48972 L .757 0 0 r
F
0 g
.28941 .48972 m
.29394 .56034 L
s
.34415 .45193 m
.35035 .46259 L
s
.62783 .45295 m
.62817 .44416 L
s
.27171 .45722 m
.28941 .48972 L
s
.65918 .49551 m .70733 .4575 L .73195 .49001 L .757 0 0 r
F
0 g
.65991 .48033 m
.66162 .4795 L
s
.66162 .4795 m
.70733 .4575 L
s
.7038 .51387 m
.70517 .49203 L
s
.51364 .347 m .5 .34651 L p .53113 .35441 L 0 .464 .922 r
F P
0 g
s
.53113 .35441 m .53117 .35019 L .51364 .347 L p 0 .464 .922 r
F P
0 g
s
.53117 .35019 m .53113 .35441 L .56305 .37884 L p 0 .235 .864 r
F P
0 g
s
0 0 0 r
.31693 .63148 m
.31693 .63148 L
s
.31693 .63148 m
.31693 .63148 L
s
.31693 .63148 m
.31693 .63148 L
s
.31693 .63148 m
.31693 .63148 L
s
.2592 .57635 m
.31693 .63148 L
s
.2592 .57635 m
.2592 .57635 L
s
.53117 .35019 m .51364 .347 L .49759 .33468 L p 0 .124 .1 r
F P
0 g
s
.56305 .37884 m .56312 .3746 L .53117 .35019 L p 0 .235 .864 r
F P
0 g
s
.51364 .347 m .53117 .35019 L .56312 .3746 L p 0 .124 .1 r
F P
0 g
s
.28941 .48972 m
.35035 .46259 L
s
.48863 .33774 m .49759 .33468 L .51364 .347 L p 0 .151 .175 r
F P
0 g
s
0 0 0 r
.21214 .65205 m
.22656 .66661 L
s
.31693 .63148 m
.31693 .63148 L
s
.31693 .63148 m
.31693 .63148 L
s
.38049 .76014 m
.38049 .76014 L
s
.38049 .76014 m
.38049 .76014 L
s
.31693 .63148 m
.31693 .63148 L
s
.42793 .36377 m .42476 .36527 L p .4417 .36066 L 0 .48 .858 r
F P
0 g
s
.44628 .3553 m .42793 .36377 L p .4417 .36066 L 0 .48 .858 r
F P
0 g
s
.4417 .36066 m .46189 .34839 L .44628 .3553 L p 0 .48 .858 r
F P
0 g
s
.4417 .36066 m .46189 .34839 L .46816 .35331 L p 0 .228 .862 r
F P
0 g
s
.12354 .71313 m .15054 .74229 L .23138 .70309 L p 0 .225 .528 r
F P
0 g
s
0 0 0 r
.23138 .70309 m
.23138 .70309 L
s
.23138 .70309 m .15054 .74229 L .17824 .77219 L p 0 .225 .528 r
F P
0 g
s
.17824 .77219 m .25962 .732 L .23138 .70309 L p 0 .225 .528 r
F P
0 g
s
0 0 0 r
.23138 .70309 m
.23138 .70309 L
s
.23072 .6956 m
.23138 .70309 L
s
.56252 .40697 m .56305 .37884 L .53175 .39285 L p 0 .467 .923 r
F P
0 g
s
.64295 .58784 m
.64415 .56113 L
s
.64295 .58784 m
.64415 .56113 L
s
.5 .36808 m .5 .34651 L .53195 .37117 L p 0 .232 .863 r
F P
0 g
s
.48268 .34849 m .46816 .35331 L p .5 .36808 L 0 .464 .922 r
F P
0 g
s
.49766 .34643 m .48268 .34849 L p .5 .36808 L 0 .464 .922 r
F P
0 g
s
.5 .36808 m .5 .34651 L .49766 .34643 L p 0 .464 .922 r
F P
0 g
s
.15054 .74229 m .12354 .71313 L .145 .68157 L p 0 .223 .695 r
F P
0 g
s
.37458 .37359 m .34429 .36757 L .35669 .35885 L .751 0 0 r
F
0 g
.35716 .37013 m
.35777 .38456 L
s
.56312 .3746 m .5456 .37155 L .51364 .347 L p 0 .124 .1 r
F P
0 g
s
.51364 .347 m .5 .34651 L .48863 .33774 L p 0 .151 .175 r
F P
0 g
s
.5 .34651 m .51364 .347 L .5456 .37155 L p 0 .151 .175 r
F P
0 g
s
.48709 .33827 m .48863 .33774 L .5 .34651 L p 0 .151 .175 r
F P
0 g
s
.145 .68157 m .17232 .71038 L .15054 .74229 L p 0 .223 .695 r
F P
0 g
s
.17232 .71038 m .145 .68157 L .17101 .64334 L p 0 .223 .695 r
F P
0 g
s
.69442 .55521 m .72272 .59687 L .6901 .62655 L 1 0 0 r
F
.69442 .55521 m .72771 .52585 L .72272 .59687 L F
0 g
.72272 .59687 m
.72695 .56063 L
s
.47533 .34278 m .48709 .33827 L .49766 .34643 L p 0 .175 .308 r
F P
0 g
s
.5 .34651 m .49766 .34643 L .48709 .33827 L p 0 .151 .175 r
F P
0 g
s
.40984 .37442 m .42476 .36527 L .40621 .37408 L p 0 .48 .858 r
F P
0 g
s
.40984 .37442 m .42476 .36527 L .436 .3743 L p 0 .224 .86 r
F P
0 g
s
.17101 .64334 m .19872 .67172 L .17232 .71038 L p 0 .223 .695 r
F P
0 g
s
.19872 .67172 m .17101 .64334 L .19713 .60495 L p 0 .223 .695 r
F P
0 g
s
.37281 .37485 m .34071 .37866 L .34429 .36757 L .751 0 0 r
F
.37458 .37359 m .37281 .37485 L .34429 .36757 L F
0 g
.35669 .35885 m
.37458 .37359 L
s
.34429 .36757 m
.35669 .35885 L
s
.37458 .37359 m
.37479 .3792 L
s
.56312 .3746 m .56305 .37884 L .53175 .39285 L p 0 .467 .923 r
F P
0 g
s
.53175 .39285 m .56305 .37884 L .59577 .40389 L p 0 .204 .478 r
F P
0 g
s
.56431 .41826 m .59577 .40389 L .56305 .37884 L p 0 .204 .478 r
F P
0 g
s
.56305 .37884 m .53175 .39285 L .56431 .41826 L p 0 .204 .478 r
F P
0 g
s
.53195 .37117 m .53175 .39285 L .56305 .37884 L p 0 .467 .923 r
F P
0 g
s
.5456 .37155 m .53195 .37117 L p .56305 .37884 L 0 .467 .923 r
F P
0 g
s
.56305 .37884 m .56312 .3746 L .5456 .37155 L p 0 .467 .923 r
F P
0 g
s
.56312 .3746 m .56305 .37884 L .59577 .40389 L p 0 .235 .864 r
F P
0 g
s
0 0 0 r
.41431 .70744 m
.41431 .70744 L
s
.41431 .70744 m
.44785 .69049 L
s
.46298 .68284 m
.5 .66414 L
s
.5 .66414 m
.5 .66414 L
s
.5456 .37155 m .53195 .37117 L .5 .34651 L p 0 .151 .175 r
F P
0 g
s
.49766 .34643 m .5 .34651 L .53195 .37117 L p 0 .151 .175 r
F P
0 g
s
.5456 .37155 m .56312 .3746 L p .53175 .39285 L 0 .467 .923 r
F P
0 g
s
.59577 .40389 m .59589 .39963 L .56312 .3746 L p 0 .235 .864 r
F P
0 g
s
.5456 .37155 m .56312 .3746 L .59589 .39963 L p 0 .124 .1 r
F P
0 g
s
.43838 .37215 m .436 .3743 L p .46843 .38193 L 0 .464 .922 r
F P
0 g
s
.45358 .36109 m .43838 .37215 L p .46843 .38193 L 0 .464 .922 r
F P
0 g
s
.46843 .38193 m .46816 .35331 L .45358 .36109 L p 0 .464 .922 r
F P
0 g
s
.46843 .38193 m .46816 .35331 L .5 .37829 L p 0 .228 .862 r
F P
0 g
s
.53195 .37117 m .5296 .37111 L .49766 .34643 L p 0 .151 .175 r
F P
0 g
s
.49766 .34643 m .48268 .34849 L .47533 .34278 L p 0 .175 .308 r
F P
0 g
s
.48268 .34849 m .49766 .34643 L .5296 .37111 L p 0 .175 .308 r
F P
0 g
s
0 0 0 r
.4402 .68635 m
.44103 .72907 L
s
.44103 .72907 m
.44103 .72907 L
s
.65736 .50738 m .73195 .49001 L .72771 .52585 L .757 0 0 r
F
.65736 .50738 m .65918 .49551 L .73195 .49001 L F
0 g
.70733 .4575 m
.73195 .49001 L
s
.22714 .70083 m .25686 .69719 L .25962 .732 L p 0 .467 .923 r
F P
0 g
s
.25962 .732 m .20035 .73992 L .22714 .70083 L p 0 .467 .923 r
F P
0 g
s
.25962 .732 m .17824 .77219 L .20035 .73992 L closepath p 0 .467 .923 r
F P
0 g
s
.25962 .732 m .17824 .77219 L .20665 .80288 L p 0 .225 .528 r
F P
0 g
s
.20665 .80288 m .28858 .76164 L .25962 .732 L p 0 .225 .528 r
F P
0 g
s
.20035 .73992 m .17824 .77219 L .25962 .732 L closepath p 0 .467 .923 r
F P
0 g
s
.20035 .73992 m .25962 .732 L .25686 .69719 L p 0 .467 .923 r
F P
0 g
s
.25404 .66157 m .25686 .69719 L .28613 .72672 L p 0 .193 .843 r
F P
0 g
s
.31616 .75703 m .28613 .72672 L .28858 .76164 L p 0 .193 .843 r
F P
0 g
s
.28858 .76164 m .3183 .79205 L .31616 .75703 L p 0 .193 .843 r
F P
0 g
s
.3183 .79205 m .25962 .732 L .25404 .66157 L p 0 .193 .843 r
F P
0 g
s
.22714 .70083 m .25404 .66157 L .25686 .69719 L closepath p 0 .467 .923 r
F P
0 g
s
.25686 .69719 m .25404 .66157 L .22714 .70083 L closepath p 0 .467 .923 r
F P
0 g
s
.28613 .72672 m .28361 .69099 L .25404 .66157 L p 0 .193 .843 r
F P
0 g
s
.31397 .72119 m .28361 .69099 L .28613 .72672 L p 0 .193 .843 r
F P
0 g
s
.28613 .72672 m .31616 .75703 L .31397 .72119 L p 0 .193 .843 r
F P
0 g
s
.25404 .66157 m .31397 .72119 L .3183 .79205 L p 0 .193 .843 r
F P
0 g
s
.25686 .69719 m .22714 .70083 L .20035 .73992 L p 0 .467 .923 r
F P
0 g
s
.28361 .69099 m .2563 .7307 L .22714 .70083 L p 0 .223 .695 r
F P
0 g
s
.22714 .70083 m .25404 .66157 L .28361 .69099 L p 0 .223 .695 r
F P
0 g
s
0 0 0 r
.28858 .76164 m
.28858 .76164 L
s
.28858 .76164 m
.28858 .76164 L
s
.28858 .76164 m
.28858 .76164 L
s
.46189 .34839 m .47533 .34278 L .48268 .34849 L p 0 .194 .423 r
F P
0 g
s
.37281 .37485 m .37232 .37643 L .34071 .37866 L .751 0 0 r
F
0 g
.37281 .37485 m
.37458 .37359 L
s
.59497 .43216 m .59577 .40389 L .56431 .41826 L p 0 .47 .925 r
F P
0 g
s
.37232 .37643 m .34702 .38917 L .34071 .37866 L .751 0 0 r
F
0 g
.34071 .37866 m
.34429 .36757 L
s
.37232 .37643 m .37324 .37793 L .34702 .38917 L .751 0 0 r
F
0 g
.34702 .38917 m
.35035 .46259 L
s
.37232 .37643 m
.37281 .37485 L
s
.37232 .37643 m
.37324 .37793 L
s
.65736 .50738 m
.65918 .49551 L
s
.34702 .38917 m
.37324 .37793 L
s
.34071 .37866 m
.34702 .38917 L
s
.48268 .34849 m .46816 .35331 L .46189 .34839 L p 0 .194 .423 r
F P
0 g
s
.5296 .37111 m .51458 .37332 L .48268 .34849 L p 0 .175 .308 r
F P
0 g
s
.46816 .35331 m .48268 .34849 L .51458 .37332 L p 0 .194 .423 r
F P
0 g
s
.53175 .39285 m .53195 .37117 L .5456 .37155 L p 0 .467 .923 r
F P
0 g
s
.59577 .40389 m .56431 .41826 L .53175 .39285 L p 0 .204 .478 r
F P
0 g
s
.56473 .39647 m .56431 .41826 L .53175 .39285 L p 0 .232 .863 r
F P
0 g
s
.53175 .39285 m .53195 .37117 L .56473 .39647 L p 0 .232 .863 r
F P
0 g
s
.53195 .37117 m .53175 .39285 L .56431 .41826 L p 0 .232 .863 r
F P
0 g
s
.51458 .37332 m .5 .37829 L p .53175 .39285 L 0 .467 .923 r
F P
0 g
s
.5296 .37111 m .51458 .37332 L p .53175 .39285 L 0 .467 .923 r
F P
0 g
s
.53175 .39285 m .53195 .37117 L .5296 .37111 L p 0 .467 .923 r
F P
0 g
s
.44628 .3553 m .46189 .34839 L .46816 .35331 L p 0 .207 .511 r
F P
0 g
s
.15054 .74229 m .17232 .71038 L .20035 .73992 L p 0 .223 .695 r
F P
0 g
s
.20035 .73992 m .17824 .77219 L .15054 .74229 L p 0 .223 .695 r
F P
0 g
s
.59589 .39963 m .57839 .39672 L .5456 .37155 L p 0 .124 .1 r
F P
0 g
s
.53195 .37117 m .5456 .37155 L .57839 .39672 L p 0 .151 .175 r
F P
0 g
s
.4364 .39599 m .436 .3743 L .422 .38692 L p 0 .464 .922 r
F P
0 g
s
.4364 .39599 m .436 .3743 L .46758 .39968 L p 0 .224 .86 r
F P
0 g
s
.17232 .71038 m .19872 .67172 L .22714 .70083 L p 0 .223 .695 r
F P
0 g
s
.22714 .70083 m .20035 .73992 L .17232 .71038 L p 0 .223 .695 r
F P
0 g
s
.40621 .37408 m .42476 .36527 L .436 .3743 L p 0 .219 .614 r
F P
0 g
s
.436 .3743 m .422 .38692 L .40621 .37408 L p 0 .219 .614 r
F P
0 g
s
.46816 .35331 m .45358 .36109 L .44628 .3553 L p 0 .207 .511 r
F P
0 g
s
.42793 .36377 m .44628 .3553 L .45358 .36109 L p 0 .214 .572 r
F P
0 g
s
.45358 .36109 m .46816 .35331 L .5 .37829 L p 0 .207 .511 r
F P
0 g
s
.51458 .37332 m .5 .37829 L .46816 .35331 L p 0 .194 .423 r
F P
0 g
s
.42476 .36527 m .42793 .36377 L .43838 .37215 L p 0 .219 .614 r
F P
0 g
s
.43838 .37215 m .436 .3743 L .42476 .36527 L p 0 .219 .614 r
F P
0 g
s
.64614 .51691 m .65736 .50738 L .72771 .52585 L .757 0 0 r
F
.45358 .36109 m .43838 .37215 L .42793 .36377 L p 0 .214 .572 r
F P
0 g
s
.6901 .62655 m .5731 .68727 L .57481 .61535 L p .968 0 0 r
F P
0 g
s
.57481 .61535 m .69442 .55521 L .6901 .62655 L p .968 0 0 r
F P
0 g
s
.6901 .62655 m
.72272 .59687 L
s
.56376 .44661 m .56431 .41826 L .59321 .44081 L p 0 .232 .863 r
F P
0 g
s
.56376 .44661 m .56431 .41826 L .53239 .43284 L p 0 .47 .925 r
F P
0 g
s
.19872 .67172 m .22522 .6329 L .25404 .66157 L p 0 .223 .695 r
F P
0 g
s
0 0 0 r
.22522 .6329 m
.22522 .6329 L
s
.22522 .6329 m
.22522 .6329 L
s
0 g
.5 .48989 m
.5 .49567 L
s
.5 .49567 m
.5 .50392 L
s
.50775 .50069 m
.50777 .49058 L
s
.50774 .50461 m
.50775 .50069 L
s
.56431 .41826 m .59577 .40389 L .62482 .42612 L p 0 .204 .478 r
F P
0 g
s
.59321 .44081 m .62482 .42612 L .59577 .40389 L p 0 .204 .478 r
F P
0 g
s
.59577 .40389 m .56431 .41826 L .59321 .44081 L p 0 .204 .478 r
F P
0 g
s
.56473 .39647 m .56431 .41826 L .59577 .40389 L p 0 .47 .925 r
F P
0 g
s
.57839 .39672 m .56473 .39647 L p .59577 .40389 L 0 .47 .925 r
F P
0 g
s
.59577 .40389 m .59589 .39963 L .57839 .39672 L p 0 .47 .925 r
F P
0 g
s
.59589 .39963 m .59577 .40389 L .56431 .41826 L p 0 .47 .925 r
F P
0 g
s
.59589 .39963 m .59577 .40389 L .62482 .42612 L p 0 .235 .864 r
F P
0 g
s
.5 .37829 m .48532 .38624 L .45358 .36109 L p 0 .207 .511 r
F P
0 g
s
.43838 .37215 m .45358 .36109 L .48532 .38624 L p 0 .214 .572 r
F P
0 g
s
0 0 0 r
.37768 .6895 m
.37768 .6895 L
s
.37768 .6895 m
.37768 .6895 L
s
.37768 .6895 m
.37768 .6895 L
s
.31693 .63148 m
.37768 .6895 L
s
.31693 .63148 m
.31693 .63148 L
s
.57839 .39672 m .56473 .39647 L .53195 .37117 L p 0 .151 .175 r
F P
0 g
s
.56431 .41826 m .56473 .39647 L .53195 .37117 L p 0 .232 .863 r
F P
0 g
s
.5296 .37111 m .53195 .37117 L .56473 .39647 L p 0 .151 .175 r
F P
0 g
s
.57839 .39672 m .59589 .39963 L p .56431 .41826 L 0 .47 .925 r
F P
0 g
s
.62482 .42612 m .6216 .41926 L .59589 .39963 L p 0 .235 .864 r
F P
0 g
s
.57839 .39672 m .59589 .39963 L .6216 .41926 L p 0 .124 .1 r
F P
0 g
s
.47 .39749 m .46758 .39968 L p .5 .40706 L 0 .467 .923 r
F P
0 g
s
.48532 .38624 m .47 .39749 L p .5 .40706 L 0 .467 .923 r
F P
0 g
s
.5 .40706 m .5 .37829 L .48532 .38624 L p 0 .467 .923 r
F P
0 g
s
.5 .40706 m .5 .37829 L .53267 .40391 L p 0 .228 .862 r
F P
0 g
s
.56473 .39647 m .56238 .39642 L .5296 .37111 L p 0 .151 .175 r
F P
0 g
s
.51458 .37332 m .5296 .37111 L .56238 .39642 L p 0 .175 .308 r
F P
0 g
s
.436 .3743 m .43838 .37215 L .47 .39749 L p 0 .219 .614 r
F P
0 g
s
.48532 .38624 m .47 .39749 L .43838 .37215 L p 0 .214 .572 r
F P
0 g
s
.64614 .51691 m .72771 .52585 L .69442 .55521 L .757 0 0 r
F
0 g
.72771 .52585 m
.73195 .49001 L
s
.64614 .51691 m
.65736 .50738 L
s
.422 .38692 m .436 .3743 L .46758 .39968 L p 0 .219 .614 r
F P
0 g
s
.47 .39749 m .46758 .39968 L .436 .3743 L p 0 .219 .614 r
F P
0 g
s
0 0 0 r
.37768 .6895 m
.37768 .6895 L
s
.37768 .6895 m
.38049 .76014 L
s
.38049 .76014 m
.38049 .76014 L
s
.3183 .79205 m .28858 .76164 L .20665 .80288 L p 0 .225 .528 r
F P
0 g
s
0 0 0 r
.28858 .76164 m
.28858 .76164 L
s
.46758 .39968 m .45345 .41249 L .422 .38692 L p 0 .219 .614 r
F P
0 g
s
.47422 .62615 m
.47434 .64142 L
s
.47434 .64142 m .45919 .69663 L .48954 .64943 L .762 0 0 r
F
0 g
.47434 .64142 m
.48954 .64943 L
s
.47344 .53117 m
.47367 .55946 L
s
.47367 .55946 m
.47375 .56994 L
s
.5 .37829 m .51458 .37332 L .54732 .39878 L p 0 .194 .423 r
F P
0 g
s
.56238 .39642 m .54732 .39878 L .51458 .37332 L p 0 .175 .308 r
F P
0 g
s
.52679 .64643 m
.52728 .5896 L
s
.50879 .65127 m .5731 .68727 L .52679 .64643 L .762 0 0 r
F
0 g
.52679 .64643 m
.52728 .5896 L
s
.62482 .42612 m .59321 .44081 L .56431 .41826 L p 0 .204 .478 r
F P
0 g
s
.5768 .40578 m .59321 .44081 L .56431 .41826 L p 0 .232 .863 r
F P
0 g
s
.56431 .41826 m .56473 .39647 L .57839 .39672 L p 0 .47 .925 r
F P
0 g
s
.56431 .41826 m .56473 .39647 L .5768 .40578 L p 0 .232 .863 r
F P
0 g
s
.53239 .43284 m .56431 .41826 L .59321 .44081 L p 0 .204 .478 r
F P
0 g
s
.56114 .45572 m .59321 .44081 L .56431 .41826 L p 0 .204 .478 r
F P
0 g
s
.56431 .41826 m .53239 .43284 L .56114 .45572 L p 0 .204 .478 r
F P
0 g
s
.56473 .39647 m .56431 .41826 L .59321 .44081 L p 0 .232 .863 r
F P
0 g
s
.53267 .40391 m .53239 .43284 L .56431 .41826 L p 0 .47 .925 r
F P
0 g
s
.54732 .39878 m .53267 .40391 L p .56431 .41826 L 0 .47 .925 r
F P
0 g
s
.56238 .39642 m .54732 .39878 L p .56431 .41826 L 0 .47 .925 r
F P
0 g
s
.56431 .41826 m .56473 .39647 L .56238 .39642 L p 0 .47 .925 r
F P
0 g
s
.56473 .39647 m .56431 .41826 L .53239 .43284 L p 0 .47 .925 r
F P
0 g
s
.17824 .77219 m .20035 .73992 L .2291 .77024 L p 0 .223 .695 r
F P
0 g
s
.2291 .77024 m .20665 .80288 L .17824 .77219 L p 0 .223 .695 r
F P
0 g
s
.48954 .64943 m .51819 .7024 L .50879 .65127 L .762 0 0 r
F
.48954 .64943 m .45919 .69663 L .51819 .7024 L F
0 g
.50879 .65127 m
.52679 .64643 L
s
.48954 .64943 m
.50879 .65127 L
s
.6216 .41926 m .59549 .40985 L .57839 .39672 L p 0 .124 .1 r
F P
0 g
s
.56473 .39647 m .57839 .39672 L .59549 .40985 L p 0 .151 .175 r
F P
0 g
s
.46779 .42148 m .46758 .39968 L .45345 .41249 L p 0 .467 .923 r
F P
0 g
s
.46779 .42148 m .46758 .39968 L .5 .42572 L p 0 .224 .86 r
F P
0 g
s
.50879 .65127 m .51819 .7024 L .5731 .68727 L .762 0 0 r
F
.63076 .42396 m .65465 .41077 L .66277 .42163 L .751 0 0 r
F
0 g
.65332 .4396 m
.65412 .42226 L
s
.63076 .42396 m .62962 .4224 L .65465 .41077 L .751 0 0 r
F
0 g
.62946 .42645 m
.62962 .4224 L
s
.20035 .73992 m .22714 .70083 L .2563 .7307 L p 0 .223 .695 r
F P
0 g
s
.2563 .7307 m .2291 .77024 L .20035 .73992 L p 0 .223 .695 r
F P
0 g
s
.48532 .38624 m .5 .37829 L .53267 .40391 L p 0 .207 .511 r
F P
0 g
s
.54732 .39878 m .53267 .40391 L .5 .37829 L p 0 .194 .423 r
F P
0 g
s
.6216 .41926 m .62482 .42612 L .59321 .44081 L p 0 .358 .744 r
F P
0 g
s
.59549 .40985 m .6216 .41926 L p .59321 .44081 L 0 .358 .744 r
F P
0 g
s
.47 .39749 m .48532 .38624 L .51789 .41204 L p 0 .214 .572 r
F P
0 g
s
.53267 .40391 m .51789 .41204 L .48532 .38624 L p 0 .207 .511 r
F P
0 g
s
.59549 .40985 m .5768 .40578 L .56473 .39647 L p 0 .151 .175 r
F P
0 g
s
.59321 .44081 m .5768 .40578 L .56473 .39647 L p 0 .232 .863 r
F P
0 g
s
.56238 .39642 m .56473 .39647 L p .53239 .43284 L 0 .47 .925 r
F P
0 g
s
.56238 .39642 m .56473 .39647 L .5768 .40578 L p 0 .151 .175 r
F P
0 g
s
.5286 .47086 m .56114 .45572 L .53239 .43284 L p 0 .204 .478 r
F P
0 g
s
.59321 .44081 m .56114 .45572 L .53239 .43284 L p 0 .204 .478 r
F P
0 g
s
.54732 .39878 m .56238 .39642 L p .53239 .43284 L 0 .47 .925 r
F P
0 g
s
.53239 .43284 m .53267 .40391 L .54732 .39878 L p 0 .47 .925 r
F P
0 g
s
.53267 .40391 m .53239 .43284 L .56114 .45572 L p 0 .228 .862 r
F P
0 g
s
.50244 .4235 m .5 .42572 L p .53239 .43284 L 0 .47 .925 r
F P
0 g
s
.51789 .41204 m .50244 .4235 L p .53239 .43284 L 0 .47 .925 r
F P
0 g
s
.53239 .43284 m .53267 .40391 L .51789 .41204 L p 0 .47 .925 r
F P
0 g
s
.5393 .40912 m .56114 .45572 L .53239 .43284 L p 0 .228 .862 r
F P
0 g
s
.53239 .43284 m .53267 .40391 L .5393 .40912 L p 0 .228 .862 r
F P
0 g
s
.5768 .40578 m .57359 .40509 L .56238 .39642 L p 0 .151 .175 r
F P
0 g
s
.54732 .39878 m .56238 .39642 L .57359 .40509 L p 0 .175 .308 r
F P
0 g
s
.63047 .42563 m .66277 .42163 L .66094 .43334 L .751 0 0 r
F
.63047 .42563 m .63076 .42396 L .66277 .42163 L F
0 g
.62962 .4224 m
.65465 .41077 L
s
.65465 .41077 m
.66277 .42163 L
s
.62962 .4224 m
.63076 .42396 L
s
.46758 .39968 m .47 .39749 L .50244 .4235 L p 0 .219 .614 r
F P
0 g
s
.51789 .41204 m .50244 .4235 L .47 .39749 L p 0 .214 .572 r
F P
0 g
s
.59321 .44081 m .5768 .40578 L .59549 .40985 L p 0 .358 .744 r
F P
0 g
s
.45345 .41249 m .46758 .39968 L .5 .42572 L p 0 .219 .614 r
F P
0 g
s
.50244 .4235 m .5 .42572 L .46758 .39968 L p 0 .219 .614 r
F P
0 g
s
.20665 .80288 m .23581 .83437 L .3183 .79205 L p 0 .225 .528 r
F P
0 g
s
.3183 .79205 m .23581 .83437 L .25861 .80136 L closepath p 0 .473 .927 r
F P
0 g
s
.31616 .75703 m .3183 .79205 L .25861 .80136 L p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.31616 .75703 m
.41431 .70744 L
s
.31616 .75703 m
.31616 .75703 L
s
.5 .42572 m .48572 .43873 L .45345 .41249 L p 0 .219 .614 r
F P
0 g
s
.62883 .42696 m .63047 .42563 L .66094 .43334 L .751 0 0 r
F
0 g
.63047 .42563 m
.63076 .42396 L
s
.50779 .48332 m .62883 .42696 L .64948 .44275 L p .751 0 0 r
F P
0 g
s
.62883 .42696 m .66094 .43334 L .64948 .44275 L .751 0 0 r
F
0 g
.62883 .42696 m
.63047 .42563 L
s
.66094 .43334 m
.66277 .42163 L
s
.41331 .67178 m
.41331 .67178 L
s
.5768 .40578 m .59321 .44081 L .56114 .45572 L p 0 .358 .744 r
F P
0 g
s
.57359 .40509 m .5768 .40578 L p .56114 .45572 L 0 .358 .744 r
F P
0 g
s
.55509 .40483 m .57359 .40509 L p .56114 .45572 L 0 .358 .744 r
F P
0 g
s
.57359 .40509 m .55509 .40483 L .54732 .39878 L p 0 .175 .308 r
F P
0 g
s
.53267 .40391 m .54732 .39878 L .55509 .40483 L p 0 .194 .423 r
F P
0 g
s
.69442 .55521 m .57481 .61535 L .5274 .57489 L p .757 0 0 r
F P
0 g
s
.5274 .57489 m
.52749 .5644 L
s
.69442 .55521 m
.72771 .52585 L
s
.6901 .62655 m
.69442 .55521 L
s
.64614 .51691 m
.69442 .55521 L
s
.23581 .83437 m .20665 .80288 L .2291 .77024 L p 0 .223 .695 r
F P
0 g
s
.5 .44763 m .5 .42572 L .48572 .43873 L p 0 .47 .925 r
F P
0 g
s
.5 .44763 m .5 .42572 L .51194 .43531 L p 0 .224 .86 r
F P
0 g
s
.56114 .45572 m .5393 .40912 L .55509 .40483 L p 0 .358 .744 r
F P
0 g
s
.55509 .40483 m .5393 .40912 L .53267 .40391 L p 0 .194 .423 r
F P
0 g
s
.2291 .77024 m .25861 .80136 L .23581 .83437 L p 0 .223 .695 r
F P
0 g
s
.25861 .80136 m .2291 .77024 L .2563 .7307 L p 0 .223 .695 r
F P
0 g
s
.56114 .45572 m .5393 .40912 L .53267 .40391 L p 0 .228 .862 r
F P
0 g
s
.51789 .41204 m .53267 .40391 L .5393 .40912 L p 0 .207 .511 r
F P
0 g
s
.2563 .7307 m .28623 .76136 L .25861 .80136 L p 0 .223 .695 r
F P
0 g
s
.28623 .76136 m .2563 .7307 L .28361 .69099 L p 0 .223 .695 r
F P
0 g
s
0 0 0 r
.28361 .69099 m
.28858 .76164 L
s
.28361 .69099 m
.28361 .69099 L
s
.28361 .69099 m
.28361 .69099 L
s
.28361 .69099 m
.38232 .64285 L
s
.51862 .63035 m .5731 .68727 L .51819 .7024 L .892 0 0 r
F
.51862 .63035 m .57481 .61535 L .5731 .68727 L F
.64948 .44275 m .52805 .5 L .50779 .48332 L p .751 0 0 r
F P
0 g
s
.64948 .44275 m
.66094 .43334 L
s
.64614 .51691 m
.64948 .44275 L
s
.62883 .42696 m
.64948 .44275 L
s
.5393 .40912 m .56114 .45572 L .5286 .47086 L p 0 .358 .744 r
F P
0 g
s
.52563 .41817 m .5393 .40912 L p .5286 .47086 L 0 .358 .744 r
F P
0 g
s
.5393 .40912 m .52563 .41817 L .51789 .41204 L p 0 .207 .511 r
F P
0 g
s
.50244 .4235 m .51789 .41204 L .52563 .41817 L p 0 .214 .572 r
F P
0 g
s
.28361 .69099 m .31397 .72119 L .28623 .76136 L p 0 .223 .695 r
F P
0 g
s
0 0 0 r
.28361 .69099 m
.28361 .69099 L
s
.28361 .69099 m
.28361 .69099 L
s
.28361 .69099 m
.28361 .69099 L
s
.30028 .74101 m
.31616 .75703 L
s
.47375 .56994 m .45824 .62463 L .4113 .6 L .757 0 0 r
F
0 g
.4113 .6 m
.47375 .56994 L
s
.47375 .56994 m
.4893 .57786 L
s
.4113 .6 m
.41331 .67178 L
s
.25861 .80136 m .28623 .76136 L .31616 .75703 L p 0 .473 .927 r
F P
0 g
s
.31616 .75703 m .28623 .76136 L .31397 .72119 L closepath p 0 .473 .927 r
F P
0 g
s
0 0 0 r
.31616 .75703 m
.31616 .75703 L
s
.31616 .75703 m
.31616 .75703 L
s
.5 .42572 m .50244 .4235 L .51354 .4324 L p 0 .219 .614 r
F P
0 g
s
.52563 .41817 m .51354 .4324 L .50244 .4235 L p 0 .214 .572 r
F P
0 g
s
.48572 .43873 m .5 .42572 L .51194 .43531 L p 0 .219 .614 r
F P
0 g
s
.51354 .4324 m .51194 .43531 L .5 .42572 L p 0 .219 .614 r
F P
0 g
s
.51354 .4324 m .52563 .41817 L p .5286 .47086 L 0 .358 .744 r
F P
0 g
s
.45824 .62463 m .51819 .7024 L .45919 .69663 L .735 0 0 r
F
0 g
.41331 .67178 m
.45919 .69663 L
s
.51194 .43531 m .50256 .45243 L .48572 .43873 L p 0 .219 .614 r
F P
0 g
s
.4893 .57786 m .50899 .57969 L .51862 .63035 L .757 0 0 r
F
0 g
.4893 .57786 m
.50899 .57969 L
s
.45824 .62463 m .51862 .63035 L .51819 .7024 L .735 0 0 r
F
0 g
.51819 .7024 m
.5731 .68727 L
s
.45919 .69663 m
.51819 .7024 L
s
.50899 .57969 m .57481 .61535 L .51862 .63035 L .757 0 0 r
F
0 g
.50899 .57969 m
.5274 .57489 L
s
.5274 .57489 m
.57481 .61535 L
s
.5731 .68727 m
.57481 .61535 L
s
.5286 .47086 m .51194 .43531 L .51354 .4324 L p 0 .358 .744 r
F P
0 g
s
.4113 .6 m
.45824 .62463 L
s
.5 .48263 m .48905 .50294 L .47314 .49511 L .751 0 0 r
F
0 g
.47314 .49511 m
.47344 .53117 L
s
.5 .48263 m .50227 .48373 L .48905 .50294 L .751 0 0 r
F
0 g
.5 .48702 m
.5 .48989 L
s
.50512 .48398 m .50779 .48332 L .52805 .5 L .751 0 0 r
F
0 g
.50777 .49058 m
.50778 .48584 L
s
.50227 .48373 m .5092 .50474 L .48905 .50294 L .751 0 0 r
F
0 g
.47314 .49511 m
.5 .48263 L
s
.50227 .48373 m .50512 .48398 L .5092 .50474 L .751 0 0 r
F
0 g
.5 .48263 m
.50227 .48373 L
s
.50512 .48398 m .52805 .5 L .5092 .50474 L .751 0 0 r
F
0 g
.50227 .48373 m
.50512 .48398 L
s
.50779 .48332 m
.52805 .5 L
s
.50512 .48398 m
.50779 .48332 L
s
.52749 .5644 m
.52805 .5 L
s
.51862 .63035 m
.57481 .61535 L
s
.47314 .49511 m
.48905 .50294 L
s
.45824 .62463 m
.51862 .63035 L
s
.5092 .50474 m
.52805 .5 L
s
.48905 .50294 m
.5092 .50474 L
s
[ .01 .01 ] 0 setdash
.26955 .66897 m
.96867 .33233 L
s
.96867 .33233 m
.93524 .57729 L
s
.93524 .57729 m
.28863 .9254 L
s
.28863 .9254 m
.26955 .66897 L
s
.0116 .41327 m
.0478 .66178 L
s
.0478 .66178 m
.28863 .9254 L
s
.28863 .9254 m
.26955 .66897 L
s
.26955 .66897 m
.0116 .41327 L
s
.003 w
[ ] 0 setdash
.0478 .66178 m
.28863 .9254 L
s
.25 Mabswid
.09401 .71237 m
.09966 .70969 L
s
gsave
.08271 .71771 -85.25 -7.68849 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.16156 .7863 m
.16716 .78353 L
s
gsave
.15035 .79185 -71 -7.53407 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.23358 .86515 m
.23913 .86227 L
s
gsave
.22249 .87091 -77 -7.36453 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.10718 .72678 m
.11057 .72517 L
s
.12052 .74138 m
.1239 .73975 L
s
.13402 .75617 m
.1374 .75453 L
s
.1477 .77114 m
.15107 .76949 L
s
.17559 .80166 m
.17894 .79999 L
s
.1898 .81723 m
.19315 .81554 L
s
.20421 .83299 m
.20755 .83129 L
s
.2188 .84896 m
.22213 .84725 L
s
.081 .69813 m
.0844 .69653 L
s
.06815 .68406 m
.07156 .68248 L
s
.05546 .67017 m
.05887 .6686 L
s
.24857 .88155 m
.25189 .87981 L
s
.26375 .89817 m
.26706 .89641 L
s
.27914 .91502 m
.28245 .91325 L
s
gsave
.09434 .81958 -76.625 -7.53407 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00b@3oool3000005@0oooo00370?ooo`80000000@0oooo0000003oool00000D`3oool00<@0
oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000D@3oool00<80oooo0P0000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0CP3oool00;d0oooo1000000?0?ooo`030000
003oool0oooo04d0oooo002j0?ooo`8000005P3oool2000004`0oooo002i0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`190?ooo`00]@3oool20000
0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`180?ooo`00]03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0AP3oool00;00oooo
0P00000G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A@3oool00:l0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`140?ooo`00Z`3oool2000001`0oooo00<00000
0?ooo`3oool03`3oool2000004<0oooo002Z0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`100?ooo`00Y`3oool200000200oooo00<000000?ooo`3o
ool0E03oool00:D0oooo0P00000R0?ooo`030000003oool0oooo01@0oooo0P00000n0?ooo`00XP3o
ool2000003h0oooo00<000000?ooo`3oool0>`3oool00:00oooo0P00001n0?ooo`00W@3oool20000
02X0oooo00<000000?ooo`3oool0603oool2000003X0oooo002K0?ooo`800000;03oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo03L0oooo002H0?ooo`800000;`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03@0oooo002G0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0<`3oool009<0oooo0P00001F0?ooo`030000003oool0oooo0380oooo002B0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0`0?oo
o`00SP3oool2000003T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0_0?ooo`00
S@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
;P3oool008T0oooo0P00001V0?ooo`800000;@3oool008P0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0Z0?ooo`00Q03oool200000480oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0Y0?ooo`00P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02/0
oooo0P00000X0?ooo`00P03oool2000004H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0U0?ooo`00OP3oool2000004P0oooo00<000000?ooo`3oool0E@3oool007/0oooo0P00001m
0?ooo`800000903oool007T0oooo0P00001=0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool08@3oool007H0oooo0P00001@0?ooo`030000003oool0oooo05D0oooo001d0?ooo`800000
DP3oool00`000000oooo0?ooo`0d0?ooo`8000007`3oool00740oooo0P00001E0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0703oool00700oooo00<000000?ooo`3oool0[@3oool0
06`0oooo0P00002E0?ooo`8000006`3oool006/0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01P0oooo001W0?ooo`800000G`3oool00`000000oooo
0?ooo`0l0?ooo`8000005`3oool006H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01@0oooo001R0?ooo`800000YP3oool00`000000oooo0?ooo`0C
0?ooo`00H@3oool00`000000oooo0?ooo`0c0?ooo`T00000K03oool00`000000oooo0?ooo`0A0?oo
o`00GP3oool2000003@0oooo0`0000090<00008000009P3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0100oooo001L0?ooo`800000<`3oool300000080`00000<000000<0000300000
20300003000002@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`00F@3o
ool2000003@0oooo0P0000060<000003000000300000`00000@0`0000`0000030<0000030000003o
ool0oooo0200oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`00E`3oool2
000003@0oooo0P0000090<000003000000300000000000<000001`3000000`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo00`0oooo001D0?ooo`800000=03oool3000000/0`0000P0000000`30
00000000000000090<0000800000JP3oool00`000000oooo0?ooo`0;0?ooo`00DP3oool2000003@0
oooo0P00000;0<0000<0000000H0l`00000000300000000006P00000000:0<0000030000003oool0
oooo01`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00C`3oool20000
03@0oooo0`00000;0<0000<000000`3c00000`000000`00000000003000000X0`00000<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo001=0?ooo`80
0000=03oool2000000`0`0000P0000040?<000H000000P007aT2000000T0`0000P00000K0?ooo`03
0000003oool0oooo04X0oooo0`0000090?ooo`00BP3oool2000003D0oooo0P00000;0<0000<00000
1@3c0004000000<002H/00<00000000O6@007aT00P00000:0<0000030000003oool0oooo01P0oooo
00<000000?ooo`3oool0B@3oool010000000oooo0?ooo`0000090?ooo`00B@3oool00`000000oooo
0?ooo`0b0?ooo`<000002`300002000000D0l`0010000003000/CP05000000009R`002H/000V;000
00000P007aT2000000X0`00000<000000?ooo`3oool0G`3oool2000000D0oooo00<000000?ooo`3o
ool01`3oool004D0oooo0P00000e0?ooo`8000002`300003000000@0l`000`000002000aK1000000
2@3000000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
3`3oool004@0oooo00<000000?ooo`3oool0<`3oool2000000/0`0000P0000050?<0008000000P00
=883000000@0035/00D00000000/CP00;4h002a>00000003000V;0D000002@300002000001H0oooo
00<000000?ooo`3oool0@03oool2000000X0oooo00<000000?ooo`3oool01`3oool00400oooo0P00
000e0?ooo`<000002`300002000000D0l`000P000003000dPP0500000000=88003B2000dPP000000
1000<F`01000000002a>000/CP00;4h20000008002H/00<00000000O6@007aT00P00000:0<000003
0000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo000o0?ooo`030000003oool0oooo03<0oooo0P00000;0<0000<00000
103c00030000008003JB00<00000000dPP0000001@00=8800`000000035/000aK002000aK0040000
0000;4h002a>000/CP8000000P009R`200000003000O6@000000000000X0`00000<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0l0?ooo`8000003@3oool00`000000oooo0?ooo`080?ooo`00
>`3oool2000003H0oooo0P0000020<000003000000300000`00000H0`0000P0000060?<000800000
1000=Y83000000H003B200<00000000aK000<F`00P00<F`00`00000002a>000/CP02000/CP800000
0P009R`00`00000001lI000O6@02000000T0`0000P00001@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0203oool003X0oooo00<000000?ooo`3oool0=@3oool00`000000`0000<00
00030<000003000000300000`00000<0`0000P0000060?<000<0000000<003RM00000000=Y800P00
0003000fTP0300000000=88003B200@003B200<00000000aK000<F`00P00<F`00`00000002a>000/
CP02000/CP8000000P009R`00`00000001lI000O6@02000000X0`00000<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0I0?ooo`00=`3oool2000003T0oooo00D000000<0000300000`0000000
00020<0000030000003000000000008000001P3c0002000000<003RM00@00000000hW@0000000000
1@00=Y800`00000003B2000dPP04000dPP0300000000<F`0035/0080035/00<00000000/CP00;4h0
2`00000:0<0000030000003oool0oooo00h0oooo00<000000?ooo`3oool0=`3oool200000180oooo
00<000000?ooo`3oool0203oool003D0oooo0P00000j0?ooo`03000000300000`00000H0`00000<0
00000?<0003c00001@3c0003000000D003RM0P0000000`00>9d00000000fTP04000fTP8000001@00
=8800`000000035/000aK004000000@002a>0P000002000V;003000000007aT00000008000002@30
0002000000h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00P0oooo000b0?ooo`800000?@3oool00`000000`0000<0000050<0000<000000`3c0003
000000<003RT00D00000000hW@00>9d003RM00000002000hW@0300000000>9d0000000H003JB00<0
0000000dPP00=8800P00=883000000@0035/00<00000000/CP00;4h00P00;4h20000008002H/00D0
0000000O6@007aT001lI0000000:0<0000030000003oool0oooo00/0oooo00<000000?ooo`3oool0
<P3oool2000001H0oooo00<000000?ooo`3oool02@3oool00300oooo0P00000o0?ooo`0300000030
0000`0000080`0000`0000020<0000@000001`00>:@00`00000003RM00000004000hW@0300000000
>9d0000000H003JB00@00000000dPP00000000000`00=8800`000000035/000aK002000aK0800000
0`00;4h20000008002H/0P000002000O6@03000000300000`00000P0`00000<000000?ooo`3oool0
1P3oool2000000<0oooo0P00000a0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2@3oool002d0oooo0P0000120?ooo`0301T000000000`00000<000001@300002000000T003RT0P00
0005000hW@<000001@00=Y83000000D003B200<00000000aK000<F`00`00<F`00`00000002a>000/
CP02000/CP05000000009R`002H/000V;00000000P007aT2000000T0`0000P0000050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool2000002L0oooo000[0?ooo`800000@P3o
ool2000000806@000P0000090<00000300000000>:@003RT00D003RT00@00000000hY000>:@00000
1P00>9d2000000<003JB00D00000000fTP00=Y8003JB00000005000dPP8000001000<F`2000000<0
02a>00D00000000V;0009R`002H/00000002000O6@8000002P30000010000000oooo00000000000e
0?ooo`030000003oool0oooo02L0oooo000X0?ooo`800000@`3oool200000080`@000P0I00000`00
0000F000000000090<00000300000000>:@003RT00<003RT00<00000000hY000>:@00P00>:@00`00
000003RM000hW@04000hW@80000000<003JB00000000=Y801000=Y800`00000003B2000dPP04000d
PP0300000000<F`0035/00<0035/00D00000000/CP00;4h002a>00000003000V;003000000007aT0
01lI008000002P3000000`000000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00T0oooo000W0?ooo`030000003oool0oooo0440oooo0`0000030<40
00806@0000@0000005P0001H000000002@3000001@00000003RT000hY000>:@0000000H003RT00<0
0000000hW@00>9d01000>9d3000000H003JB0P000005000dPP0300000000<F`0035/0080035/3`00
00090<0000030000003oool0oooo008000000`00=h<2000000@0oooo00<000000?ooo`3oool08`3o
ool2000001l0oooo00<000000?ooo`3oool02@3oool002<0oooo0P0000150?ooo`050000003o0000
`@000<40000000000P31000201T000050000001H0000F00005P0000000002@3000000`00000003RT
00000008000hY00300000000>9d003RM00<003RM10000007000fTP0300000000=88003B200<003B2
00@00000000aK000000000000P00<F`00`00000002a>000/CP02000/CP04000000009R`002H/000V
;0D000002@300002000000H003N30`0000030?ooo`030000003oool0oooo0200oooo0P00000Q0?oo
o`030000003oool0oooo00T0oooo000R0?ooo`030000003oool0oooo04<0oooo0P0000050<400005
0000003100006@0001T000000000101H0002000000P0`0000P000009000hY00500000000>9d003RM
000hW@0000000`00>9d2000000L003JB00<00000000dPP00=8800P00=88300000080035/30000002
000O6@8000002P3000000`00000003N3000gP`04000gP`@000000`3oool00`000000oooo0?ooo`0K
0?ooo`800000<03oool001d0oooo0`0000170?ooo`030000003o0000`@0000H0`@0000@0000001T0
000I000000001@1H0002000000T0`00000<00000000hY000>:@01`00>:@00`00000003RM00000005
000hW@<000001P00=Y801000000003B2000000000002000dPP<000001`00Fkh01000000005^n001K
_P00Fkh300000003000O6@000000000000X0`00000<00000000gP`00=h<01@00=h<00`00000000`I
000000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0<03oool001/0oooo00<0
00000?ooo`3oool0B03oool00`000000`@000<4000080<4000030000000I0000000000H0F0000P00
00090<00000300000000>:@003RT00L003RT0P000006000hW@<000001@00=Y82000000<003B200<0
0000001K_P0000002@00Fkh00`00000005^n001K_P03001K_PD0000020300002000000L003N300<0
0000000<6@0000000`3oool00`000000oooo0?ooo`0D0?ooo`800000:03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool2000004L0oooo0P00000<0<4000800000201H00000`000000`0000<000007
0<00008000001P00>:@01000000003RT000hY0000007000hW@8000000`00=Y801P00000003JB000f
TP00000003B2000000<005^n00<00000001K_P00Fkh01P00Fkh00`00000005^n001K_P06001K_P<0
00001030000300000080`00000<00000000gP`00=h<01000=h<5000000<0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000K0?ooo`800000
AP3oool00`000000`@000<40000<0<40000301T000000000F00000P0F0000P0000090<0000030000
0000>:@003RT008003RT00<00000000hY000>:@00P00>:@00`00000003RM000hW@05000hW@800000
00<003JB00000000=Y800`00=Y800`00000005^n001K_P02001K_P0300000000Fkh005^n00L005^n
00<00000001K_P00Fkh01`00Fkh2000000030<0000000000000000H0`00000@00000000gP`00=h<0
03N30P000003000gP`<000000`3oool00`000000oooo0?ooo`0=0?ooo`800000;03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo000000140?ooo`03000000310000`@0000d0`@00
00<06@000000001H00002@1H0002000000T0`00000@00000000hY000>:@000001P00>:@00`000000
03RM000hW@05000hW@<000000`00=Y800`00000005^n001K_P03001K_P0300000000Fkh005^n00P0
05^n00<00000001K_P00Fkh01P00Fkh010000000J0000000000000070<0000@000001P00=h<50000
00030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0>@3oool001/0oooo00@000000?ooo`3o
ool00000@`3oool00`000000`@000<4000020<4000<0o`002031000201T000030000001H0000F000
00P0F0000P0000090<00008000002000>:@00`00000003RM000hW@03000hW@0700000000>9d00000
000hW@00000003JB00000007001K_P0300000000Fkh005^n00L005^n00<00000001K_P00Fkh01P00
Fkh4000000H0`00000<000000<40000000000P000007000gP`H000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo03X0oooo000L0?ooo`80000000<0oooo0000003oool0@03oool0
0`000000`@000<4000040<400080o`001`310000101L00006@0001T00000000;05P0008000002P30
00000`00000003RT000hY006000hY00500000000>9d003RM000hW@0000000`00>9d00`00000003RM
00000008001K_P0300000000Fkh005^n00P005^n00<00000001K_P00Fkh00P00Fkh4000000<0`000
00<000000<00003000000`3000000`000000`@000<4000020<40000300000000=h<003N300H003N3
00<00000000<6@0000000P0000020?ooo`030000003oool0oooo00<0oooo0P00000a0?ooo`030000
003oool0oooo00X0oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3o
ool00`000000`@000<4000080<4000030?l0001L0000`@0000<0`@000P0I00000`000000F00005P0
000;05P0008000002@3000000`00000003RT000hY006000hY00300000000>9d0000000D003RM00<0
0000001K_P00Fkh02000Fkh00`00000005^n001K_P07001K_P0300000000Fkh005^n00@000001P30
00001P000000`0000<000030000000000>P000D0`@0000<00000000gP`00=h<01P00=h<00`000000
00`I0000000200000080oooo00<000000?ooo`3oool00P00000c0?ooo`030000003oool0oooo00X0
oooo000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?03oool00`000000`@00
0<40000;0<4000<0G0000P0I00000`000000F00005P0000<05P0008000002@300002000000L003RT
0P000005000hW@0300000000Fkh005^n00P005^n00<00000001K_P00Fkh01`00Fkh200000003001K
_P000000000000T0`00000D000000<0000000000o`000>P000060<40000300000000=h<003N300D0
03N32@00000e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`8000001@3oool00`000000oooo
0?ooo`0j0?ooo`03000000310000`@0000l0`@000P0I00000`000000F00005P0000=05P000800000
2P3000000`00000003RT000hY004000hY00300000000>:@0000000<003RM00<00000001K_P000000
2P00Fkh00`00000005^n001K_P04001K_PD000002`30000200000080o`0000<0j0000<4000310000
1@310002000000<003N30P000003000gP`D0000000<0oooo000000000000<`3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`110?ooo`03000000310000`@0000l0`@000P0I
00000`000000F00005P0000>05P0008000002P3000000`00000003RT000hY002000hY00500000000
>:@003RT000hY00000000P00>9d00`00000005^n0000000:001K_P0400000000Fkh005^n001K_PD0
000030300002000000050?H000000000o`000?l0003X00002@310003000000@003N31`0000020?oo
o`030000003oool0oooo03h0oooo000L0?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool0>03oool00`000000`@000<40000?0<4000030000000I000000000140F0000`0000090<000004
00000000>:@003RT000000D003RT00<00000000hW@0000000P00Fkh00`00000005^n001K_P07001K
_P0500000000Fkh0000000000000Fkh00P00000<0<00008000000`3f000010000000o`000?l0003X
000:0<40000300000000=h<003N3008003N300<00000000gP`00=h<00P00=h<5000003<0oooo00<0
00000?ooo`3oool02`3oool001`0oooo0P0000080?ooo`030000003oool0oooo03H0oooo00<00000
0<4000310000403100000`0000006@000000000B05P000<000002@300002000000L003RT00@00000
001K_P00Fkh005^n0P000008001K_P80000000<005^n00000000000030300003000000@0mP0000@0
00000?l0003o0000j0002`3100000`00000003N3000gP`07000gP`D0000000<0oooo000000000000
;`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000000T0oooo00<000000?ooo`3oool0=@3o
ool00`000000`@000<40000A0<4000800000501H0002000000X0`00000<00000000hY000>:@01000
>:@00`00000005^n001K_P02001K_P0300000000Fkh005^n00@005^n0P0000000`00Fkh000000000
000<0<00008000001`3f000010000000o`000?l0003X000;0<4000<000002000=h<500000080oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`00303oool01`0@410000000000
00000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`040?ooo`800000@03oool00`000000
`@000<40000A0<40008000005@1H0002000000X0`00000<00000000hY000>:@00P00>:@00`000000
05^n001K_P03001K_P8000000`00Fkh200000003001K_P000000000000`0`0000P0000090?H00004
0000003o0000o`000>P000T0`@001000000:000gP`H00000;`3oool00`000000oooo0?ooo`0;0?oo
o`003`3oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P000001P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03<0oooo00<06@000000003100003`310002000000<0`@005@1H
0002000000X0`00000D00000000hY000>:@003RT00000006001K_P0500000000Fkh0000000000000
Fkh00P00000<0<00008000002`3f00000`000000o`000?l000080<4000800000103100000`000000
03N3000gP`05000gP`8000000P00=h<5000000030?ooo`000000000003T0oooo000@0?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03<0oooo0P0I00000`000000`@000<40000:0<4000<000001P31000E05P000800000
2P3000001000000003RT000000000007001K_P@000002`300003000000d0mP0000<000000?l0003o
00001P310002000000L0`@0000<00000000gP`00=h<00P00=h<2000000H003N3100000020?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0303oool00100oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`000000oooo0?ooo`0b0?ooo`806@00
00<000000<400031000020310003000000T0`@005@1H0002000000X0`0000P000005001K_P@00000
3030000200000100mP0000<000000?l0003o00000`310003000000X0`@0010000009000gP`D00000
:P3oool00`000000oooo0?ooo`0<0?ooo`003`3oool0102HV9P000000?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0a0?ooo`806@00
00<000000<40003100001@310002000000d0`@005P1H00000`000000`0000<0000080<0000030000
0000Fkh005^n00D000003030000200000180mP0000<000000?l0003o00000P310002000000`0`@00
00<00000000gP`00=h<02`00=h<00`00000000`I00000002000000040?ooo`0000000000000002D0
oooo00<000000?ooo`3oool0303oool000`0oooo100000000`2HV9P0oooo000000030?ooo`030000
003oool0oooo00@0oooo0P00000>0?ooo`030000003oool0oooo0300oooo0P0I00000`000000`@00
0<4000020<4000<000004031000F05P00003000000300000`00000L0`0001P00000<0<0000800000
503f00000`000000o`0000000002000000l0`@0000<00000000gP`00=h<03000=h<0100031T00000
0000000000030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0303oool000`0oooo
00<0MgMg05EEE@3oool00`3oool01@000000V9RH0?ooo`2HV9P0000000L0oooo0P00000>0?ooo`03
0000003oool0oooo02l0oooo0`0I000010000000`@0000000000000D0<4001H0F00000<000000<00
003000001030000200000080`0000`00000;0<00008000005P3f0002000000030?l000310000`@00
0100`@0000<00000000gP`00=h<02`00=h<6000003D0oooo000=0?ooo`06010@400000000000038b
<P3oool0V9RH0`0000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo03l0oooo100I0002
000001H0`@005P1H00000`000000`0000<0000020<000005000000300000`0000<00000000000`30
00000`000000`0000<0000060<0000800000603f00000`000000o`000?l0000C0<40000300000000
=h<003N300L003N300H0043M00000000000007W]00000000NNd400000080oooo00<000000?ooo`3o
ool0;`3oool001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]0?ooo`@06@00
00<000000540000000005`31000E05P000040000003000000000000000T0`0000P0000040<000080
00005`3f0002000000040?H000000000o`000?l000`0`@0000<000000<4000310000103100001000
000003N3000gP`00@=d5000gP`8000000`00NNd00`00000007W]001ik@0400000080oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool200000140oooo00<000000?oo
o`3oool0;03oool401T000040000001A0000D@00000001L0`@005@1H0002000000`0`00000@00000
0<000000000000005`3f0002000000<0mP0000@000000?l0003o000000004P3100000`00000003N3
000gP`04000gP`8000001@00NNd00`00000007W]001ik@02001ik@@0000000<0oooo0000003oool0
7`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02/0oooo100I00001@000000D@000540001A0000000001L0`@00501H000010000000QP00
0000000000090<0000<000005P3f0002000000H0mP0000@000000?l0003o000000004P3100000`00
000003N3000gP`02000gP`8000001`00NNd00`00000007W]001ik@02001ik@D000000P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0000003l0
oooo100I00000`000000D@000540000205400003000000310000`@0001D0`@004`1H000010000000
QP0008H00026000900000080h`0000<000000?H0003f00004`3f00000`000000mP000?H000060?H0
00040000003o0000o`0000000180`@0000<00000000gP`00=h<00P000009001ik@0500000000NNd0
07W]001ik@0000000`00NNd300000080oooo00<000000?ooo`3oool0:P3oool001h0oooo0P00000D
0?ooo`030000003oool0oooo02T0oooo100I00000`000000D@000540000305400003000000310000
`@0001D0`@004P1H000010000000QP0008H0002600060;d000D0h`0000<000000?H0003f00003`3f
0002000000/0mP0000@000000?l00000000000004P310003000000/007W]00@00000001ik@00NNd0
00001P00NNd3000000030?ooo`000000oooo02X0oooo000O0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0:@3oool301T000030000001A0000D@0000@0D@0000<000000<4000310000
5@3100000`000000F00005P0000>05P00004000000260000QP0008H000H0_@001@3S00000`000000
mP000?H0000>0?H000030000003f0000mP0000/0mP000P00000C0<4000<000003000NNd00`000000
07W]00000007001ik@@000000P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0
oooo000?0?ooo`0309RHV014A4@0oooo0080oooo00D0410@000000000000000009RHV0060?ooo`80
00005@3oool00`000000oooo0?ooo`0X0?ooo`<06@0000<000000540001A00001@1A00000`000000
`@000<40000E0<40008000003P1H000010000000QP0008H0002600060;d000D0h`0000<000000?H0
003f0000703f0002000001<0`@0000<00000001ik@0000003000NNd2000000L007W]00@00000001i
k@00NNd007W]0P0000020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool0
00l0oooo00<0k^k^0000003^k^h01@3oool00`2HV9P000000?ooo`050?ooo`030000003oool0oooo
03l0oooo0`0I00000`000000D@000540000605400003000000310000`@0001H0`@0000<0000005P0
001H00002`1H000010000000QP0008H0002600060;d000D0h`0000<000000?H0003f00002P3f0002
000000h0mP000P0000020<400003000000310000`@000100`@000P00000<001ik@8000001`00NNd0
0`00000007W]001ik@04001ik@040000003oool0oooo000001H0oooo00<000000?ooo`3oool03P3o
ool00100oooo00<0A4A40:VYZ@3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool09P3oool301T000030000001A0000D@0000L0D@0000<00000
0<40003100005P3100000`000000F00005P0000:05P00004000000260000QP0008H000H0_@001@3S
00000`000000mP000?H000090?H000030000003f0000mP0000`0mP000P0000050<40000300000031
0000`@0000l0`@000P00000:001ik@@000001P00NNd00`00000007W]001ik@05001ik@8000000`3o
ool2000002@0oooo000@0?ooo`0309RHV01EEED0oooo00D0oooo00<000000?ooo`3oool0103oool2
000001P0oooo00<000000?ooo`3oool09@3oool01@0000006@0001T0000I0000000000T0D@000P00
000G0<4000030000001H0000F00000T0F00000@0000008H000260000QP001P2m00050><000030000
003f0000mP0000H0mP000P00000>0?H000800000203100000`000000`@000<40000=0<4000<00000
2000NNd20000008007W]0P000005001ik@0300000000NNd007W]00@007W]0P0000070?ooo`030000
003oool0oooo0240oooo000@0?ooo`030>k^kP000000oooo00@0oooo00<0V9RH0000003oool01@3o
ool00`000000oooo0?ooo`0o0?ooo`050000000I00006@0001T0000000002P1A0002000001L0`@00
00<0000005P0001H0000201H000010000000QP0008H0002600060;d000D0h`0000<000000?H0003f
0000103f0002000000h0mP000P00000;0<400003000000310000`@0000/0`@0000@000000?l00000
NNd000001P00NNd2000000@007W]0P000004001ik@0300000000NNd007W]00<007W]0P00000:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00140oooo00<08B4Q0:VYZ@3o
ool0100000000`2HV9P0oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0903oool0100000006@0001T00000000;0540008000005`3100000`000000F00005P0000705P0
0004000000260000QP0008H000H0_@00103S0002000000<0mP000P00000?0?H0008000003P310002
000000X0`@0000D000000?l0003o000007W]00000005001ik@0300000000NNd007W]00@007W]0P00
0003001ik@0300000000NNd007W]008007W]0P00000>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool000h0oooo00P08B4Q0;Zj^P3oool0QhN705EEE@3oool0MgMg05EEE@X0
oooo0P00000J0?ooo`030000003oool0oooo02<0oooo00@0000001T0000I00000000301A00020000
01L0`@0000<0000005P0001H00001P1H000010000000QP0008H0002600060;d000@0h`000P000002
0?H000030000003f0000mP0000d0mP000P00000B0<400003000000310000`@0000D0`@000P000003
0?l00003001ik@00000007W]008007W]0P000007001ik@0500000000NNd007W]001ik@0000000P00
NNd300000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`003P3oool0
1@1gMgL00000000000000000410@0080oooo00@0410@000000000000<S8b1`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<0000001T0000000003@1A0002000001L0`@00
0P00000605P00004000000260000QP0008H000H0_@00103S000200000100mP000P00000E0<400003
000000310000`@0000<0`@0000<000000?l0003o00000`3o00000`00NNd00000001ik@02000000T0
07W]00D00000001ik@00NNd00000001ik@02000001D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool200000440oooo00<0000001T0000000003`1A00000`000000
`@000<40000F0<4000030000001H0000F00000<0F00000@0000008H000260000QP001P2m00030><0
008000003`3f0002000001P0`@0000D000000<4000310000`@00000000060?l00003001ik@000000
000000/007W]00<00000001ik@0000000P00000f0?ooo`00803oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0240oooo00<0000001T000000000401A00000`000000`@000<40000F0<40
00030000001H0000F0000080F00000@0000008H000260000QP001P2m00040><000030000003f0000
mP0000/0mP000P00000K0<400003000000310000000000L0o`000P00000<001ik@<000006`3oool2
000000T0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0P0?ooo`030000000I000000000140D@0000<000000<40003100005P3100001@00
0000F00005P0001H0000000000<0QP001P2m000200000080h`0000<000000?H0003f00002@3f0002
000001d0`@000P0000080?l0000300000000NNd007W]00X007W]0P00000O0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03`3oool00200oooo0`00000N0?ooo`030000003oool0oooo
01/0oooo0P0000030?ooo`8000004P1A00000`000000`@000<40000F0<4000040000001H0000F000
000000<0QP00102m0002000000@0h`0000<000000?H0003f00001`3f0002000001d0`@000P000000
0`3g000000000?l000070?l0000300000000NNd007W]00P007W]0P00000Z0?ooo`030000003oool0
oooo00l0oooo000P0?ooo`800000?03oool00`000000oooo0?ooo`030?ooo`<000004P1A00020000
01L0`@0000<0000005P0000000000`2600000`2m00000000000000030;d000@0h`0000<000000?H0
003f00001@3f0002000001D0`@0000<000000<40003100001@310002000000<0m`0000<000000?l0
003o00001P3o00000`00000007W]001ik@06001ik@8000009@3oool2000000D0oooo00<000000?oo
o`3oool03`3oool00200oooo00<000000?ooo`3oool0803oool2000001D0oooo0P0000060?ooo`80
00000`00=h<00`000000D@000540000@0540008000005`31000200000080QP000P0000050;d000@0
h`0000<000000?H0003f00000`3f0002000001d0`@000P0000050?L000030000003o0000o`0000H0
o`0000<00000001ik@00NNd01000NNd2000002T0oooo00<000000?ooo`3oool0503oool000`0oooo
0`0000000`3oool0V9RH000000020000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0
103oool200000280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`800000
1P00=h<00`000000D@000540000@0540008000005P31000300000080QP001P2m00040><000030000
003f0000mP0000<000007@310002000000L0m`0000<000000?l0003o00001@3o00000`3J00000000
001ik@03001ik@800000<03oool00`000000oooo0?ooo`0?0?ooo`003@3oool03P000000oooo0?oo
o`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P000001P3oool00`000000oooo
0?ooo`0j0?ooo`8000002@00=h<00`000000D@000540000A05400003000000310000`@000140`@00
0`0000020<40008000001P2m00040><000<000001`3100000`3f0000`@000<40000D0<4000800000
2@3g00000`000000o`000?l000050?l000030=X00000000007W]008007W]00<000000?ooo`3oool0
;@3oool2000000030?ooo`000000oooo0100oooo00020?ooo`H000001@3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool2000002<0oooo
00<000000?ooo`3oool03@3oool2000000@0oooo0P00000<000gP`030000001A0000D@000140D@00
00<000000<40003100003P310002000000L0`@00100000020;d00080h`00100000020?H001/0`@00
0P00000;0?L000030000003o0000o`0000D0o`0000<0fP0000000000NNd00P00000a0?ooo`800000
4P3oool00080oooo00H0ZJVY038b<P3oool0oooo0>k^kP0b<S850?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool02P3oool2000000@0oooo0P0000000`00=h<00000000gP`0<000g
P`030000001A0000D@0000P0D@0000<000000540001A00001P1A00000`000000`@000<40000;0<40
00<0000030310004000000@0`@0000<000000<400031000060310002000000d0m`0000<000000?l0
003o00001@3o000300000340oooo0`00000C0?ooo`000`3oool00`1VIVH0MgMg0?ooo`070?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool2000000@0oooo0`000004000g
P`0300000000=h<003N300/003N300<000000540001A00004@1A00000`000000`@000<4000080<40
0080000000<0`@000000003100005@3100000`000000`@000<40000F0<4000030000003g0000m`00
00d0m`0000<000000?l0003o00001@3o00000`000000oooo0?ooo`0_0?ooo`80000000<0oooo0000
003oool04`3oool000<0oooo00<0k^k^024Q8@3<c<`01`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool3000002/0oooo0P0000040?oo
o`8000002000=h<00`00000003N3000gP`0:000gP`8000004`1A00000`000000`@000<4000050<40
00@000006@310002000001@0`@000P00000@0?L000030000003o0000o`0000D0o`0000<000000?oo
o`3oool0;P3oool3000001H0oooo00040?ooo`030<c<c00Q8B40k^k^00H0oooo00h000000?ooo`3o
ool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH000000H0oooo0P00000W0?oo
o`040000003oool00000000000D0oooo0P00000;000gP`0300000000=h<003N300L003N30P000002
000gP`030000001A0000D@000140D@0000<000000<40003100000P310004000001d0`@0000<00000
0<40003100003`31000200000140m`0000<000000?l0003o00001P3o00000`000000oooo0?ooo`0/
0?ooo`<00000603oool000D0oooo00<0MgMg06IVIP3oool0103oool01@0Q8B4000000?ooo`3oool0
V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`050?ooo`8000009`3oool0
0`000000oooo0?ooo`030?ooo`8000003P00=h<00`00000003N3000gP`04000gP`8000001@00=h<0
0`000000D@000540000A054000030000003100000000008000003P3100001@260000`@000<400031
0000_@0000h0`@0000<000000<400031000030310002000001<0m`0000<000000?l0003o00001@3o
0002000002`0oooo0`00000J0?ooo`000P3oool01P0b<S80k^k^0?ooo`3oool0<S8b0:VYZAX0oooo
00<000000?ooo`3oool08P3oool2000000<0oooo00<000000?ooo`3oool00P00000A000gP`030000
0000=h<003N300<000002000=h<00`000000D@000540000A054000800000903100000`000000`@00
0<4000090<40008000005@3g00000`000000o`000?l000040?l000030000003oool0oooo02X0oooo
0`00000L0?ooo`000P3oool6000001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`040?ooo`8000005000=h<2000000`003N300<000000540001A00003@1A00020000000305400000
0000P`00008000008`310002000000L0`@000P00000G0?L000030000003o0000o`0000<0o`0000<0
00000?ooo`3oool0:@3oool2000000030?ooo`000000oooo01`0oooo000R0?ooo`<000007@3oool2
000000P0oooo0`00000B000gP`80000000<003N300000000=h<03000=h<00`000000D@000540000;
054000050000001A0000D@000540000000000`2300000`000000`@000<4000090<40000300000031
0000`@0001H0`@0000<000000<40003100000P310002000001T0m`0000<000000?l0003o00000P3o
00000`000000oooo0?ooo`0X0?ooo`@000007`3oool00280oooo0P00000M0?ooo`030000003oool0
oooo00P0oooo1000000?000gP`8000001000=h<00`00000003N3000gP`0;000gP`030000001A0000
D@0000h0D@0000<0000008<0002300000P230002000002<0`@0000@000000<400000000000006`3g
00001@000000o`000?l0003o0000000002T0oooo1000000Q0?ooo`008P3oool2000001X0oooo0P00
000;0?ooo`0300000000>K4003Va00<000003000=h<2000000L003N300<00000000gP`00=h<02P00
=h<2000000L0D@000P00000605400003000000230000P`0000@0P`000P00000P0<4000<000007@3g
000010000000o`000?l00000000Y0?ooo`<000008`3oool000d0oooo0`0000000`3oool000000000
0002000000030;Zj^P3oool0410@00<0000000<0V9RH0?ooo`3oool0103oool3000001P0oooo00<0
00000?ooo`3oool02P3oool00`00000003Va000i/@02000i/@80000000<003N300000000=h<01`00
=h<2000000X003N300<00000000gP`00=h<01`00=h<30000008003N31@1A00000`000000D@000540
000605400003000000230000P`0000H0P`0000<000000<40003100006@31000400000080i00000<0
00000?L0003g00006`3g00000`000000o`000000000X0?ooo`<000009@3oool000h0oooo00P00000
0?ooo`3oool0c<c<0>k^kP3oool0c<c<05EEE@@0oooo00<0V9RH0000003oool01P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<00000000i/@00>K400`00>K43000000D0
03N30`00000=000gP`0300000000=h<003N300@003N30`000005000gP`03054000000000000000X0
D@0000<0000008<0002300001`230002000001H0`@000`0000060>@000030000003g0000m`0001/0
m`000P00000W0?ooo`80000000<0oooo0000003oool09@3oool000h0oooo00H000000?ooo`3oool0
oooo0<c<c03^k^h70?ooo`030000003oool0oooo00D0oooo0P00000D0?ooo`8000003P3oool00`00
000003Va000i/@05000i/@<000000P00=h<20000014003N300@00000000gP`00=h<003N30P000007
000gP`800000301A00000`000000P`0008<0000908<000T000002@310004000000T0i00000<00000
0?L0003g00006`3g00000`000000oooo0?ooo`0T0?ooo`<00000:@3oool000h0oooo00<000000?oo
o`3oool00P3oool00`2YZJT0k^k^0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`0300000000>K4003Va00L003Va1000000D000g
P`<000001P00=h<2000000@003N32`1A00000`000000P`0008<0000908<000T0_0002@00000=0>@0
00030000003g0000m`0001P0m`000P00000U0?ooo`@00000:`3oool000h0oooo00<000000?ooo`3o
ool00P3oool00`3MgMd0IVIV0?ooo`040?ooo`0309RHV0000000oooo00H0oooo00<000000?ooo`3o
ool03P3oool200000140oooo00<00000000i/@00>K402@00>K43000001<003N310000005000gP`03
00000000=h<003N300D003N32P1A00000`000000P`0008<0000908<00100_0003`3T00000`000000
m`000?L0000F0?L0008000009`3oool2000002d0oooo000>0?ooo`040000003oool0oooo07MgM`80
oooo00<000000?ooo`3oool0100000000`2HV9P0oooo0?ooo`050?ooo`8000003P3oool00`000000
oooo0?ooo`0A0?ooo`0300000000>K4003Va00T003Va00@00000000i/@00000000003`00=h<30000
00@003N300<00000000gP`0000002`00=h<905400003000000230000P`0000T0P`00402l000?0>@0
00030000003g0000m`0001@0m`000P00000W0?ooo`800000;`3oool000h0oooo00@000000?ooo`3o
ool000000P2HV9P01@000000oooo0?ooo`1gMgL0EEEE00X0oooo0P00000:0?ooo`8000005@3oool0
0`00000003Va000i/@09000i/@0400000000>K4003Va000i/@8000003000=h<3000000L003N300<0
0000000gP`00=h<02`00=h<805400003000000230000P`0000T0P`00402l000?0>@000030000003g
0000m`000180m`000P00000W0?ooo`800000<@3oool000d0oooo00D08B4Q0000003oool0oooo09RH
V0020000000509RHV03oool0oooo0?ooo`0@41000P0000000`0b<S80oooo0?ooo`050?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool0503oool00`00000003Va000i/@09000i/@030000
0000>K4003Va00<003Va00<00000000gP`00=h<02000=h<3000000P003N300<00000000gP`000000
2`00=h<2000000L0D@0000<0000008<0002300002@23000@0;`000l0i00000<000000?L0003g0000
403g0002000002L0oooo0`00000b0?ooo`00903oool00`000000oooo0?ooo`040?ooo`800000603o
ool00`00>K400000000i/@09000i/@0300000000>K4003Va00@003Va0P000006000gP`<000001`00
=h<2000000@003N300<00000000gP`00=h<01P00=h<2000000<003N31P1A00000`000000P`0008<0
000908<00100_0003`3T00000`000000m`000?L0000>0?L0008000009`3oool3000003@0oooo000T
0?ooo`<000000P3oool2000001T0oooo00@00000000i/@00>K4000002000>K400`00000003Va000i
/@06000i/@8000000`00=h<2000000P003N30P000007000gP`0300000000=h<003N300<003N30P00
0006000gP`D0D@0000<0000008<0002300002@23000@0;`000h0i00000<000000?L0003g00003@3g
0002000002L0oooo0P00000g0?ooo`00903oool010000000oooo00000000000K0?ooo`0300000000
>K4003Va008003Va00<00000000i/@00>K401000>K400`00000003Va000i/@08000i/@@000001`00
=h<2000000/003N300<00000000gP`0000000P000009000gP`@0D@0000<0000008<0002300002@23
000@0;`000h0i00000<000000?L0003g0000303g00000`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0100oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0V9RH00<0000000<0
V9RH0?ooo`3oool05P3oool002@0oooo0P00000M0?ooo`0300000000>K4003Va00<003Va00<00000
000i/@00>K400P00>K400`00000003Va000i/@0:000i/@0300000000=h<003N300D003N30P00000=
000gP`8000003@00=h<305400003000000230000P`0000T0P`00402l000>0>@000030000003g0000
m`0000X0m`000P00000W0?ooo`800000503oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P0
00000?ooo`000000V9RH0?ooo`2HV9P00000603oool002@0oooo0P00000L0?ooo`0300000000>K40
03Va00D003Va00D00000000i/@00>K4003Va0000000<000i/@0500000000=h<0000000000000=h<0
0P00000>000gP`8000000P00=h<00`00000003N3000gP`0;000gP`80D@0000<0000008<000230000
2@23000@0;`000h0i00000<000000?L0003g0000203g0002000002L0oooo0`00000E0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`00
3`3oool3000000030?ooo`0@410000000080000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo
0?ooo`050?ooo`<000006@3oool00`00000003Va000i/@07000i/@0300000000>K40000000`003Va
00<00000000i/@0000000P00=h<00`00000003N3000gP`0<000gP`8000001@00=h<00`00000003N3
000gP`0;000gP`03054000000000P`0000X0P`00402l000>0>@000030000003g0000m`0000H0m`00
0P00000W0?ooo`<000005`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool00`3oool0202HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P00000203oool00`000000oooo0?ooo`0G0?ooo`0300000000>K40
03Va00T003Va00<00000000i/@00>K402P00>K401@00000003Va000i/@00>K40000000h003N30P00
0008000gP`0300000000=h<003N300X003N30`00000:08<00100_0003P3T00000`000000m`000?L0
00040?L0008000009P3oool3000001X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`8000005`3oool00`00000003Va000i
/@09000i/@8000002`00>K400`00000003Va000i/@02000i/@8000002P00=h<2000000/003N300<0
0000000gP`00=h<01`00=h<30000008007W]0P00000808<00100_0003P3T00000`000000m`000?L0
00020?L0008000009`3oool3000001/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`8000005@3oool00`00000003Va000i
/@09000i/@0400000000>K4003Va000000T003Va00<00000000i/@00>K401000>K400`00000003N3
000gP`05000gP`<000003P00=h<00`00000003N3000gP`04000gP`8000001`00NNd00`000000P`00
08<0000508<00100_0003P3T00000`000000m`000?L00002000002L0oooo0P00000N0?ooo`0>0000
003oool0oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV000000H0?ooo`00
403oool00`000000oooo0?ooo`030?ooo`0409RHV0000000oooo000000<0oooo00<000000?ooo`3o
ool02@3oool300000180oooo00<00000000i/@00>K402@00>K400`00000003Va000i/@02000i/@03
00000000>K4003Va00D003Va00<00000000i/@00>K401@00>K42000000@003N30P00000B000gP`04
00000000=h<003N3000gP`8000002P00NNd2000000D0P`00402l000>0>@000<00000:03oool30000
01d0oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool0100000000`2HV9P0oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`00>K400000000i/@09000i
/@0300000000>K4003Va00<003Va00<00000000i/@00>K401000>K400`00000003Va000i/@05000i
/@0400000000>K400000000gP`8000005@00=h<3000000h007W]0P00000308<00100_000303T0003
000002P0oooo0`0000160?ooo`00403oool01@000000oooo0?ooo`1gMgL0EEEE00@0oooo00D00000
09RHV03oool0V9RH0000000=0?ooo`800000403oool01000000003Va000i/@000008000i/@030000
0000>K4003Va00D003Va00<00000000i/@00>K400P00>K400`00000003Va000i/@09000i/@800000
5@00=h<30000010007W]0`0000000`230000_0000;`0000>0;`000T0i0000`00000Y0?ooo`800000
B@3oool000l0oooo00<08B4Q0000003oool00P3oool01P0@410000000000000b<S80oooo09RHV0<0
000000<0V9RH0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`0300000000>K4003Va0080
03Va00<00000000i/@00>K401000>K400`00000003Va000i/@07000i/@0500000000>K400000000i
/@0000003000>K400`00000003N3000gP`0A000gP`8000000P00NNd00`00000007W]001ik@0=001i
k@80000000<007W]000000000000402l00050>@000@00000:P3oool2000004/0oooo000]0?ooo`80
0000303oool00`00000003Va000i/@04000i/@0300000000>K4003Va008003Va00<00000000i/@00
>K402@00>K43000000T003Va00<00000000i/@0000000P00>K400`00000003N3000gP`0>000gP`80
00001000NNd00`00000007W]001ik@0:001ik@<0000000<007W]00000000NNd00P00NNd9000000L0
_0000P3T0003000002`0oooo0P00001=0?ooo`00;P3oool00`000000oooo0?ooo`0:0?ooo`030000
0000>K4003Va00D003Va00D00000000i/@00>K4003Va0000000<000i/@0300000000>K4003Va00P0
03Va0P000004000i/@0300000000=h<003N300/003N30P000006001ik@0300000000NNd007W]00P0
07W]0P000004001ik@0300000000NNd007W]00X007W]2@00000]0?ooo`<00000CP3oool002l0oooo
00<000000?ooo`3oool0203oool00`00000003Va000i/@07000i/@0300000000>K40000000d003Va
00<00000000i/@00>K402000>K42000000D003Va00<00000000gP`00=h<02000=h<2000000P007W]
00<00000001ik@00NNd01P00NNd2000000H007W]00<00000001ik@00NNd02000NNd2000003D0oooo
0P00001@0?ooo`00;`3oool2000000030?ooo`000000oooo00D0oooo00<00000000i/@00>K402@00
>K400`00000003Va000i/@0;000i/@0300000000>K40000000T003Va00<00000000i/@00>K401@00
>K400`00000003N3000gP`05000gP`8000002P00NNd00`00000007W]001ik@04001ik@8000002000
NNd00`00000007W]001ik@07001ik@030000003oool0oooo03<0oooo0P00001B0?ooo`00<03oool2
000000H0oooo00<00000000i/@00>K402P00>K42000000/003Va00D00000000i/@00>K4003Va0000
0007000i/@0300000000>K4003Va00L003Va00<00000000gP`00=h<00P00=h<2000000`007W]00<0
0000001ik@00NNd00P00NNd2000000X007W]00<00000001ik@00NNd01@00NNd2000003<0oooo0`00
001D0?ooo`00<@3oool00`000000oooo0?ooo`040?ooo`0300000000>K4003Va00T003Va00@00000
000i/@00>K4000002P00>K400`00000003Va000i/@02000i/@0300000000>K4003Va00@003Va00<0
0000000i/@0000002000>K401000000003N300000000000>001ik@0300000000NNd007W]00800000
3000NNd00`00000007W]001ik@03001ik@800000=03oool3000005D0oooo000P0?ooo`07010@4000
000000000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo00D0oooo0P0000050?ooo`03
00000000>K4003Va00L003Va00<00000000i/@00>K400P00>K400`00000003Va000i/@06000i/@03
00000000>K4003Va00@003Va00<00000000i/@00>K400P00>K401000000003Va000i/@000009000i
/@8000003`00NNd3000000h007W]00@00000001ik@00NNd007W]0P00000d0?ooo`<00000E`3oool0
02<0oooo00P0V9RH0000003oool0000009RHV03oool0V9RH000000P0oooo00<000000?ooo`000000
103oool00`00000003Va000i/@06000i/@0300000000>K4003Va00<003Va00<00000000i/@00>K40
1000>K400`00000003Va000i/@06000i/@0500000000>K4003Va000i/@0000000P00>K400`000000
03Va000i/@07000i/@0300000000NNd007W]00d007W]0P00000@001ik@0400000000NNd000000000
03@0oooo0`00001I0?ooo`00903oool00`000000oooo000000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`00000003Va000i/@04000i/@0300000000>K4003Va00D0
03Va00<00000000i/@00>K400P00>K400`00000003Va000i/@08000i/@0300000000>K40000000`0
03Va0P00000=001ik@8000000P00NNd00`00000007W]001ik@0=001ik@800000=03oool2000005`0
oooo000H0?ooo`L000001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`00000003Va000i/@02000i/@0300000000>K4003Va00L003Va
00D00000000i/@00>K4003Va0000000;000i/@0300000000>K4003Va00X003Va00<00000001ik@00
00002`00NNd2000000@007W]00<00000001ik@00NNd02`00NNd2000003D0oooo0P00001M0?ooo`00
8`3oool0102HV9P000000?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool01@00000003Va000i/@00>K40000000X003Va00<00000000i/@0000003@00>K401@00
000003Va000i/@00>K40000000L003Va00<00000001ik@0000002@00NNd2000000H007W]00<00000
001ik@00NNd02@00NNd2000003@0oooo0`00001O0?ooo`00803oool40000000309RHV03oool00000
00<0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<00000000i/@0000003000>K400`00
000003Va000i/@0:000i/@0400000000>K4003Va0000008003Va00<00000000i/@00>K401000>K40
1@00000007W]001ik@00NNd0000000H007W]0P000008001ik@0300000000NNd007W]00L007W]0P00
000e0?ooo`<00000H03oool00200oooo00<0MgMg05EEE@3oool00`3oool01@000000V9RH0?ooo`2H
V9P0000000d0oooo00<000000?ooo`3oool0103oool2000000`003Va00<00000000i/@00>K402@00
>K400`00000003Va000i/@02000i/@0300000000>K40000000D003Va00<00000001ik@00NNd00P00
NNd00`00000007W]001ik@02001ik@8000002P00NNd00`00000007W]001ik@05001ik@800000=@3o
ool300000680oooo000Q0?ooo`06010@400000000000038b<P3oool0V9RH0`0000000`2HV9P0oooo
0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<00000000i/@00>K402000>K400`00000003Va
0000000:000i/@0300000000>K4003Va00<003Va0P000005000i/@0300000000NNd007W]008007W]
00<00000001ik@00NNd00P00000<001ik@0300000000NNd007W]00<007W]0P00000e0?ooo`800000
I@3oool003T0oooo0P0000070?ooo`0300000000>K4003Va00H003Va00D00000000i/@00>K4003Va
00000008000i/@0300000000>K4003Va00D003Va00<00000000i/@00>K400P00>K400`00000007W]
001ik@03001ik@<000003P00NNd01000000007W]001ik@00NNd2000003H0oooo00<000000?ooo`3o
ool0I@3oool003X0oooo0`0000060?ooo`0300000000>K4003Va00@003Va00<00000000i/@00>K40
0`00>K400`00000003Va000i/@04000i/@0300000000>K4003Va00H003Va0P000003000i/@040000
0000NNd007W]001ik@<000004000NNd01000000007W]00000000000f0?ooo`800000J03oool003/0
oooo00<000000?ooo`3oool01P3oool00`00000003Va000i/@03000i/@0300000000>K4003Va00@0
03Va00<00000000i/@00>K400P00>K400`00000003Va000i/@07000i/@0400000000>K400000000i
/@D000000P00NNd00`00000007W]001ik@0>001ik@800000=@3oool4000006T0oooo000l0?ooo`03
0000003oool0oooo00H0oooo00D00000000i/@00>K4003Va00000008000i/@0500000000>K4003Va
000i/@0000002P00>K401000000003Va000000000006001ik@0300000000NNd007W]00`007W]0P00
000f0?ooo`<000003P3oool01@2HV9P00000000000000000V9RH05P0oooo000m0?ooo`030000003o
ool0oooo00H0oooo00<00000000i/@0000002P00>K400`00000003Va0000000;000i/@0300000000
>K40000000L007W]00<00000001ik@00NNd02P00NNd2000003H0oooo0P00000A0?ooo`050000002H
V9P0oooo09RHV0000000F03oool003h0oooo0`0000060?ooo`0300000000>K4003Va00X003Va00<0
0000000i/@00>K402`00>K400`00000007W]001ik@06001ik@0300000000NNd007W]00P007W]0P00
000f0?ooo`8000004`3oool01@000000oooo0?ooo`3oool0000005P0oooo000o0?ooo`030000003o
ool0oooo00D0oooo00<00000000i/@00>K402`00>K400`00000003Va000i/@09000i/@0300000000
NNd007W]00L007W]00<00000001ik@00NNd01P00NNd2000003L0oooo00<000000?ooo`3oool04`3o
ool01@000000oooo0?ooo`3oool0000005P0oooo00100?ooo`030000003oool0oooo00D0oooo00<0
0000000i/@00>K402000>K401000000003Va000i/@00000:000i/@0300000000NNd007W]00L007W]
00<00000001ik@00NNd01000NNd2000003L0oooo0P00000F0?ooo`050000003oool0oooo0?ooo`00
0000F03oool00440oooo100000040?ooo`0300000000>K4003Va00H003Va00<00000000i/@00>K40
0P00>K400`00000003Va000i/@06000i/@8000002@00NNd00`00000007W]001ik@02001ik@800000
=P3oool3000001P0oooo00D000000?ooo`3oool0oooo0000001H0?ooo`00@P3oool2000000H0oooo
00<00000000i/@00>K401@00>K400`00000003Va000i/@03000i/@0300000000>K4003Va00@003Va
00<00000001ik@0000002@00NNd00`00000007W]001ik@02000003L0oooo0P00000J0?ooo`050000
002HV9P0oooo09RHV0000000F03oool004<0oooo00<000000?ooo`3oool01@3oool00`00000003Va
000i/@03000i/@0300000000>K4003Va00D003Va00<00000000i/@00>K400P00>K400`00000007W]
001ik@0:001ik@0300000000NNd0000003L0oooo0P00000L0?ooo`0509RHV000000000000000002H
V9P0F03oool004@0oooo00<000000?ooo`3oool0103oool00`00000003Va000i/@02000i/@030000
0000>K4003Va00L003Va00D00000000i/@00>K4003Va00000008001ik@D00000=`3oool2000007/0
oooo000g0?ooo`0509RHV000000000000000002HV9P0203oool2000000H0oooo00D00000000i/@00
>K4003Va0000000:000i/@0300000000>K400000008007W]1`0000000`00NNd000000000000h0?oo
o`800000O03oool003L0oooo00D0000009RHV03oool0V9RH000000090?ooo`<000001@3oool00`00
000003Va0000000<000i/@@0000000<007W]00000000NNd00`00NNd2000003P0oooo0P00001n0?oo
o`00=`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01@3oool00`00
000003Va000i/@0;000i/@0300000000NNd007W]008007W]00<00000001ik@00NNd00P00000g0?oo
o`<00000<P3oool3000004/0oooo000g0?ooo`050000003oool0oooo0?ooo`0000002`3oool20000
00H0oooo00<00000000i/@00>K402@00>K400`00000007W]001ik@04001ik@800000>03oool20000
03@0oooo00<0k^k^0000003^k^h0B`3oool003L0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`8000001P3oool00`00000003Va000i/@07000i/@0300000000NNd007W]00<007W]0P00000h0?oo
o`800000=`3oool00`000000oooo0?ooo`1:0?ooo`00=`3oool01@000000oooo0?ooo`3oool00000
00d0oooo0`0000050?ooo`0300000000>K4003Va00H003Va00<00000001ik@00NNd00P00NNd01000
0000oooo0?ooo`00000e0?ooo`<00000=`3oool00`3^k^h000000>k^kP1;0?ooo`00=`3oool01@00
0000V9RH0?ooo`2HV9P0000000h0oooo00<000000?ooo`3oool01@3oool00`00000003Va000i/@04
000i/@0400000000NNd007W]001ik@8000000`3oool00`000000oooo0?ooo`0b0?ooo`800000>@3o
ool304A4A4/0oooo000S0?ooo`<0000000<0oooo07MgM`0000000P00000<0?ooo`0509RHV0000000
00000000002HV9P03`3oool00`000000oooo0?ooo`050?ooo`0300000000>K4003Va008003Va00<0
0000001ik@00NNd00P0000050?ooo`030000003oool0oooo02l0oooo0`00000j0?ooo`0508N7Q`14
A4@0oooo038b<P2YZJT0BP3oool002@0oooo00H0V9RH07MgM`3oool0oooo024Q8@2YZJTR0?ooo`03
0000003oool0oooo00D0oooo00@00000000i/@00>K4003Va0`0000070?ooo`030000003oool0oooo
02d0oooo0`00000k0?ooo`070<c<c0000000k^k^0?ooo`3<c<`000000<c<c0190?ooo`009@3oool0
101EEED0V9RH07MgM`1VIVHT0?ooo`8000001P3oool01000000003Va00000000000h0?ooo`800000
?@3oool200000003038b<P3oool0000000800000B@3oool002D0oooo00<0k^k^024Q8@0b<S809P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3o
ool3000008h0oooo000U0?ooo`030>k^kP0@4100<S8b02L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0X0?ooo`<00000T03oool002D0oooo00@0IVIV07MgM`2YZJT0IVIV9P3oool2
00000140oooo00<000000?ooo`3oool09P3oool2000009<0oooo000T0?ooo`040:VYZ@0Q8B40oooo
0?ooo`80V9RH00<0k^k^0?ooo`3oool08`3oool3000000l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`2C0?ooo`008`3oool30000000307MgM`3oool0<S8b0080000000<0^[Zj0?oo
o`3oool08`3oool00`000000oooo0?ooo`0a0?ooo`80000000<0oooo000000000000UP3oool00580
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`800000V03oool005<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0O0?ooo`800000VP3oool005@0oooo00@0
00000?ooo`00000000002`3oool00`000000oooo0?ooo`0L0?ooo`800000W03oool005D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`800000WP3oool005H0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`2N0?ooo`00E`3oool00`000000oooo0?ooo`0S0?oo
o`800000X@3oool004@0oooo00L0410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo0`00002S
0?ooo`00A`3oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P000002P3oool2000000P0oooo
00<000000?ooo`3oool04P3oool3000001X0oooo0`0000000`3oool0V9RH000000020000000309RH
V03oool0V9RH00<0000000<0V9RH0?ooo`3oool0NP3oool004P0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`0A0?ooo`8000007@3o
ool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
O03oool004P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01P0oooo0P00000O0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`1j0?ooo`00A`3oool0102HV9P000000?ooo`0000030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool2000001H0oooo1`0000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1j0?ooo`00
A03oool40000000309RHV03oool0000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo
000000040?ooo`030000003oool0oooo00`0oooo0P00000R0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1j0?ooo`00A03oool00`1gMgL0EEEE
0?ooo`030?ooo`050000002HV9P0oooo09RHV00000003P3oool2000000@0oooo00<000000?ooo`3o
ool0203oool4000002@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?oo
o`030000003oool0oooo07X0oooo00150?ooo`06010@400000000000038b<P3oool0V9RH0`000000
0`2HV9P0oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`8000009P3oool0
3P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000O03o
ool005l0oooo00D000000?ooo`3oool0oooo000000070?ooo`<000009`3oool01@0Q8B4000000?oo
o`3oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`1j0?ooo`00H03o
ool2000000P0oooo0P00002d0?ooo`00H@3oool3000000D0oooo00<000000?ooo`3oool0]03oool0
0680oooo0P0000020?ooo`<00000]`3oool006<0oooo1000002i0?ooo`00I03oool00`000000oooo
0?ooo`2i0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0929502, -0.0464777, \
0.00380821, 0.00380821}}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-2.478997229715674`*^-10\) - 
              1.7406542873743548`*^-11\ \[ImaginaryI]\)},
          {\(\(\(0.72372644321679`\)\(\[InvisibleSpace]\)\) - 
              4.573485614786793`*^-11\ \[ImaginaryI]\)},
          {\(3.4574454410574164`*^-12 + 
              9.795025901482291`*^-13\ \[ImaginaryI]\)},
          {\(\(-1.3370995283201736`*^-11\) - 
              4.151165522436884`*^-12\ \[ImaginaryI]\)},
          {\(\(-1.683712926026093`*^-11\) + 
              7.000233726017768`*^-14\ \[ImaginaryI]\)},
          {\(1.0195660820472297`*^-8 + 
              2.4070894583116955`*^-12\ \[ImaginaryI]\)},
          {\(1.3770484752484436`*^-12 + 
              1.0143182384432311`*^-12\ \[ImaginaryI]\)},
          {\(4.3151506673444473`*^-13 + 
              4.5352688618494066`*^-13\ \[ImaginaryI]\)},
          {\(\(-2.8340160079798337`*^-13\) + 
              2.1046870843366427`*^-13\ \[ImaginaryI]\)},
          {\(\(-2.078679025782626`*^-14\) - 
              1.390898247272121`*^-13\ \[ImaginaryI]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Complex[ -2.4789972297156739*^-10, -1.7406542873743548*^-11], 
        Complex[ 0.72372644321679003, -4.5734856147867929*^-11], 
        Complex[ 3.4574454410574164*^-12, 9.7950259014822913*^-13], 
        Complex[ -1.3370995283201736*^-11, -4.1511655224368837*^-12], 
        Complex[ -1.6837129260260929*^-11, 7.000233726017768*^-14], 
        Complex[ 1.0195660820472297*^-08, 2.4070894583116955*^-12], 
        Complex[ 1.3770484752484436*^-12, 1.0143182384432311*^-12], 
        Complex[ 4.3151506673444473*^-13, 4.5352688618494066*^-13], 
        Complex[ -2.8340160079798337*^-13, 2.1046870843366427*^-13], 
        Complex[ -2.0786790257826259*^-14, -1.3908982472721209*^-13]}]]], \
"Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Harmonic analysis of the Ffeld integrals", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Sequence of Integrated Dipole [T mm], Quadrupole[T], Sextupole [T \
/ mm],.. The real (imaginary) part is the normal (skew) component. The \
functions   ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "harm",
  StyleBox[" and m",
    Evaluatable->False,
    AspectRatioFixed->True],
  "ultipole",
  StyleBox[" are dedined in the section \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "Defining The Model",
  StyleBox["\". As expected, the next dominant  multipole following the \
quadrupole is the dodecapole. Note that the harmonic content is normally \
independent of the radius over which it is computed. Numerically, this is \
confirmed . One must nevertheless increase nharm as one approached the radius \
of the quadrupole in order to sample the field in a larger number of points \
when they get closer to the pole. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nharm = 10; ra = 20; y = 0; z = 0;\), "\n", 
    \(\(w = harm[t, {y, z, ra}, nharm];\)\), "\n", 
    \(\(mm = Table[multipol[w, i], {i, 0, nharm - 1}];\)\), "\n", 
    \(N[mm, 4]\)}], "Input"],

Cell[BoxData[
    \({3.5163678191452165`*^-9 + 
        1.2667932480781018`*^-9\ \[ImaginaryI], \(\(0.7237266356666924`\)\(\
\[InvisibleSpace]\)\) - 
        5.894802082226369`*^-11\ \[ImaginaryI], \(-7.44260741925018`*^-12\) + 
        3.376809942778891`*^-14\ \[ImaginaryI], 
      2.4301932749859478`*^-8 - 
        6.321378975826519`*^-14\ \[ImaginaryI], \(-3.5294089872905946`*^-15\) \
- 4.739770798067866`*^-15\ \[ImaginaryI], 
      1.0195970700569656`*^-8 - 
        3.8010211644845523`*^-16\ \[ImaginaryI], \(-1.57214380402948`*^-17\) \
+ 2.7246314541562803`*^-17\ \[ImaginaryI], \(-2.090374489838176`*^-14\) - 
        2.0376259013410445`*^-18\ \[ImaginaryI], 
      8.50671581786866`*^-20 + 
        2.9951666147276515`*^-21\ \[ImaginaryI], \(-3.66167667000903`*^-15\) \
+ 5.533280084124569`*^-21\ \[ImaginaryI]}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetic field plots ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Here are a few plots of magnetic field and field integrals. ", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ob = t; z = 0; x1 = 0; x2 = 30; ymax = 60; Npt = 20;\), "\n", 
    \(\(bz1 = 
        radFldLst[ob, "\<Bz\>", {x1, 0, z}, {x1, ymax, z}, Npt, "\<arg\>", 
          0];\)\), "\n", 
    \(\(bz2 = 
        radFldLst[ob, "\<Bz\>", {x2, 0, z}, {x2, ymax, z}, Npt, "\<arg\>", 
          0];\)\n\), "\n", 
    \(\(MultipleListPlot[bz1, bz2, \n\tPlotJoined \[Rule] True, \n\t
        Frame -> True, \n\tRotateLabel\  -> \ False, \n\t
        GridLines\  -> \ Automatic, \n\tSymbolShape -> None, \n\t
        PlotStyle -> {GrayLevel[0], Dashing[{Dash}]}, \n\t
        PlotLabel -> "\<\>", \n\t
        FrameLabel -> \ {"\<Y [mm]\>", "\<Bz [T]\>"}\n];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.015873 0.0147151 1.78435 [
[.02381 -0.0125 -5 -14 ]
[.02381 -0.0125 5 0 ]
[.18254 -0.0125 -8 -14 ]
[.18254 -0.0125 8 0 ]
[.34127 -0.0125 -8 -14 ]
[.34127 -0.0125 8 0 ]
[.5 -0.0125 -8 -14 ]
[.5 -0.0125 8 0 ]
[.65873 -0.0125 -8 -14 ]
[.65873 -0.0125 8 0 ]
[.81746 -0.0125 -8 -14 ]
[.81746 -0.0125 8 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.0625 -28 ]
[.5 -0.0125 21.0625 -14 ]
[-0.0125 .01472 -10 -7 ]
[-0.0125 .01472 0 7 ]
[-0.0125 .10393 -25 -7 ]
[-0.0125 .10393 0 7 ]
[-0.0125 .19315 -19 -7 ]
[-0.0125 .19315 0 7 ]
[-0.0125 .28237 -25 -7 ]
[-0.0125 .28237 0 7 ]
[-0.0125 .37158 -19 -7 ]
[-0.0125 .37158 0 7 ]
[-0.0125 .4608 -25 -7 ]
[-0.0125 .4608 0 7 ]
[-0.0125 .55002 -19 -7 ]
[-0.0125 .55002 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -60.5 -7 ]
[-0.01875 .30902 -25 7 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .10393 m
1 .10393 L
s
0 .19315 m
1 .19315 L
s
0 .28237 m
1 .28237 L
s
0 .37158 m
1 .37158 L
s
0 .4608 m
1 .4608 L
s
0 .55002 m
1 .55002 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.0625 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.625 14.000 moveto
(@) show
78.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 14.000 moveto
(D) show
101.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10393 m
.00625 .10393 L
s
gsave
-0.0125 .10393 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .19315 m
.00625 .19315 L
s
gsave
-0.0125 .19315 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .28237 m
.00625 .28237 L
s
gsave
-0.0125 .28237 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .37158 m
.00625 .37158 L
s
gsave
-0.0125 .37158 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .4608 m
.00625 .4608 L
s
gsave
-0.0125 .4608 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .55002 m
.00625 .55002 L
s
gsave
-0.0125 .55002 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03256 m
.00375 .03256 L
s
0 .0504 m
.00375 .0504 L
s
0 .06825 m
.00375 .06825 L
s
0 .08609 m
.00375 .08609 L
s
0 .12178 m
.00375 .12178 L
s
0 .13962 m
.00375 .13962 L
s
0 .15746 m
.00375 .15746 L
s
0 .17531 m
.00375 .17531 L
s
0 .21099 m
.00375 .21099 L
s
0 .22884 m
.00375 .22884 L
s
0 .24668 m
.00375 .24668 L
s
0 .26452 m
.00375 .26452 L
s
0 .30021 m
.00375 .30021 L
s
0 .31805 m
.00375 .31805 L
s
0 .3359 m
.00375 .3359 L
s
0 .35374 m
.00375 .35374 L
s
0 .38943 m
.00375 .38943 L
s
0 .40727 m
.00375 .40727 L
s
0 .42512 m
.00375 .42512 L
s
0 .44296 m
.00375 .44296 L
s
0 .47865 m
.00375 .47865 L
s
0 .49649 m
.00375 .49649 L
s
0 .51433 m
.00375 .51433 L
s
0 .53218 m
.00375 .53218 L
s
0 .56786 m
.00375 .56786 L
s
0 .58571 m
.00375 .58571 L
s
0 .60355 m
.00375 .60355 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -121.5 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.312 14.000 moveto
(@) show
83.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.562 14.000 moveto
(D) show
94.500 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10393 m
1 .10393 L
s
.99375 .19315 m
1 .19315 L
s
.99375 .28237 m
1 .28237 L
s
.99375 .37158 m
1 .37158 L
s
.99375 .4608 m
1 .4608 L
s
.99375 .55002 m
1 .55002 L
s
.125 Mabswid
.99625 .03256 m
1 .03256 L
s
.99625 .0504 m
1 .0504 L
s
.99625 .06825 m
1 .06825 L
s
.99625 .08609 m
1 .08609 L
s
.99625 .12178 m
1 .12178 L
s
.99625 .13962 m
1 .13962 L
s
.99625 .15746 m
1 .15746 L
s
.99625 .17531 m
1 .17531 L
s
.99625 .21099 m
1 .21099 L
s
.99625 .22884 m
1 .22884 L
s
.99625 .24668 m
1 .24668 L
s
.99625 .26452 m
1 .26452 L
s
.99625 .30021 m
1 .30021 L
s
.99625 .31805 m
1 .31805 L
s
.99625 .3359 m
1 .3359 L
s
.99625 .35374 m
1 .35374 L
s
.99625 .38943 m
1 .38943 L
s
.99625 .40727 m
1 .40727 L
s
.99625 .42512 m
1 .42512 L
s
.99625 .44296 m
1 .44296 L
s
.99625 .47865 m
1 .47865 L
s
.99625 .49649 m
1 .49649 L
s
.99625 .51433 m
1 .51433 L
s
.99625 .53218 m
1 .53218 L
s
.99625 .56786 m
1 .56786 L
s
.99625 .58571 m
1 .58571 L
s
.99625 .60355 m
1 .60355 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01472 m
.07393 .0558 L
.12406 .09697 L
.17419 .13829 L
.22431 .17985 L
.27444 .22169 L
.32456 .26386 L
.37469 .30638 L
.42481 .34927 L
.47494 .3925 L
.52506 .43598 L
.57519 .47927 L
.62531 .52113 L
.67544 .55893 L
.72556 .58831 L
.77569 .60332 L
.82581 .59767 L
.87594 .56843 L
.92607 .52029 L
.97619 .46239 L
s
[ .04 .015 ] 0 setdash
.02381 .01472 m
.07393 .04608 L
.12406 .07753 L
.17419 .10915 L
.22431 .14108 L
.27444 .17346 L
.32456 .2065 L
.37469 .24045 L
.42481 .27564 L
.47494 .31238 L
.52506 .35096 L
.57519 .39139 L
.62531 .43301 L
.67544 .47377 L
.72556 .50964 L
.77569 .53422 L
.82581 .53982 L
.87594 .52139 L
.92607 .48184 L
.97619 .42982 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00YP3oool3000001D0oooo0`00001O0?ooo`00YP3o
ool00`000000k^k^0?ooo`0F0?ooo`030>k^kP000000oooo05h0oooo002M0?ooo`<000001P3oool0
10000000oooo0?ooo`3oool3000000040?ooo`00000000000?ooo`D0000000@0oooo000000000000
oooo0P0000040?ooo`030000003oool0oooo05d0oooo002M0?ooo`030>k^kP000000k^k^00H0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1M0?ooo`00WP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
G@3oool009d0oooo00<0k^k^0000003^k^h01P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo05d0oooo002M0?ooo`<0A4A41P3oool00`000000oooo0?ooo`020?ooo`07
0000003<c<`0c<c<0000002j^[X0c<c<000000020?ooo`070000003<c<`0c<c<0000002j^[X0c<c<
000000050?ooo`030000003oool0oooo05d0oooo002L0?ooo`0508N7Q`14A4@0oooo038b<P2YZJT0
1@3oool010000000oooo0?ooo`3oool20000000709RHV0000000QhN709RHV0000000V9RH0?ooo`02
0000000609RHV0000000QhN709RHV0000000V9RH1@3oool00`000000oooo0?ooo`1M0?ooo`00V`3o
ool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`0103oool00`000000k^k^0?ooo`0F0?ooo`03
0>k^kP000000oooo05h0oooo002K0?ooo`80000000<0<S8b0?ooo`0000000P0000040?ooo`<00000
5@3oool3000005l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo00120?ooo`0509RHV000000000000000002HV9P07@3o
ool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3oool05P3oool4000000030;Zj^P3o
ool0V9RH00<0000000<0V9RH0?ooo`3oool05P3oool0100@41000000010@401gMgL20?ooo`0509RH
V000000000000000002HV9P06`3oool010000000oooo0?ooo`2HV9P30000000309RHV03oool0oooo
01H0oooo00L0410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool05P3o
ool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`00
@P3oool01@000000V9RH0?ooo`2HV9P0000001h0oooo00P000000?ooo`3oool0000009RHV03oool0
V9RH000001P0oooo00/0c<c<0>k^kP3oool0c<c<05EEE@3oool0000009RHV03oool0V9RH0000000K
0?ooo`0807MgM`1VIVH0oooo0000002HV9P0oooo09RHV000000K0?ooo`080000003oool0oooo0000
002HV9P0oooo09RHV000000K0?ooo`0809RHV0000000oooo0000002HV9P0oooo09RHV000000H0?oo
o`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000103oool00480oooo
00D000000?ooo`3oool0oooo0000000N0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool05`3oool00`3<c<`0k^k^0?ooo`020?ooo`050000003oool0oooo0?ooo`000000703oool0
0`000000oooo000000030?ooo`030000003oool0oooo01H0oooo1`0000030?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00120?ooo`050000003o
ool0oooo0?ooo`0000007P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01P0
oooo00D0ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00D0gMgM08N7
Q`000000oooo000000030?ooo`030000003oool0oooo01H0oooo00@0A4A409RHV03oool000000P3o
ool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0F0?ooo`070000003<c<`0oooo09RHV0000000oooo000000030?ooo`030000003oool0oooo
0080oooo00120?ooo`050000003oool0oooo0?ooo`0000007P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo01P0oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003o
ool0oooo01L0oooo00H0EEEE010@40000000V9RH0?ooo`0000030?ooo`030000003oool0oooo01H0
oooo00@0k^k^010@403MgMd000000P3oool01@000000oooo0?ooo`3oool0000001/0oooo00@0V9RH
0000003oool000000`3oool00`000000oooo0?ooo`0F0?ooo`07010@401EEED000000000002HV9P0
oooo000000030?ooo`030000003oool0oooo0080oooo00120?ooo`050000003oool0oooo0?ooo`00
00007P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01H0oooo00@0MgMg0?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool0000001/0oooo00@0^[Zj09RHV03oool00000
0`3oool00`000000oooo0?ooo`0G0?ooo`030:VYZ@0b<S8000000080oooo00D000000?ooo`3oool0
oooo0000000H0?ooo`@0000000<0V9RH0?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`03
07MgM`14A4@0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`00@P3oool01@000000
V9RH0?ooo`2HV9P0000001h0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000001P0oooo
00@0000009RHV02HV9P000000P3oool01@000000V9RH0?ooo`2HV9P0000001P0oooo00/0A4A40;Zj
^P3oool0^[Zj0000003oool0000009RHV03oool0V9RH0000000J0?ooo`0906IVIP000000oooo0?oo
o`000000V9RH0?ooo`2HV9P0000001P0oooo00<0MgMg05EEE@3oool00`3oool01@000000V9RH0?oo
o`2HV9P0000001T0oooo00<0EEEE07MgM`3oool00P3oool01@000000V9RH0?ooo`2HV9P0000000@0
oooo00120?ooo`0509RHV000000000000000002HV9P07@3oool01@0Q8B4000000?ooo`3oool0V9RH
00<0000000<0V9RH0?ooo`3oool05P3oool0102HV9P000000000002HV9P20?ooo`0509RHV0000000
00000000002HV9P0603oool01`3^k^h0A4A4000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0
oooo0?ooo`0H0?ooo`050>k^kP0@4100oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0G0?oo
o`06010@400000000000038b<P3oool0V9RH0`0000000`2HV9P0oooo0?ooo`0H0?ooo`0509RHV014
A4@0QhN70?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@03ooooM000000<0oooo000e0?ooo`0509RHV000
000000000000002HV9P01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool003D0oooo00D0000009RHV03oool0V9RH000000060?ooo`030000
003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000
O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000
003oool0oooo0040oooo000e0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000<0oooo
0P00000Q0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool08`3oool3000000<0oooo
000e0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`800000
7`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool0
0@3oool003D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo
0`00000M0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo
0?ooo`010?ooo`00=@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1P3oool010000000oooo00000000000K0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3o
ool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`010?ooo`00=@3oool01@000000V9RH0?ooo`2HV9P0000000H0
oooo0P0000080?ooo`80000000<0oooo0000003oool06@3oool00`0007l0oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo02@0oooo0P0000030?ooo`00=@3oool01@2HV9P00000000000000000V9RH00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00@03oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000001L0oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`00000000005P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0
oooo00<000000?ooo`3oool00@3oool00400oooo0P00000=0?ooo`030000003oool0oooo00800000
503oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02@0oooo0P0000030?ooo`00@03o
ool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3o
ool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00@03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo008000004@3oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool000000100oooo00<0001o0?ooo`3oool0803oool0
0`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool0
0`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?ooo`8000004P3oool00`00
0000oooo0?ooo`0A0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`00
07l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0903oool20000
00<0oooo00100?ooo`030000003oool0oooo0180oooo0P0000030?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040
oooo00100?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`03
0000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00
@03oool2000001H0oooo00<000000?ooo`3oool00P3oool2000000T0oooo00<0001o0?ooo`3oool0
803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
803oool00`0007l0oooo0?ooo`0T0?ooo`8000000`3oool00400oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`8000001`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo02D0oooo00<000000?ooo`3oool00@3oool002H0oooo00D0V9RH000000000000000009RH
V0020?ooo`03038b<P3oool0V9RH00<0000000<0V9RH0?ooo`0@41000`0000000`2HV9P0oooo0?oo
o`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?oo
o`010?ooo`009P3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D0000009RHV03oool0V9RH
000000040?ooo`0309RHV0000000oooo00D0oooo00<000000?ooo`3oool0603oool2000000/0oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo
000V0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0103oool2000001/0001o00<000000000O`0007l0100007l00`000000
001o0000O`2c0000O`<000000`3oool002H0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0007lR0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0
oooo02D0oooo00<000000?ooo`3oool00@3oool002H0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`2HV9P000000?ooo`050?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0103oool2000000030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`009P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00H000000?ooo`3oool0oooo0000003oool40000000309RHV03oool0oooo00@0
oooo00<000000?ooo`3oool07@3oool2000000H0oooo0P00000Q0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0
oooo00<000000?ooo`3oool00@3oool002H0oooo00D0000009RHV03oool0V9RH000000040?ooo`08
0000002HV9P0oooo09RHV0000000oooo07MgM`1EEED90?ooo`800000803oool00`000000oooo0?oo
o`030?ooo`030000O`3oool000000200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0903oool2000000<0oooo000V
0?ooo`0509RHV000000000000000002HV9P0103oool01@2HV9P00000000000000000V9RH0080oooo
00@0410@000000000000<S8b1P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080
oooo00@0001o0?ooo`3oool000007`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo
0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo
0040oooo00100?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo0000O`0R0?oo
o`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0007l50?ooo`8000006`3oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?oo
o`030000003oool0oooo0040oooo00100?ooo`800000903oool2000000030000O`3oool0oooo00D0
oooo00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0T0?ooo`8000000`3oool00400oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`800000603oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0
001o0000003oool0203oool3000001D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?oo
o`010?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0000000/0oooo00<00000
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?oo
o`8000009P3oool00`0007l0oooo0?ooo`02000001h0oooo00<0001o0?ooo`3oool0803oool00`00
07l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0903oool20000
00<0oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`8000004@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040
oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo
0?ooo`010?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<0
00000?ooo`3oool00@3oool00400oooo0P00000V0?ooo`030000O`3oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool2000000d0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0903oool2000000<0oooo00100?oo
o`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool01P3oool2000000/0oooo0P00000;0?oo
o`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool002`0oooo00D0V9RH00000000
0000000009RHV0020?ooo`04038b<P3oool0oooo0?ooo`<000001P3oool00`000000oooo0?ooo`0U
0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool002`0oooo00D0000009RH
V03oool0V9RH000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0803oool0
0`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool0
0`000000oooo0?ooo`010?ooo`00;03oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool01@3oool2000003<0001o00<000000000O`0007l02P0007l2000009H0001o0`000003
0?ooo`00;03oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo00/0oooo0P00000<0?ooo`8000001@3oool0
0`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool0
0`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo000/0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<0001o
0?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<0001o
0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00;03oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00h0oooo00<000000?ooo`3oool02`3oool200000080oooo00<0001o0?ooo`3oool0803oool0
0`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool0
0`000000oooo0?ooo`010?ooo`00;03oool01@000000V9RH0?ooo`2HV9P0000000L0oooo00<00000
0?ooo`3oool01@3oool2000002H0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0001o0280oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo02@0oooo0P0000030?ooo`00;03oool01@2HV9P00000000000000000
V9RH00H0oooo00<08B4Q0000003oool01P3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0
oooo0100oooo00<000000?ooo`3oool0303oool00`000000001o0?ooo`0Q0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0
oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool04@3oool20000
00d0oooo00@0001o0?ooo`00000000007`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00@03oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool02P3oool01@00
07l0oooo0?ooo`3oool0000001h0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo0P00000V0?oo
o`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`020?oo
o`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo02@0oooo0P0000030?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01D0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`030?ooo`03
0000003oool0oooo01X0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0F0?ooo`800000203oool00`0007l0oooo0?ooo`040?ooo`800000
6P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`010?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`060?ooo`030000003o
ool0oooo01L0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo0P00000V0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0T0?ooo`8000000`3oool0
0400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo
00<0oooo00<0001o0?ooo`3oool0203oool2000001H0oooo00<0001o0?ooo`3oool0803oool00`00
07l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400
oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo0080
oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040
oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0703oool200000080oooo
00<0001o0?ooo`3oool02`3oool2000001<0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo0P00
000V0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`0007l03`3oool00`000000oooo0?oo
o`0@0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0T0?ooo`8000000`3oool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0O
0?ooo`030000000007l0oooo00l0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`01
0?ooo`009P3oool01@2HV9P00000000000000000V9RH0080oooo00@0<S8b0?ooo`3oool0oooo0`00
00000`3oool0410@000000020000000309RHV03oool0oooo00@0oooo00<000000?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo0P00000?0?ooo`030000O`3o
ool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003o
ool0oooo0040oooo000V0?ooo`050000002HV9P0oooo09RHV00000001`3oool00`000000oooo0?oo
o`030?ooo`0309RHV0000000oooo00D0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`000000oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool002H0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool2000004/0001o00<000000000O`0007l0400007l2000007P0001o0`0000030?ooo`004P3oool3
000000T0oooo0`0000050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0P0?ooo`040000O`3oool0oooo000001<0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo
0?ooo`010?ooo`004P3oool00`000000k^k^0?ooo`0:0?ooo`030>k^kP000000oooo00@0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00<0oooo00<0V9RH0000003oool0
1@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00D0001o0?ooo`3oool0
oooo0000000C0?ooo`8000002@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`000P3oool60000000309RH
V03oool0000000@000000`3oool00`000000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0400000003
09RHV03oool0oooo00@0oooo0P00000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3o
ool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02@0oooo0P0000030?ooo`00
0`3oool02@000000k^k^0?ooo`3oool0V9RH0000003oool0c<c<024Q8@020?ooo`05038b<P3oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00D0
000009RHV03oool0V9RH000000070?ooo`050000003oool0oooo07MgM`1EEED02@3oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool00`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`2HV9P0EEEE00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00D0V9RH00000000
0000000009RHV0060?ooo`03024Q8@000000oooo0080oooo00@0410@000000000000<S8b1P3oool0
0`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0103oool2
000001<0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`000`3oool01P00
0000oooo0?ooo`3MgMd0MgMg038b<P<0oooo00<0EEEE09RHV03oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?oo
o`0G0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0U0?ooo`030000003oool0oooo0040oooo00030?ooo`D0000000L0gMgM0?ooo`1VIVH0oooo0>k^
kP0Q8B40c<c<00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01d0oooo0P00000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0B0?ooo`8000000P3oool00`0007l0oooo0?ooo`0P0?ooo`030000
O`3oool0oooo0200oooo00<0001o0?ooo`3oool0903oool2000000<0oooo00030?ooo`070000003o
ool0oooo0?ooo`2YZJT08B4Q0?ooo`05000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0U
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0001o0280oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U
0?ooo`030000003oool0oooo0040oooo00030?ooo`060000003oool0oooo0?ooo`2HV9P000002@3o
ool01@000000k^k^0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`3^k^h0
00000?ooo`0N0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`090?ooo`800000503oool00`000000001o0?ooo`0Q0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`000P3oool60000000309RH
V03oool0oooo00L0oooo0`0000000`3oool0000000000005000000040?ooo`0000000000000001l0
oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo00/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00@03oool2000002H0oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo
00<0001o0000003oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02@0oooo
0P0000030?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool000000200oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo0010
0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00@0001o0?ooo`3oool000007`3oool00`0007l0oooo0?oo
o`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo00<00000
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo00l0oooo0P00000?
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U
0?ooo`030000003oool0oooo0040oooo00100?ooo`8000009P3oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`030?oo
o`8000006`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02@0oooo0P0000030?oo
o`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3o
ool04P3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3o
ool0603oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3o
ool00@3oool002`0oooo00D0V9RH000000000000000009RHV0020?ooo`03038b<P3oool0000000<0
000000<0^[Zj0?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00H0
oooo00<000000?ooo`3oool05`3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0
oooo00<000000?ooo`3oool00@3oool002`0oooo00D0000009RHV03oool0V9RH000000040?ooo`05
0<c<c03^k^h0oooo0<c<c01EEED01P3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo
0200oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool05P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo
02D0oooo00<000000?ooo`3oool00@3oool002`0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030<c<c03^k^h0oooo00L0oooo0P00001Q0000O`030000000007l0001o01<0001o00<000000000
O`0007l0GP0007l3000000<0oooo000/0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`2Y
ZJT0k^k^0?ooo`060?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`00
07l0oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`010?ooo`00;03oool01@000000oooo0?ooo`3oool0000000H0oooo00<0gMgM06IV
IP3oool01P3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?oo
o`3oool05`3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo0200oooo00<0001o0?oo
o`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo000/0?ooo`05
0000003oool0oooo0?ooo`000000103oool0101gMgL0oooo0?ooo`0000070?ooo`030000003oool0
oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`00;03oool01@00
0000V9RH0?ooo`2HV9P0000000@0oooo00@0000009RHV02HV9P000001`3oool2000002H0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<0
001o0?ooo`3oool03@3oool200000140oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0T0?ooo`8000000`3oool002`0oooo00D0V9RH000000000000000009RHV0040?ooo`0409RHV000
0000000009RHV0L0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000
O`3oool0oooo01X0oooo0P0000040?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool0
0@3oool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo01`0oooo00D000000?ooo`3oool0oooo0000O`0B0?ooo`030000003oool0oooo00d0oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo
00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0M0?ooo`040000003oool0oooo0000Oa<0oooo00<000000?ooo`3oool0303oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00400oooo0P00
000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0000
O`0D0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?oo
o`0T0?ooo`8000000`3oool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo01l0oooo0P00000E0?ooo`030000003oool0oooo00X0oooo00<0001o
0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?oo
o`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`000000oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?oo
o`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3o
ool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0000001D0oooo00<000000?ooo`3o
ool0203oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3o
ool00@3oool00400oooo0P00000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
803oool0100007l0oooo0?ooo`00000E0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0803oool00`0007l0oooo0?ooo`0T0?ooo`8000000`3oool00400oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00D0001o0?ooo`3oool0
oooo0000000E0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0O0?ooo`800000103oool00`000000oooo0?ooo`010?ooo`00@03oool00`000000oooo
0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`020?ooo`800000503oool2000000H0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0U0?ooo`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo00@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0010
0?ooo`8000009P3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0001o
0?ooo`3oool0803oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`00@03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?oo
o`3oool0803oool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D000000?oo
o`3oool0oooo0000O`0R0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`010?ooo`009P3oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b
0?ooo`0000000`0000000`2j^[X0oooo010@40030000000309RHV03oool0oooo00@0oooo00<00000
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000V0?oo
o`050000002HV9P0oooo09RHV0000000103oool01@3<c<`0k^k^0?ooo`3<c<`0EEEE00@0oooo00<0
V9RH0000003oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000000O`3oool08@3oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00@3oool002H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030<c<c03^
k^h0oooo00H0oooo00<000000?ooo`3oool0103oool2000007P0001o00<000000000O`0007l05000
07l00`000000001o0000O`0l0000O`030000000007l0001o00@0001o00<000000000O`0007l00`00
00030?ooo`009P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0ZJVY0>k^kP3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803o
ool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool04`3o
ool00`0007l000000?ooo`0P0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000V0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`3MgMd0IVIV0?ooo`040?ooo`0309RHV0000000oooo00D0oooo00<0
00000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool000000200oooo00<0
001o0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool002H0oooo00D000000?ooo`3oool0oooo000000040?ooo`0407MgM`3o
ool0oooo00000080oooo100000000`2HV9P0oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo00`0oooo
00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`03000001d0oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000V0?ooo`050000002H
V9P0oooo09RHV0000000103oool010000000V9RH09RHV00000020?ooo`0307MgM`1EEED0oooo00P0
oooo0P00000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0=0?ooo`8000004@3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo01X0
oooo00<0001o0?ooo`3oool0503oool2000000L0oooo00<000000?ooo`3oool0103oool2000000<0
oooo000V0?ooo`0509RHV000000000000000002HV9P0103oool0102HV9P000000000002HV9P30?oo
o`04010@400000000000038b<PH0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool00400oooo00<000000?oo
o`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?oo
o`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo00D0oooo0P00000I0?oo
o`030000O`3oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3o
ool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool0303oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00@3oool00400oooo0P00000V0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0
803oool00`0007l0oooo0?ooo`0B0?ooo`800000303oool00`0007l0oooo0?ooo`080?ooo`800000
5P3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool2000000<0oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803o
ool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool02@3o
ool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3o
ool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0200oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`00@03oool20000
02H0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo
01H0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo
0140oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool00400
oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo00l0
oooo0P00000?0?ooo`030000O`3oool0oooo00X0oooo0P0000090?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00@3oool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0603oool2000000H0oooo
00<0001o0?ooo`3oool04@3oool2000000d0oooo00<0001o0?ooo`3oool0203oool2000000T0oooo
0P00000@0?ooo`030000003oool0oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo01X0oooo00<0
00000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<0
001o0?ooo`3oool01@3oool3000000X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`010?ooo`00@03oool2000002H0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P
0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0D
0?ooo`8000002P3oool00`0007l0oooo0?ooo`030?ooo`800000303oool00`000000oooo0?ooo`0@
0?ooo`8000000`3oool00400oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?oo
o`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0703oool200000080oooo00<0001o0?oo
o`3oool05P3oool2000000<0oooo100000000`3oool0001o0?ooo`02000000l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`010?ooo`00;03oool01@2HV9P00000000000000000V9RH
0080oooo00H0<S8b0?ooo`0@41000000010@401gMgL70?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo01h0oooo00<0
00000?ooo`0007l08@3oool300000100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`010?ooo`00;03oool01@000000V9RH0?ooo`2HV9P0000000L0oooo00<0MgMg06IVIP3oool01@3o
ool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803o
ool00`0007l0oooo0?ooo`0O0?ooo`8000008P3oool00`0007l0oooo0?ooo`0>0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool00@3oool002`0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00@0oooo0P00002@0000O`030000000007l0001o02l0001o00<0
00000000O`0007l04`0007l3000000<0oooo000/0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`3MgMd0QhN7000000060?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803o
ool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`000000803o
ool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00@3o
ool002`0oooo00D000000?ooo`3oool0oooo000000050?ooo`0405EEE@0@4100000009RHV0H0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`02000001h0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0040oooo000/0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`2j^[X0V9RH0?ooo`050?ooo`030000003oool0oooo02D0oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo
00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000O`3oool0oooo00X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`010?ooo`00;03oool01@000000V9RH0?oo
o`2HV9P0000000@0oooo00D0A4A40;Zj^P3oool0^[Zj000000060?ooo`8000009P3oool00`0007l0
oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`030?ooo`8000006`3oool00`0007l0oooo0?ooo`080?ooo`8000006P3oool2000000<0
oooo000/0?ooo`0509RHV000000000000000002HV9P0103oool01@3^k^h0A4A4000000000000V9RH
00H0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo
0200oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`050?ooo`8000006@3oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00@3oool00400
oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200
oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01H0
oooo00<0001o0?ooo`3oool01@3oool2000001h0oooo00<000000?ooo`3oool00@3oool00400oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo
00<0001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`080?ooo`8000005P3oool00`0007l0oooo
0?ooo`030?ooo`800000803oool00`000000oooo0?ooo`010?ooo`00@03oool2000002H0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool07`3oool2000000<0oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o
0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o
0?ooo`3oool02`3oool300000180oooo00<0001o0?ooo`3oool00P00000S0?ooo`030000003oool0
oooo0040oooo00100?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0803oool00`00
07l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool03P3oool40000
00h0oooo00<0001o0?ooo`0000009@3oool00`000000oooo0?ooo`010?ooo`00@03oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool0803oool00`0007l0
oooo0?ooo`0P0?ooo`030000O`3oool0oooo0180oooo0`0000070?ooo`H000009P3oool00`000000
oooo0?ooo`010?ooo`00@03oool2000002H0oooo00<0001o0?ooo`3oool0803oool00`0007l0oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0001o0?ooo`3oool05@3oool7000000@0oooo
00<0001o0?ooo`3oool0903oool2000000<0oooo00100?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0P0?ooo`030000O`3oool0oooo0200oooo00<0
001o0?ooo`3oool0803oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo0010
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00@03ooooM000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-20.0374, -0.100062, \
0.286874, 0.00255194}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ob = t; z = 0; ymax = 10;\), "\n", 
    \(\(RadPlotOptions[\ ];\)\), "\n", 
    \(\(Iz0 = 
        radFldInt[
          ob, "\<inf\>", "\<ibz\>", {\(-1\), 1, z}, {1, 1, z}];\)\n\), "\n", 
    \(\(Plot[\((radFldInt[
                  ob, "\<inf\>", "\<ibz\>", {\(-1\), y, z}, {1, y, z}]/\((y*
                    Iz0)\) - 1)\)*100, {y, 0.01, ymax}, 
        FrameLabel -> {"\<Y [mm]\>", "\<dIz [%]\>", "\<Z = \>" <> 
              ToString[z] <> "\< mm\>", "\<\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0228561 0.0953334 0.0148031 41.9277 [
[.02286 -0.0125 -5 -14 ]
[.02286 -0.0125 5 0 ]
[.21352 -0.0125 -5 -14 ]
[.21352 -0.0125 5 0 ]
[.40419 -0.0125 -5 -14 ]
[.40419 -0.0125 5 0 ]
[.59486 -0.0125 -5 -14 ]
[.59486 -0.0125 5 0 ]
[.78552 -0.0125 -5 -14 ]
[.78552 -0.0125 5 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.0625 -28 ]
[.5 -0.0125 21.0625 -14 ]
[-0.0125 .0148 -10 -7 ]
[-0.0125 .0148 0 7 ]
[-0.0125 .09866 -31 -7 ]
[-0.0125 .09866 0 7 ]
[-0.0125 .18251 -31 -7 ]
[-0.0125 .18251 0 7 ]
[-0.0125 .26637 -31 -7 ]
[-0.0125 .26637 0 7 ]
[-0.0125 .35022 -31 -7 ]
[-0.0125 .35022 0 7 ]
[-0.0125 .43408 -25 -7 ]
[-0.0125 .43408 0 7 ]
[-0.0125 .51794 -31 -7 ]
[-0.0125 .51794 0 7 ]
[-0.0125 .60179 -31 -7 ]
[-0.0125 .60179 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -71.0625 -7 ]
[-0.01875 .30902 -31 7 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -26.3125 0 ]
[.5 .63053 26.3125 14 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21352 0 m
.21352 .61803 L
s
.40419 0 m
.40419 .61803 L
s
.59486 0 m
.59486 .61803 L
s
.78552 0 m
.78552 .61803 L
s
0 .09866 m
1 .09866 L
s
0 .18251 m
1 .18251 L
s
0 .26637 m
1 .26637 L
s
0 .35022 m
1 .35022 L
s
0 .43408 m
1 .43408 L
s
0 .51794 m
1 .51794 L
s
0 g
.02286 0 m
.02286 .00625 L
s
gsave
.02286 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21352 0 m
.21352 .00625 L
s
gsave
.21352 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40419 0 m
.40419 .00625 L
s
gsave
.40419 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59486 0 m
.59486 .00625 L
s
gsave
.59486 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78552 0 m
.78552 .00625 L
s
gsave
.78552 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07052 0 m
.07052 .00375 L
s
.11819 0 m
.11819 .00375 L
s
.16586 0 m
.16586 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.30886 0 m
.30886 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.49952 0 m
.49952 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.69019 0 m
.69019 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.88086 0 m
.88086 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.0625 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.625 14.000 moveto
(@) show
78.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 14.000 moveto
(D) show
101.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0148 m
.00625 .0148 L
s
gsave
-0.0125 .0148 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09866 m
.00625 .09866 L
s
gsave
-0.0125 .09866 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.002) show
1.000 setlinewidth
grestore
0 .18251 m
.00625 .18251 L
s
gsave
-0.0125 .18251 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.004) show
1.000 setlinewidth
grestore
0 .26637 m
.00625 .26637 L
s
gsave
-0.0125 .26637 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.006) show
1.000 setlinewidth
grestore
0 .35022 m
.00625 .35022 L
s
gsave
-0.0125 .35022 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.008) show
1.000 setlinewidth
grestore
0 .43408 m
.00625 .43408 L
s
gsave
-0.0125 .43408 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
0 .51794 m
.00625 .51794 L
s
gsave
-0.0125 .51794 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.012) show
1.000 setlinewidth
grestore
0 .60179 m
.00625 .60179 L
s
gsave
-0.0125 .60179 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.014) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03577 m
.00375 .03577 L
s
0 .05673 m
.00375 .05673 L
s
0 .07769 m
.00375 .07769 L
s
0 .11962 m
.00375 .11962 L
s
0 .14059 m
.00375 .14059 L
s
0 .16155 m
.00375 .16155 L
s
0 .20348 m
.00375 .20348 L
s
0 .22444 m
.00375 .22444 L
s
0 .24541 m
.00375 .24541 L
s
0 .28733 m
.00375 .28733 L
s
0 .3083 m
.00375 .3083 L
s
0 .32926 m
.00375 .32926 L
s
0 .37119 m
.00375 .37119 L
s
0 .39215 m
.00375 .39215 L
s
0 .41312 m
.00375 .41312 L
s
0 .45504 m
.00375 .45504 L
s
0 .47601 m
.00375 .47601 L
s
0 .49697 m
.00375 .49697 L
s
0 .5389 m
.00375 .5389 L
s
0 .55986 m
.00375 .55986 L
s
0 .58083 m
.00375 .58083 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.062 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dIz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.250 14.000 moveto
(@) show
85.188 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(%) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.125 14.000 moveto
(D) show
99.062 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02286 .61178 m
.02286 .61803 L
s
.21352 .61178 m
.21352 .61803 L
s
.40419 .61178 m
.40419 .61803 L
s
.59486 .61178 m
.59486 .61803 L
s
.78552 .61178 m
.78552 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07052 .61428 m
.07052 .61803 L
s
.11819 .61428 m
.11819 .61803 L
s
.16586 .61428 m
.16586 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.30886 .61428 m
.30886 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.49952 .61428 m
.49952 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.69019 .61428 m
.69019 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.88086 .61428 m
.88086 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -87.3125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
84.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 14.000 moveto
(mm) show
111.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .0148 m
1 .0148 L
s
.99375 .09866 m
1 .09866 L
s
.99375 .18251 m
1 .18251 L
s
.99375 .26637 m
1 .26637 L
s
.99375 .35022 m
1 .35022 L
s
.99375 .43408 m
1 .43408 L
s
.99375 .51794 m
1 .51794 L
s
.99375 .60179 m
1 .60179 L
s
.125 Mabswid
.99625 .03577 m
1 .03577 L
s
.99625 .05673 m
1 .05673 L
s
.99625 .07769 m
1 .07769 L
s
.99625 .11962 m
1 .11962 L
s
.99625 .14059 m
1 .14059 L
s
.99625 .16155 m
1 .16155 L
s
.99625 .20348 m
1 .20348 L
s
.99625 .22444 m
1 .22444 L
s
.99625 .24541 m
1 .24541 L
s
.99625 .28733 m
1 .28733 L
s
.99625 .3083 m
1 .3083 L
s
.99625 .32926 m
1 .32926 L
s
.99625 .37119 m
1 .37119 L
s
.99625 .39215 m
1 .39215 L
s
.99625 .41312 m
1 .41312 L
s
.99625 .45504 m
1 .45504 L
s
.99625 .47601 m
1 .47601 L
s
.99625 .49697 m
1 .49697 L
s
.99625 .5389 m
1 .5389 L
s
.99625 .55986 m
1 .55986 L
s
.99625 .58083 m
1 .58083 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .0148 m
1 .0148 L
s
.02286 0 m
.02286 .61803 L
s
.002 w
.02381 .0148 m
.02499 .01476 L
.02605 .01472 L
.02729 .01478 L
.02846 .01472 L
.02954 .01472 L
.03053 .01475 L
.03163 .01474 L
.03279 .01473 L
.03395 .01473 L
.0352 .01475 L
.03638 .01475 L
.03746 .01474 L
.03873 .01474 L
.03939 .01475 L
.04011 .01475 L
.04141 .01475 L
.04262 .01473 L
.04327 .01475 L
.04396 .01473 L
.04519 .01474 L
.04588 .01475 L
.04663 .01474 L
.04733 .01474 L
.04797 .01475 L
.04921 .01475 L
.05038 .01474 L
.05164 .01475 L
.05236 .01474 L
.05302 .01474 L
.05414 .01475 L
.05519 .01475 L
.05634 .01474 L
.05759 .01474 L
.0588 .01474 L
.05994 .01475 L
.06125 .01475 L
.06244 .01475 L
.06372 .01474 L
.06443 .01474 L
.06509 .01475 L
.06629 .01475 L
.06756 .01474 L
.06822 .01475 L
.06893 .01475 L
.07022 .01475 L
.07101 .01475 L
.07175 .01475 L
.07242 .01475 L
.07315 .01475 L
Mistroke
.07385 .01475 L
.07461 .01475 L
.07533 .01475 L
.07599 .01475 L
.07676 .01475 L
.07757 .01475 L
.07825 .01475 L
.079 .01475 L
.07971 .01475 L
.08036 .01475 L
.0811 .01475 L
.08181 .01475 L
.08306 .01475 L
.08372 .01476 L
.08443 .01476 L
.08567 .01475 L
.08684 .01476 L
.08752 .01476 L
.08823 .01476 L
.08951 .01476 L
.09015 .01476 L
.09084 .01476 L
.09209 .01476 L
.09285 .01476 L
.09356 .01476 L
.0942 .01476 L
.0949 .01476 L
.09617 .01476 L
.09735 .01477 L
.09858 .01477 L
.09924 .01477 L
.09994 .01477 L
.10119 .01477 L
.10237 .01477 L
.10458 .01478 L
.10572 .01478 L
.10694 .01478 L
.1081 .01478 L
.10916 .01478 L
.11033 .01479 L
.11162 .01479 L
.11227 .01479 L
.11297 .01479 L
.11422 .01479 L
.12446 .01482 L
.12942 .01484 L
.13411 .01485 L
.14288 .01489 L
.15258 .01495 L
.16287 .01502 L
Mistroke
.18131 .0152 L
.20086 .01546 L
.21917 .01581 L
.23943 .01632 L
.25796 .01693 L
.27696 .01773 L
.29769 .01882 L
.31902 .02025 L
.33835 .02183 L
.3775 .02606 L
.41759 .0321 L
.45616 .03995 L
.49718 .05094 L
.53669 .06458 L
.57468 .08103 L
.61513 .10269 L
.65405 .12818 L
.69543 .16095 L
.7353 .19878 L
.77365 .24166 L
.81445 .29506 L
.85374 .35486 L
.89151 .42089 L
.93173 .50127 L
.97044 .58929 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{411.125, 254.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006K0000oR000`400?l00000o`00003oo`3ooonL
0?ooo`00o`3ooonL0?ooo`00o`3ooonL0?ooo`00k03oool3000001@0oooo0`00002E0?ooo`00k03o
ool00`000000k^k^0?ooo`0E0?ooo`030>k^kP000000oooo09@0oooo003R0?ooo`<000001`3oool0
10000000oooo0?ooo`3oool3000000040?ooo`00000000000?ooo`D0000000@0oooo000000000000
oooo0P0000030?ooo`030000003oool0oooo09<0oooo003R0?ooo`030>k^kP000000k^k^00L0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2C0?ooo`00h`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
T`3oool00>80oooo00<0k^k^0000003^k^h01`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo09<0oooo003R0?ooo`<0A4A41`3oool00`000000oooo0?ooo`020?ooo`07
0000003<c<`0c<c<0000002j^[X0c<c<000000020?ooo`070000003<c<`0c<c<0000002j^[X0c<c<
000000040?ooo`030000003oool0oooo09<0oooo003Q0?ooo`0508N7Q`14A4@0oooo038b<P2YZJT0
1P3oool010000000oooo0?ooo`3oool20000000709RHV0000000QhN709RHV0000000V9RH0?ooo`02
0000000609RHV0000000QhN709RHV0000000V9RH103oool00`000000oooo0?ooo`2C0?ooo`00h03o
ool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`01@3oool00`000000k^k^0?ooo`0E0?ooo`03
0>k^kP000000oooo09@0oooo003P0?ooo`80000000<0<S8b0?ooo`0000000P0000050?ooo`<00000
503oool3000009D0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oooi`0
oooo003o0?oooi`0oooo003o0?oooi`0oooo001C0?ooo`0509RHV000000000000000002HV9P0>P3o
ool4000000030;Zj^P3oool0oooo03/0oooo00<000000?ooo`3oool0>03oool01@2HV9P000000000
00000000V9RH03X0oooo00D0V9RH000000000000000009RHV00h0?ooo`<0000000<0oooo09RHV000
00000P0000000`2HV9P0oooo0?ooo`050?ooo`00D`3oool01@000000V9RH0?ooo`2HV9P0000003X0
oooo00D0c<c<0>k^kP3oool0c<c<05EEE@0m0?ooo`030000003oool0oooo03P0oooo00D0000009RH
V03oool0V9RH0000000j0?ooo`050000002HV9P0oooo09RHV0000000>@3oool020000000oooo0?oo
o`000000V9RH0?ooo`2HV9P000001`3oool005<0oooo00D000000?ooo`3oool0oooo0000000k0?oo
o`030<c<c03^k^h0oooo03/0oooo1P00000h0?ooo`050000003oool0oooo0?ooo`000000>P3oool0
1@000000oooo0?ooo`3oool0000003T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`050?ooo`00D`3oool01@000000oooo0?ooo`3oool0000003`0oooo00<0ZJVY0>k^kP3oool0
>P3oool01014A4@0V9RH0?ooo`00000j0?ooo`050000003<c<`0oooo09RHV0000000>P3oool01@2H
V9P0MgMg0;Zj^P2YZJT0EEEE03T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`050?ooo`00D`3oool01@000000oooo0?ooo`3oool0000003`0oooo00<0gMgM06IVIP3oool0>P3o
ool0103^k^h0410@0=gMg@00000j0?ooo`05010@401EEED000000000002HV9P0>P3oool0103MgMd0
8B4Q04A4A00b<S8j0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool0
05<0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`0407MgM`3oool0oooo000003`0oooo00<0
ZJVY038b<P000000>P3oool00`1gMgL0A4A40?ooo`0l0?ooo`05024Q8@2YZJT0oooo0=gMg@0b<S80
>@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo001C0?ooo`050000
002HV9P0oooo09RHV0000000>P3oool010000000V9RH09RHV000000m0?ooo`0306IVIP000000oooo
03X0oooo00<0EEEE07MgM`3oool0>`3oool01@000000V9RH0?ooo`2HV9P0000003T0oooo00P00000
0?ooo`3oool0000009RHV03oool0V9RH000000L0oooo001C0?ooo`0509RHV000000000000000002H
V9P0>P3oool0102HV9P000000000002HV9Pm0?ooo`030>k^kP0@4100oooo03/0oooo00<0V9RH04A4
A027QhL0>P3oool01@2HV9P00000000000000000V9RH03P0oooo00D08B4Q0000003oool0oooo09RH
V0030000000309RHV03oool0oooo00D0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oooi`0
oooo003o0?oooi`0oooo003o0?oooi`0oooo001?0?ooool00000BP0000030?ooo`00C`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool004<0oooo00D0V9RH000000000000000009RHV0070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004<0oooo00D0000009RHV03oool0
V9RH000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0
oooo0?ooo`130?ooo`030000003oool0oooo0040oooo00130?ooo`050000003oool0oooo0?ooo`00
00001`3ooooo000004X000000`3oool004<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3ooolP000002D0oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool00@3oool004<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0G0?ooo`d00000603oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`010?ooo`00@`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo02@0oooo2P00000>0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`03
0000003oool0oooo0040oooo00130?ooo`050000002HV9P0oooo09RHV00000001`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0;P3oool9000000D0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0
oooo00<000000?ooo`3oool00@3oool004<0oooo00D0V9RH000000000000000009RHV0070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0g0?ooo`L0
0000?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`0000001000000g0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<0
00000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo00@0oooo1@00
000b0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@P3oool2000000<0oooo001?
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l
0?ooo`030000O`3oool0oooo00T0oooo1000000^0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0=0?oo
o`@00000:P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0oooo00<000000?oo
o`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool04@3oool5000002D0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo01H0oooo1000000Q0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0J0?ooo`<000007P3o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3o
ool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool07@3oool3000001/0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`8000001@3oool00`00
0000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0803oool30000
01P0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`120?ooo`8000000`3oool004l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool08`3oool2000001H0oooo00<0001o0?ooo`3oool0?03oool00`0007l0
oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02D0oooo
0`00000C0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0X0?ooo`8000004@3oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0:P3oool3000000h0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`13
0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02d0oooo0`00000;0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?oo
o`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0`0?ooo`8000002@3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo0P0000050?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0b0?ooo`<00000
1P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo0480oooo0P0000030?ooo`00C`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0e0?ooo`800000103oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0=`3oool2
00000080oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`030000003oool0
oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03T0oooo0P0000000`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0>`3oool2000003d0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00
;P3oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2HV9P0
oooo09RHV0030000000309RHV03oool0000000<0000000<0^[Zj0?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0000003`0oooo00<0001o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`010?ooo`00;P3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo0140000009RHV03o
ool0V9RH0000003oool0000009RHV03oool0V9RH0000003oool0c<c<0>k^kP3oool0c<c<05EEE@07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l
0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool00P00000j0?ooo`030000O`3oool0
oooo04<0oooo00<000000?ooo`3oool00@3oool002h0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0<c<c03^
k^h02@3oool3000000@0001o00<000000000O`0007l0_P0007l2000007`0001o0`0000030?ooo`00
;P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00H000000?ooo`3oool0oooo0:VYZ@3^k^h80?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0103oool2000003H0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`010?ooo`00;P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00H000000?ooo`3oool0oooo0=gMg@1VIVH80?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool00@3oool002h0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0MgMg0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo00L0
oooo0P00000c0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool002h0oooo
00D0000009RHV03oool0V9RH000000040?ooo`0=0000002HV9P0oooo09RHV0000000oooo0000002H
V9P0oooo09RHV0000000oooo0000000209RHV0030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`010?ooo`00;P3oool01@2HV9P00000000000000000V9RH00@0
oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00P000000
0`2HV9P0oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool02P3oool2
00000300oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`8000001@3oool00`000000
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0
oooo0?ooo`0=0?ooo`030000003oool0oooo02`0oooo00<0001o0?ooo`3oool0@P3oool2000000<0
oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool03P3oool2000002`0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0:@3oool00`0007l0oooo0?oo
o`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool04@3oool2000002T0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`01
0?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo01<0oooo00<000000?oo
o`3oool09P3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`0E0?ooo`8000009@3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo0040oooo001?0?ooo`8000001@3oool00`000000oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0G0?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool0@P3oool2000000<0oooo001?0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`030000O`3oool0
oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo01X0
oooo0P00000P0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?oo
o`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool00@3oool004l0oooo0P0000050?ooo`030000003oool0oooo03`0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo01l0oooo00<000000?oo
o`3oool06P3oool00`0007l0oooo0?ooo`120?ooo`8000000`3oool004l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo00<0001o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo0240oooo00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool08P3o
ool00`000000oooo0?ooo`0G0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3o
ool002h0oooo00D0V9RH000000000000000009RHV0020?ooo`03038b<P3oool0V9RH00<0000000<0
V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo00<0
001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00;P3oool01@000000V9RH0?ooo`2H
V9P0000000@0oooo00/0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH00000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l
0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0T
0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`01
0?ooo`00;P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`0000001@0000060?ooo`<00000100007l00`000000001o
0000O`3Q0000O`030000000007l0001o05P0001o0`0000030?ooo`00;P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00H000000?oo
o`14A4@0V9RH0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool09P3o
ool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3o
ool002h0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`060000003oool0k^k^010@403MgMd00000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`13
0?ooo`030000003oool0oooo0040oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01P000000oooo0?ooo`2YZJT0<S8b0000
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo
0140oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00;P3oool01@000000
V9RH0?ooo`2HV9P0000000@0oooo00/0000009RHV03oool0V9RH0000003oool0000009RHV03oool0
V9RH000000030?ooo`0306IVIP000000oooo00L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0
oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`010?ooo`00;P3oool01@2HV9P00000000000000000V9RH00@0oooo00L0V9RH00000000
0000000009RHV03oool0V9RH00<0000000H0V9RH0?ooo`3oool0oooo0>k^kP0@41080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0?0?ooo`030000
O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<000000?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo0480oooo0P0000030?ooo`00C`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool03@3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo04<0
oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo
0?ooo`0^0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo02l0oooo00<0
00000?ooo`3oool02P3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l
0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`09
0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool0>`3oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo00<0001o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<000000?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3o
ool0<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0480oooo0P0000030?ooo`00
C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03<0oooo00<000000?ooo`3oool0
1P3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0@`3oool0
0`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
03H0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo
0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool00@3oool004l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0h0?ooo`050000003oool0oooo0?ooo`00
07l0A@3oool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<000000?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0
>03oool01@000000oooo0?ooo`3oool0001o04@0oooo0P0000030?ooo`00C`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0k0?ooo`030000O`3oool0oooo03T0oooo00@000000?ooo`3oool0001oA@3oool00`000000
oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo
00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03X0oooo
00<000000?ooo`0007l0A@3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo03/0oooo00<000000000O`3oool0A03oool00`000000oooo0?oo
o`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03/0oooo00<00000
0000O`3oool0A03oool00`000000oooo0?ooo`010?ooo`00;P3oool01@2HV9P00000000000000000
V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0
V9RH00<0000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0
oooo03`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`010?ooo`00;P3oool01@00
0000V9RH0?ooo`2HV9P0000000@0oooo0140000009RHV03oool0V9RH0000003oool0000009RHV03o
ool0V9RH0000003oool0000009RHV03oool0V9RH000000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0?03oool00`0007l000000?ooo`130?ooo`030000003oool0oooo0040oooo
000^0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo0`0000040000
O`030000000007l0001o0?X0001o00<000000000O`0007l0?`0007l3000000<0oooo000^0?ooo`05
0000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool01`000000oooo0000003<c<`0oooo09RHV00000001`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo03`0oooo00@0001o0?ooo`3oool00000@P3oool00`000000oooo0?ooo`010?oo
o`00;P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00@000000?ooo`0@4100EEEE0P0000000`2HV9P0oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool0100007l0oooo0?ooo`0000120?ooo`03
0000003oool0oooo0040oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo07MgM`14A4@:0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool01@0007l0oooo0?ooo`3oool000000440oooo
00<000000?ooo`3oool00@3oool002h0oooo00D0000009RHV03oool0V9RH000000040?ooo`0;0000
002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV00000000P3oool00`1EEED0MgMg0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00@3oool002h0oooo00D0V9RH
000000000000000009RHV0040?ooo`0709RHV000000000000000002HV9P0oooo09RHV00300000007
09RHV03oool0oooo0?ooo`2HV9P0A4A408N7Q`070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`010?oo
o`00C`3oool2000000D0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`040?ooo`03
0000003oool0oooo03/0oooo0P0000030?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00@3o
ool001H0oooo0`00000<0?ooo`<000009`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0040oooo000F0?ooo`030000003^k^h0oooo00d0oooo00<0k^k^0000003oool09P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0040oooo00040?ooo`0409RHV0000000000007Mg
M`D0000000<0oooo0000000000000`0000030?ooo`030000003oool0oooo00<0oooo00L0410@0;Zj
^P3oool0EEEE0000000b<S80k^k^00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0040oooo00040?ooo`050000002HV9P0oooo0<c<c00000000P3o
ool01@000000oooo0?ooo`3<c<`08B4Q0080oooo00D0<S8b0?ooo`3oool0oooo000000050?ooo`07
09RHV00b<S80oooo0000003^k^h0MgMg05EEE@040?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo00P0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`00103oool01@000000oooo0?ooo`3oool0
00000080oooo00H000000?ooo`3oool0oooo09RHV01EEED50?ooo`030000003oool0oooo00@0oooo
00H0410@0;Zj^P0b<S80IVIV0>k^kP0000040?ooo`030000003oool0oooo02D0oooo0P0000050?oo
o`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?oo
o`8000000`3oool000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<0EEEE09RHV03oool00`3oool00`000000oooo0?ooo`040?ooo`0609RHV00b<S80k^k^
05EEE@000000<S8b103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00@3oool000@0oooo00D0000009RHV03oool0^[Zj000000020?ooo`080000003o
ool0oooo06IVIP3oool0k^k^024Q8@3<c<`30?ooo`0:0000003oool0oooo0?ooo`1VIVH00000038b
<P3^k^h0410@0;Zj^PL0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0040oooo00040?ooo`0509RHV0000000000006IVIP0000000P3oool00`000000
oooo0?ooo`05000000<0oooo00X000000?ooo`3oool0oooo0000003^k^h0MgMg04A4A02HV9P0<S8b
1`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
0@3oool000P0oooo00@000000?ooo`3oool000002P3oool02`000000k^k^0?ooo`3oool0A4A406IV
IP3MgMd000000?ooo`0@4100^[Zj00D0oooo00<0k^k^0000003oool09P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0040oooo00070?ooo`80000000@0oooo00000000000000002@3o
ool3000000030?ooo`3^k^h0<S8b00@0000000<0<S8b0?ooo`3oool00P3oool3000002L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo00`0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool03@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0040oooo001?0?ooo`8000001@3oool00`000000oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool2000000<0oooo001?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0>0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0040oooo000^0?ooo`0509RHV000000000000000002HV9P00P3oool00`0b<S80oooo09RH
V0030000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0@0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00@3oool002h0oooo00D00000
09RHV03oool0V9RH000000040?ooo`0A0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo
09RHV0000000oooo0000002HV9P0oooo09RHV00000001`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0040oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo0`0000040000O`030000000007l0001o0?l0001o3@0007l00`000000001o0000O`0]
0000O`<000000`3oool002h0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`070000003oool0V9RH07MgM`2j^[X0ZJVY05EEE@070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0B0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00@3oool002h0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003o
ool0gMgM024Q8@14A4@0<S8b203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0040
oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool01`000000oooo024Q8@2YZJT0oooo0=gMg@0b<S801`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0040oooo000^0?ooo`050000002HV9P0oooo09RHV0000000
103oool04@000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000
V9RH0?ooo`2HV9P0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`010?oo
o`00;P3oool01@2HV9P00000000000000000V9RH00@0oooo00L0V9RH000000000000000009RHV03o
ool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0D0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<000000?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0F0?ooo`030000003oool0oooo02T0oooo0P0000030?ooo`00C`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool05P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0040oooo001?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0I0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo01T0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<000000?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo02D0oooo0P0000030?ooo`00C`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool06P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0040
oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0M0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00@3oool004l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo01d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`010?ooo`00C`3oool2000000D0oooo00<00000
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo0P000003
0?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool07`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0040oooo001?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0O0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0040oooo000d0?ooo`0509RHV000000000000000002HV9P00P3oool00`0b<S80oooo09RH
V0030000000409RHV03oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0040oooo000d0?ooo`050000002HV9P0oooo09RHV0000000103oool01@000000V9RH
0?ooo`2HV9P0000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0040oooo000d0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3oool3000000@0001o00<000000000
O`0007l0o`0007lN0000O`030000000007l0001o01`0001o0`0000030?ooo`00=03oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo0280oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`010?ooo`00=03oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`010?ooo`00=03oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`010?ooo`00=03o
ool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D0000009RHV03oool0V9RH000000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo02@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`010?ooo`00
=03oool01@2HV9P00000000000000000V9RH00@0oooo00D0V9RH000000000000000009RHV0030?oo
o`03024Q8@000000oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`010?oo
o`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0040oooo001?0?ooo`800000
1@3oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool0
6P3oool2000000<0oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03o
ool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00@3o
ool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo02H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo
0?ooo`0l0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0040oooo001?
0?ooo`8000001@3oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02T0oooo00<00000
0?ooo`3oool05P3oool2000000<0oooo001?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo02X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`00
C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
:P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0[0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0040oooo001?0?ooo`8000001@3oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02`0
oooo00<000000?ooo`3oool04`3oool2000000<0oooo001?0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0040oooo001?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0^0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00@3oool002h0oooo00D0V9RH00000000
0000000009RHV0020?ooo`03038b<P3oool0V9RH00<0000000@0V9RH0?ooo`3oool0oooo0`000000
0`3oool0000000000002000000030;Zj^P3oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`010?ooo`00;P3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D00000
09RHV03oool0V9RH000000040?ooo`080000003oool0oooo0<c<c03^k^h0oooo0<c<c01EEED70?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0_0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00@3oool002h0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01P000000oooo0?ooo`3o
ool0c<c<0>k^kPT0oooo0`0000040000O`030000000007l0001o0?l0001o:`0007l00`000000001o
0000O`0?0000O`<000000`3oool002h0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030:VYZ@3^k^h0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo0300
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`010?ooo`00;P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<0gMgM06IVIP3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0040oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool0MgMg0P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0a0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00@3oool002h0oooo00D0000009RHV03oool0V9RH0000
00040?ooo`050000002HV9P0oooo09RHV0000000103oool010000000oooo0?ooo`00000209RHV003
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo0340oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`010?ooo`00
;P3oool01@2HV9P00000000000000000V9RH00@0oooo00D0V9RH000000000000000009RHV0030?oo
o`05024Q8@000000oooo0?ooo`2HV9P00P0000000`2HV9P0oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0b0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00@3oool004l0oooo0P0000050?ooo`030000003oool0oooo
03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool004l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`010?ooo`00C`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l
0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`01
0?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool0=03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo001?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0e0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool004l0oooo0P0000050?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`800000
0`3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo03H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00C`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo001?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo
03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0g0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo03L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`010?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo
00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo
001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool004l0oooo0P000005
0?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`07
0?ooo`8000000`3oool004l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?oo
o`00C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo001?0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0j0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool004l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`010?ooo`00;P3oool01@2HV9P00000000000000000V9RH0080oooo00<0
<S8b0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
>P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0040oooo000^0?ooo`050000002H
V9P0oooo09RHV0000000103oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00@3oool002h0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`06000000H0oooo0`0000040?ooo`030000003oool0oooo
03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool002h0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
1`000000oooo0?ooo`14A4@0V9RH0?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0040oooo000^0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0k^k^010@403MgMd0000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool00@3oool002h0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool0ZJVY038b<P000000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0040oooo000^0?ooo`050000002HV9P0oooo09RHV000
0000103oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00<000000?ooo`3oool00P3oool00`1V
IVH000000?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool002h0
oooo00D0V9RH000000000000000009RHV0040?ooo`0509RHV000000000000000002HV9P00`3oool0
0`0Q8B4000000?ooo`030?ooo`030>k^kP0@4100oooo00L0ooooo`00001:000000<0oooo003o0?oo
oi`0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oooi`0oooo003o0?oo
oi`0oooo003o0?oooi`0oooo003o0?oooi`0oooo003K0?ooo`H000003`3oool01@2HV9P000000000
00000000V9RH00@0oooo0`000000103oool000000000003oool5000000040?ooo`00000000000?oo
o`800000T03oool00=/0oooo00H0ZJVY038b<P3oool0oooo0>k^kP0b<S850?ooo`L000000`3oool0
1@000000V9RH0?ooo`2HV9P0000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000940oooo003L0?ooo`0306IVIP1gMgL0oooo0140
oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00002A0?ooo`00g03oool00`3^k^h08B4Q0<c<
c00A0?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000T@3oool00=d0oooo00<0c<c<024Q
8@3^k^h01P3oool7000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`070000003<c<`0
c<c<0000002j^[X0c<c<000000020?ooo`070000003<c<`0c<c<0000002j^[X0c<c<0000002A0?oo
o`00gP3oool00`1gMgL0IVIV0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000103oool20000
000709RHV0000000QhN709RHV0000000V9RH0?ooo`020000000609RHV0000000QhN709RHV0000000
V9RHT@3oool00=/0oooo00H0<S8b0>k^kP3oool0oooo038b<P2YZJT?0?ooo`050000002HV9P0oooo
09RHV0000000YP3oool00=/0oooo1P00000?0?ooo`0509RHV000000000000000002HV9P0YP3oool0
0?l0ooooW03oool00?l0ooooW03oool00001\
\>"],
  ImageRangeCache->{{{0, 410.125}, {253.125, 0}} -> {-2.77704, -0.00268528, \
0.0319485, 7.26432*^-5}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(grad[
          y_] := \((eps = 
            0.1; \(\(-\((radFldInt[
                      t, "\<inf\>", "\<ibz\>", {\(-1\), y - eps, 0}, {1, 
                        y - eps, 0}] - 
                    radFldInt[
                      ob, "\<inf\>", "\<ibz\>", {\(-1\), y + eps, 0}, {1, 
                        y + eps, 0}])\)\)/2\)/
            eps)\);\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(pl = 
        ListPlot[Table[{y, grad[y]}, {y, 0, radius*1.5, radius/10}], 
          PlotJoined \[Rule] True, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integ. Gradient[T] \
vs position [mm]\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.137787 0.619954 [
[.02381 -0.0125 -5 -14 ]
[.02381 -0.0125 5 0 ]
[.21055 -0.0125 -8 -14 ]
[.21055 -0.0125 8 0 ]
[.39729 -0.0125 -8 -14 ]
[.39729 -0.0125 8 0 ]
[.58403 -0.0125 -8 -14 ]
[.58403 -0.0125 8 0 ]
[.77077 -0.0125 -8 -14 ]
[.77077 -0.0125 8 0 ]
[.95752 -0.0125 -8 -14 ]
[.95752 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0138 -27.25 -7 ]
[-0.0125 .0138 0 7 ]
[-0.0125 .13779 -10 -7 ]
[-0.0125 .13779 0 7 ]
[-0.0125 .26178 -19 -7 ]
[-0.0125 .26178 0 7 ]
[-0.0125 .38577 -19 -7 ]
[-0.0125 .38577 0 7 ]
[-0.0125 .50976 -19 -7 ]
[-0.0125 .50976 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -88.125 0 ]
[.5 .63053 88.125 14 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21055 0 m
.21055 .61803 L
s
.39729 0 m
.39729 .61803 L
s
.58403 0 m
.58403 .61803 L
s
.77077 0 m
.77077 .61803 L
s
0 .13779 m
1 .13779 L
s
0 .26178 m
1 .26178 L
s
0 .38577 m
1 .38577 L
s
0 .50976 m
1 .50976 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21055 0 m
.21055 .00625 L
s
gsave
.21055 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39729 0 m
.39729 .00625 L
s
gsave
.39729 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.58403 0 m
.58403 .00625 L
s
gsave
.58403 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.77077 0 m
.77077 .00625 L
s
gsave
.77077 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.95752 0 m
.95752 .00625 L
s
gsave
.95752 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0138 m
.00625 .0138 L
s
gsave
-0.0125 .0138 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .13779 m
.00625 .13779 L
s
gsave
-0.0125 .13779 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .26178 m
.00625 .26178 L
s
gsave
-0.0125 .26178 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .38577 m
.00625 .38577 L
s
gsave
-0.0125 .38577 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .50976 m
.00625 .50976 L
s
gsave
-0.0125 .50976 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04479 m
.00375 .04479 L
s
0 .07579 m
.00375 .07579 L
s
0 .10679 m
.00375 .10679 L
s
0 .16878 m
.00375 .16878 L
s
0 .19978 m
.00375 .19978 L
s
0 .23078 m
.00375 .23078 L
s
0 .29278 m
.00375 .29278 L
s
0 .32377 m
.00375 .32377 L
s
0 .35477 m
.00375 .35477 L
s
0 .41677 m
.00375 .41677 L
s
0 .44776 m
.00375 .44776 L
s
0 .47876 m
.00375 .47876 L
s
0 .54076 m
.00375 .54076 L
s
0 .57175 m
.00375 .57175 L
s
0 .60275 m
.00375 .60275 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0138 m
1 .0138 L
s
.99375 .13779 m
1 .13779 L
s
.99375 .26178 m
1 .26178 L
s
.99375 .38577 m
1 .38577 L
s
.99375 .50976 m
1 .50976 L
s
.125 Mabswid
.99625 .04479 m
1 .04479 L
s
.99625 .07579 m
1 .07579 L
s
.99625 .10679 m
1 .10679 L
s
.99625 .16878 m
1 .16878 L
s
.99625 .19978 m
1 .19978 L
s
.99625 .23078 m
1 .23078 L
s
.99625 .29278 m
1 .29278 L
s
.99625 .32377 m
1 .32377 L
s
.99625 .35477 m
1 .35477 L
s
.99625 .41677 m
1 .41677 L
s
.99625 .44776 m
1 .44776 L
s
.99625 .47876 m
1 .47876 L
s
.99625 .54076 m
1 .54076 L
s
.99625 .57175 m
1 .57175 L
s
.99625 .60275 m
1 .60275 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .13779 m
1 .13779 L
s
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -149.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integ) show
87.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Gradient) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.375 14.000 moveto
(@) show
139.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.625 14.000 moveto
(D) show
153.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
167.188 14.000 moveto
(position) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
208.750 14.000 moveto
(@) show
212.688 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
231.312 14.000 moveto
(D) show
235.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .58646 m
.0873 .58647 L
.15079 .58653 L
.21429 .5868 L
.27778 .58752 L
.34127 .58897 L
.40476 .59141 L
.46825 .59494 L
.53175 .59934 L
.59524 .60332 L
.65873 .60258 L
.72222 .58686 L
.78571 .53852 L
.84921 .43539 L
.9127 .25831 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;@3oool0
1@2HV9P00000000000000000V9RH02D0oooo0`0000000`3oool0V9RH000000020000000309RHV03o
ool0oooo01h0oooo100000000`2j^[X0oooo09RHV0030000000309RHV03oool0oooo01h0oooo00@0
410@0000000@4100MgMg0P3oool01@2HV9P00000000000000000V9RH02@0oooo00@000000?ooo`3o
ool0V9RH0`0000000`2HV9P0oooo0?ooo`0N0?ooo`07010@4000000000000000002HV9P0oooo09RH
V0030000000309RHV03oool0oooo0140oooo000]0?ooo`050000002HV9P0oooo09RHV00000009P3o
ool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000803oool02`3<c<`0k^k^0?ooo`3<c<`0
EEEE0?ooo`000000V9RH0?ooo`2HV9P0000002<0oooo00P0MgMg06IVIP3oool0000009RHV03oool0
V9RH000002@0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000002<0oooo00P0V9RH0000
003oool0000009RHV03oool0V9RH000001<0oooo000]0?ooo`050000003oool0oooo0?ooo`000000
9P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01l0oooo00<0c<c<0>k^kP3o
ool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0O0?ooo`L000000`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool04@3oool002d0oooo00D000000?ooo`3oool0oooo0000000V0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0803oool01@2YZJT0k^k^0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0803oool01@3MgMd0QhN70000003oool0000000<0oooo
00<000000?ooo`3oool07`3oool01014A4@0V9RH0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`000000903oool00`000000oooo000000030?ooo`030000003oool0oooo0140oooo000]0?ooo`05
0000003oool0oooo0?ooo`0000009P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0200oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003oool0oooo01l0oooo00H0
EEEE010@40000000V9RH0?ooo`0000030?ooo`030000003oool0oooo01l0oooo00@0k^k^010@403M
gMd000000P3oool01@000000oooo0?ooo`3oool0000002<0oooo00@0V9RH0000003oool000000`3o
ool00`000000oooo0?ooo`0A0?ooo`00;@3oool01@000000oooo0?ooo`3oool0000002H0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0N0?ooo`0407MgM`3oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000000S0?ooo`040;Zj^P2HV9P0oooo000000<0oooo00<00000
0?ooo`3oool0803oool00`2YZJT0<S8b000000020?ooo`050000003oool0oooo0?ooo`000000803o
ool40000000309RHV03oool0000000<0oooo00<000000?ooo`3oool04@3oool002d0oooo00D00000
09RHV03oool0V9RH0000000V0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000P0?oo
o`040000002HV9P0V9RH00000080oooo00D0000009RHV03oool0V9RH0000000P0?ooo`0;04A4A02j
^[X0oooo0;Zj^P000000oooo0000002HV9P0oooo09RHV00000008`3oool02@1VIVH000000?ooo`3o
ool0000009RHV03oool0V9RH0000000P0?ooo`0307MgM`1EEED0oooo00<0oooo00D0000009RHV03o
ool0V9RH0000000C0?ooo`00;@3oool01@2HV9P00000000000000000V9RH02D0oooo00D08B4Q0000
003oool0oooo09RHV0030000000309RHV03oool0oooo01h0oooo00@0V9RH000000000000V9RH0P3o
ool01@2HV9P00000000000000000V9RH0200oooo00L0k^k^04A4A0000000000009RHV03oool0V9RH
00<0000000<0V9RH0?ooo`3oool08@3oool01@3^k^h0410@0?ooo`3oool0V9RH00<0000000<0V9RH
0?ooo`3oool07`3oool01P0@410000000000000b<S80oooo09RHV0<0000000<0V9RH0?ooo`3oool0
4@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002X0ooooj@00000=0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool2000000d0oooo000F0?ooo`0509RHV000000000000000002HV9P00P3oool00`0b<S80oooo
00000003000000030;Zj^P3oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0;0?ooo`005P3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D0c<c<0>k^kP3oool0
c<c<05EEE@060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000F0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`3<c<`0k^k^0?ooo`070?ooo`<000000`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo02`0oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`003`3oool8000000<0
oooo00<000000?ooo`3oool0103oool00`2YZJT0k^k^0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0
oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool001H0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0=gMg@1VIVH0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`00
5P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@0MgMg0?ooo`3oool000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000F0?ooo`050000002HV9P0oooo09RH
V0000000103oool010000000V9RH09RHV00000070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool001H0oooo00D0V9RH000000000000000009RHV0040?ooo`0409RHV0000000
000009RHV0L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo02/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00:P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000103oool00`00
0000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<000000?ooo`3oool0103oool20000
00d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0
oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool002X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo
00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?oo
o`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?oo
o`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?oo
o`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000
103oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0
:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool0
1@3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0
oooo02P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0
oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0
001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0
001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo000Z
0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02L0oooo00<00000
0?ooo`3oool01`3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:@3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0
:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0
9P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0V0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool001l0oooo00D0V9RH000000000000000009RH
V0060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?oo
o`0V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool001l0oooo00D00000
09RHV03oool0V9RH000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool001l0oooo00D000000?ooo`3oool0oooo000000060?ooonT000003@3oool001l0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool001l0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool001l0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0T0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool001l0oooo00D0000009RHV03oool0V9RH0000
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool001l0oooo00D0V9RH
000000000000000009RHV0060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0
oooo02@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool08`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000103oool00`000000
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool02`3oool2000000d0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:@3oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0
:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0
8P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000103o
ool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3oool03@3o
ool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool0
02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo
0240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool08@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0Y0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool0803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`800000103oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0200oooo00<000000?oo
o`3oool03P3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000
O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000
O`3oool0oooo01l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`00:P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool07`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02`3oool001H0oooo00D0V9RH000000000000000009RHV002
0?ooo`03038b<P3oool0000000<0000000<0^[Zj0?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00/0oooo000F0?ooo`050000002HV9P0oooo09RHV0000000103oool0
1@3<c<`0k^k^0?ooo`3<c<`0EEEE00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0Y0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0;0?ooo`005P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0c<c<0>k^kP3oool01`3o
ool3000000<0001o00<000000000O`0007l0b`0007l00`000000001o0000O`0?0000O`<000003@3o
ool001H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030:VYZ@3^k^h0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01d0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`005P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<0gMgM06IVIP3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo000F0?ooo`050000003oool0oooo0?ooo`000000103oool0101gMgL0oooo0?oo
o`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0M0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool001H0oooo00D0
000009RHV03oool0V9RH000000040?ooo`040000002HV9P0V9RH000000L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0;0?ooo`005P3oool01@2HV9P00000000000000000V9RH00@0
oooo00@0V9RH000000000000V9RH1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool002X0oooo
0P0000040?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo
0?ooo`0C0?ooo`8000003@3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0Y0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?oo
o`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0J0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000
O`3oool0oooo02T0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3o
ool002X0oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool06@3oool0
0`000000oooo0?ooo`0E0?ooo`8000003@3oool002X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0
oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0
oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01L0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo01H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000
O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0F0?ooo`030000
003oool0oooo01P0oooo0P00000=0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool0
0`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool0
02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo
01D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0503oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo000F0?ooo`0509RHV000000000000000002H
V9P00P3oool00`0b<S80oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0;0?ooo`005P3oool01@000000V9RH0?ooo`2HV9P0000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0
oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0
oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0
oooo000F0?ooo`050000003oool0oooo0?ooo`000000103oool6000000D0oooo0`0000030000O`03
0000000007l0001o0<00001o00<000000000O`0007l06P0007l3000000d0oooo000F0?ooo`050000
003oool0oooo0?ooo`000000103oool01014A4@0V9RH0?ooo`0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool02`3oool001H0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040>k^kP0@4100gMgM000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;
0?ooo`005P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0ZJVY038b<P0000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool04P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo000F0?ooo`050000002HV9P0oooo
09RHV00000001P3oool00`1VIVH000000?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool02`3oool001H0oooo00D0V9RH000000000000000009RHV0060?ooo`030>k^kP0@4100
oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000103oool00`000000
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool07@3oool2000000d0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0100oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo00l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0
:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0
3P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`800000103o
ool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool08@3o
ool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool0
0`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool0
02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo
00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0303oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0Y0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`800000103oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00T0oooo00<000000?oo
o`3oool09@3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000
O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000
O`3oool0oooo00P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`00:P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03o
ool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0;0?ooo`005P3oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?oo
o`2HV9P00`0000000`2HV9P0oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?oo
o`3oool0:@3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool02`3oool001H0oooo00D0000009RHV03oool0V9RH000000040?ooo`050000002HV9P0oooo
09RHV00000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo000F0?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo0`00
00030000O`030000000007l0001o0;40001o00<000000000O`0007l0:@0007l3000000d0oooo000F
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000c<c<0?ooo`2HV9P0000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo
00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00<0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`005P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D0410@05EEE@000000000009RHV0060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0
oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02`3oool001H0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
07MgM`14A4@0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0;0?ooo`00
5P3oool01@000000V9RH0?ooo`2HV9P0000000D0oooo00<0EEEE07MgM`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool00P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00/0oooo000F0?ooo`0509RHV000000000000000002H
V9P01P3oool00`2HV9P0A4A408N7Q`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3o
ool0:@3oool01@0007l0oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool02`3oool002X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0
oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0Y0?ooo`040000O`3oool000000000
0340oooo00<000000?ooo`3oool02`3oool002X0oooo0P0000040?ooo`030000003oool0oooo02P0
oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02T0
oooo00<0001o0000003oool0<@3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo
00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo
000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?oo
o`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool09`3oool2000000030000O`3o
ool0oooo0380oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool0
0`0007l0oooo0?ooo`0V0?ooo`040000003oool0oooo0000Oc@0oooo00<000000?ooo`3oool02`3o
ool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0T0?ooo`8000000`3oool0
0`0007l0oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo
02P0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo
0380oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00:P3oool2000000@0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo
0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0803oool2000000L0oooo
00<0001o0?ooo`3oool0<@3oool2000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0
001o0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0380oooo00<0
00000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X
0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0N
0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;
0?ooo`00:P3oool00`000000oooo0?ooo`030?ooocD000008@3oool00`0007l0oooo0?ooo`0X0?oo
o`030000O`3oool0oooo01/0oooo0`00000;0?ooo`030000O`3oool0oooo0380oooo00<000000?oo
o`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`03
0000O`3oool0oooo00L0oooo;000000P0?ooo`030000O`3oool0oooo01P0oooo0`00000>0?ooo`03
0000O`3oool0oooo0380oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0
203oool>00000180oooo00<0001o0?ooo`3oool0503oool400000140oooo00<0001o0?ooo`3oool0
<P3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02P0oooo00<0001o0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0F0?ooo`l000000`3o
ool00`0007l0oooo0?ooo`0A0?ooo`<000005@3oool00`0007l0oooo0?ooo`0b0?ooo`030000003o
ool0oooo00/0oooo000Z0?ooo`800000103oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0
oooo02P0oooo00<0001o0?ooo`3oool09@3ooolG000001P0oooo00<0001o0?ooo`3oool0<@3oool2
000000d0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool00`00
07l0oooo0?ooo`0X0?ooo`030000O`3oool0oooo02P0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02`3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`00:P3ooooY000000d0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo001J0?ooo`0609RHV00@41000000010@401g
MgL0k^k^D03oool3000006d0oooo001J0?ooo`060000002j^[X0oooo0>k^kP27QhL0<S8b<03oool3
000000X0oooo0`00000A0?ooo`030000003oool0oooo02H0oooo0`00000D0?ooo`<00000;03oool0
05X0oooo00H0MgMg0>k^kP3oool0oooo0=gMg@00000`0?ooo`030000003^k^h0oooo00/0oooo00<0
k^k^0000003oool0403oool00`000000oooo0?ooo`0V0?ooo`030000003^k^h0oooo01D0oooo00<0
k^k^0000003oool0:`3oool004P0oooo0`0000001@3oool00000000000000000oooo0080000000T0
oooo0:VYZ@0b<S80V9RH0000000@4100c<c<0?ooo`1gMgL00`000000100@4100QhN70?ooo`0b<S85
0?ooo`0609RHV000000000000000001EEED0gMgM0P3oool3000000070?ooo`2HV9P0000009RHV00Q
8B40EEEE09RHV0020000000307MgM`000000000000<0000000D0V9RH0000000@4100c<c<0?ooo`03
000000080?ooo`00000000000?ooo`2YZJT0<S8b0?ooo`0000050?ooo`<000001P3oool030000000
oooo0?ooo`3oool0gMgM0000003MgMd0oooo0000001EEED0000009RHV0H0oooo00H0000004A4A000
0000V9RH0?ooo`2HV9P30000000709RHV03oool0000005EEE@000000V9RH0?ooo`03000000030?oo
o`2YZJT0<S8b00<0000000H0V9RH000000000000000009RHV03oool3000000030?ooo`0000000000
00@0oooo00@000000?ooo`3oool0oooo0`000000103oool000000000003oool5000000040?ooo`00
000000000?ooo`8000000`3oool00`000000oooo0?ooo`0Z0?ooo`00B@3oool01@000000oooo0?oo
o`3oool000000080oooo00`000000?ooo`3oool000000?ooo`000000V9RH0;Zj^P0@4100oooo038b
<P3MgMd:0?ooo`0309RHV0000000V9RH0080oooo00<0c<c<0000003oool00P3oool03@000000oooo
0?ooo`000000V9RH0=gMg@000000k^k^0000002HV9P0oooo0<c<c00000000P3oool01P000000oooo
0000002HV9P0^[Zj010@4080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00D0oooo00`000000?ooo`3oool0oooo08N7Q`000000QhN70?oo
o`0Q8B40k^k^09RHV00000060?ooo`0?0000003<c<`0V9RH0000003oool0000009RHV03oool0V9RH
0000003oool08B4Q0>k^kP2HV9P000000080oooo00@000000?ooo`3oool000000P3oool01`000000
oooo0000002HV9P0oooo09RHV00000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0:P3oool004T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`060000003oool0oooo0000003oool00000103oool01@3MgMd08B4Q0000
000@4100ZJVY00L0oooo00<0000009RHV03oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00H0000009RHV03oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool00000
1@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool01@3oool01`000000oooo0?ooo`3oool08B4Q07MgM`0Q8B400P3oool00`3<c<`0A4A404A4
A0060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`3<c<`204A4
A080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo02X0oooo00190?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`000000oooo00@0000000H0oooo024Q8@27QhL0oooo0=gMg@0000070?ooo`030000
003oool0oooo0080oooo0`0000020?ooo`040000003oool0oooo09RHV0<0000000<0oooo0000003o
ool00P3oool01@000000oooo0?ooo`000000oooo00@000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool02`000000oooo0?oo
o`3MgMd000000?ooo`0@4100gMgM08N7Q`0b<S80V9RH00L0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`050000003oool0QhN7038b<P2HV9P00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:P3oool004T0oooo
00P000000?ooo`3oool0oooo0000003<c<`0V9RH00000080oooo00<000000?ooo`0000000P2HV9P0
1`000000oooo0000003<c<`0oooo08N7Q`0000001`3oool00`000000oooo0?ooo`070?ooo`030000
003^k^h0oooo0080oooo00P0V9RH0000003oool0000009RHV03oool0^[Zj00000080oooo00<00000
0?ooo`0000000P2HV9P01`000000oooo0?ooo`000000c<c<09RHV00000000P3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00`000000?ooo`3oool0MgMg05EEE@3oool0
MgMg06IVIP000000V9RH0>k^kP0Q8B460?ooo`0?0000002j^[X0V9RH0000003oool0000009RHV03o
ool0V9RH0000003oool0000009RHV03^k^h08B4Q0080oooo00@000000?ooo`3oool000000P3oool0
1`000000oooo0000002HV9P0oooo09RHV00000000P3oool010000000c<c<09RHV00000050?ooo`03
0000003oool0oooo0080oooo00L000000<c<c03<c<`000000;Zj^P3<c<`000000080oooo00L00000
0<c<c03<c<`000000;Zj^P3<c<`0000000@0oooo00<000000?ooo`3oool0:P3oool004T0oooo00<0
00000?ooo`3oool00P000000102HV9P0000009RHV03oool30000000:09RHV0000000000009RHV03o
ool0c<c<010@40000000A4A40>k^kPL0oooo00<0000009RHV03oool00`3oool00`0b<S80oooo0?oo
o`020000000309RHV00Q8B40A4A40080000000<0V9RH0?ooo`2HV9P00P0000000`1VIVH000000?oo
o`02000000060?ooo`2HV9P000000000002HV9P0oooo0P000000102HV9P0000009RHV03oool30000
00030?ooo`000000oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080000000L0oooo000000000000V9RH0000001EEED0000000D0oooo
0P0000001@2HV9P0000009RHV03oool0V9RH00<0000000L0V9RH0?ooo`2HV9P0000005EEE@000000
oooo0080000000<0oooo0000000000000`0000000`3oool0V9RH000000020000000709RHV03oool0
00000000002HV9P0000009RHV0050?ooo`040000003oool0oooo0?ooo`80000000L0V9RH00000027
QhL0V9RH0000002HV9P0oooo0080000000H0V9RH00000027QhL0V9RH0000002HV9P40?ooo`030000
003oool0oooo02X0oooo00190?ooo`030000003oool0oooo00H0oooo00<0QhN70000003oool04@3o
ool01`2HV9P0000009RHV03oool0k^k^05EEE@0000003`3oool00`000000oooo0?ooo`0=0?ooo`06
08N7Q`000000oooo0?ooo`000000k^k^0P3oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0?ooo`3^k^h00000903oool00`27QhL000000?ooo`0C0?ooo`030000003^k^h0oooo01D0
oooo00<0k^k^0000003oool0:`3oool004P0oooo0`0000080?ooo`03038b<P3oool0oooo0140oooo
00H0V9RH000000000000410@06IVIP00000>0?ooo`8000000P3oool00`0b<S80oooo0?ooo`0;0?oo
o`03038b<P3oool0oooo00<0000000<0oooo0000000000001@0000020?ooo`<000008P3oool0100b
<S80oooo0?ooo`0b<S820?ooo`03038b<P3oool0oooo00l0oooo0`00000D0?ooo`<00000;03oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.1478, -0.339921, \
0.231202, 0.00696421}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetization in the Iron ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Here are a few methods for plotting the magnetization in the iron. \
The first one plots a vector in the center of each subdivided element. The \
vector is oriented according to the local magnetization and its color is \
related to its absolute value. The other methods  makes  a contour plot of \
the  absolute value of the magnetization over a slice of material. This \
second method is more complicated to use and probably less usefull than the \
first  one. \
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RadPlot3DOptions[];\)\n\), "\n", 
    \(\(ListPlotVectorField3D[radObjM[g]\n, VectorHeads -> True\n, 
        ColorFunction -> \ Hue\n, 
        PlotLabel -> "\<Magnetization in Element # \>" <> ToString[g]\n, 
        ViewPoint -> {3, 1\ , \ 0}\n, PlotRange -> {All, All, {30, 170}}\ \n, 
        ScaleFactor -> 8];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.5 1.0125 -79.1562 0 ]
[.5 1.0125 79.1562 14 ]
[.84887 .86472 -8 0 ]
[.84887 .86472 8 14 ]
[.84045 .87264 -8 0 ]
[.84045 .87264 8 14 ]
[.83164 .88092 -8 0 ]
[.83164 .88092 8 14 ]
[.83952 .93601 -7.8125 0 ]
[.83952 .93601 7.8125 14 ]
[.16908 .15154 -5 -14 ]
[.16908 .15154 5 0 ]
[.39299 .13937 -8 -14 ]
[.39299 .13937 8 0 ]
[.63375 .12628 -11 -14 ]
[.63375 .12628 11 0 ]
[.47952 .07216 -7.8125 -14 ]
[.47952 .07216 7.8125 0 ]
[.8607 .25636 0 -2.29735 ]
[.8607 .25636 16 11.7027 ]
[.86283 .5 0 -7 ]
[.86283 .5 22 7 ]
[.8607 .74364 0 -11.7027 ]
[.8607 .74364 22 2.29735 ]
[.92533 .5 0 -7 ]
[.92533 .5 14.3125 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -140.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnetization) show
135.125 14.000 moveto
(in) show
147.438 14.000 moveto
(Element) show
190.312 14.000 moveto
(#) show
199.312 14.000 moveto
(107) show
217.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
[ ] 0 setdash
.85033 .85085 m
.82807 .87178 L
s
.25 Mabswid
.84887 .85222 m
.84887 .84597 L
s
gsave
.84887 .86472 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.84045 .86014 m
.84045 .85389 L
s
gsave
.84045 .87264 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83164 .86842 m
.83164 .86217 L
s
gsave
.83164 .88092 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.84722 .85377 m
.84722 .85002 L
s
.84555 .85534 m
.84555 .85159 L
s
.84386 .85693 m
.84386 .85318 L
s
.84216 .85853 m
.84216 .85478 L
s
.83872 .86177 m
.83872 .85802 L
s
.83697 .86341 m
.83697 .85966 L
s
.83521 .86506 m
.83521 .86131 L
s
.83343 .86674 m
.83343 .86299 L
s
.82983 .87013 m
.82983 .86638 L
s
gsave
.83952 .93601 -68.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.16478 .16428 m
.82807 .12822 L
s
.25 Mabswid
.16908 .16404 m
.16908 .17029 L
s
gsave
.16908 .15154 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.39299 .15187 m
.39299 .15812 L
s
gsave
.39299 .13937 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.63375 .13878 m
.63375 .14503 L
s
gsave
.63375 .12628 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.2126 .16168 m
.2126 .16543 L
s
.25674 .15928 m
.25674 .16303 L
s
.30151 .15684 m
.30151 .16059 L
s
.34692 .15437 m
.34692 .15812 L
s
.43974 .14933 m
.43974 .15308 L
s
.48717 .14675 m
.48717 .1505 L
s
.53531 .14413 m
.53531 .14788 L
s
.58416 .14148 m
.58416 .14523 L
s
.68408 .13604 m
.68408 .13979 L
s
.73519 .13326 m
.73519 .13701 L
s
.78709 .13044 m
.78709 .13419 L
s
gsave
.47952 .07216 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.85033 .14915 m
.85033 .85085 L
s
.25 Mabswid
.85033 .24939 m
.84514 .24591 L
s
gsave
.8607 .25636 -61 -6.29735 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.85033 .5 m
.84408 .5 L
s
gsave
.86283 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.85033 .75061 m
.84514 .75409 L
s
gsave
.8607 .74364 -61 -15.7027 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.85033 .29951 m
.84702 .29774 L
s
.85033 .34964 m
.84685 .34823 L
s
.85033 .39976 m
.8467 .39878 L
s
.85033 .44988 m
.84661 .44938 L
s
.85033 .55012 m
.84661 .55062 L
s
.85033 .60024 m
.8467 .60122 L
s
.85033 .65036 m
.84685 .65177 L
s
.85033 .70049 m
.84702 .70226 L
s
.85033 .19927 m
.84741 .19692 L
s
.85033 .80073 m
.84741 .80308 L
s
gsave
.92533 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.2189 .18144 m
.2189 .81856 L
s
.2189 .81856 m
.85033 .85085 L
s
.85033 .85085 m
.85033 .14915 L
s
.85033 .14915 m
.2189 .18144 L
s
.16478 .16428 m
.82807 .12822 L
s
.82807 .12822 m
.82807 .87178 L
s
.82807 .87178 m
.16478 .83572 L
s
.16478 .83572 m
.16478 .16428 L
s
.2189 .18144 m
.2189 .81856 L
s
.2189 .81856 m
.16478 .83572 L
s
.16478 .83572 m
.16478 .16428 L
s
.16478 .16428 m
.2189 .18144 L
s
.85033 .14915 m
.82807 .12822 L
s
.82807 .12822 m
.82807 .87178 L
s
.82807 .87178 m
.85033 .85085 L
s
.85033 .85085 m
.85033 .14915 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .028 0 r
.5 Mabswid
[ ] 0 setdash
.22916 .64476 m
.22918 .64476 L
s
.2291 .64475 m
.22916 .64476 L
s
.22915 .64469 m
.22916 .64476 L
s
.22912 .64475 m
.2291 .64475 L
s
.22915 .64469 m
.2291 .64475 L
s
.22912 .64475 m
.22915 .64469 L
s
.22918 .64476 m
.22915 .64469 L
s
.22911 .64501 m
.22915 .64469 L
s
.22918 .64476 m
.22912 .64475 L
s
.452 0 1 r
.2496 .51179 m
.25453 .51183 L
s
.24706 .51185 m
.2496 .51179 L
s
.2496 .51179 m
.25081 .50638 L
s
.299 0 1 r
.24935 .45132 m
.25439 .45139 L
s
.24755 .4513 m
.24935 .45132 L
s
.24935 .45132 m
.25103 .44607 L
s
.683 0 1 r
.25211 .58317 m
.25744 .5819 L
s
.25744 .5819 m
.25929 .58092 L
s
.25744 .5819 m
.2542 .57652 L
s
0 .016 1 r
.24953 .39161 m
.25427 .39173 L
s
.24805 .39153 m
.24953 .39161 L
s
.24953 .39161 m
.25127 .38673 L
s
.299 0 1 r
.25439 .45139 m
.25261 .45136 L
s
.25103 .44607 m
.25439 .45139 L
s
.452 0 1 r
.25453 .51183 m
.25201 .51189 L
s
.25081 .50638 m
.25453 .51183 L
s
0 .508 1 r
.24991 .33274 m
.25408 .33291 L
s
.24864 .33264 m
.24991 .33274 L
s
.24991 .33274 m
.25152 .32848 L
s
0 .016 1 r
.25427 .39173 m
.2528 .39164 L
s
.25127 .38673 m
.25427 .39173 L
s
0 .508 1 r
.25408 .33291 m
.25282 .33281 L
s
.25152 .32848 m
.25408 .33291 L
s
0 1 .741 r
.25405 .27544 m
.25372 .27549 L
s
.25066 .27503 m
.25405 .27544 L
s
.25255 .27189 m
.25405 .27544 L
s
.25032 .27508 m
.25066 .27503 L
s
.25066 .27503 m
.25255 .27189 L
s
0 .508 1 r
.25075 .34997 m
.25152 .32848 L
s
0 1 .741 r
.25075 .28873 m
.25255 .27189 L
s
.452 0 1 r
.25075 .53368 m
.25081 .50638 L
s
.299 0 1 r
.25075 .47244 m
.25103 .44607 L
s
0 .016 1 r
.25075 .4112 m
.25127 .38673 L
s
.452 0 1 r
.25081 .50638 m
.25201 .51189 L
s
.24706 .51185 m
.25081 .50638 L
s
.683 0 1 r
.25396 .58219 m
.25211 .58317 L
s
.2542 .57652 m
.25211 .58317 L
s
.299 0 1 r
.25103 .44607 m
.25261 .45136 L
s
.24755 .4513 m
.25103 .44607 L
s
0 .016 1 r
.25127 .38673 m
.2528 .39164 L
s
.24805 .39153 m
.25127 .38673 L
s
.128 1 0 r
.25687 .21306 m
.25665 .21299 L
s
.25454 .21281 m
.25687 .21306 L
s
.25581 .21058 m
.25687 .21306 L
s
.25432 .21275 m
.25454 .21281 L
s
.25454 .21281 m
.25581 .21058 L
s
.683 0 1 r
.25929 .58092 m
.2542 .57652 L
s
.2542 .57652 m
.25396 .58219 L
s
.2617 .60418 m
.2542 .57652 L
s
0 .508 1 r
.25152 .32848 m
.25282 .33281 L
s
.24864 .33264 m
.25152 .32848 L
s
.128 1 0 r
.25473 .22219 m
.25581 .21058 L
s
.452 0 1 r
.25201 .51189 m
.24706 .51185 L
s
0 1 .741 r
.25255 .27189 m
.25372 .27549 L
s
.25032 .27508 m
.25255 .27189 L
s
1 0 0 r
.25801 .70802 m
.25801 .70806 L
s
.25802 .70803 m
.25801 .70802 L
s
.25801 .70802 m
.25799 .70804 L
s
.25804 .70804 m
.25801 .70802 L
s
.25804 .70812 m
.25801 .70802 L
s
.25801 .70806 m
.25804 .70804 L
s
.25799 .70804 m
.25801 .70806 L
s
.25804 .70804 m
.25802 .70803 L
s
.299 0 1 r
.25261 .45136 m
.24755 .4513 L
s
1 0 0 r
.25802 .70803 m
.25799 .70804 L
s
.128 1 0 r
.25581 .21058 m
.25665 .21299 L
s
.25432 .21275 m
.25581 .21058 L
s
0 .016 1 r
.2528 .39164 m
.24805 .39153 L
s
0 .508 1 r
.25282 .33281 m
.24864 .33264 L
s
.683 0 1 r
.25929 .58092 m
.25396 .58219 L
s
0 1 .741 r
.25372 .27549 m
.25032 .27508 L
s
.128 1 0 r
.25665 .21299 m
.25432 .21275 L
s
.269 0 1 r
.29076 .65996 m
.294 .65646 L
s
.294 .65646 m
.29417 .65349 L
s
.294 .65646 m
.28825 .65402 L
s
1 0 0 r
.29606 .5557 m
.30287 .55409 L
s
.30287 .55409 m
.30535 .55274 L
s
.30287 .55409 m
.29875 .54711 L
s
.269 0 1 r
.28825 .65402 m
.29076 .65996 L
s
.29417 .65349 m
.28825 .65402 L
s
.28825 .65402 m
.29093 .65698 L
s
.30936 .66755 m
.28825 .65402 L
s
.29093 .65698 m
.29076 .65996 L
s
.29417 .65349 m
.29093 .65698 L
s
1 0 .524 r
.30598 .60132 m
.31012 .59694 L
s
.31012 .59694 m
.31037 .59297 L
s
.31012 .59694 m
.30276 .59373 L
s
1 0 0 r
.29852 .55434 m
.29606 .5557 L
s
.29875 .54711 m
.29606 .5557 L
s
.30535 .55274 m
.29875 .54711 L
s
.29875 .54711 m
.29852 .55434 L
s
.30852 .5827 m
.29875 .54711 L
s
1 0 .524 r
.30276 .59373 m
.30598 .60132 L
s
.31037 .59297 m
.30276 .59373 L
s
.30276 .59373 m
.30623 .59735 L
s
.32993 .61088 m
.30276 .59373 L
s
1 0 .282 r
.31129 .50565 m
.31842 .50572 L
s
.31052 .50573 m
.31129 .50565 L
s
.31129 .50565 m
.31453 .49865 L
s
.31842 .50572 m
.31767 .5058 L
s
.31453 .49865 m
.31842 .50572 L
s
1 0 0 r
.30535 .55274 m
.29852 .55434 L
s
1 0 .524 r
.30623 .59735 m
.30598 .60132 L
s
1 0 .456 r
.31875 .44481 m
.31836 .44486 L
s
.31182 .44458 m
.31875 .44481 L
s
.3153 .43786 m
.31875 .44481 L
s
.31141 .44463 m
.31182 .44458 L
s
.31182 .44458 m
.3153 .43786 L
s
1 0 .807 r
.31915 .38478 m
.31885 .38484 L
s
.31266 .38437 m
.31915 .38478 L
s
.31612 .37817 m
.31915 .38478 L
s
.31234 .38442 m
.31266 .38437 L
s
.31266 .38437 m
.31612 .37817 L
s
1 0 .524 r
.31037 .59297 m
.30623 .59735 L
s
.647 0 1 r
.31946 .32572 m
.31934 .32584 L
s
.31365 .32512 m
.31946 .32572 L
s
.31705 .31973 m
.31946 .32572 L
s
.31352 .32523 m
.31365 .32512 L
s
.31365 .32512 m
.31705 .31973 L
s
0 1 .883 r
.3134 .23789 m
.31809 .22086 L
s
.647 0 1 r
.31425 .34844 m
.31705 .31973 L
s
0 .069 1 r
.31425 .28658 m
.3199 .26294 L
s
1 0 .282 r
.31425 .53402 m
.31453 .49865 L
s
1 0 .456 r
.31425 .47216 m
.3153 .43786 L
s
1 0 .807 r
.31425 .4103 m
.31612 .37817 L
s
1 0 .282 r
.31453 .49865 m
.31767 .5058 L
s
.31052 .50573 m
.31453 .49865 L
s
0 .069 1 r
.32114 .26797 m
.32121 .26855 L
s
.31633 .2668 m
.32114 .26797 L
s
.3199 .26294 m
.32114 .26797 L
s
1 0 .456 r
.3153 .43786 m
.31836 .44486 L
s
.31141 .44463 m
.3153 .43786 L
s
0 .069 1 r
.31639 .26738 m
.31633 .2668 L
s
.31633 .2668 m
.3199 .26294 L
s
1 0 .807 r
.31612 .37817 m
.31885 .38484 L
s
.31234 .38442 m
.31612 .37817 L
s
0 1 .883 r
.31912 .2245 m
.31866 .2251 L
s
.31564 .22344 m
.31912 .2245 L
s
.31809 .22086 m
.31912 .2245 L
s
.31518 .22404 m
.31564 .22344 L
s
.31564 .22344 m
.31809 .22086 L
s
.647 0 1 r
.31705 .31973 m
.31934 .32584 L
s
.31352 .32523 m
.31705 .31973 L
s
1 0 .282 r
.31767 .5058 m
.31052 .50573 L
s
1 0 .456 r
.31836 .44486 m
.31141 .44463 L
s
1 0 .807 r
.31885 .38484 m
.31234 .38442 L
s
0 .069 1 r
.3199 .26294 m
.32121 .26855 L
s
.31639 .26738 m
.3199 .26294 L
s
.647 0 1 r
.31934 .32584 m
.31352 .32523 L
s
0 1 .883 r
.31809 .22086 m
.31866 .2251 L
s
.31518 .22404 m
.31809 .22086 L
s
.31866 .2251 m
.31518 .22404 L
s
0 .069 1 r
.32121 .26855 m
.31639 .26738 L
s
.765 0 1 r
.38519 .6121 m
.38676 .60764 L
s
.38676 .60764 m
.38521 .60358 L
s
.38676 .60764 m
.37964 .60773 L
s
.37964 .60773 m
.38519 .6121 L
s
.38521 .60358 m
.37964 .60773 L
s
.37964 .60773 m
.38364 .60804 L
s
.40753 .60828 m
.37964 .60773 L
s
0 .279 1 r
.39005 .69577 m
.39127 .69216 L
s
.39127 .69216 m
.39007 .6891 L
s
.39127 .69216 m
.38571 .69229 L
s
.765 0 1 r
.38364 .60804 m
.38519 .6121 L
s
.38521 .60358 m
.38364 .60804 L
s
0 .279 1 r
.38571 .69229 m
.39005 .69577 L
s
.39007 .6891 m
.38571 .69229 L
s
.38571 .69229 m
.38884 .69272 L
s
.40753 .69302 m
.38571 .69229 L
s
.38884 .69272 m
.39005 .69577 L
s
.39007 .6891 m
.38884 .69272 L
s
0 1 .475 r
.22885 .20163 m
.22977 .20178 L
s
.22586 .2009 m
.22885 .20163 L
s
.2285 .19825 m
.22885 .20163 L
s
.2251 .21369 m
.2285 .19825 L
s
.22678 .20105 m
.22586 .2009 L
s
.22586 .2009 m
.2285 .19825 L
s
.2285 .19825 m
.22977 .20178 L
s
.22678 .20105 m
.2285 .19825 L
s
.22977 .20178 m
.22678 .20105 L
s
1 .033 0 r
.18773 .65131 m
.18766 .65133 L
s
.18775 .65133 m
.18773 .65131 L
s
.18773 .65131 m
.18772 .6514 L
s
.18772 .6514 m
.18768 .65135 L
s
.18772 .6514 m
.18766 .65133 L
s
.18775 .65133 m
.18772 .6514 L
s
.18766 .65106 m
.18772 .6514 L
s
.18766 .65133 m
.18768 .65135 L
s
.18768 .65135 m
.18775 .65133 L
s
.73 0 1 r
.51024 .6146 m
.51154 .61008 L
s
.51154 .61008 m
.51015 .60597 L
s
.51154 .61008 m
.50446 .61026 L
s
.655 0 1 r
.21095 .51123 m
.21418 .51131 L
s
.20582 .5113 m
.21095 .51123 L
s
.21095 .51123 m
.20998 .50536 L
s
.528 0 1 r
.21009 .44806 m
.21422 .44816 L
s
.20588 .44813 m
.21009 .44806 L
s
.21009 .44806 m
.21005 .44236 L
s
.73 0 1 r
.50446 .61026 m
.51024 .6146 L
s
.51015 .60597 m
.50446 .61026 L
s
.50446 .61026 m
.50884 .6105 L
s
.53323 .6104 m
.50446 .61026 L
s
.859 0 1 r
.2109 .58595 m
.21671 .58453 L
s
.21671 .58453 m
.21857 .58343 L
s
.21671 .58453 m
.21307 .57874 L
s
0 .295 1 r
.51516 .69977 m
.51619 .69609 L
s
.51619 .69609 m
.51512 .693 L
s
.51619 .69609 m
.51063 .69628 L
s
.222 0 1 r
.20996 .38578 m
.21402 .38592 L
s
.20625 .38585 m
.20996 .38578 L
s
.20996 .38578 m
.21015 .38048 L
s
.73 0 1 r
.51015 .60597 m
.50884 .6105 L
s
.50884 .6105 m
.51024 .6146 L
s
0 .259 1 r
.21005 .32431 m
.21355 .32456 L
s
.20665 .32448 m
.21005 .32431 L
s
.21005 .32431 m
.21011 .31972 L
s
0 .295 1 r
.51063 .69628 m
.51516 .69977 L
s
.51512 .693 m
.51063 .69628 L
s
.51063 .69628 m
.51409 .69667 L
s
.53323 .6968 m
.51063 .69628 L
s
.655 0 1 r
.20904 .51138 m
.20582 .5113 L
s
.20582 .5113 m
.20998 .50536 L
s
.21006 .53509 m
.20998 .50536 L
s
.528 0 1 r
.21006 .47129 m
.21005 .44236 L
s
.222 0 1 r
.21006 .40749 m
.21015 .38048 L
s
0 .259 1 r
.21006 .34369 m
.21011 .31972 L
s
.859 0 1 r
.21275 .58486 m
.2109 .58595 L
s
.21307 .57874 m
.2109 .58595 L
s
.655 0 1 r
.20998 .50536 m
.20904 .51138 L
s
.20998 .50536 m
.21418 .51131 L
s
.528 0 1 r
.21422 .44816 m
.21001 .44823 L
s
.21005 .44236 m
.21422 .44816 L
s
.655 0 1 r
.21418 .51131 m
.20904 .51138 L
s
0 .295 1 r
.51512 .693 m
.51409 .69667 L
s
.51409 .69667 m
.51516 .69977 L
s
.222 0 1 r
.21402 .38592 m
.21031 .38598 L
s
.21015 .38048 m
.21402 .38592 L
s
.859 0 1 r
.21857 .58343 m
.21307 .57874 L
s
.21307 .57874 m
.21275 .58486 L
s
.22139 .60854 m
.21307 .57874 L
s
.528 0 1 r
.21005 .44236 m
.21001 .44823 L
s
.20588 .44813 m
.21005 .44236 L
s
.21001 .44823 m
.20588 .44813 L
s
.222 0 1 r
.21015 .38048 m
.21031 .38598 L
s
.20625 .38585 m
.21015 .38048 L
s
0 .259 1 r
.21355 .32456 m
.21015 .32473 L
s
.21011 .31972 m
.21355 .32456 L
s
.222 0 1 r
.21031 .38598 m
.20625 .38585 L
s
1 .011 0 r
.21776 .71681 m
.21778 .71684 L
s
.21777 .71678 m
.21776 .71681 L
s
.21782 .7168 m
.21776 .71681 L
s
.21782 .7168 m
.21778 .71684 L
s
.21777 .71678 m
.21782 .7168 L
s
.21779 .71681 m
.21782 .7168 L
s
.21761 .71684 m
.21782 .7168 L
s
.21778 .71684 m
.21779 .71681 L
s
.21779 .71681 m
.21777 .71678 L
s
.859 0 1 r
.21857 .58343 m
.21275 .58486 L
s
0 .259 1 r
.21015 .32473 m
.20665 .32448 L
s
.20665 .32448 m
.21011 .31972 L
s
.21011 .31972 m
.21015 .32473 L
s
0 1 .879 r
.20694 .27537 m
.20835 .25688 L
s
.20711 .26029 m
.21055 .26073 L
s
.20558 .26044 m
.20711 .26029 L
s
.20711 .26029 m
.20835 .25688 L
s
0 .846 1 r
.28141 .22867 m
.28672 .21109 L
s
0 1 .879 r
.21055 .26073 m
.20903 .26088 L
s
.20835 .25688 m
.21055 .26073 L
s
.20835 .25688 m
.20903 .26088 L
s
.20558 .26044 m
.20835 .25688 L
s
.20903 .26088 m
.20558 .26044 L
s
.4 0 1 r
.25091 .66649 m
.25444 .66273 L
s
.25444 .66273 m
.25452 .65954 L
s
.25444 .66273 m
.24822 .66012 L
s
1 0 .072 r
.25678 .55859 m
.26385 .55686 L
s
.26385 .55686 m
.26621 .55539 L
s
.26385 .55686 m
.2594 .54971 L
s
.4 0 1 r
.24822 .66012 m
.25091 .66649 L
s
.25452 .65954 m
.24822 .66012 L
s
.24822 .66012 m
.25098 .6633 L
s
.27075 .67463 m
.24822 .66012 L
s
0 .846 1 r
.28464 .21313 m
.28828 .21482 L
s
.28302 .21442 m
.28464 .21313 L
s
.28464 .21313 m
.28672 .21109 L
s
.4 0 1 r
.25098 .6633 m
.25091 .66649 L
s
0 .846 1 r
.28828 .21482 m
.28666 .21611 L
s
.28672 .21109 m
.28828 .21482 L
s
.4 0 1 r
.25452 .65954 m
.25098 .6633 L
s
1 0 .528 r
.26719 .6058 m
.27153 .60121 L
s
.27153 .60121 m
.27168 .59707 L
s
.27153 .60121 m
.2638 .59791 L
s
1 0 .072 r
.25912 .55713 m
.25678 .55859 L
s
.2594 .54971 m
.25678 .55859 L
s
.26621 .55539 m
.2594 .54971 L
s
.2594 .54971 m
.25912 .55713 L
s
.26987 .58619 m
.2594 .54971 L
s
0 .846 1 r
.28666 .21611 m
.28302 .21442 L
s
.28302 .21442 m
.28672 .21109 L
s
.28672 .21109 m
.28666 .21611 L
s
1 0 .399 r
.27511 .50643 m
.28104 .50657 L
s
.27079 .50658 m
.27511 .50643 L
s
.27511 .50643 m
.27595 .49935 L
s
1 0 .528 r
.2638 .59791 m
.26719 .6058 L
s
.27168 .59707 m
.2638 .59791 L
s
.2638 .59791 m
.26733 .60166 L
s
.29206 .61558 m
.2638 .59791 L
s
1 0 .072 r
.26621 .55539 m
.25912 .55713 L
s
1 0 .528 r
.26733 .60166 m
.26719 .6058 L
s
1 0 .615 r
.27505 .44294 m
.28126 .44329 L
s
.27169 .44319 m
.27505 .44294 L
s
.27505 .44294 m
.27665 .43629 L
s
1 0 .528 r
.27168 .59707 m
.26733 .60166 L
s
1 0 .399 r
.28104 .50657 m
.27674 .50671 L
s
.27595 .49935 m
.28104 .50657 L
s
.992 0 1 r
.27564 .38037 m
.28146 .38096 L
s
.27266 .38075 m
.27564 .38037 L
s
.27564 .38037 m
.27738 .37443 L
s
1 0 .399 r
.27581 .53546 m
.27595 .49935 L
s
1 0 .615 r
.27581 .47099 m
.27665 .43629 L
s
.992 0 1 r
.27581 .40651 m
.27738 .37443 L
s
.407 0 1 r
.27581 .34204 m
.278 .3139 L
s
1 0 .615 r
.28126 .44329 m
.27792 .44353 L
s
.27665 .43629 m
.28126 .44329 L
s
1 0 .399 r
.27595 .49935 m
.27674 .50671 L
s
.27079 .50658 m
.27595 .49935 L
s
.407 0 1 r
.27632 .31884 m
.28145 .31968 L
s
.27367 .3194 m
.27632 .31884 L
s
.27632 .31884 m
.278 .3139 L
s
.992 0 1 r
.28146 .38096 m
.27849 .38134 L
s
.27738 .37443 m
.28146 .38096 L
s
1 0 .399 r
.27674 .50671 m
.27079 .50658 L
s
1 0 .615 r
.27665 .43629 m
.27792 .44353 L
s
.27169 .44319 m
.27665 .43629 L
s
.407 0 1 r
.28145 .31968 m
.27881 .32023 L
s
.278 .3139 m
.28145 .31968 L
s
1 0 .615 r
.27792 .44353 m
.27169 .44319 L
s
.992 0 1 r
.27738 .37443 m
.27849 .38134 L
s
.27266 .38075 m
.27738 .37443 L
s
.27849 .38134 m
.27266 .38075 L
s
.407 0 1 r
.278 .3139 m
.27881 .32023 L
s
.27367 .3194 m
.278 .3139 L
s
0 .186 1 r
.27286 .27299 m
.2786 .25043 L
s
.407 0 1 r
.27881 .32023 m
.27367 .3194 L
s
0 .186 1 r
.27604 .25347 m
.28061 .25518 L
s
.27428 .25474 m
.27604 .25347 L
s
.27604 .25347 m
.2786 .25043 L
s
.28061 .25518 m
.27886 .25646 L
s
.2786 .25043 m
.28061 .25518 L
s
.702 0 1 r
.64013 .61662 m
.64124 .61203 L
s
.64124 .61203 m
.64011 .60787 L
s
.64124 .61203 m
.63419 .61215 L
s
0 .186 1 r
.27886 .25646 m
.27428 .25474 L
s
.27428 .25474 m
.2786 .25043 L
s
.2786 .25043 m
.27886 .25646 L
s
.702 0 1 r
.63419 .61215 m
.64013 .61662 L
s
.64011 .60787 m
.63419 .61215 L
s
.63419 .61215 m
.639 .61246 L
s
.66394 .61261 m
.63419 .61215 L
s
0 .326 1 r
.64529 .70361 m
.64615 .69989 L
s
.64615 .69989 m
.64529 .69676 L
s
.64615 .69989 m
.64064 .70005 L
s
.702 0 1 r
.64011 .60787 m
.639 .61246 L
s
.639 .61246 m
.64013 .61662 L
s
0 .326 1 r
.64064 .70005 m
.64529 .70361 L
s
.64529 .69676 m
.64064 .70005 L
s
.64064 .70005 m
.64442 .70049 L
s
.66394 .70074 m
.64064 .70005 L
s
.64529 .69676 m
.64442 .70049 L
s
.64442 .70049 m
.64529 .70361 L
s
.797 0 1 r
.34914 .6168 m
.35087 .6121 L
s
.35087 .6121 m
.34921 .60785 L
s
.35087 .6121 m
.34337 .61217 L
s
.34337 .61217 m
.34914 .6168 L
s
.34921 .60785 m
.34337 .61217 L
s
.34337 .61217 m
.34747 .61254 L
s
.37251 .61293 m
.34337 .61217 L
s
0 .19 1 r
.35396 .70416 m
.35535 .70028 L
s
.35535 .70028 m
.35401 .69704 L
s
.35535 .70028 m
.34937 .70042 L
s
.34937 .70042 m
.35396 .70416 L
s
.35401 .69704 m
.34937 .70042 L
s
.34937 .70042 m
.35262 .70091 L
s
.37251 .70131 m
.34937 .70042 L
s
.797 0 1 r
.34747 .61254 m
.34914 .6168 L
s
.34921 .60785 m
.34747 .61254 L
s
0 .19 1 r
.35262 .70091 m
.35396 .70416 L
s
.35401 .69704 m
.35262 .70091 L
s
1 0 .945 r
.72925 .63412 m
.72856 .62939 L
s
.72856 .62939 m
.7258 .6252 L
s
.72856 .62939 m
.72145 .632 L
s
.72145 .632 m
.72925 .63412 L
s
.7258 .6252 m
.72145 .632 L
s
.72145 .632 m
.72649 .62993 L
s
.75195 .62026 m
.72145 .632 L
s
.7258 .6252 m
.72649 .62993 L
s
.72649 .62993 m
.72925 .63412 L
s
0 .066 1 r
.76007 .69506 m
.75949 .69124 L
s
.75949 .69124 m
.7574 .68804 L
s
.75949 .69124 m
.75394 .69331 L
s
.75394 .69331 m
.76007 .69506 L
s
.7574 .68804 m
.75394 .69331 L
s
.75394 .69331 m
.75798 .69186 L
s
.77798 .68448 m
.75394 .69331 L
s
.7574 .68804 m
.75798 .69186 L
s
.75798 .69186 m
.76007 .69506 L
s
.771 0 1 r
.47892 .61965 m
.48036 .61488 L
s
.48036 .61488 m
.47882 .61057 L
s
.48036 .61488 m
.47287 .61508 L
s
.47287 .61508 m
.47892 .61965 L
s
.47882 .61057 m
.47287 .61508 L
s
.47287 .61508 m
.47738 .61534 L
s
.50299 .61524 m
.47287 .61508 L
s
0 .222 1 r
.48386 .70856 m
.485 .70463 L
s
.485 .70463 m
.48382 .70135 L
s
.485 .70463 m
.47907 .70484 L
s
.771 0 1 r
.47882 .61057 m
.47738 .61534 L
s
.47738 .61534 m
.47892 .61965 L
s
0 .222 1 r
.47907 .70484 m
.48386 .70856 L
s
.48382 .70135 m
.47907 .70484 L
s
.47907 .70484 m
.48267 .70528 L
s
.50299 .70543 m
.47907 .70484 L
s
.48382 .70135 m
.48267 .70528 L
s
.48267 .70528 m
.48386 .70856 L
s
1 .195 0 r
.83113 .73351 m
.83116 .73328 L
s
.83116 .73328 m
.83112 .73309 L
s
.83116 .73328 m
.83083 .73329 L
s
.83083 .73329 m
.83113 .73351 L
s
.83112 .73309 m
.83083 .73329 L
s
.83083 .73329 m
.83109 .73332 L
s
.83229 .73333 m
.83083 .73329 L
s
.83112 .73309 m
.83109 .73332 L
s
.83109 .73332 m
.83113 .73351 L
s
.729 0 1 r
.61401 .62184 m
.61523 .61701 L
s
.61523 .61701 m
.61399 .61265 L
s
.61523 .61701 m
.6078 .61714 L
s
.6078 .61714 m
.61401 .62184 L
s
.61399 .61265 m
.6078 .61714 L
s
.6078 .61714 m
.61277 .61748 L
s
.63892 .61764 m
.6078 .61714 L
s
0 .264 1 r
.61919 .71273 m
.62015 .70876 L
s
.62015 .70876 m
.61919 .70546 L
s
.62015 .70876 m
.61428 .70894 L
s
.729 0 1 r
.61399 .61265 m
.61277 .61748 L
s
.61277 .61748 m
.61401 .62184 L
s
0 .264 1 r
.61428 .70894 m
.61919 .71273 L
s
.61919 .70546 m
.61428 .70894 L
s
.61428 .70894 m
.61823 .70943 L
s
.63892 .70971 m
.61428 .70894 L
s
.61919 .70546 m
.61823 .70943 L
s
.61823 .70943 m
.61919 .71273 L
s
1 0 .93 r
.70675 .64005 m
.70611 .63506 L
s
.70611 .63506 m
.70322 .63067 L
s
.70611 .63506 m
.69862 .63776 L
s
.69862 .63776 m
.70675 .64005 L
s
.70322 .63067 m
.69862 .63776 L
s
.69862 .63776 m
.70385 .63565 L
s
.73058 .62571 m
.69862 .63776 L
s
.70322 .63067 m
.70385 .63565 L
s
.70385 .63565 m
.70675 .64005 L
s
0 .015 1 r
.73871 .70389 m
.73816 .69981 L
s
.73816 .69981 m
.73594 .69643 L
s
.73816 .69981 m
.73225 .70197 L
s
.73225 .70197 m
.73871 .70389 L
s
.73594 .69643 m
.73225 .70197 L
s
.73225 .70197 m
.73648 .7005 L
s
.7577 .69287 m
.73225 .70197 L
s
.73594 .69643 m
.73648 .7005 L
s
.73648 .7005 m
.73871 .70389 L
s
1 .285 0 r
.81263 .74429 m
.81268 .74395 L
s
.81268 .74395 m
.81263 .74368 L
s
.81268 .74395 m
.8122 .74397 L
s
.8122 .74397 m
.81263 .74429 L
s
.81263 .74368 m
.8122 .74397 L
s
.8122 .74397 m
.81257 .74402 L
s
.81434 .74404 m
.8122 .74397 L
s
.81263 .74368 m
.81257 .74402 L
s
.81257 .74402 m
.81263 .74429 L
s
0 g
.001 w
[ .01 .01 ] 0 setdash
.16478 .16428 m
.82807 .12822 L
s
.82807 .12822 m
.82807 .87178 L
s
.82807 .87178 m
.16478 .83572 L
s
.16478 .83572 m
.16478 .16428 L
s
.85033 .14915 m
.82807 .12822 L
s
.82807 .12822 m
.82807 .87178 L
s
.82807 .87178 m
.85033 .85085 L
s
.85033 .85085 m
.85033 .14915 L
s
.003 w
[ ] 0 setdash
.85033 .85085 m
.82807 .87178 L
s
.25 Mabswid
.84887 .85222 m
.84887 .84597 L
s
gsave
.84887 .86472 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.84045 .86014 m
.84045 .85389 L
s
gsave
.84045 .87264 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.83164 .86842 m
.83164 .86217 L
s
gsave
.83164 .88092 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.84722 .85377 m
.84722 .85002 L
s
.84555 .85534 m
.84555 .85159 L
s
.84386 .85693 m
.84386 .85318 L
s
.84216 .85853 m
.84216 .85478 L
s
.83872 .86177 m
.83872 .85802 L
s
.83697 .86341 m
.83697 .85966 L
s
.83521 .86506 m
.83521 .86131 L
s
.83343 .86674 m
.83343 .86299 L
s
.82983 .87013 m
.82983 .86638 L
s
gsave
.83952 .93601 -68.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 350},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001GR000`400?l00000o`00003oo`3ooomO
0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO
0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO
0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00X`3oool3
00000;P0oooo002S0?ooo`030>k^kP000000k^k^0;P0oooo002T0?ooo`030000003oool0oooo0;L0
oooo002S0?ooo`030>k^kP000000k^k^0;P0oooo002S0?ooo`<0A4A4^03oool00:80oooo00D0QhN7
04A4A03oool0<S8b0:VYZ@2g0?ooo`00X@3oool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`0
]P3oool00:40oooo0P0000000`0b<S80oooo0000000200000;H0oooo003o0?oooel0oooo003o0?oo
oel0oooo003o0?oooel0oooo003o0?oooel0oooo003o0?oooel0oooo003o0?oooel0oooo003o0?oo
oel0oooo003o0?oooel0oooo003o0?oooel0oooo003o0?oooel0oooo003C0?ooo`<0000000<0oooo
09RHV00000000P0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo07X0oooo003D0?oo
o`0>0000003oool0oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV000001l
0?ooo`00e03oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0NP3oool00=@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo07X0oooo003D0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`1j0?ooo`00Q@3oool01`0@41000000000000000000
V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`120?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1j0?ooo`00R03oool0202HV9P000000?oo
o`000000V9RH0?ooo`2HV9P00000A03oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P00000O03oool008T0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`110?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV003
0000000309RHV03oool0oooo07X0oooo00290?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0c03oool003h0oooo00D0V9RH000000000000000009RHV0150?ooo`0409RHV0000000oooo
000000<0oooo00<000000?ooo`3oool0c03oool003h0oooo00D0000009RHV03oool0V9RH00000012
0?ooo`@0000000<0V9RH0?ooo`0000000`3oool00`000000oooo0?ooo`200?ooo`X00000@P3oool0
03h0oooo00D000000?ooo`3oool0oooo000000120?ooo`0307MgM`1EEED0oooo00<0oooo00D00000
09RHV03oool0V9RH0000001_0?oooa<000002@3oool200000440oooo000n0?ooo`050000003oool0
oooo0?ooo`000000@`3oool01P0@410000000000000b<S80oooo09RHV0<0000000<0V9RH0?ooo`3o
ool0F`3ooolB000000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000100?ooo`00
?P3oool01@000000oooo0?ooo`3oool0000009H0oooo5000000?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0@03oool003h0oooo00D000000?ooo`3oool0oooo000000250?oooa<0
0000403oool00`000000oooo0?ooo`1`0?ooo`00?P3oool01@000000V9RH0?ooo`2HV9P0000007<0
oooo4P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@P3oool2000003d0
oooo000n0?ooo`0509RHV000000000000000002HV9P0G`3ooolD000000@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03X0oooo002@0?oooa@00000
1P3oool00`000000oooo0?ooo`1[0?ooo`@000000`3oool4000003/0oooo001m0?oooa@000002@3o
ool00`000000oooo0?ooo`1W0?ooo`@000000`3oool400000080oooo1@0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0>@3oool006`0oooo4`00000<0?ooo`030000003oool0
oooo0680oooo1@0000020?ooo`@000000`3oool4000001T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0i0?ooo`00F@3ooolD000000h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1>0?ooo`D000000P3oool4000000<0oooo1000000]0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0>@3oool004P0oooo4P0000040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0FP3oool400000080oooo1@0000020?ooo`@00000B03oool00`000000
oooo0?ooo`0i0?ooo`00?`3oool9000000L0oooo00<000000?ooo`3oool0H`3oool400000080oooo
1@0000020?ooo`@00000G03oool00`000000oooo0?ooo`0i0?ooo`00?`3oool010000000oooo0000
0000001N0?ooo`@000000`3oool400000080oooo1@00001X0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`0000000`3oool3000004D0oooo1000
00030?ooo`@000000P3oool5000007`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0i0?ooo`00?`3oool00`000000oooo0?ooo`060?ooo`800000;`3oool500000080oooo10000003
0?ooo`@00000T03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?oo
o`030000003oool0oooo00X0oooo0`00000I0?ooo`8000000P3oool4000000<0oooo1000002T0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool004l0oooo00<000000?ooo`3o
ool00P3oool200000080oooo1@0000020?ooo`@000000`3oool200000;X0oooo00<000000?ooo`3o
ool0>@3oool00540oooo0`00003>0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000
oooo0?ooo`3I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool005@0oooo
00<00?mi0?ooo`3oool0a03oool00`000000oooo0?ooo`030?ooo`800000>`3oool00540oooo00<0
00000?ooo`00ogT00P00ogW<0?ooo`030000003oool0oooo03T0oooo001A0?ooo`040000003oool0
oooo003oNLd0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo003oN@370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool0
03l0oooo00<000000?ooo`3oool03`3oool00`000000oooo003oN@090?ooo`03023o003oool0oooo
00L0oooo00<00=So0?ooo`3oool0/@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03T0oooo000o0?ooo`030000003oool0oooo0140oooo00<00?mi0?ooo`3oool01`3oool2023o00L0
oooo0P00f?nc0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo
00<000000?ooo`3oool06`3oool00`0Po`00oooo0?ooo`070?ooo`800=So/P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo001M0?ooo`03023o003oool0oooo00L0oooo00<0
0=So0?ooo`3oool0/@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo001A
0?ooo`030000003oool0oooo00T0oooo00<08?l00?ooo`3oool01P3oool00`00f?l0oooo0?ooo`08
0?ooo`800?oR[`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0180oooo00<00=So0?ooo`3oool0203oool2003ohZl0oooo00<000000?oo
o`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
003Ho`3oool0oooo00P0oooo00<00?oR0?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
7@3oool00`00on80oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
>@3oool003l0oooo00<000000?ooo`3oool0;`3oool00`00on80oooo0?ooo`2W0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0;P3oool0
0`00on80oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool0
0540oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00D@3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0c03oool3000003/0oooo000o0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool00`00;ol0oooo0?ooo`2c0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`8002oo]@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?oo
o`030000003oool0oooo00`0oooo00<00?oQ0?ooo`3oool04P3oool3000_okD0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00CP3oool00`00on40oooo0?ooo`0C0?ooo`03
000_o`3oool0oooo0;@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00
C@3oool2003oh@80oooo00<000000?ooo`3oool0403oool00`00;ol0oooo0?ooo`0;0?ooo`03000A
o`3oool0oooo0:d0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0303o
ool01000on40oooo0?ooo`00000B0?ooo`03000_o`3oool0oooo00/0oooo00<0017o0?ooo`3oool0
[@3oool00`000000oooo0?ooo`020?ooo`07010@4000000000000000002HV9P0oooo09RHV0030000
000309RHV03oool0oooo02X0oooo000o0?ooo`030000003oool0oooo00/0oooo00D00?oQ0?ooo`3o
ool0oooo0000000B0?ooo`03000_o`3oool0oooo00X0oooo0`004OnW0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
;03oool003l0oooo00<000000?ooo`3oool02`3oool01@00on40oooo0?ooo`3oool0000000X0oooo
00<00?nm0?ooo`3oool0103oool00`00;ol0oooo0?ooo`0<0?ooo`03000Ao`3oool0oooo0:H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0:P3oool003l0oooo00<000000?ooo`3oool02`3oool00`00on40oooo0?oo
o`0<0?ooo`03003o_@3oool0oooo00@0oooo00<002oo0?ooo`3oool0303oool00`004Ol0oooo0?oo
o`2V0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo02X0oooo000o0?ooo`030000003oool0oooo00/0oooo00<00?oQ
0?ooo`3oool02`3oool3003o_A<0oooo00<0017o0?ooo`3oool0Y`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00@0V9RH0000003oool000000`3oool00`000000oooo0?oo
o`0Z0?ooo`00G03oool00`00okd0oooo0?ooo`0B0?ooo`03000Ao`3oool0oooo0:L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`@0000000<0V9RH0?ooo`0000000`3oool0
0`000000oooo0?ooo`0Z0?ooo`00D@3oool00`000000oooo0?ooo`080?ooo`03003o_@3oool0oooo
0180oooo00<0017o0?ooo`3oool0[P3oool00`000000oooo0?ooo`020?ooo`0307MgM`1EEED0oooo
00<0oooo00D0000009RHV03oool0V9RH0000000/0?ooo`00?`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo00<00?nm0?ooo`3oool04P3oool00`004Ol0oooo0?ooo`2^0?oo
o`030000003oool0oooo00<0oooo00H0410@000000000000<S8b0?ooo`2HV9P30000000309RHV03o
ool0oooo02X0oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool0
0`00okd0oooo0?ooo`2l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool0
03l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo003o0?oooa`0oooo00<000000?ooo`3oool0
0`3oool2000003/0oooo001A0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0>@3o
ool00540oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<0J03o0?ooo`3oool0/`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo0280oooo0P1X
0?ne0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool004h0oooo00<004;o
0?ooo`3oool04P3oool406P0o`X0oooo00<0Y@3o0?ooo`3oool0Y`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03T0oooo001>0?ooo`040012o`3oool0oooo000001<0oooo00<0J03o
0?ooo`3oool02@3oool00`2U0?l0oooo0?ooo`2^0?ooo`030000003oool0oooo03T0oooo000o0?oo
o`030000003oool0oooo00/0oooo0`00@_l00`3oool000000?ooo`0B0?ooo`0306P0o`3oool0oooo
00P0oooo0`2U0?n_0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00`0
oooo00@004;o0?ooo`3oool000002P3oool00`00P_l0oooo0?ooo`060?ooo`0306P0o`3oool0oooo
00T0oooo00<0Y@3o0?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03T0oooo000o0?ooo`030000003oool0oooo00`0oooo00@004;o0?ooo`3oool000002P3oool00`00
P_l0oooo0?ooo`050?ooo`0306P0o`3oool0oooo00X0oooo00<0Y@3o0?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00`0
oooo00<004;o0?ooo`3oool02P3oool30022o`H0oooo00<0J03o0?ooo`3oool02P3oool00`2U0?l0
oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo
00<000000?ooo`3oool0303oool00`00@_l0oooo0?ooo`0;0?ooo`030022o`3oool0oooo00D0oooo
00<0J03o0?ooo`3oool02P3oool00`2U0?l0oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0>@3oool004h0oooo00@004;o0?ooo`3oool000002P3oool00`00P_l0oooo
0?ooo`050?ooo`0306P0o`3oool0oooo00X0oooo00<0Y@3o0?ooo`3oool0[P3oool00`000000oooo
0?ooo`0i0?ooo`00CP3oool01000@_l0oooo0?ooo`00000:0?ooo`030022o`3oool0oooo00D0oooo
00<0J03o0?ooo`3oool02P3oool00`2U0?l0oooo0?ooo`2^0?ooo`030000003oool0oooo03T0oooo
000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00P_l0oooo0?oo
o`0B0?ooo`030:D0o`3oool0oooo0:h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030022o`3oool0oooo0180oooo00<0Y@3o
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`030?ooo`800000>`3oool003l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>@3oool003l0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo003o0?oooa`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0i0?ooo`00D@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo001A
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0
8P3oool00`3m0?l0oooo0?ooo`2d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
>@3oool003l0oooo00<000000?ooo`3oool08P3oool00`3m0?l0oooo0?ooo`2d0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0>@3oool004h0oooo00<0>03o0?ooo`3oool04P3oool3
0?d0o`/0oooo00<0o`3>0?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03T0oooo001>0?ooo`0403P0o`3oool0oooo00000180oooo0`3m0?l:0?ooo`030?l0cP3oool0
oooo0:h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool02`3oool303P0
o`030?ooo`000000oooo00T0oooo00<000Co0?ooo`3oool01@3oool00`3m0?l0oooo0?ooo`090?oo
o`<0o`3>[`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<0?ooo`04
03P0o`3oool0oooo000000X0oooo00<000Co0?ooo`3oool01@3oool00`3m0?l0oooo0?ooo`0:0?oo
o`030?l0cP3oool0oooo0:L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?oo
o`00?`3oool00`000000oooo0?ooo`0<0?ooo`0403P0o`3oool0oooo000000T0oooo0`001?l60?oo
o`030?d0o`3oool0oooo00X0oooo00<0o`3>0?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00`0oooo00<0>03o0?ooo`3o
ool02`3oool00`001?l0oooo0?ooo`050?ooo`030?d0o`3oool0oooo00X0oooo00<0o`3>0?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo001>0?ooo`0303P0
o`3oool0oooo00/0oooo00<000Co0?ooo`3oool01@3oool00`3m0?l0oooo0?ooo`0:0?ooo`030?l0
cP3oool0oooo0:L0oooo00<000000?ooo`3oool00`3oool2000003/0oooo001>0?ooo`0403P0o`3o
ool0oooo000000X0oooo00<000Co0?ooo`3oool01@3oool00`3m0?l0oooo0?ooo`0:0?ooo`030?l0
cP3oool0oooo0:h0oooo00<000000?ooo`3oool0>@3oool004h0oooo00@0>03o0?ooo`3oool00000
2P3oool00`001?l0oooo0?ooo`050?ooo`030?d0o`3oool0oooo00X0oooo00<0o`3>0?ooo`3oool0
[P3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<0?ooo`0403P0o`3o
ool0oooo000000X0oooo00<000Co0?ooo`3oool01@3oool00`3m0?l0oooo0?ooo`0:0?ooo`030?l0
cP3oool0oooo0:h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`080?ooo`030004o`3oool0oooo0180oooo00<0o`3>0?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0203oool00`001?l0oooo0?ooo`2l0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo003o0?oooa`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0i0?ooo`00D@3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool08P3oool00`3o09d0oooo
0?ooo`0:0?ooo`030?l0M03oool0oooo0:L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0i0?ooo`00H`3oool30?l0W@/0oooo00<0o`1d0?ooo`3oool0Y`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03T0oooo001>0?ooo`0408L0o`3oool0oooo00000100oooo1@3o
09d90?ooo`<0o`1d[`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<
0?ooo`0408L0o`3oool0oooo000000X0oooo00<0C03o0?ooo`3oool01@3oool00`3o09d0oooo0?oo
o`090?ooo`<0o`1d[`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0;
0?ooo`<0Q`3o00<0oooo0000003oool0203oool204`0o`L0oooo00<0o`2M0?ooo`3oool02P3oool0
0`3o07@0oooo0?ooo`2W0?ooo`030000003oool0oooo00<0oooo0P00000k0?ooo`00?`3oool00`00
0000oooo0?ooo`0<0?ooo`0408L0o`3oool0oooo000000P0oooo101<0?l60?ooo`030?l0W@3oool0
oooo00X0oooo00<0o`1d0?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03T0oooo000o0?ooo`030000003oool0oooo00`0oooo00<0Q`3o0?ooo`3oool02`3oool00`1<
0?l0oooo0?ooo`050?ooo`030?l0W@3oool0oooo00X0oooo00<0o`1d0?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo001>0?ooo`0308L0o`3oool0oooo00/0
oooo00<0C03o0?ooo`3oool01@3oool00`3o09d0oooo0?ooo`0:0?ooo`030?l0M03oool0oooo0:L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00CP3oool010270?l0oooo
0?ooo`00000:0?ooo`0304`0o`3oool0oooo00D0oooo00<0o`2M0?ooo`3oool02P3oool00`3o07@0
oooo0?ooo`2^0?ooo`030000003oool0oooo03T0oooo001>0?ooo`0408L0o`3oool0oooo000000X0
oooo00<0C03o0?ooo`3oool01@3oool00`3o09d0oooo0?ooo`0:0?ooo`030?l0M03oool0oooo0:h0
oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0303oool010270?l0oooo
0?ooo`00000:0?ooo`0304`0o`3oool0oooo00D0oooo00<0o`2M0?ooo`3oool02P3oool00`3o07@0
oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo
00<000000?ooo`3oool0303oool010270?l0oooo0?ooo`00000:0?ooo`0304`0o`3oool0oooo00D0
oooo00<0o`2M0?ooo`3oool02P3oool00`3o07@0oooo0?ooo`2W0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`0304`0o`3oool0oooo0180oooo00<0o`1d0?ooo`3oool0Y`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00o`3ooolL0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>@3oool00540oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0
V9RH00<0000000<0V9RH0?ooo`3oool00P3oool6000001/0oooo000o0?ooo`030000003oool0oooo
02l0oooo00<0o`180?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
000000@0oooo00H0ZJVY038b<P3oool0oooo0>k^kP0b<S8K0?ooo`00D@3oool00`000000oooo0?oo
o`0@0?ooo`030?l0IP3oool0oooo00X0oooo00<0o`180?ooo`3oool0[03oool3000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
00<0IVIV07MgM`3oool07@3oool00540oooo00<000000?ooo`3oool03`3oool30?l0IPX0oooo0`3o
04R_0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo00<0k^k^024Q8@3<c<`07@3oool003l0oooo00<0
00000?ooo`3oool0303oool0102W0?l0oooo0?ooo`00000:0?ooo`0307<0o`3oool0oooo00<0oooo
1@3o06H80?ooo`@0o`18[`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030<c<c00Q8B40k^k^01`0
oooo000o0?ooo`030000003oool0oooo00`0oooo00@0Y`3o0?ooo`3oool000002@3oool207<0o`L0
oooo00<0o`1V0?ooo`3oool02P3oool00`3o04P0oooo0?ooo`2W0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01@3oool00`1gMgL0IVIV0?ooo`0K0?ooo`00?`3oool00`000000
oooo0?ooo`0;0?ooo`<0Y`3o00<0oooo0000003oool01`3oool407<0o`H0oooo00<0o`1V0?ooo`3o
ool02P3oool00`3o04P0oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2H
V9P00000103oool01P0b<S80k^k^0?ooo`3oool0<S8b0:VYZA/0oooo000o0?ooo`030000003oool0
oooo00`0oooo00<0Y`3o0?ooo`3oool02`3oool00`1c0?l0oooo0?ooo`050?ooo`030?l0IP3oool0
oooo00X0oooo00<0o`180?ooo`3oool0Y`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0
V9RH0?ooo`3oool00P3oool6000001/0oooo001>0?ooo`030:L0o`3oool0oooo00/0oooo00<0L`3o
0?ooo`3oool01@3oool00`3o06H0oooo0?ooo`0:0?ooo`030?l0B03oool0oooo0:L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00CP3oool0102W0?l0oooo0?ooo`00000:
0?ooo`0307<0o`3oool0oooo00D0oooo00<0o`1V0?ooo`3oool02P3oool00`3o04P0oooo0?ooo`2^
0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00`0oooo00@0Y`3o0?oo
o`3oool000002P3oool00`1c0?l0oooo0?ooo`050?ooo`030?l0IP3oool0oooo00X0oooo00<0o`18
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<0?oo
o`040:L0o`3oool0oooo000000X0oooo00<0L`3o0?ooo`3oool01@3oool00`3o06H0oooo0?ooo`0:
0?ooo`030?l0B03oool0oooo0:L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i
0?ooo`00?`3oool00`000000oooo0?ooo`0<0?ooo`040:L0o`3oool0oooo000000X0oooo00<0L`3o
0?ooo`3oool01@3oool00`3o06H0oooo0?ooo`0:0?ooo`030?l0B03oool0oooo0:L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<0?oo
o`030:L0o`3oool0oooo00/0oooo00<0L`3o0?ooo`3oool01@3oool00`3o06H0oooo0?ooo`0:0?oo
o`030?l0B03oool0oooo0:L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?oo
o`00?`3oool00`000000oooo0?ooo`0<0?ooo`030:L0o`3oool0oooo01<0oooo00<0o`1V0?ooo`3o
ool0]03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo003o0?oooa`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00D@3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00X0oooo0P3o018;0?ooo`<0o`00[@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02P3oool00`3o0180oooo0?l04P0:0?ooo`@0o`00[03oool00`000000oooo0?ooo`030?ooo`80
0000>`3oool003l0oooo00<000000?ooo`3oool0703oool40?l04PT0oooo0`3o002]0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool005h0oooo0`3o018;0?ooo`030?l0003o
ool0oooo0:`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00D@3oool0
0`000000oooo0?ooo`0;0?ooo`030?l04P3oool0oooo00X0oooo00<0o`000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0i0?ooo`00D@3oool00`000000oooo0?ooo`0<0?ooo`030?l04P3oool0oooo
00X0oooo00<0o`000?ooo`3oool0/P3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<0o`0B0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`2b0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0303oool00`3o0180oooo0?ooo`0:0?ooo`030?l0003oool0oooo0:/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00d0oooo00<0o`0B0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`2Z0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<00000
0?ooo`3oool06`3oool01@2^0?l0oooo0?ooo`3oool0o`0B00`0oooo00<0o`000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo001?0?ooo`030=/0o`3oool0
oooo00/0oooo00D0[P3o0?ooo`3oool0oooo0?l04P0<0?ooo`030?l0003oool0oooo0:X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00C`3oool20=/0o`030000003oool0
oooo00P0oooo0`2^0?l30?ooo`030?l04P3oool0oooo00X0oooo00<0o`000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0<0?ooo`@0f`3o303oool01@2^
0?l0oooo0?ooo`3oool0o`0B0;l0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?oo
o`3oool03P3oool00`3K0?l000000?ooo`0;0?ooo`030:h0o`3oool0oooo0;X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0>0?ooo`03
0=/0o`000000oooo00/0oooo00<0[P3o0?ooo`3oool0^P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00h0oooo00<0f`3o0?ooo`3oool0
2`3oool00`2^0?l0oooo0?ooo`0<0?ooo`<0o`26Z`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<0f`3o0?ooo`3oool02P3o
ool00`2^0?l0oooo0?l0Q`020?l0Q`X0oooo0`3o08J[0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0>@3oool00540oooo00<0f`3o0?ooo`3oool02`3oool0102^0?l0o`270?ooo`3o
08L;0?ooo`040?l0QP3oool0o`260?l0QZl0oooo0P00000k0?ooo`00D@3oool00`3K0?l0oooo0?oo
o`0;0?ooo`030:h0o`3oool0o`2700<0o`273@3oool00`3o08H0oooo0?ooo`0C0?ooo`030<<0o`3o
ool0oooo09L0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool0
0`000000f`3o0?ooo`0=0?ooo`050?l0Q`3oool0oooo0?ooo`3o08L03@3oool20?l0QQ80oooo0P33
0?lW0?ooo`80^P3oL03oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?
0?ooo`030000003K0?l0oooo0180oooo0P3o08L=0?ooo`030?l0QP3oool0oooo00<0oooo0P3<0?l9
0?ooo`X0``3o7`3oool;0;X0ob40oooo0P2c0?ln0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030?l0Q`3oool0oooo00/0oooo00@0o`260?ooo`3oool0oooo2`3<0?l30?ooo`030<<0o`3oool0
oooo01/0oooo0P350?l80?ooo`<0^P3o8@3oool00`2j0?l0oooo0?ooo`030?ooo`/0/`3o=P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo
02L0oooo00<0o`270?ooo`3oool03`3oool30<`0obL0oooo2`350?l00`3oool0^P3o0?ooo`0P0?oo
o`80^P3o1P3oool30;<0ocd0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?oo
o`00O03oool00`3<0?l0oooo0?ooo`0W0?ooo`<0a@3o:@3oool;0;X0och0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0i0?ooo`00D@3oool00`000000oooo0?ooo`1C0?ooo`030<D0
o`3oool0oooo02X0oooo00<0^P3o0?ooo`3oool0:@3oool20?l0lB00oooo00<000000?ooo`3oool0
>@3oool00540oooo00<000000?ooo`3oool0Y@3oool0103o0?40oooo0?ooo`3oool30?l0lB80oooo
00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`2U0?ooo`80o`3^0P3o0?4N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3o
ool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2M0?ooo`030?l0kP3oool0
oooo0080oooo0`3o0>h20?l0lB00oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i
0?ooo`00?`3oool00`000000oooo0?ooo`2_0?ooo`030?l0kP3oool0oooo0080o`3^00<0oooo0?l0
l@3o0?400P3o0?4P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0
oooo00<000000?ooo`3oool0[P3oool40?l0kRL0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0i0?ooo`00l03oool30?l0kRP0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0i0?ooo`00D@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo000o
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o1`3<0?ooo`030000003oool0
oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00D0
oooo00<0o`P00?ooo`3oool01`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00<0
oooo0P00000k0?ooo`00?`3oool00`000000oooo0?ooo`0V0?ooo`<0A03o/03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo02H0oooo1014
0?n_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool00540oooo00<00000
0?ooo`3oool01`3oool306H0o`/0oooo00@0A03o0?ooo`3oool0A03o]@3oool00`000000oooo0?oo
o`0i0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`<0IP3o3`3oool204@0ok<0oooo00<00000
0?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?oo
o`0406H0o`3oool0IP3o06H0o`l0oooo00<0A03o0?ooo`3oool0/03oool00`000000oooo0?ooo`0i
0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<0IP3o0?oo
o`3oool0^03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`1V0?l0oooo0?ooo`2g0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0
803oool00`1V0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
>@3oool00?l0oooo703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo001A
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`2e0?ooo`80013o5`3oool00`000000oooo0?ooo`0i0?oo
o`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03H0oooo00<004Oo0?ooo`3o
ool0MP3oool00`004?l0oooo0?ooo`03000@oa80oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03D0oooo
0P00Aomh0?ooo`<0013o5@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo
000o0?ooo`030000003oool0oooo04H0oooo2000AolS0?ooo`03001;o`3oool0oooo04`0oooo0P00
0ol00`004?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3o
ool003l0oooo00<000000?ooo`3oool0>`3oool2000`o`/0oooo00<004Oo0?ooo`3oool09@3oool8
001;ob@0oooo00<005?o0?ooo`3oool06`3oool00`000ol0oooo0?ooo`030003oaT0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00O03oool5000`oc80oooo00<004_o0?oo
o`3oool09`3oool8001CoaL0oooo0`000olL0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>@3oool00540oooo00<000000?ooo`3oool0:P3oool00`00<?l0oooo0?ooo`04000`ob<0
oooo0P00>?ld0?ooo`03001Co`3oool0oooo01X0oooo0`000olS0?ooo`800000>`3oool003l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`T003So9@3oool00`00@ol0oooo
0?ooo`1:0?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02P3oool00`3o0000oooo0?ooo`180?ooo`03000ho`3oool0oooo02P0oooo2@00
@oln0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`210?ooo`030013o`3oool0oooo04<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?oo
o`030?l2003oool0oooo0<L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?oo
o`00D@3oool00`3o0P00oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0>@3oool00540oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00D@3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00@0oooo0`0000000`3oool0410@0000
00020000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0903oool003l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`0809RHV0000000oooo0000002HV9P0oooo
09RHV000000V0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0T0?ooo`00?`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0<L0oooo00<000000?la003oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0T0?ooo`00?`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`0409RHV0000000oooo000000<0oooo00<0
00000?ooo`3oool0903oool00?l0oooo703oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0100000000`2HV9P0oooo000000030?ooo`030000003oool0
oooo02@0oooo001A0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`1gMgL0EEEE00@0oooo00D0000009RHV03oool0V9RH0000000V0?ooo`00?`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<40oooo0P3oB00;0?ooo`030000003oool0
oooo00@0oooo00<08B4Q0000003oool00P3oool01P0@410000000000000b<S80oooo09RHV0<00000
00<0V9RH0?ooo`3oool0903oool003l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00<0oooo0P00000k
0?ooo`00?`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000>`3oool003l0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo001A0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
>@3oool00540oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0>@3oool0
03l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo
003o0?oooa`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00D@3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03T0oooo001A0?ooo`030000003oool0oooo
0<h0oooo00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0>@3oool003l0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03T0oooo000o0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00o`3ooolL0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0>@3oool00540oooo00<000000?ooo`3oool0c@3oool2000003/0
oooo000o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0i
0?ooo`00?`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>@3oool00500oooo100000370?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0>@3oool004h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000<0
oooo0`00002j0?ooo`030000003oool0oooo03T0oooo00190?ooo`<00000703oool00`000000oooo
0?ooo`0500000080oooo100000030?ooo`<00000YP3oool00`000000oooo0?ooo`0i0?ooo`00?`3o
ool00`000000oooo0?ooo`050?ooo`800000<`3oool00`000000oooo0?ooo`0500000080oooo1000
00020?ooo`<00000T`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool010000000oooo0?ooo`3o
ool2000004X0oooo0P0000020?ooo`@000000`3oool400000080oooo0`00001h0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003l0oooo00@000000?ooo`0000000000H03o
ool200000080oooo100000020?ooo`D000000P3oool3000006@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0i0?ooo`00?`3oool2000000<0oooo1000001_0?ooo`040000003oool0
oooo0?ooo`@000000P3oool500000080oooo0`00001@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0>@3oool004X0oooo1@0000020?ooo`@000000`3oool300000700oooo00@00000
0?ooo`3oool0oooo100000020?ooo`@000000`3oool3000003`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0i0?ooo`00F`3oool00`000000oooo0?ooo`04000000<0oooo10000002
0?ooo`<00000L@3oool00`000000oooo0?ooo`0500000080oooo100000030?ooo`<00000;`3oool0
0`000000oooo0?ooo`0i0?ooo`00KP3oool200000080oooo100000030?ooo`@00000MP3oool00`00
0000oooo0?ooo`04000000<0oooo1000000P0?ooo`800000>`3oool007l0oooo1@0000020?ooo`@0
00000P3oool500000780oooo1@0000020?ooo`@000000`3oool4000000H0oooo00<000000?ooo`3o
ool00`3oool2000003/0oooo002C0?ooo`@000000`3oool400000080oooo0`00001d0?ooo`D00000
0P3oool5000003/0oooo002S0?ooo`8000000P3oool400000080oooo1@0000020?ooo`<00000I03o
ool010000000oooo0?ooo`3oool3000003`0oooo002g0?ooo`040000003oool0oooo0?ooo`@00000
0P3oool5000005D0oooo00<000000?ooo`3oool00`00000m0?ooo`00b03oool4000000<0oooo1000
00020?ooo`@00000A03oool3000003h0oooo003L0?ooo`@000000P3oool500000080oooo1000000_
0?ooo`<00000?`3oool00?00oooo100000020?ooo`@000000`3oool3000001/0oooo0`0000100?oo
o`00o`3oool10?ooo`030000003oool0oooo00D000000P3oool4000000<0oooo0`0000070?ooo`80
0000@@3oool00?l0oooo5@3oool00`000000oooo0?ooo`0500000480oooo003o0?oooel0oooo003o
0?oooel0oooo003o0?oooah0oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0oooo
03H0oooo003o0?oooal0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000003P0oooo003o
0?oooaX0oooo100000000`2j^[X0000009RHV0030000000309RHV03oool0000003P0oooo003o0?oo
oaX0oooo00D0c<c<0>k^kP3oool0c<c<05EEE@020000000609RHV0000000V9RH0000003oool00000
>03oool00?l0oooo6`3oool0103<c<`0k^k^0?ooo`3oool2000000060?ooo`000000oooo0000003o
ool00000>03oool00?l0oooo5`3oool01`0@41000000010@401gMgL0oooo0:VYZ@1?Cdl00`000000
1P2HV9P000000?ooo`000000oooo000003P0oooo003o0?oooaX0oooo00D0MgMg06IVIP3MgMd00000
09RHV0040000000409RHV0000000V9RH000003P0oooo003o0?oooaX0oooo00D0MgMg0000003oool0
0000024Q8@030000000509RHV000000000000000002HV9P0>03oool00?l0oooo6@3oool01@3MgMd0
00000000002HV9P000000080oooo0P0000000`3oool0V9RH0000000j0?ooo`00o`3ooolH0?ooo`03
05EEE@0@4100000000<000000P3oool01@2HV9P00000000000000000V9RH03X0oooo003o0?oooaX0
oooo00@0^[Zj09RHV03oool000000`3oool00`000000oooo0?ooo`0k0?ooo`00o`3ooolG0?ooo`0;
04A4A02j^[X0oooo0;Zj^P000000oooo0000002HV9P0oooo09RHV0000000?@3oool00?l0oooo5`3o
ool01`3^k^h0A4A4000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0k0?ooo`00
o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00
o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00
o`3ooolJ0?ooo`<0000000<0oooo07MgM`0000000P00000m0?ooo`00o`3ooolK0?ooo`0609RHV01g
MgL0oooo0?ooo`0Q8B40ZJVY?P3oool00?l0oooo703oool0101EEED0V9RH07MgM`1VIVHo0?ooo`00
o`3ooolL0?ooo`030>k^kP0Q8B40<S8b0400oooo003o0?oooa`0oooo00<0k^k^010@400b<S80@03o
ool00?l0oooo703oool0101VIVH0MgMg0:VYZ@1VIVHo0?ooo`00o`3ooolK0?ooo`040:VYZ@0Q8B40
oooo0?ooo`80V9RH00<0k^k^0?ooo`3oool0>`3oool00?l0oooo6P3oool30000000307MgM`3oool0
<S8b0080000000<0^[Zj0?ooo`3oool0>P3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0oooo
G`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0oooo
G`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0ooooG`3oool00?l0oooo
G`3oool00?l0ooooG`3oool00740oooo00H0V9RH010@40000000410@07MgM`3^k^kW0?ooo`00L@3o
ool01P000000^[Zj0?ooo`3^k^h0QhN7038b<^L0oooo001a0?ooo`0607MgM`3^k^h0oooo0?ooo`3M
gMd00000i`3oool00640oooo0`000000103oool0^[Zj04A4A03oool3000000070?ooo`2HV9P00000
09RHV00Q8B40EEEE07MgM`0300000003010@4027QhL000000080000000L0oooo000000000000V9RH
0000000@4100c<c<0080oooo00<0ZJVY038b<P0000001`000000202HV9P0000009RHV00Q8B40EEEE
0?ooo`2YZJT0<S8b0`0000001P2HV9P00000000000000000V9RH0?ooo`<0000000<0oooo00000000
00001@3oool6000000030?ooo`000000000000<0oooo1P0000002@2HV9P00000000000000000V9RH
0000000@4100c<c<0?ooo`03000000040?ooo`00000000000?ooo`80000000D0V9RH0000000@4100
c<c<0?ooo`03000000060?ooo`00000000000?ooo`2YZJT0<S8b1P3oool00`000000oooo00000007
0?ooo`<0000000<0oooo09RHV00000000P0000001@2HV9P0oooo0?ooo`2HV9P0A4A406H0oooo001Q
0?ooo`0B0=gMg@000000c<c<0?ooo`0b<S8000000=gMg@3^k^h000000>k^kP3oool0000009RHV03M
gMd000000>k^kP0b<S80gMgM1@3oool02@000000oooo0?ooo`000000oooo0000002HV9P0^[Zj010@
40020?ooo`070000003oool0oooo0000003oool0c<c<024Q8@020?ooo`08038b<P000000V9RH0=gM
g@000000k^k^0?ooo`0000020?ooo`070000003oool0000009RHV03oool0V9RH000000020?ooo`04
0000003oool0oooo000000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`0=0000003oool0oooo0?ooo`2YZJT0A4A40?ooo`000000oooo0000002HV9P0^[Zj010@4002
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`000000V9RH0;Zj^P0@41020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool0100b<S80^[Zj038b<P2j^[X7
0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV00000020?ooo`030>k^kP000000k^k^06D0
oooo001R0?ooo`040000003oool0^[Zj038b<P80MgMg00h0oooo0000003oool0oooo0000002HV9P0
oooo0000003oool0gMgM024Q8@000000410@0:VYZ@80oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`040000003oool0oooo00000080oooo00P0V9RH05EEE@3oool0oooo0000002HV9P0oooo
00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00D0oooo00@0<S8b0;Zj^P0b<S80^[Zj1`3oool010000000oooo0?ooo`0000030?ooo`06
0000003oool0oooo0?ooo`14A4@0ZJVYI@3oool00680oooo00P000000?ooo`0b<S80ZJVY0>k^kP0@
4100oooo00000080oooo00X0V9RH00000000000000000?ooo`0Q8B40QhN70?ooo`3MgMd000000P3o
ool01@000000oooo0?ooo`000000oooo00@000000P3oool010000000oooo0?ooo`0000030?ooo`04
05EEE@2HV9P0oooo09RHV0<000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00<000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo1@0000070?ooo`040000003o
ool0oooo000000<0oooo00H000000?ooo`3oool0oooo09RHV01EEEEU0?ooo`00HP3oool00`000000
^[Zj010@40020?ooo`0305EEE@2YZJT0000000@0oooo00P0V9RH0000003oool000000<c<c03oool0
QhN700000080oooo00H000000<c<c02HV9P000000?ooo`00000209RHV0040000003oool0oooo0000
0080oooo00L000000?ooo`1VIVH0oooo0>k^kP0Q8B40c<c<0080oooo00D0V9RH0000003oool0oooo
000000020?ooo`070000003oool0000009RHV03oool0V9RH000000020?ooo`040000003<c<`0V9RH
000000L0oooo00L000000?ooo`3oool000000<c<c02HV9P0000000D0oooo100000030?ooo`030000
003oool000000080V9RH00@000000?ooo`3oool000000P3<c<`01P000000^[Zj0<c<c0000000oooo
00000080V9RH00L000000?ooo`3oool000000<c<c02HV9P000000080oooo00<000000?ooo`3oool0
1@3oool407MgM`L0oooo00@000000?ooo`3oool000000`3oool01P000000oooo0?ooo`3oool0k^k^
000006D0oooo001R0?ooo`030000000b<S80V9RH0080oooo00<0gMgM04A4A00000000P3oool02`14
A4@000000000002HV9P0oooo0<c<c00@4100000004A4A03^k^h0oooo0080000000D0V9RH0000002H
V9P0oooo09RHV0020000000309RHV03oool0000000@0000000<0oooo0000000000000`0000001@14
A4@000000000002HV9P0oooo00D0000000<0oooo09RHV00000000P0000001`2HV9P0oooo00000000
0000V9RH0000002HV9P01P3oool2000000060?ooo`000000000009RHV0000000V9RH1@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0V9RH0080000000`0V9RH0?ooo`000000000009RH
V0000000QhN709RHV0000000V9RH0?ooo`2HV9P20000000809RHV03oool000000000002HV9P00000
09RHV03oool3000000H0oooo1@0000060?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`0Q8B40ZJVY0?ooo`1S0?ooo`00H@3oool00`3^k^h00000010@40040?ooo`03
038b<P000000k^k^01L0oooo00<0QhN70000003oool03@3oool00`27QhL000000?ooo`0Q0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0H0?ooo`0308N7Q`000000oooo
00H0oooo00@0^[Zj038b<P2j^[X0<S8b1`3oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P0
00000?ooo`0Q8B40^[Zj0?ooo`27QhL0EEEEI03oool00640oooo0P0000000`2HV9P0oooo0?ooo`02
0?ooo`030:VYZ@000000000001P0oooo00@0<S8b0?ooo`3oool0<S8b303oool0100b<S80oooo0?oo
o`0b<S8C0?ooo`03038b<P3oool0oooo00P0oooo1P0000000`3oool000000000000K0?ooo`03038b
<P3oool0oooo00H0oooo00<000000?ooo`0000001P3oool01@0Q8B4000000?ooo`3oool0V9RH00<0
000000<0V9RH0?ooo`1gMgL00`0000000`0@4100oooo0?ooo`1R0?ooo`00o`3ooomO0?ooo`00o`3o
oomO0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 349}, {349, 0}} -> {-0.027412, -5.06255*^-6, \
0.00302242, 0.00302242}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RadPlot3DOptions[];\)\n\), "\n", 
    \(\(ListPlotVectorField3D[radObjM[t]\n, VectorHeads -> True\n, 
        ColorFunction -> \ Hue\n, 
        PlotLabel -> "\<Magnetization in Element # \>" <> ToString[t]\n, 
        ViewPoint -> {3, 2\ , \ 0}\n, PlotRange -> {All, All, All}\ \n, 
        ScaleFactor -> 8];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.5 1.0125 -79.1562 0 ]
[.5 1.0125 79.1562 14 ]
[.82613 .88094 -12.125 0 ]
[.82613 .88094 12.125 14 ]
[.81023 .88535 -5 0 ]
[.81023 .88535 5 14 ]
[.79395 .88987 -8 0 ]
[.79395 .88987 8 14 ]
[.81023 .94785 -7.8125 0 ]
[.81023 .94785 7.8125 14 ]
[.20953 .16104 -15.125 -14 ]
[.20953 .16104 15.125 0 ]
[.33375 .14923 -15.125 -14 ]
[.33375 .14923 15.125 0 ]
[.46729 .13653 -5 -14 ]
[.46729 .13653 5 0 ]
[.61125 .12283 -11 -14 ]
[.61125 .12283 11 0 ]
[.7669 .10803 -11 -14 ]
[.7669 .10803 11 0 ]
[.46729 .07403 -7.8125 -14 ]
[.46729 .07403 7.8125 0 ]
[.84997 .15361 0 -5.14139 ]
[.84997 .15361 30.25 8.85861 ]
[.85028 .32685 0 -6.0707 ]
[.85028 .32685 30.25 7.9293 ]
[.85039 .5 0 -7 ]
[.85039 .5 10 7 ]
[.85028 .67315 0 -7.9293 ]
[.85028 .67315 22 6.0707 ]
[.84997 .84639 0 -8.85861 ]
[.84997 .84639 22 5.14139 ]
[.91289 .5 0 -7 ]
[.91289 .5 14.3125 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -140.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnetization) show
135.125 14.000 moveto
(in) show
147.438 14.000 moveto
(Element) show
190.312 14.000 moveto
(#) show
199.312 14.000 moveto
(111) show
217.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
[ ] 0 setdash
.83789 .86518 m
.78139 .88085 L
s
.25 Mabswid
.82613 .86844 m
.82613 .86219 L
s
gsave
.82613 .88094 -73.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.81023 .87285 m
.81023 .8666 L
s
gsave
.81023 .88535 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.79395 .87737 m
.79395 .87112 L
s
gsave
.79395 .88987 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.82219 .86953 m
.82219 .86578 L
s
.81823 .87063 m
.81823 .86688 L
s
.81424 .87174 m
.81424 .86799 L
s
.8062 .87397 m
.8062 .87022 L
s
.80214 .87509 m
.80214 .87134 L
s
.79805 .87623 m
.79805 .87248 L
s
.83004 .86735 m
.83004 .8636 L
s
.83393 .86627 m
.83393 .86252 L
s
.8378 .8652 m
.8378 .86145 L
s
.78982 .87851 m
.78982 .87476 L
s
.78566 .87966 m
.78566 .87591 L
s
.78148 .88082 m
.78148 .87707 L
s
gsave
.81023 .94785 -68.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.19888 .17456 m
.78139 .11915 L
s
.25 Mabswid
.20953 .17354 m
.20953 .17979 L
s
gsave
.20953 .16104 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.33375 .16173 m
.33375 .16798 L
s
gsave
.33375 .14923 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.46729 .14903 m
.46729 .15528 L
s
gsave
.46729 .13653 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.61125 .13533 m
.61125 .14158 L
s
gsave
.61125 .12283 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7669 .12053 m
.7669 .12678 L
s
gsave
.7669 .10803 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.23368 .17125 m
.23368 .175 L
s
.25816 .16892 m
.25816 .17267 L
s
.283 .16655 m
.283 .1703 L
s
.30819 .16416 m
.30819 .16791 L
s
.35967 .15926 m
.35967 .16301 L
s
.38598 .15676 m
.38598 .16051 L
s
.41268 .15422 m
.41268 .15797 L
s
.43978 .15164 m
.43978 .15539 L
s
.49521 .14637 m
.49521 .15012 L
s
.52355 .14367 m
.52355 .14742 L
s
.55234 .14094 m
.55234 .14469 L
s
.58156 .13816 m
.58156 .14191 L
s
.6414 .13247 m
.6414 .13622 L
s
.67203 .12955 m
.67203 .1333 L
s
.70314 .12659 m
.70314 .13034 L
s
.73476 .12359 m
.73476 .12734 L
s
gsave
.46729 .07403 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.83789 .13482 m
.83789 .86518 L
s
.25 Mabswid
.83789 .1504 m
.83184 .1488 L
s
gsave
.84997 .15361 -61 -9.14139 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.83789 .3252 m
.83169 .32438 L
s
gsave
.85028 .32685 -61 -10.0707 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.83789 .5 m
.83164 .5 L
s
gsave
.85039 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.83789 .6748 m
.83169 .67562 L
s
gsave
.85028 .67315 -61 -11.9293 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.83789 .8496 m
.83184 .8512 L
s
gsave
.84997 .84639 -61 -12.8586 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.83789 .18536 m
.83424 .18449 L
s
.83789 .22032 m
.83422 .21954 L
s
.83789 .25528 m
.8342 .2546 L
s
.83789 .29024 m
.83418 .28965 L
s
.83789 .36016 m
.83416 .35977 L
s
.83789 .39512 m
.83415 .39482 L
s
.83789 .43008 m
.83414 .42988 L
s
.83789 .46504 m
.83414 .46494 L
s
.83789 .53496 m
.83414 .53506 L
s
.83789 .56992 m
.83414 .57012 L
s
.83789 .60488 m
.83415 .60518 L
s
.83789 .63984 m
.83416 .64023 L
s
.83789 .70976 m
.83418 .71035 L
s
.83789 .74472 m
.8342 .7454 L
s
.83789 .77968 m
.83422 .78046 L
s
.83789 .81464 m
.83424 .81551 L
s
gsave
.91289 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.26805 .18607 m
.26805 .81393 L
s
.26805 .81393 m
.83789 .86518 L
s
.83789 .86518 m
.83789 .13482 L
s
.83789 .13482 m
.26805 .18607 L
s
.19888 .17456 m
.78139 .11915 L
s
.78139 .11915 m
.78139 .88085 L
s
.78139 .88085 m
.19888 .82544 L
s
.19888 .82544 m
.19888 .17456 L
s
.26805 .18607 m
.26805 .81393 L
s
.26805 .81393 m
.19888 .82544 L
s
.19888 .82544 m
.19888 .17456 L
s
.19888 .17456 m
.26805 .18607 L
s
.83789 .13482 m
.78139 .11915 L
s
.78139 .11915 m
.78139 .88085 L
s
.78139 .88085 m
.83789 .86518 L
s
.83789 .86518 m
.83789 .13482 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .285 0 r
.5 Mabswid
[ ] 0 setdash
.27502 .48759 m
.27503 .48753 L
s
.27503 .48753 m
.27492 .48746 L
s
.27503 .48753 m
.2749 .48761 L
s
.2749 .48761 m
.27502 .48759 L
s
.27492 .48746 m
.2749 .48761 L
s
.2749 .48761 m
.27492 .48752 L
s
.27525 .48717 m
.2749 .48761 L
s
.27492 .48746 m
.27492 .48752 L
s
.27492 .48752 m
.27502 .48759 L
s
.27525 .51283 m
.27559 .51327 L
s
.27558 .51318 m
.27547 .51324 L
s
.27557 .51312 m
.27558 .51318 L
s
.27559 .51327 m
.27558 .51318 L
s
.27547 .51324 m
.27547 .51318 L
s
.27559 .51327 m
.27547 .51324 L
s
.27547 .51318 m
.27557 .51312 L
s
.27557 .51312 m
.27559 .51327 L
s
.27547 .51318 m
.27559 .51327 L
s
0 .015 1 r
.29111 .49188 m
.29101 .49141 L
s
.29101 .49141 m
.28946 .49094 L
s
.29101 .49141 m
.28977 .49288 L
s
.28946 .49094 m
.28956 .4914 L
s
.28946 .49094 m
.28977 .49288 L
s
.28977 .49288 m
.29111 .49188 L
s
.28977 .49288 m
.28956 .4914 L
s
.29236 .4855 m
.28977 .49288 L
s
.28956 .4914 m
.29111 .49188 L
s
.29236 .5145 m
.29496 .5219 L
s
.29517 .52041 m
.29362 .52089 L
s
.29527 .51995 m
.29517 .52041 L
s
.29496 .5219 m
.29517 .52041 L
s
.29362 .52089 m
.29372 .52043 L
s
.29496 .5219 m
.29362 .52089 L
s
.29527 .51995 m
.29496 .5219 L
s
.29372 .52043 m
.29496 .5219 L
s
.29372 .52043 m
.29527 .51995 L
s
1 0 .93 r
.30615 .50168 m
.306 .50108 L
s
.306 .50108 m
.30402 .50049 L
s
.306 .50108 m
.30443 .50297 L
s
.30402 .50049 m
.30417 .50108 L
s
.30402 .50049 m
.30443 .50297 L
s
0 .264 1 r
.30619 .46086 m
.30625 .46011 L
s
.30625 .46011 m
.30497 .45934 L
s
.30625 .46011 m
.30473 .46119 L
s
1 0 .93 r
.30443 .50297 m
.30615 .50168 L
s
.30443 .50297 m
.30417 .50108 L
s
.30771 .49353 m
.30443 .50297 L
s
0 .264 1 r
.30473 .46119 m
.30619 .46086 L
s
.30497 .45934 m
.30473 .46119 L
s
.30473 .46119 m
.3049 .46009 L
s
.30898 .45575 m
.30473 .46119 L
s
.30497 .45934 m
.3049 .46009 L
s
1 0 .93 r
.30417 .50108 m
.30615 .50168 L
s
0 .264 1 r
.3049 .46009 m
.30619 .46086 L
s
1 0 .93 r
.30771 .50647 m
.311 .51593 L
s
.31125 .51403 m
.30927 .51463 L
s
.31141 .51345 m
.31125 .51403 L
s
.311 .51593 m
.31125 .51403 L
s
0 .264 1 r
.30898 .54425 m
.31323 .5497 L
s
1 0 .93 r
.30927 .51463 m
.30943 .51405 L
s
.311 .51593 m
.30927 .51463 L
s
1 .195 0 r
.25584 .48734 m
.25585 .4873 L
s
.25585 .4873 m
.25577 .48725 L
s
.25585 .4873 m
.25576 .48736 L
s
.25576 .48736 m
.25584 .48734 L
s
.25577 .48725 m
.25576 .48736 L
s
.25576 .48736 m
.25577 .48729 L
s
.256 .48704 m
.25576 .48736 L
s
.25577 .48725 m
.25577 .48729 L
s
.25577 .48729 m
.25584 .48734 L
s
1 0 .93 r
.31141 .51345 m
.311 .51593 L
s
.30943 .51405 m
.311 .51593 L
s
1 .195 0 r
.256 .51296 m
.25625 .51328 L
s
0 .264 1 r
.31305 .54859 m
.31177 .54937 L
s
.31299 .54785 m
.31305 .54859 L
s
.31323 .5497 m
.31305 .54859 L
s
1 .195 0 r
.25624 .51321 m
.25616 .51326 L
s
.25623 .51317 m
.25624 .51321 L
s
.25625 .51328 m
.25624 .51321 L
s
.25616 .51326 m
.25616 .51321 L
s
.25625 .51328 m
.25616 .51326 L
s
.25616 .51321 m
.25623 .51317 L
s
.25623 .51317 m
.25625 .51328 L
s
.25616 .51321 m
.25625 .51328 L
s
1 0 .93 r
.30943 .51405 m
.31141 .51345 L
s
0 .264 1 r
.31177 .54937 m
.3117 .54863 L
s
.31323 .5497 m
.31177 .54937 L
s
.3117 .54863 m
.31299 .54785 L
s
.31299 .54785 m
.31323 .5497 L
s
.3117 .54863 m
.31323 .5497 L
s
.729 0 1 r
.32083 .48155 m
.32091 .48058 L
s
.32091 .48058 m
.31928 .4796 L
s
.32091 .48058 m
.31898 .48195 L
s
.31898 .48195 m
.32083 .48155 L
s
.31928 .4796 m
.31898 .48195 L
s
.31898 .48195 m
.3192 .48057 L
s
.32438 .47507 m
.31898 .48195 L
s
.31928 .4796 m
.3192 .48057 L
s
.3192 .48057 m
.32083 .48155 L
s
.32438 .52493 m
.32979 .53183 L
s
0 .066 1 r
.272 .49173 m
.2719 .49127 L
s
.2719 .49127 m
.27035 .49081 L
s
.2719 .49127 m
.27067 .49274 L
s
.27035 .49081 m
.27045 .49126 L
s
.27035 .49081 m
.27067 .49274 L
s
.27067 .49274 m
.272 .49173 L
s
.27067 .49274 m
.27045 .49126 L
s
.2732 .48535 m
.27067 .49274 L
s
.729 0 1 r
.32956 .53044 m
.32793 .53142 L
s
.32949 .52948 m
.32956 .53044 L
s
.32979 .53183 m
.32956 .53044 L
s
0 .066 1 r
.27045 .49126 m
.272 .49173 L
s
.729 0 1 r
.32793 .53142 m
.32786 .53047 L
s
.32979 .53183 m
.32793 .53142 L
s
0 .222 1 r
.33016 .43027 m
.33021 .42954 L
s
.33021 .42954 m
.3289 .42874 L
s
.33021 .42954 m
.32866 .43063 L
s
0 .066 1 r
.2732 .51465 m
.27573 .52206 L
s
0 .222 1 r
.32866 .43063 m
.33016 .43027 L
s
.3289 .42874 m
.32866 .43063 L
s
.32866 .43063 m
.32885 .42948 L
s
.33299 .42502 m
.32866 .43063 L
s
.3289 .42874 m
.32885 .42948 L
s
0 .066 1 r
.27595 .52057 m
.2744 .52103 L
s
.27605 .52012 m
.27595 .52057 L
s
.27573 .52206 m
.27595 .52057 L
s
.729 0 1 r
.32786 .53047 m
.32949 .52948 L
s
.32949 .52948 m
.32979 .53183 L
s
0 .066 1 r
.2744 .52103 m
.2745 .52058 L
s
.27573 .52206 m
.2744 .52103 L
s
.729 0 1 r
.32786 .53047 m
.32979 .53183 L
s
0 .222 1 r
.32885 .42948 m
.33016 .43027 L
s
0 .066 1 r
.27605 .52012 m
.27573 .52206 L
s
.2745 .52058 m
.27573 .52206 L
s
.2745 .52058 m
.27605 .52012 L
s
0 .222 1 r
.33299 .57498 m
.33733 .5806 L
s
.33714 .57944 m
.33583 .58024 L
s
.33709 .57871 m
.33714 .57944 L
s
.33733 .5806 m
.33714 .57944 L
s
.33583 .58024 m
.33579 .5795 L
s
.33733 .5806 m
.33583 .58024 L
s
.33579 .5795 m
.33709 .57871 L
s
.33709 .57871 m
.33733 .5806 L
s
.33579 .5795 m
.33733 .5806 L
s
1 0 .945 r
.2871 .50168 m
.28696 .50109 L
s
.28696 .50109 m
.28497 .50051 L
s
.28696 .50109 m
.28539 .503 L
s
.28497 .50051 m
.2851 .5011 L
s
.28497 .50051 m
.28539 .503 L
s
0 .326 1 r
.28713 .46037 m
.28721 .45963 L
s
.28721 .45963 m
.28593 .45886 L
s
.28721 .45963 m
.2857 .4607 L
s
1 0 .945 r
.28539 .503 m
.2871 .50168 L
s
.28539 .503 m
.2851 .5011 L
s
.28862 .49346 m
.28539 .503 L
s
0 .326 1 r
.2857 .4607 m
.28713 .46037 L
s
.28593 .45886 m
.2857 .4607 L
s
.2857 .4607 m
.28586 .4596 L
s
.28989 .45529 m
.2857 .4607 L
s
.28593 .45886 m
.28586 .4596 L
s
.771 0 1 r
.34503 .45099 m
.34509 .45005 L
s
.34509 .45005 m
.34344 .44906 L
s
.34509 .45005 m
.34314 .45145 L
s
1 0 .945 r
.2851 .5011 m
.2871 .50168 L
s
0 .326 1 r
.28586 .4596 m
.28713 .46037 L
s
.771 0 1 r
.34314 .45145 m
.34503 .45099 L
s
.34344 .44906 m
.34314 .45145 L
s
.34314 .45145 m
.34338 .45 L
s
.3486 .44434 m
.34314 .45145 L
s
.34344 .44906 m
.34338 .45 L
s
1 0 .945 r
.28862 .50654 m
.29186 .5161 L
s
.771 0 1 r
.34338 .45 m
.34503 .45099 L
s
1 0 .945 r
.29214 .51418 m
.29014 .51477 L
s
.29228 .5136 m
.29214 .51418 L
s
.29186 .5161 m
.29214 .51418 L
s
0 .326 1 r
.28989 .54471 m
.2941 .55013 L
s
1 0 .945 r
.29014 .51477 m
.29028 .51419 L
s
.29186 .5161 m
.29014 .51477 L
s
1 .195 0 r
.2362 .48721 m
.23621 .48716 L
s
.23621 .48716 m
.23613 .48712 L
s
.23621 .48716 m
.23612 .48723 L
s
.23612 .48723 m
.2362 .48721 L
s
.23613 .48712 m
.23612 .48723 L
s
.23612 .48723 m
.23612 .48716 L
s
.23636 .48691 m
.23612 .48723 L
s
.23613 .48712 m
.23612 .48716 L
s
.23612 .48716 m
.2362 .48721 L
s
1 0 .945 r
.29228 .5136 m
.29186 .5161 L
s
.29028 .51419 m
.29186 .5161 L
s
0 .326 1 r
.29393 .54902 m
.29265 .5498 L
s
.29386 .54828 m
.29393 .54902 L
s
.2941 .55013 m
.29393 .54902 L
s
1 .195 0 r
.23636 .51309 m
.2366 .51341 L
s
.2366 .51335 m
.23652 .5134 L
s
.23659 .5133 m
.2366 .51335 L
s
.2366 .51341 m
.2366 .51335 L
s
.23652 .5134 m
.23651 .51335 L
s
.2366 .51341 m
.23652 .5134 L
s
.23651 .51335 m
.23659 .5133 L
s
.23659 .5133 m
.2366 .51341 L
s
.23651 .51335 m
.2366 .51341 L
s
1 0 .945 r
.29028 .51419 m
.29228 .5136 L
s
0 .326 1 r
.29265 .5498 m
.29258 .54906 L
s
.2941 .55013 m
.29265 .5498 L
s
.771 0 1 r
.3486 .55566 m
.35408 .56279 L
s
0 .326 1 r
.29258 .54906 m
.29386 .54828 L
s
.29386 .54828 m
.2941 .55013 L
s
.29258 .54906 m
.2941 .55013 L
s
.771 0 1 r
.35384 .56133 m
.35219 .56233 L
s
.35379 .56039 m
.35384 .56133 L
s
.35408 .56279 m
.35384 .56133 L
s
.35219 .56233 m
.35213 .56139 L
s
.35408 .56279 m
.35219 .56233 L
s
0 .19 1 r
.3544 .39919 m
.35445 .39844 L
s
.35445 .39844 m
.35314 .39762 L
s
.35445 .39844 m
.35287 .39954 L
s
.35287 .39954 m
.3544 .39919 L
s
.35314 .39762 m
.35287 .39954 L
s
.35287 .39954 m
.35308 .39837 L
s
.35734 .39387 m
.35287 .39954 L
s
.35314 .39762 m
.35308 .39837 L
s
.771 0 1 r
.35213 .56139 m
.35379 .56039 L
s
.35379 .56039 m
.35408 .56279 L
s
.35213 .56139 m
.35408 .56279 L
s
0 .19 1 r
.35308 .39837 m
.3544 .39919 L
s
.702 0 1 r
.30182 .48132 m
.30191 .48035 L
s
.30191 .48035 m
.30027 .47937 L
s
.30191 .48035 m
.29997 .48172 L
s
.29997 .48172 m
.30182 .48132 L
s
.30027 .47937 m
.29997 .48172 L
s
.29997 .48172 m
.30018 .48033 L
s
.30537 .47481 m
.29997 .48172 L
s
.30027 .47937 m
.30018 .48033 L
s
0 .19 1 r
.35734 .60613 m
.36181 .6118 L
s
.702 0 1 r
.30018 .48033 m
.30182 .48132 L
s
0 .19 1 r
.3616 .61062 m
.36029 .61145 L
s
.36155 .60988 m
.3616 .61062 L
s
.36181 .6118 m
.3616 .61062 L
s
.36029 .61145 m
.36024 .61071 L
s
.36181 .6118 m
.36029 .61145 L
s
.702 0 1 r
.30537 .52519 m
.31079 .53213 L
s
0 .19 1 r
.36024 .61071 m
.36155 .60988 L
s
.36155 .60988 m
.36181 .6118 L
s
.36024 .61071 m
.36181 .6118 L
s
0 .066 1 r
.25243 .49164 m
.25235 .49118 L
s
.25235 .49118 m
.25078 .49071 L
s
.25235 .49118 m
.2511 .49267 L
s
.25078 .49071 m
.25086 .49117 L
s
.25078 .49071 m
.2511 .49267 L
s
.2511 .49267 m
.25243 .49164 L
s
.2511 .49267 m
.25086 .49117 L
s
.25364 .4852 m
.2511 .49267 L
s
.702 0 1 r
.31056 .53072 m
.30893 .53171 L
s
.31048 .52976 m
.31056 .53072 L
s
.31079 .53213 m
.31056 .53072 L
s
0 .066 1 r
.25086 .49117 m
.25243 .49164 L
s
.702 0 1 r
.30893 .53171 m
.30884 .53075 L
s
.31079 .53213 m
.30893 .53171 L
s
0 .295 1 r
.31123 .42945 m
.31129 .42872 L
s
.31129 .42872 m
.31 .42793 L
s
.31129 .42872 m
.30976 .4298 L
s
0 .066 1 r
.25364 .5148 m
.25618 .52229 L
s
0 .295 1 r
.30976 .4298 m
.31123 .42945 L
s
.31 .42793 m
.30976 .4298 L
s
.30976 .4298 m
.30993 .42866 L
s
.31403 .42424 m
.30976 .4298 L
s
.31 .42793 m
.30993 .42866 L
s
0 .066 1 r
.25641 .52078 m
.25484 .52125 L
s
.2565 .52033 m
.25641 .52078 L
s
.25618 .52229 m
.25641 .52078 L
s
.702 0 1 r
.30884 .53075 m
.31048 .52976 L
s
.31048 .52976 m
.31079 .53213 L
s
0 .066 1 r
.25484 .52125 m
.25493 .5208 L
s
.25618 .52229 m
.25484 .52125 L
s
.702 0 1 r
.30884 .53075 m
.31079 .53213 L
s
.797 0 1 r
.3694 .41987 m
.36944 .41891 L
s
.36944 .41891 m
.3678 .41788 L
s
.36944 .41891 m
.36746 .42029 L
s
0 .295 1 r
.30993 .42866 m
.31123 .42945 L
s
.797 0 1 r
.36746 .42029 m
.3694 .41987 L
s
.3678 .41788 m
.36746 .42029 L
s
.36746 .42029 m
.36775 .41883 L
s
.37317 .41319 m
.36746 .42029 L
s
.3678 .41788 m
.36775 .41883 L
s
0 .066 1 r
.2565 .52033 m
.25618 .52229 L
s
.25493 .5208 m
.25618 .52229 L
s
.25493 .5208 m
.2565 .52033 L
s
.797 0 1 r
.36775 .41883 m
.3694 .41987 L
s
0 .295 1 r
.31403 .57576 m
.31831 .58133 L
s
.31813 .58018 m
.31683 .58097 L
s
.31807 .57946 m
.31813 .58018 L
s
.31831 .58133 m
.31813 .58018 L
s
.31683 .58097 m
.31677 .58024 L
s
.31831 .58133 m
.31683 .58097 L
s
.797 0 1 r
.37317 .58681 m
.37889 .59394 L
s
0 .295 1 r
.31677 .58024 m
.31807 .57946 L
s
.31807 .57946 m
.31831 .58133 L
s
.4 0 1 r
.3762 .37698 m
.3767 .37579 L
s
.3767 .37579 m
.37563 .37449 L
s
.3767 .37579 m
.3745 .37628 L
s
0 .295 1 r
.31677 .58024 m
.31831 .58133 L
s
.4 0 1 r
.3745 .37628 m
.3762 .37698 L
s
.37563 .37449 m
.3745 .37628 L
s
.3745 .37628 m
.37513 .37568 L
s
.38158 .37357 m
.3745 .37628 L
s
.37563 .37449 m
.37513 .37568 L
s
.797 0 1 r
.37859 .59247 m
.37694 .59351 L
s
.37855 .59152 m
.37859 .59247 L
s
.37889 .59394 m
.37859 .59247 L
s
.4 0 1 r
.37513 .37568 m
.3762 .37698 L
s
.797 0 1 r
.37694 .59351 m
.3769 .59256 L
s
.37889 .59394 m
.37694 .59351 L
s
1 0 .945 r
.26761 .5017 m
.26748 .50111 L
s
.26748 .50111 m
.26546 .50051 L
s
.26748 .50111 m
.26588 .50303 L
s
.26546 .50051 m
.26558 .50111 L
s
.26546 .50051 m
.26588 .50303 L
s
0 .326 1 r
.26764 .45996 m
.26772 .45921 L
s
.26772 .45921 m
.26643 .45843 L
s
.26772 .45921 m
.26619 .46029 L
s
1 0 .945 r
.26588 .50303 m
.26761 .5017 L
s
.26588 .50303 m
.26558 .50111 L
s
.26913 .49339 m
.26588 .50303 L
s
0 .326 1 r
.26619 .46029 m
.26764 .45996 L
s
.26643 .45843 m
.26619 .46029 L
s
.26619 .46029 m
.26634 .45918 L
s
.27041 .45482 m
.26619 .46029 L
s
.797 0 1 r
.3769 .59256 m
.37855 .59152 L
s
.37855 .59152 m
.37889 .59394 L
s
0 .326 1 r
.26643 .45843 m
.26634 .45918 L
s
.797 0 1 r
.3769 .59256 m
.37889 .59394 L
s
1 0 .528 r
.38154 .39645 m
.38215 .39496 L
s
.38215 .39496 m
.38082 .39335 L
s
.38215 .39496 m
.37942 .39557 L
s
.37942 .39557 m
.38154 .39645 L
s
.38082 .39335 m
.37942 .39557 L
s
.37942 .39557 m
.38022 .39484 L
s
.38824 .39221 m
.37942 .39557 L
s
.73 0 1 r
.32615 .45042 m
.32622 .44948 L
s
.32622 .44948 m
.32456 .44848 L
s
.32622 .44948 m
.32426 .45087 L
s
1 0 .945 r
.26558 .50111 m
.26761 .5017 L
s
0 .326 1 r
.26634 .45918 m
.26764 .45996 L
s
.73 0 1 r
.32426 .45087 m
.32615 .45042 L
s
.32456 .44848 m
.32426 .45087 L
s
.32426 .45087 m
.32449 .44943 L
s
.32972 .44376 m
.32426 .45087 L
s
.32456 .44848 m
.32449 .44943 L
s
1 0 .528 r
.38082 .39335 m
.38022 .39484 L
s
1 0 .945 r
.26913 .50661 m
.27239 .51627 L
s
1 0 .528 r
.38022 .39484 m
.38154 .39645 L
s
.4 0 1 r
.38158 .62643 m
.38868 .62915 L
s
.73 0 1 r
.32449 .44943 m
.32615 .45042 L
s
1 0 .945 r
.27268 .51433 m
.27066 .51493 L
s
.27281 .51374 m
.27268 .51433 L
s
.27239 .51627 m
.27268 .51433 L
s
0 .326 1 r
.27041 .54518 m
.27464 .55065 L
s
1 0 .945 r
.27066 .51493 m
.27079 .51434 L
s
.27239 .51627 m
.27066 .51493 L
s
1 .011 0 r
.38428 .35003 m
.38429 .35004 L
s
.38428 .35002 m
.38428 .35003 L
s
.38429 .35003 m
.38428 .35003 L
s
.38429 .35003 m
.38429 .35004 L
s
.38428 .35002 m
.38429 .35003 L
s
.38429 .35003 m
.38429 .35003 L
s
.38424 .35006 m
.38429 .35003 L
s
.38429 .35004 m
.38429 .35003 L
s
.38429 .35003 m
.38428 .35002 L
s
.38424 .64994 m
.38418 .6499 L
s
.38419 .64992 m
.38419 .64991 L
s
.38419 .64991 m
.3842 .6499 L
s
.38419 .64991 m
.38418 .6499 L
s
.3842 .6499 m
.3842 .64991 L
s
.3842 .6499 m
.38418 .6499 L
s
.3842 .64991 m
.38419 .64992 L
s
.38418 .6499 m
.38419 .64992 L
s
.38418 .6499 m
.3842 .64991 L
s
1 .285 0 r
.21608 .4872 m
.21609 .48713 L
s
.21609 .48713 m
.21598 .48707 L
s
.21609 .48713 m
.21596 .48722 L
s
.21596 .48722 m
.21608 .4872 L
s
.21598 .48707 m
.21596 .48722 L
s
.21596 .48722 m
.21597 .48713 L
s
.21631 .48677 m
.21596 .48722 L
s
.21598 .48707 m
.21597 .48713 L
s
.21597 .48713 m
.21608 .4872 L
s
1 0 .945 r
.27281 .51374 m
.27239 .51627 L
s
.27079 .51434 m
.27239 .51627 L
s
0 .326 1 r
.27448 .54954 m
.27319 .55032 L
s
.2744 .54879 m
.27448 .54954 L
s
.27464 .55065 m
.27448 .54954 L
s
1 .285 0 r
.21631 .51323 m
.21665 .51369 L
s
.21664 .51359 m
.21653 .51366 L
s
.21663 .51353 m
.21664 .51359 L
s
.21665 .51369 m
.21664 .51359 L
s
.21653 .51366 m
.21652 .51359 L
s
.21665 .51369 m
.21653 .51366 L
s
1 0 .945 r
.27079 .51434 m
.27281 .51374 L
s
1 .285 0 r
.21652 .51359 m
.21663 .51353 L
s
.21663 .51353 m
.21665 .51369 L
s
.21652 .51359 m
.21665 .51369 L
s
0 .326 1 r
.27319 .55032 m
.2731 .54957 L
s
.27464 .55065 m
.27319 .55032 L
s
.4 0 1 r
.38803 .62855 m
.38697 .62986 L
s
.38754 .62736 m
.38803 .62855 L
s
.38868 .62915 m
.38803 .62855 L
s
.73 0 1 r
.32972 .55624 m
.33519 .56338 L
s
0 .326 1 r
.2731 .54957 m
.2744 .54879 L
s
.2744 .54879 m
.27464 .55065 L
s
.4 0 1 r
.38697 .62986 m
.38648 .62866 L
s
.38868 .62915 m
.38697 .62986 L
s
0 .326 1 r
.2731 .54957 m
.27464 .55065 L
s
.4 0 1 r
.38648 .62866 m
.38754 .62736 L
s
.38754 .62736 m
.38868 .62915 L
s
1 0 .528 r
.38824 .60779 m
.39711 .61118 L
s
.73 0 1 r
.33496 .56192 m
.3333 .56292 L
s
.3349 .56098 m
.33496 .56192 L
s
.33519 .56338 m
.33496 .56192 L
s
.4 0 1 r
.38648 .62866 m
.38868 .62915 L
s
1 0 .072 r
.39034 .39027 m
.39205 .38875 L
s
.39205 .38875 m
.39165 .3871 L
s
.39205 .38875 m
.38923 .3876 L
s
.38923 .3876 m
.39034 .39027 L
s
.39165 .3871 m
.38923 .3876 L
s
.38923 .3876 m
.38995 .38862 L
s
.39807 .39302 m
.38923 .3876 L
s
.73 0 1 r
.3333 .56292 m
.33323 .56198 L
s
.33519 .56338 m
.3333 .56292 L
s
0 .279 1 r
.33561 .39802 m
.33567 .39729 L
s
.33567 .39729 m
.33437 .39648 L
s
.33567 .39729 m
.33411 .39837 L
s
1 0 .072 r
.38995 .38862 m
.39034 .39027 L
s
0 .279 1 r
.33411 .39837 m
.33561 .39802 L
s
.33437 .39648 m
.33411 .39837 L
s
.33411 .39837 m
.33431 .39721 L
s
.3385 .39276 m
.33411 .39837 L
s
.33437 .39648 m
.33431 .39721 L
s
.73 0 1 r
.33323 .56198 m
.3349 .56098 L
s
.3349 .56098 m
.33519 .56338 L
s
.33323 .56198 m
.33519 .56338 L
s
1 0 .072 r
.39165 .3871 m
.38995 .38862 L
s
0 .279 1 r
.33431 .39721 m
.33561 .39802 L
s
.702 0 1 r
.28239 .48112 m
.2825 .48014 L
s
.2825 .48014 m
.28084 .47915 L
s
.2825 .48014 m
.28053 .48153 L
s
.28053 .48153 m
.28239 .48112 L
s
.28084 .47915 m
.28053 .48153 L
s
.28053 .48153 m
.28074 .48013 L
s
.28596 .47454 m
.28053 .48153 L
s
1 0 .528 r
.39629 .61044 m
.39497 .61206 L
s
.39569 .60894 m
.39629 .61044 L
s
.39711 .61118 m
.39629 .61044 L
s
.702 0 1 r
.28084 .47915 m
.28074 .48013 L
s
0 .279 1 r
.3385 .60724 m
.34289 .61286 L
s
1 0 .528 r
.39497 .61206 m
.39437 .61056 L
s
.39711 .61118 m
.39497 .61206 L
s
.702 0 1 r
.28074 .48013 m
.28239 .48112 L
s
1 0 .528 r
.39437 .61056 m
.39569 .60894 L
s
.39569 .60894 m
.39711 .61118 L
s
.859 0 1 r
.39731 .373 m
.39871 .37176 L
s
.39871 .37176 m
.3984 .3704 L
s
.39871 .37176 m
.39641 .37081 L
s
.39641 .37081 m
.39731 .373 L
s
.3984 .3704 m
.39641 .37081 L
s
.39641 .37081 m
.397 .37164 L
s
.40367 .37529 m
.39641 .37081 L
s
0 .279 1 r
.34269 .61169 m
.34139 .6125 L
s
.34264 .61096 m
.34269 .61169 L
s
.34289 .61286 m
.34269 .61169 L
s
1 0 .528 r
.39437 .61056 m
.39711 .61118 L
s
.859 0 1 r
.397 .37164 m
.39731 .373 L
s
0 .279 1 r
.34139 .6125 m
.34134 .61177 L
s
.34289 .61286 m
.34139 .6125 L
s
1 0 .072 r
.39807 .60698 m
.40694 .60154 L
s
.859 0 1 r
.3984 .3704 m
.397 .37164 L
s
.702 0 1 r
.28596 .52546 m
.29141 .53246 L
s
0 .279 1 r
.34134 .61177 m
.34264 .61096 L
s
.34264 .61096 m
.34289 .61286 L
s
1 0 .399 r
.3999 .40053 m
.40183 .3994 L
s
.40183 .3994 m
.40188 .39815 L
s
.40183 .3994 m
.39954 .3977 L
s
0 .279 1 r
.34134 .61177 m
.34289 .61286 L
s
0 .015 1 r
.23239 .49162 m
.23232 .49114 L
s
.23232 .49114 m
.23071 .49065 L
s
.23232 .49114 m
.23102 .49266 L
s
1 0 .399 r
.39954 .3977 m
.3999 .40053 L
s
.40188 .39815 m
.39954 .3977 L
s
.39954 .3977 m
.39994 .39928 L
s
.40629 .40592 m
.39954 .3977 L
s
0 .015 1 r
.23071 .49065 m
.23078 .49113 L
s
.23071 .49065 m
.23102 .49266 L
s
1 0 .399 r
.39994 .39928 m
.3999 .40053 L
s
0 .015 1 r
.23102 .49266 m
.23239 .49162 L
s
.23102 .49266 m
.23078 .49113 L
s
.23366 .48504 m
.23102 .49266 L
s
1 .011 0 r
.40074 .32895 m
.40073 .32895 L
s
.40074 .32893 m
.40074 .32895 L
s
.40074 .32895 m
.40072 .32894 L
s
.40075 .32894 m
.40074 .32895 L
s
.40073 .32892 m
.40074 .32895 L
s
.40074 .32893 m
.40072 .32894 L
s
.40075 .32894 m
.40074 .32893 L
s
.40073 .32895 m
.40075 .32894 L
s
.40072 .32894 m
.40073 .32895 L
s
.40073 .67108 m
.40073 .67111 L
s
.40073 .67112 m
.40072 .67111 L
s
.40074 .67111 m
.40073 .67112 L
s
.40073 .67111 m
.40073 .67112 L
s
.40073 .6711 m
.40074 .67111 L
s
.40073 .67111 m
.40074 .67111 L
s
.40072 .67111 m
.40073 .6711 L
s
.40072 .67111 m
.40073 .67111 L
s
.40073 .6711 m
.40073 .67111 L
s
.702 0 1 r
.2912 .53105 m
.28954 .53204 L
s
.2911 .53007 m
.2912 .53105 L
s
.29141 .53246 m
.2912 .53105 L
s
0 .015 1 r
.23078 .49113 m
.23239 .49162 L
s
1 0 .399 r
.40188 .39815 m
.39994 .39928 L
s
1 .033 0 r
.40249 .6434 m
.40248 .64338 L
s
.40248 .64338 m
.40247 .64337 L
s
.40248 .64338 m
.40246 .6434 L
s
.702 0 1 r
.28954 .53204 m
.28944 .53107 L
s
.29141 .53246 m
.28954 .53204 L
s
1 .033 0 r
.40246 .6434 m
.40249 .6434 L
s
.40247 .64337 m
.40246 .6434 L
s
.40246 .6434 m
.40248 .64339 L
s
.40255 .64332 m
.40246 .6434 L
s
.40247 .64337 m
.40248 .64339 L
s
.40248 .64339 m
.40249 .6434 L
s
.40262 .35674 m
.40261 .35676 L
s
.40263 .35673 m
.40262 .35674 L
s
.40264 .35676 m
.40262 .35674 L
s
.40255 .35668 m
.40264 .35676 L
s
.40261 .35676 m
.40262 .35674 L
s
.40264 .35676 m
.40261 .35676 L
s
.40262 .35674 m
.40263 .35673 L
s
.40263 .35673 m
.40264 .35676 L
s
.40262 .35674 m
.40264 .35676 L
s
0 .295 1 r
.29185 .42871 m
.29193 .42797 L
s
.29193 .42797 m
.29061 .42717 L
s
.29193 .42797 m
.29038 .42906 L
s
1 0 .072 r
.40621 .60257 m
.40582 .60422 L
s
.40451 .60104 m
.40621 .60257 L
s
.40694 .60154 m
.40621 .60257 L
s
0 .015 1 r
.23366 .51496 m
.23631 .52259 L
s
0 .295 1 r
.29038 .42906 m
.29185 .42871 L
s
.29061 .42717 m
.29038 .42906 L
s
.29038 .42906 m
.29054 .42791 L
s
.29466 .42344 m
.29038 .42906 L
s
.29061 .42717 m
.29054 .42791 L
s
.859 0 1 r
.40367 .62471 m
.41096 .62022 L
s
0 .015 1 r
.23654 .52105 m
.23493 .52155 L
s
.23662 .52058 m
.23654 .52105 L
s
.23631 .52259 m
.23654 .52105 L
s
.702 0 1 r
.28944 .53107 m
.2911 .53007 L
s
.2911 .53007 m
.29141 .53246 L
s
.28944 .53107 m
.29141 .53246 L
s
0 .015 1 r
.23493 .52155 m
.23501 .52107 L
s
.23631 .52259 m
.23493 .52155 L
s
1 0 .072 r
.40412 .60269 m
.40451 .60104 L
s
.40451 .60104 m
.40694 .60154 L
s
.765 0 1 r
.35068 .419 m
.35074 .41805 L
s
.35074 .41805 m
.34908 .41702 L
s
.35074 .41805 m
.34875 .41944 L
s
0 .295 1 r
.29054 .42791 m
.29185 .42871 L
s
.765 0 1 r
.34875 .41944 m
.35068 .419 L
s
.34908 .41702 m
.34875 .41944 L
s
.34875 .41944 m
.34902 .41797 L
s
.35441 .41227 m
.34875 .41944 L
s
.34908 .41702 m
.34902 .41797 L
s
1 0 .072 r
.40582 .60422 m
.40412 .60269 L
s
.40694 .60154 m
.40582 .60422 L
s
0 .015 1 r
.23662 .52058 m
.23631 .52259 L
s
.23501 .52107 m
.23631 .52259 L
s
.23501 .52107 m
.23662 .52058 L
s
1 0 .399 r
.40629 .59408 m
.41307 .58584 L
s
1 .033 0 r
.40666 .64871 m
.40665 .64869 L
s
.40665 .64869 m
.40663 .64868 L
s
.40665 .64869 m
.40663 .64871 L
s
.40663 .64871 m
.40666 .64871 L
s
.40663 .64868 m
.40663 .64871 L
s
.40663 .64871 m
.40664 .64869 L
s
.40672 .64863 m
.40663 .64871 L
s
.40663 .64868 m
.40664 .64869 L
s
.40664 .64869 m
.40666 .64871 L
s
.40679 .35144 m
.40677 .35145 L
s
.4068 .35143 m
.40679 .35144 L
s
.4068 .35145 m
.40679 .35144 L
s
.40672 .35137 m
.4068 .35145 L
s
.40677 .35145 m
.40678 .35144 L
s
.4068 .35145 m
.40677 .35145 L
s
.40678 .35144 m
.4068 .35143 L
s
.4068 .35143 m
.4068 .35145 L
s
.40678 .35144 m
.4068 .35145 L
s
1 0 .072 r
.40412 .60269 m
.40694 .60154 L
s
.765 0 1 r
.34902 .41797 m
.35068 .419 L
s
.859 0 1 r
.41036 .62106 m
.41005 .62243 L
s
.40895 .61982 m
.41036 .62106 L
s
.41096 .62022 m
.41036 .62106 L
s
0 .295 1 r
.29466 .57656 m
.29896 .58219 L
s
.859 0 1 r
.40865 .62118 m
.40895 .61982 L
s
.40895 .61982 m
.41096 .62022 L
s
1 0 .399 r
.41265 .58744 m
.41271 .58868 L
s
.41072 .5863 m
.41265 .58744 L
s
.41307 .58584 m
.41265 .58744 L
s
0 .295 1 r
.29879 .58103 m
.29748 .58183 L
s
.29872 .58029 m
.29879 .58103 L
s
.29896 .58219 m
.29879 .58103 L
s
.859 0 1 r
.41005 .62243 m
.40865 .62118 L
s
.41096 .62022 m
.41005 .62243 L
s
1 0 .399 r
.41078 .58754 m
.41072 .5863 L
s
.41072 .5863 m
.41307 .58584 L
s
0 .295 1 r
.29748 .58183 m
.29741 .58109 L
s
.29896 .58219 m
.29748 .58183 L
s
.859 0 1 r
.40865 .62118 m
.41096 .62022 L
s
.765 0 1 r
.35441 .58773 m
.36008 .59492 L
s
0 .295 1 r
.29741 .58109 m
.29872 .58029 L
s
.29872 .58029 m
.29896 .58219 L
s
1 0 .615 r
.41207 .41492 m
.41392 .41387 L
s
.41392 .41387 m
.41414 .41272 L
s
.41392 .41387 m
.4118 .41216 L
s
0 .295 1 r
.29741 .58109 m
.29896 .58219 L
s
1 0 .399 r
.41271 .58868 m
.41078 .58754 L
s
.41307 .58584 m
.41271 .58868 L
s
.269 0 1 r
.3576 .37557 m
.3581 .3744 L
s
.3581 .3744 m
.35705 .37312 L
s
.3581 .3744 m
.35595 .37487 L
s
.35595 .37487 m
.3576 .37557 L
s
.35705 .37312 m
.35595 .37487 L
s
.35595 .37487 m
.35656 .37429 L
s
.36286 .37223 m
.35595 .37487 L
s
1 0 .399 r
.41078 .58754 m
.41307 .58584 L
s
1 0 .615 r
.4118 .41216 m
.41207 .41492 L
s
.41414 .41272 m
.4118 .41216 L
s
.4118 .41216 m
.41229 .41377 L
s
.41833 .42044 m
.4118 .41216 L
s
.41229 .41377 m
.41207 .41492 L
s
.269 0 1 r
.35705 .37312 m
.35656 .37429 L
s
.655 0 1 r
.41448 .38447 m
.41609 .38352 L
s
.41609 .38352 m
.41611 .38245 L
s
.41609 .38352 m
.41416 .38211 L
s
.765 0 1 r
.3598 .59344 m
.35814 .59447 L
s
.35975 .59249 m
.3598 .59344 L
s
.36008 .59492 m
.3598 .59344 L
s
.269 0 1 r
.35656 .37429 m
.3576 .37557 L
s
.655 0 1 r
.41416 .38211 m
.41448 .38447 L
s
.41611 .38245 m
.41416 .38211 L
s
.41416 .38211 m
.4145 .38341 L
s
.41984 .38887 m
.41416 .38211 L
s
.4145 .38341 m
.41448 .38447 L
s
.765 0 1 r
.35814 .59447 m
.35809 .59353 L
s
.36008 .59492 m
.35814 .59447 L
s
1 0 .93 r
.24765 .50173 m
.24755 .50112 L
s
.24755 .50112 m
.24549 .5005 L
s
.24755 .50112 m
.24591 .50306 L
s
1 0 .615 r
.41414 .41272 m
.41229 .41377 L
s
1 0 .93 r
.24549 .5005 m
.2456 .50112 L
s
.24549 .5005 m
.24591 .50306 L
s
0 .264 1 r
.24768 .45962 m
.24778 .45885 L
s
.24778 .45885 m
.24645 .45805 L
s
.24778 .45885 m
.2462 .45996 L
s
1 0 .93 r
.24591 .50306 m
.24765 .50173 L
s
.24591 .50306 m
.2456 .50112 L
s
.24923 .49332 m
.24591 .50306 L
s
.655 0 1 r
.41611 .38245 m
.4145 .38341 L
s
0 .264 1 r
.2462 .45996 m
.24768 .45962 L
s
.24645 .45805 m
.2462 .45996 L
s
.2462 .45996 m
.24635 .45882 L
s
.25052 .45435 m
.2462 .45996 L
s
.765 0 1 r
.35809 .59353 m
.35975 .59249 L
s
.35975 .59249 m
.36008 .59492 L
s
0 .264 1 r
.24645 .45805 m
.24635 .45882 L
s
.4 0 1 r
.41721 .66843 m
.41901 .66805 L
s
.41901 .66805 m
.41929 .66782 L
s
.41901 .66805 m
.41784 .66633 L
s
.765 0 1 r
.35809 .59353 m
.36008 .59492 L
s
.859 0 1 r
.41778 .34577 m
.41968 .34512 L
s
.41968 .34512 m
.41988 .34432 L
s
.41968 .34512 m
.41806 .34327 L
s
1 0 .524 r
.36281 .39531 m
.36344 .39379 L
s
.36344 .39379 m
.36211 .39216 L
s
.36344 .39379 m
.36068 .3944 L
s
.4 0 1 r
.41749 .6682 m
.41721 .66843 L
s
.41784 .66633 m
.41721 .66843 L
s
1 0 .524 r
.36068 .3944 m
.36281 .39531 L
s
.36211 .39216 m
.36068 .3944 L
s
.36068 .3944 m
.36147 .39367 L
s
.36956 .39107 m
.36068 .3944 L
s
.859 0 1 r
.41798 .34497 m
.41778 .34577 L
s
.41806 .34327 m
.41778 .34577 L
s
.73 0 1 r
.30684 .4499 m
.30692 .44894 L
s
.30692 .44894 m
.30524 .44794 L
s
.30692 .44894 m
.30495 .45036 L
s
1 0 .93 r
.2456 .50112 m
.24765 .50173 L
s
0 .264 1 r
.24635 .45882 m
.24768 .45962 L
s
.4 0 1 r
.41929 .66782 m
.41784 .66633 L
s
.41784 .66633 m
.41749 .6682 L
s
.41988 .67533 m
.41784 .66633 L
s
.859 0 1 r
.41988 .34432 m
.41806 .34327 L
s
.41806 .34327 m
.41798 .34497 L
s
.42192 .35214 m
.41806 .34327 L
s
1 0 .615 r
.41833 .57956 m
.42488 .57126 L
s
.73 0 1 r
.30495 .45036 m
.30684 .4499 L
s
.30524 .44794 m
.30495 .45036 L
s
.30495 .45036 m
.30516 .44889 L
s
.31043 .44316 m
.30495 .45036 L
s
.30524 .44794 m
.30516 .44889 L
s
1 0 .524 r
.36211 .39216 m
.36147 .39367 L
s
.4 0 1 r
.41929 .66782 m
.41749 .6682 L
s
1 0 .93 r
.24923 .50668 m
.25256 .51644 L
s
1 0 .524 r
.36147 .39367 m
.36281 .39531 L
s
.269 0 1 r
.36286 .62777 m
.3698 .63042 L
s
.655 0 1 r
.41984 .61113 m
.42553 .60435 L
s
.4 0 1 r
.42227 .31755 m
.42256 .31777 L
s
.42047 .31716 m
.42227 .31755 L
s
.42192 .31566 m
.42227 .31755 L
s
.859 0 1 r
.41988 .34432 m
.41798 .34497 L
s
.4 0 1 r
.41988 .32467 m
.42192 .31566 L
s
.73 0 1 r
.30516 .44889 m
.30684 .4499 L
s
1 0 .93 r
.25287 .51448 m
.25082 .51509 L
s
.25298 .51388 m
.25287 .51448 L
s
.25256 .51644 m
.25287 .51448 L
s
1 0 .615 r
.42437 .57288 m
.42461 .57402 L
s
.42252 .57182 m
.42437 .57288 L
s
.42488 .57126 m
.42437 .57288 L
s
.4 0 1 r
.42076 .31738 m
.42047 .31716 L
s
.42047 .31716 m
.42192 .31566 L
s
0 .264 1 r
.25052 .54565 m
.25484 .55128 L
s
1 0 .93 r
.25082 .51509 m
.25092 .51449 L
s
.25256 .51644 m
.25082 .51509 L
s
1 0 .615 r
.42275 .57296 m
.42252 .57182 L
s
.42252 .57182 m
.42488 .57126 L
s
.4 0 1 r
.42192 .31566 m
.42256 .31777 L
s
.42076 .31738 m
.42192 .31566 L
s
.859 0 1 r
.42192 .64786 m
.42579 .63897 L
s
1 0 0 r
.36552 .34848 m
.36553 .34849 L
s
.36553 .34847 m
.36552 .34848 L
s
.36552 .34848 m
.36552 .34848 L
s
.36553 .34848 m
.36552 .34848 L
s
.36554 .34848 m
.36552 .34848 L
s
.36553 .34849 m
.36553 .34848 L
s
.36553 .34848 m
.36553 .34847 L
s
.36552 .34848 m
.36553 .34849 L
s
.36553 .34847 m
.36552 .34848 L
s
.36554 .65152 m
.36556 .65152 L
s
.36556 .65152 m
.36555 .65153 L
s
.36555 .65151 m
.36556 .65152 L
s
.36556 .65152 m
.36556 .65152 L
s
.36555 .65152 m
.36555 .65151 L
s
.36555 .65151 m
.36556 .65152 L
s
.36555 .65153 m
.36555 .65152 L
s
.36556 .65152 m
.36555 .65153 L
s
.36555 .65152 m
.36556 .65152 L
s
.655 0 1 r
.42518 .60566 m
.42521 .60672 L
s
.42357 .6047 m
.42518 .60566 L
s
.42553 .60435 m
.42518 .60566 L
s
.4 0 1 r
.42256 .31777 m
.42076 .31738 L
s
1 0 .93 r
.25298 .51388 m
.25256 .51644 L
s
.25092 .51449 m
.25256 .51644 L
s
0 .264 1 r
.25469 .55013 m
.25336 .55094 L
s
.25459 .54937 m
.25469 .55013 L
s
.25484 .55128 m
.25469 .55013 L
s
.859 0 1 r
.42587 .64068 m
.42607 .64147 L
s
.42397 .64003 m
.42587 .64068 L
s
.42579 .63897 m
.42587 .64068 L
s
1 0 .615 r
.42461 .57402 m
.42275 .57296 L
s
.42488 .57126 m
.42461 .57402 L
s
1 0 .93 r
.25092 .51449 m
.25298 .51388 L
s
.655 0 1 r
.42359 .60576 m
.42357 .6047 L
s
.42357 .6047 m
.42553 .60435 L
s
1 0 .615 r
.42275 .57296 m
.42488 .57126 L
s
.269 0 1 r
.36918 .62983 m
.36814 .63112 L
s
.36869 .62866 m
.36918 .62983 L
s
.3698 .63042 m
.36918 .62983 L
s
0 .264 1 r
.25336 .55094 m
.25326 .55017 L
s
.25484 .55128 m
.25336 .55094 L
s
.859 0 1 r
.42417 .64082 m
.42397 .64003 L
s
.42397 .64003 m
.42579 .63897 L
s
.73 0 1 r
.31043 .55684 m
.31594 .56405 L
s
.269 0 1 r
.36814 .63112 m
.36764 .62994 L
s
.3698 .63042 m
.36814 .63112 L
s
.655 0 1 r
.42521 .60672 m
.42359 .60576 L
s
.42553 .60435 m
.42521 .60672 L
s
0 .264 1 r
.25326 .55017 m
.25459 .54937 L
s
.25459 .54937 m
.25484 .55128 L
s
.992 0 1 r
.42455 .42959 m
.42623 .42866 L
s
.42623 .42866 m
.42665 .42766 L
s
.42623 .42866 m
.42439 .42701 L
s
.655 0 1 r
.42359 .60576 m
.42553 .60435 L
s
0 .264 1 r
.25326 .55017 m
.25484 .55128 L
s
.269 0 1 r
.36764 .62994 m
.36869 .62866 L
s
.36869 .62866 m
.3698 .63042 L
s
.859 0 1 r
.42579 .63897 m
.42607 .64147 L
s
.42417 .64082 m
.42579 .63897 L
s
.42607 .64147 m
.42417 .64082 L
s
.528 0 1 r
.42664 .39897 m
.42819 .39805 L
s
.42819 .39805 m
.4283 .39704 L
s
.42819 .39805 m
.42634 .39666 L
s
1 0 .524 r
.36956 .60893 m
.37849 .61228 L
s
.992 0 1 r
.42439 .42701 m
.42455 .42959 L
s
.42665 .42766 m
.42439 .42701 L
s
.42439 .42701 m
.42496 .42858 L
s
.43044 .43506 m
.42439 .42701 L
s
.42496 .42858 m
.42455 .42959 L
s
.269 0 1 r
.36764 .62994 m
.3698 .63042 L
s
.73 0 1 r
.31571 .56258 m
.31403 .56359 L
s
.31564 .56163 m
.31571 .56258 L
s
.31594 .56405 m
.31571 .56258 L
s
1 0 0 r
.37161 .38892 m
.37338 .38738 L
s
.37338 .38738 m
.37298 .3857 L
s
.37338 .38738 m
.37051 .38617 L
s
.528 0 1 r
.42634 .39666 m
.42664 .39897 L
s
.4283 .39704 m
.42634 .39666 L
s
.42634 .39666 m
.42674 .39795 L
s
.43196 .40339 m
.42634 .39666 L
s
.42674 .39795 m
.42664 .39897 L
s
.655 0 1 r
.42807 .36734 m
.42968 .36638 L
s
.42968 .36638 m
.4297 .36529 L
s
.42968 .36638 m
.42774 .36497 L
s
1 0 0 r
.37051 .38617 m
.37161 .38892 L
s
.37298 .3857 m
.37051 .38617 L
s
.37051 .38617 m
.37121 .38725 L
s
.37944 .39188 m
.37051 .38617 L
s
.73 0 1 r
.31403 .56359 m
.31396 .56264 L
s
.31594 .56405 m
.31403 .56359 L
s
.655 0 1 r
.42774 .36497 m
.42807 .36734 L
s
.4297 .36529 m
.42774 .36497 L
s
.42774 .36497 m
.42809 .36625 L
s
.43348 .37169 m
.42774 .36497 L
s
.992 0 1 r
.42665 .42766 m
.42496 .42858 L
s
0 .279 1 r
.31635 .39694 m
.31642 .3962 L
s
.31642 .3962 m
.3151 .39538 L
s
.31642 .3962 m
.31485 .39729 L
s
.655 0 1 r
.42809 .36625 m
.42807 .36734 L
s
1 0 0 r
.37121 .38725 m
.37161 .38892 L
s
0 .279 1 r
.31485 .39729 m
.31635 .39694 L
s
.3151 .39538 m
.31485 .39729 L
s
.31485 .39729 m
.31504 .39612 L
s
.31926 .39163 m
.31485 .39729 L
s
.528 0 1 r
.4283 .39704 m
.42674 .39795 L
s
0 .279 1 r
.3151 .39538 m
.31504 .39612 L
s
.73 0 1 r
.31396 .56264 m
.31564 .56163 L
s
.31564 .56163 m
.31594 .56405 L
s
.31396 .56264 m
.31594 .56405 L
s
.655 0 1 r
.4297 .36529 m
.42809 .36625 L
s
1 0 0 r
.37298 .3857 m
.37121 .38725 L
s
0 .279 1 r
.31504 .39612 m
.31635 .39694 L
s
1 0 .072 r
.43134 .33674 m
.43367 .33596 L
s
.43367 .33596 m
.43391 .33498 L
s
.43367 .33596 m
.43169 .33369 L
s
.992 0 1 r
.43044 .56494 m
.4365 .55687 L
s
.729 0 1 r
.26253 .48096 m
.26265 .47997 L
s
.26265 .47997 m
.26096 .47896 L
s
.26265 .47997 m
.26065 .48138 L
s
0 .19 1 r
.43169 .70284 m
.43302 .70199 L
s
.43302 .70199 m
.43303 .7013 L
s
.43302 .70199 m
.43144 .70087 L
s
1 0 .072 r
.43158 .33576 m
.43134 .33674 L
s
.43169 .33369 m
.43134 .33674 L
s
1 0 .528 r
.43209 .65912 m
.43434 .65863 L
s
.43434 .65863 m
.43468 .65833 L
s
.43434 .65863 m
.43287 .65648 L
s
0 .19 1 r
.43144 .70087 m
.43169 .70284 L
s
.43303 .7013 m
.43144 .70087 L
s
.43144 .70087 m
.4317 .70215 L
s
.43607 .70685 m
.43144 .70087 L
s
.729 0 1 r
.26065 .48138 m
.26253 .48096 L
s
.26096 .47896 m
.26065 .48138 L
s
.26065 .48138 m
.26084 .47995 L
s
.26614 .47427 m
.26065 .48138 L
s
.992 0 1 r
.43592 .55845 m
.43635 .55945 L
s
.43424 .55752 m
.43592 .55845 L
s
.4365 .55687 m
.43592 .55845 L
s
1 0 .072 r
.43391 .33498 m
.43169 .33369 L
s
.43169 .33369 m
.43158 .33576 L
s
.43636 .34457 m
.43169 .33369 L
s
1 0 .524 r
.37769 .61155 m
.37635 .61319 L
s
.37705 .61003 m
.37769 .61155 L
s
.37849 .61228 m
.37769 .61155 L
s
0 .19 1 r
.4317 .70215 m
.43169 .70284 L
s
.729 0 1 r
.26096 .47896 m
.26084 .47995 L
s
.528 0 1 r
.43196 .59661 m
.43759 .58986 L
s
1 0 .528 r
.43243 .65881 m
.43209 .65912 L
s
.43287 .65648 m
.43209 .65912 L
s
.43468 .65833 m
.43287 .65648 L
s
.43287 .65648 m
.43243 .65881 L
s
.43545 .66769 m
.43287 .65648 L
s
.992 0 1 r
.43466 .55852 m
.43424 .55752 L
s
.43424 .55752 m
.4365 .55687 L
s
0 .19 1 r
.43303 .7013 m
.4317 .70215 L
s
0 .279 1 r
.31926 .60837 m
.32368 .61406 L
s
1 0 .524 r
.37635 .61319 m
.37572 .61167 L
s
.37849 .61228 m
.37635 .61319 L
s
.729 0 1 r
.26084 .47995 m
.26253 .48096 L
s
.655 0 1 r
.43348 .62831 m
.43924 .62157 L
s
1 0 .072 r
.43391 .33498 m
.43158 .33576 L
s
1 0 .524 r
.37572 .61167 m
.37705 .61003 L
s
.37705 .61003 m
.37849 .61228 L
s
.528 0 1 r
.43719 .59117 m
.4373 .59218 L
s
.43563 .59024 m
.43719 .59117 L
s
.43759 .58986 m
.43719 .59117 L
s
.992 0 1 r
.43635 .55945 m
.43466 .55852 L
s
.4365 .55687 m
.43635 .55945 L
s
.43466 .55852 m
.4365 .55687 L
s
1 0 .528 r
.43468 .65833 m
.43243 .65881 L
s
.683 0 1 r
.37893 .37166 m
.38031 .37046 L
s
.38031 .37046 m
.38001 .36913 L
s
.38031 .37046 m
.37807 .3695 L
s
.37807 .3695 m
.37893 .37166 L
s
.38001 .36913 m
.37807 .3695 L
s
.37807 .3695 m
.37863 .37033 L
s
.38508 .37396 m
.37807 .3695 L
s
.528 0 1 r
.43574 .59125 m
.43563 .59024 L
s
.43563 .59024 m
.43759 .58986 L
s
1 0 .528 r
.43545 .33231 m
.43803 .32108 L
s
0 .279 1 r
.32348 .61288 m
.32217 .61369 L
s
.32342 .61214 m
.32348 .61288 L
s
.32368 .61406 m
.32348 .61288 L
s
1 0 .528 r
.43846 .32343 m
.43881 .32372 L
s
.43621 .32294 m
.43846 .32343 L
s
.43803 .32108 m
.43846 .32343 L
s
1 0 .524 r
.37572 .61167 m
.37849 .61228 L
s
.683 0 1 r
.37863 .37033 m
.37893 .37166 L
s
0 .19 1 r
.43607 .29315 m
.44072 .28715 L
s
.655 0 1 r
.43888 .62286 m
.43891 .62394 L
s
.43727 .6219 m
.43888 .62286 L
s
.43924 .62157 m
.43888 .62286 L
s
0 .279 1 r
.32217 .61369 m
.3221 .61296 L
s
.32368 .61406 m
.32217 .61369 L
s
1 0 .528 r
.43656 .32323 m
.43621 .32294 L
s
.43621 .32294 m
.43803 .32108 L
s
1 0 .072 r
.43636 .65543 m
.44104 .64452 L
s
1 0 0 r
.37944 .60812 m
.38841 .60238 L
s
.528 0 1 r
.4373 .59218 m
.43574 .59125 L
s
.43759 .58986 m
.4373 .59218 L
s
.43574 .59125 m
.43759 .58986 L
s
.683 0 1 r
.38001 .36913 m
.37863 .37033 L
s
.655 0 1 r
.4373 .62298 m
.43727 .6219 L
s
.43727 .6219 m
.43924 .62157 L
s
.729 0 1 r
.26614 .52573 m
.27166 .53285 L
s
1 0 .282 r
.38123 .39939 m
.38324 .39821 L
s
.38324 .39821 m
.38323 .39692 L
s
.38324 .39821 m
.38087 .39647 L
s
0 .279 1 r
.3221 .61296 m
.32342 .61214 L
s
.32342 .61214 m
.32368 .61406 L
s
.3221 .61296 m
.32368 .61406 L
s
1 0 .072 r
.44114 .64662 m
.44139 .64758 L
s
.43881 .64583 m
.44114 .64662 L
s
.44104 .64452 m
.44114 .64662 L
s
1 0 .528 r
.43803 .32108 m
.43881 .32372 L
s
.43656 .32323 m
.43803 .32108 L
s
1 0 .282 r
.38087 .39647 m
.38123 .39939 L
s
.38323 .39692 m
.38087 .39647 L
s
.38087 .39647 m
.38122 .39809 L
s
.38771 .40492 m
.38087 .39647 L
s
0 .19 1 r
.44044 .28843 m
.44046 .28912 L
s
.43911 .28758 m
.44044 .28843 L
s
.44072 .28715 m
.44044 .28843 L
s
1 0 .282 r
.38122 .39809 m
.38123 .39939 L
s
.655 0 1 r
.43891 .62394 m
.4373 .62298 L
s
.43924 .62157 m
.43891 .62394 L
s
1 0 .528 r
.43881 .32372 m
.43656 .32323 L
s
1 0 .072 r
.43906 .6468 m
.43881 .64583 L
s
.43881 .64583 m
.44104 .64452 L
s
.407 0 1 r
.43737 .44462 m
.4388 .44385 L
s
.4388 .44385 m
.43941 .44302 L
s
.4388 .44385 m
.43733 .44234 L
s
.655 0 1 r
.4373 .62298 m
.43924 .62157 L
s
0 .19 1 r
.43913 .28827 m
.43911 .28758 L
s
.43911 .28758 m
.44072 .28715 L
s
.222 0 1 r
.4391 .41375 m
.44054 .4129 L
s
.44054 .4129 m
.44073 .41198 L
s
.44054 .4129 m
.43885 .41158 L
s
1 0 0 r
.38214 .32706 m
.38214 .32707 L
s
.38213 .32706 m
.38214 .32706 L
s
.38214 .32706 m
.38213 .32707 L
s
.38214 .32707 m
.38214 .32706 L
s
.38212 .3271 m
.38214 .32706 L
s
.38214 .32707 m
.38214 .32707 L
s
.38213 .32707 m
.38214 .32707 L
s
.38213 .32706 m
.38213 .32707 L
s
.38214 .32707 m
.38213 .32706 L
s
.38212 .6729 m
.38211 .67286 L
s
.38211 .67286 m
.38212 .67287 L
s
.3821 .67287 m
.38211 .67286 L
s
.38211 .67286 m
.38211 .67286 L
s
.38211 .67287 m
.3821 .67287 L
s
.3821 .67287 m
.38211 .67286 L
s
.38212 .67287 m
.38211 .67287 L
s
.38211 .67286 m
.38212 .67287 L
s
.38211 .67286 m
.38211 .67287 L
s
1 0 .399 r
.44057 .34925 m
.44249 .34808 L
s
.44249 .34808 m
.44254 .34675 L
s
.44249 .34808 m
.44014 .3464 L
s
.528 0 1 r
.4402 .38204 m
.44173 .38109 L
s
.44173 .38109 m
.44181 .38002 L
s
.44173 .38109 m
.43983 .37974 L
s
.222 0 1 r
.43885 .41158 m
.4391 .41375 L
s
.44073 .41198 m
.43885 .41158 L
s
.43885 .41158 m
.43929 .41282 L
s
.44417 .41801 m
.43885 .41158 L
s
.729 0 1 r
.27145 .53141 m
.26976 .53242 L
s
.27134 .53042 m
.27145 .53141 L
s
.27166 .53285 m
.27145 .53141 L
s
.222 0 1 r
.43929 .41282 m
.4391 .41375 L
s
.407 0 1 r
.43733 .44234 m
.43737 .44462 L
s
.43941 .44302 m
.43733 .44234 L
s
.43733 .44234 m
.43799 .44379 L
s
.44264 .44978 m
.43733 .44234 L
s
.43799 .44379 m
.43737 .44462 L
s
1 0 .282 r
.38323 .39692 m
.38122 .39809 L
s
0 .19 1 r
.44046 .28912 m
.43913 .28827 L
s
.44072 .28715 m
.44046 .28912 L
s
.528 0 1 r
.43983 .37974 m
.4402 .38204 L
s
.44181 .38002 m
.43983 .37974 L
s
.43983 .37974 m
.44028 .38097 L
s
.4457 .38621 m
.43983 .37974 L
s
1 0 .399 r
.44014 .3464 m
.44057 .34925 L
s
.44254 .34675 m
.44014 .3464 L
s
.44014 .3464 m
.44062 .34791 L
s
.44723 .35439 m
.44014 .3464 L
s
0 .19 1 r
.43913 .28827 m
.44072 .28715 L
s
.528 0 1 r
.44028 .38097 m
.4402 .38204 L
s
1 .028 0 r
.3839 .35508 m
.3839 .35511 L
s
.38392 .35509 m
.3839 .35508 L
s
.3839 .35508 m
.3839 .3551 L
s
.38392 .3551 m
.3839 .35508 L
s
.38395 .35516 m
.3839 .35508 L
s
.3839 .35511 m
.38392 .3551 L
s
.38392 .3551 m
.38392 .35509 L
s
.3839 .3551 m
.3839 .35511 L
s
.38392 .35509 m
.3839 .3551 L
s
1 0 .399 r
.44062 .34791 m
.44057 .34925 L
s
.729 0 1 r
.26976 .53242 m
.26965 .53144 L
s
.27166 .53285 m
.26976 .53242 L
s
1 .028 0 r
.38395 .64484 m
.384 .64477 L
s
.384 .64478 m
.38399 .6448 L
s
.38398 .64477 m
.384 .64478 L
s
.384 .64477 m
.384 .64478 L
s
.38397 .64478 m
.38398 .64477 L
s
.38398 .64477 m
.384 .64477 L
s
.38399 .6448 m
.38397 .64478 L
s
.384 .64477 m
.38399 .6448 L
s
.38397 .64478 m
.384 .64477 L
s
1 0 .072 r
.44104 .64452 m
.44139 .64758 L
s
.43906 .6468 m
.44104 .64452 L
s
.407 0 1 r
.43941 .44302 m
.43799 .44379 L
s
0 .222 1 r
.27201 .42805 m
.2721 .42729 L
s
.2721 .42729 m
.27074 .42647 L
s
.2721 .42729 m
.2705 .42842 L
s
.222 0 1 r
.44073 .41198 m
.43929 .41282 L
s
1 0 .072 r
.44139 .64758 m
.43906 .6468 L
s
1 0 0 r
.38769 .60346 m
.38731 .60514 L
s
.38592 .60191 m
.38769 .60346 L
s
.38841 .60238 m
.38769 .60346 L
s
0 .222 1 r
.2705 .42842 m
.27201 .42805 L
s
.27074 .42647 m
.2705 .42842 L
s
.2705 .42842 m
.27065 .42724 L
s
.27489 .42263 m
.2705 .42842 L
s
.27074 .42647 m
.27065 .42724 L
s
.683 0 1 r
.38508 .62604 m
.39211 .62157 L
s
.528 0 1 r
.44181 .38002 m
.44028 .38097 L
s
.407 0 1 r
.44728 .54423 m
.4479 .54506 L
s
.44586 .54346 m
.44728 .54423 L
s
.44794 .54277 m
.44728 .54423 L
s
.44264 .55022 m
.44794 .54277 L
s
.729 0 1 r
.26965 .53144 m
.27134 .53042 L
s
.27134 .53042 m
.27166 .53285 L
s
1 0 .399 r
.44254 .34675 m
.44062 .34791 L
s
.729 0 1 r
.26965 .53144 m
.27166 .53285 L
s
1 0 0 r
.38554 .60359 m
.38592 .60191 L
s
.38592 .60191 m
.38841 .60238 L
s
.765 0 1 r
.33151 .41814 m
.33159 .41718 L
s
.33159 .41718 m
.3299 .41614 L
s
.33159 .41718 m
.32957 .41859 L
s
0 .222 1 r
.27065 .42724 m
.27201 .42805 L
s
.765 0 1 r
.32957 .41859 m
.33151 .41814 L
s
.3299 .41614 m
.32957 .41859 L
s
.32957 .41859 m
.32982 .4171 L
s
.33525 .41134 m
.32957 .41859 L
s
.407 0 1 r
.44648 .54428 m
.44586 .54346 L
s
.44586 .54346 m
.44794 .54277 L
s
.222 0 1 r
.44417 .58199 m
.44949 .57554 L
s
.765 0 1 r
.3299 .41614 m
.32982 .4171 L
s
1 0 0 r
.38731 .60514 m
.38554 .60359 L
s
.38841 .60238 m
.38731 .60514 L
s
1 0 .282 r
.38771 .59508 m
.39459 .5866 L
s
.407 0 1 r
.4479 .54506 m
.44648 .54428 L
s
.44794 .54277 m
.4479 .54506 L
s
.44648 .54428 m
.44794 .54277 L
s
1 .028 0 r
.38809 .34972 m
.38809 .34975 L
s
.3881 .34972 m
.38809 .34972 L
s
.38809 .34972 m
.38808 .34973 L
s
.38811 .34974 m
.38809 .34972 L
s
.38814 .34979 m
.38809 .34972 L
s
.38809 .34975 m
.38811 .34974 L
s
.38811 .34974 m
.3881 .34972 L
s
.38808 .34973 m
.38809 .34975 L
s
.3881 .34972 m
.38808 .34973 L
s
.38814 .65021 m
.38819 .65014 L
s
.38819 .65015 m
.38818 .65016 L
s
.38817 .65014 m
.38819 .65015 L
s
.38819 .65014 m
.38819 .65015 L
s
.38816 .65015 m
.38817 .65014 L
s
.38817 .65014 m
.38819 .65014 L
s
.38818 .65016 m
.38816 .65015 L
s
.38819 .65014 m
.38818 .65016 L
s
.38816 .65015 m
.38819 .65014 L
s
1 0 0 r
.38554 .60359 m
.38841 .60238 L
s
.528 0 1 r
.4457 .61379 m
.45158 .6073 L
s
.765 0 1 r
.32982 .4171 m
.33151 .41814 L
s
.222 0 1 r
.44905 .5768 m
.44924 .57772 L
s
.44761 .57595 m
.44905 .5768 L
s
.44949 .57554 m
.44905 .5768 L
s
.797 0 1 r
.44709 .68252 m
.44877 .68145 L
s
.44877 .68145 m
.44878 .68056 L
s
.44877 .68145 m
.44677 .68003 L
s
.683 0 1 r
.39154 .6224 m
.39125 .62373 L
s
.39016 .6212 m
.39154 .6224 L
s
.39211 .62157 m
.39154 .6224 L
s
0 .222 1 r
.27489 .57737 m
.27929 .58317 L
s
.797 0 1 r
.44677 .68003 m
.44709 .68252 L
s
.44878 .68056 m
.44677 .68003 L
s
.44677 .68003 m
.4471 .68163 L
s
.4526 .68757 m
.44677 .68003 L
s
.222 0 1 r
.4478 .57687 m
.44761 .57595 L
s
.44761 .57595 m
.44949 .57554 L
s
.797 0 1 r
.4471 .68163 m
.44709 .68252 L
s
1 0 .399 r
.44723 .64561 m
.45435 .6376 L
s
.683 0 1 r
.38986 .62252 m
.39016 .6212 L
s
.39016 .6212 m
.39211 .62157 L
s
.528 0 1 r
.45112 .60855 m
.45121 .60961 L
s
.44959 .60759 m
.45112 .60855 L
s
.45158 .6073 m
.45112 .60855 L
s
.222 0 1 r
.44924 .57772 m
.4478 .57687 L
s
.44949 .57554 m
.44924 .57772 L
s
1 0 .282 r
.39422 .58825 m
.39421 .58953 L
s
.3922 .58707 m
.39422 .58825 L
s
.39459 .5866 m
.39422 .58825 L
s
.222 0 1 r
.4478 .57687 m
.44949 .57554 L
s
.683 0 1 r
.39125 .62373 m
.38986 .62252 L
s
.39211 .62157 m
.39125 .62373 L
s
0 .222 1 r
.27913 .58198 m
.27777 .5828 L
s
.27905 .58122 m
.27913 .58198 L
s
.27929 .58317 m
.27913 .58198 L
s
.797 0 1 r
.44878 .68056 m
.4471 .68163 L
s
.528 0 1 r
.44968 .60865 m
.44959 .60759 L
s
.44959 .60759 m
.45158 .6073 L
s
1 0 .282 r
.3922 .58835 m
.3922 .58707 L
s
.3922 .58707 m
.39459 .5866 L
s
.683 0 1 r
.38986 .62252 m
.39211 .62157 L
s
0 .222 1 r
.27777 .5828 m
.27769 .58204 L
s
.27929 .58317 m
.27777 .5828 L
s
.765 0 1 r
.33525 .58866 m
.34095 .59593 L
s
1 0 .456 r
.39354 .41395 m
.39551 .41284 L
s
.39551 .41284 m
.39557 .41163 L
s
.39551 .41284 m
.39324 .41109 L
s
0 .186 1 r
.45972 .5287 m
.46092 .52924 L
s
.45888 .52819 m
.45972 .5287 L
s
.46063 .52727 m
.45972 .5287 L
s
1 0 .399 r
.45385 .63913 m
.45391 .64046 L
s
.45193 .63796 m
.45385 .63913 L
s
.45435 .6376 m
.45385 .63913 L
s
.528 0 1 r
.45121 .60961 m
.44968 .60865 L
s
.45158 .6073 m
.45121 .60961 L
s
0 .222 1 r
.27769 .58204 m
.27905 .58122 L
s
.27905 .58122 m
.27929 .58317 L
s
.528 0 1 r
.44968 .60865 m
.45158 .6073 L
s
1 0 .456 r
.39324 .41109 m
.39354 .41395 L
s
.39557 .41163 m
.39324 .41109 L
s
.39324 .41109 m
.3936 .41274 L
s
.39981 .41959 m
.39324 .41109 L
s
0 .222 1 r
.27769 .58204 m
.27929 .58317 L
s
.269 0 1 r
.33846 .37425 m
.33897 .37306 L
s
.33897 .37306 m
.3379 .37177 L
s
.33897 .37306 m
.33679 .37354 L
s
1 0 .456 r
.3936 .41274 m
.39354 .41395 L
s
.269 0 1 r
.33679 .37354 m
.33846 .37425 L
s
.3379 .37177 m
.33679 .37354 L
s
.33679 .37354 m
.33739 .37295 L
s
.34375 .37087 m
.33679 .37354 L
s
1 0 .282 r
.39421 .58953 m
.3922 .58835 L
s
.39459 .5866 m
.39421 .58953 L
s
1 0 .399 r
.45199 .63929 m
.45193 .63796 L
s
.45193 .63796 m
.45435 .6376 L
s
1 0 .282 r
.3922 .58835 m
.39459 .5866 L
s
0 .186 1 r
.46092 .52924 m
.46008 .52873 L
s
.46063 .52727 m
.46092 .52924 L
s
.45304 .46027 m
.45388 .45976 L
s
.45388 .45976 m
.45507 .45922 L
s
.45388 .45976 m
.45332 .4583 L
s
.45888 .52819 m
.46063 .52727 L
s
.46008 .52873 m
.46063 .52727 L
s
.45698 .53448 m
.46063 .52727 L
s
.46008 .52873 m
.45888 .52819 L
s
.269 0 1 r
.3379 .37177 m
.33739 .37295 L
s
0 .259 1 r
.4518 .4288 m
.45304 .42807 L
s
.45304 .42807 m
.45335 .42727 L
s
.45304 .42807 m
.45161 .42686 L
s
1 0 .615 r
.45268 .36424 m
.45444 .36307 L
s
.45444 .36307 m
.45456 .36175 L
s
.45444 .36307 m
.45215 .36152 L
s
.797 0 1 r
.4526 .31243 m
.45846 .30487 L
s
.222 0 1 r
.45265 .39702 m
.45403 .39611 L
s
.45403 .39611 m
.45416 .3951 L
s
.45403 .39611 m
.45226 .39487 L
s
.765 0 1 r
.34068 .59443 m
.33899 .59548 L
s
.34061 .59347 m
.34068 .59443 L
s
.34095 .59593 m
.34068 .59443 L
s
.452 0 1 r
.39622 .38342 m
.39779 .3825 L
s
.39779 .3825 m
.39778 .38147 L
s
.39779 .3825 m
.39592 .38114 L
s
0 .186 1 r
.45698 .46552 m
.45332 .4583 L
s
.269 0 1 r
.33739 .37295 m
.33846 .37425 L
s
1 0 .456 r
.39557 .41163 m
.3936 .41274 L
s
0 .186 1 r
.45507 .45922 m
.45423 .45973 L
s
.45507 .45922 m
.45332 .4583 L
s
.452 0 1 r
.39592 .38114 m
.39622 .38342 L
s
.39778 .38147 m
.39592 .38114 L
s
.39592 .38114 m
.39621 .38239 L
s
.40133 .38768 m
.39592 .38114 L
s
.222 0 1 r
.45226 .39487 m
.45265 .39702 L
s
.45416 .3951 m
.45226 .39487 L
s
.45226 .39487 m
.45277 .39602 L
s
.45799 .40083 m
.45226 .39487 L
s
0 .259 1 r
.45161 .42686 m
.4518 .4288 L
s
.45335 .42727 m
.45161 .42686 L
s
.45161 .42686 m
.45211 .42801 L
s
.45645 .43273 m
.45161 .42686 L
s
1 0 .615 r
.45215 .36152 m
.45268 .36424 L
s
.45456 .36175 m
.45215 .36152 L
s
.45215 .36152 m
.45281 .36291 L
s
.45954 .3689 m
.45215 .36152 L
s
1 0 .399 r
.45391 .64046 m
.45199 .63929 L
s
.45435 .6376 m
.45391 .64046 L
s
0 .259 1 r
.45211 .42801 m
.4518 .4288 L
s
.765 0 1 r
.33899 .59548 m
.33892 .59452 L
s
.34095 .59593 m
.33899 .59548 L
s
.452 0 1 r
.39621 .38239 m
.39622 .38342 L
s
.222 0 1 r
.45277 .39602 m
.45265 .39702 L
s
0 .186 1 r
.45332 .4583 m
.45304 .46027 L
s
.45332 .4583 m
.45423 .45973 L
s
.45423 .45973 m
.45304 .46027 L
s
1 0 .615 r
.45281 .36291 m
.45268 .36424 L
s
1 0 .399 r
.45199 .63929 m
.45435 .6376 L
s
0 .259 1 r
.45335 .42727 m
.45211 .42801 L
s
.222 0 1 r
.45416 .3951 m
.45277 .39602 L
s
.452 0 1 r
.39778 .38147 m
.39621 .38239 L
s
.765 0 1 r
.33892 .59452 m
.34061 .59347 L
s
.34061 .59347 m
.34095 .59593 L
s
1 0 .615 r
.45456 .36175 m
.45281 .36291 L
s
.797 0 1 r
.45812 .30647 m
.45814 .30736 L
s
.45644 .30541 m
.45812 .30647 L
s
.45846 .30487 m
.45812 .30647 L
s
.269 0 1 r
.39879 .67043 m
.40056 .67006 L
s
.40056 .67006 m
.40081 .66983 L
s
.40056 .67006 m
.39941 .66836 L
s
.765 0 1 r
.33892 .59452 m
.34095 .59593 L
s
.683 0 1 r
.39935 .34441 m
.4012 .34377 L
s
.4012 .34377 m
.40137 .34297 L
s
.4012 .34377 m
.3996 .34198 L
s
1 0 .524 r
.34368 .39419 m
.34433 .39266 L
s
.34433 .39266 m
.34297 .39101 L
s
.34433 .39266 m
.34154 .39327 L
s
.269 0 1 r
.39904 .6702 m
.39879 .67043 L
s
.39941 .66836 m
.39879 .67043 L
s
1 0 .524 r
.34154 .39327 m
.34368 .39419 L
s
.34297 .39101 m
.34154 .39327 L
s
.34154 .39327 m
.34232 .39254 L
s
.35049 .3899 m
.34154 .39327 L
s
0 .259 1 r
.45645 .56727 m
.46131 .5614 L
s
.797 0 1 r
.45645 .30629 m
.45644 .30541 L
s
.45644 .30541 m
.45846 .30487 L
s
.771 0 1 r
.28709 .44943 m
.28718 .44845 L
s
.28718 .44845 m
.28547 .44743 L
s
.28718 .44845 m
.28517 .44989 L
s
0 .222 1 r
.45742 .73586 m
.45874 .73499 L
s
.45874 .73499 m
.45875 .73431 L
s
.45874 .73499 m
.45715 .73389 L
s
.683 0 1 r
.39952 .34362 m
.39935 .34441 L
s
.3996 .34198 m
.39935 .34441 L
s
.269 0 1 r
.40081 .66983 m
.39941 .66836 L
s
.39941 .66836 m
.39904 .6702 L
s
.40137 .6772 m
.39941 .66836 L
s
.683 0 1 r
.40137 .34297 m
.3996 .34198 L
s
.3996 .34198 m
.39952 .34362 L
s
.40343 .35056 m
.3996 .34198 L
s
0 .222 1 r
.45715 .73389 m
.45742 .73586 L
s
.45875 .73431 m
.45715 .73389 L
s
.45715 .73389 m
.45743 .73517 L
s
.46185 .73984 m
.45715 .73389 L
s
1 0 .456 r
.39981 .58041 m
.4064 .57188 L
s
.771 0 1 r
.28517 .44989 m
.28709 .44943 L
s
.28547 .44743 m
.28517 .44989 L
s
.28517 .44989 m
.28538 .4484 L
s
.29074 .44255 m
.28517 .44989 L
s
0 .259 1 r
.46079 .56255 m
.46111 .56335 L
s
.45956 .56181 m
.46079 .56255 L
s
.46131 .5614 m
.46079 .56255 L
s
0 .222 1 r
.45743 .73517 m
.45742 .73586 L
s
.771 0 1 r
.28547 .44743 m
.28538 .4484 L
s
1 0 .524 r
.34297 .39101 m
.34232 .39254 L
s
.222 0 1 r
.45799 .59917 m
.46375 .5932 L
s
.269 0 1 r
.40081 .66983 m
.39904 .6702 L
s
.797 0 1 r
.45814 .30736 m
.45645 .30629 L
s
.45846 .30487 m
.45814 .30736 L
s
0 .259 1 r
.45987 .5626 m
.45956 .56181 L
s
.45956 .56181 m
.46131 .5614 L
s
1 0 .524 r
.34232 .39254 m
.34368 .39419 L
s
.269 0 1 r
.34375 .62913 m
.35073 .63181 L
s
.797 0 1 r
.45645 .30629 m
.45846 .30487 L
s
.452 0 1 r
.40133 .61232 m
.40676 .60575 L
s
.269 0 1 r
.40371 .31581 m
.40397 .31603 L
s
.40194 .31543 m
.40371 .31581 L
s
.40334 .31396 m
.40371 .31581 L
s
.683 0 1 r
.40137 .34297 m
.39952 .34362 L
s
.269 0 1 r
.40137 .3228 m
.40334 .31396 L
s
0 .222 1 r
.45875 .73431 m
.45743 .73517 L
s
.771 0 1 r
.28538 .4484 m
.28709 .44943 L
s
.269 0 1 r
.40219 .31565 m
.40194 .31543 L
s
.40194 .31543 m
.40334 .31396 L
s
0 .259 1 r
.46111 .56335 m
.45987 .5626 L
s
.46131 .5614 m
.46111 .56335 L
s
.45987 .5626 m
.46131 .5614 L
s
1 0 .615 r
.45954 .6311 m
.46695 .62369 L
s
.222 0 1 r
.46322 .59436 m
.46335 .59536 L
s
.46184 .59344 m
.46322 .59436 L
s
.46375 .5932 m
.46322 .59436 L
s
1 0 .456 r
.40603 .57354 m
.40611 .57474 L
s
.40406 .57243 m
.40603 .57354 L
s
.4064 .57188 m
.40603 .57354 L
s
.269 0 1 r
.40334 .31396 m
.40397 .31603 L
s
.40219 .31565 m
.40334 .31396 L
s
.683 0 1 r
.40343 .64944 m
.40726 .64083 L
s
.222 0 1 r
.46197 .59444 m
.46184 .59344 L
s
.46184 .59344 m
.46375 .5932 L
s
1 0 .456 r
.40414 .57363 m
.40406 .57243 L
s
.40406 .57243 m
.4064 .57188 L
s
1 0 0 r
.34648 .65314 m
.34648 .65314 L
s
.34648 .65313 m
.34648 .65314 L
s
.34649 .65314 m
.34648 .65314 L
s
.3464 .34687 m
.3464 .34686 L
s
.3464 .34686 m
.3464 .34685 L
s
.3464 .34686 m
.34639 .34686 L
s
.34649 .65314 m
.34648 .65314 L
s
.34648 .65313 m
.34649 .65314 L
s
.34648 .65314 m
.34649 .65314 L
s
.34644 .65314 m
.34649 .65314 L
s
.34648 .65314 m
.34648 .65314 L
s
.34648 .65314 m
.34648 .65313 L
s
.34644 .34686 m
.34639 .34686 L
s
.3464 .34685 m
.3464 .34686 L
s
.3464 .34685 m
.34639 .34686 L
s
.3464 .34686 m
.3464 .34687 L
s
.34639 .34686 m
.3464 .34687 L
s
.34639 .34686 m
.3464 .34686 L
s
.452 0 1 r
.40646 .60702 m
.40646 .60804 L
s
.40489 .60609 m
.40646 .60702 L
s
.40676 .60575 m
.40646 .60702 L
s
.269 0 1 r
.40397 .31603 m
.40219 .31565 L
s
0 .222 1 r
.46185 .26016 m
.46657 .2542 L
s
.683 0 1 r
.40733 .64249 m
.40751 .64327 L
s
.40548 .64184 m
.40733 .64249 L
s
.40726 .64083 m
.40733 .64249 L
s
.452 0 1 r
.40489 .60712 m
.40489 .60609 L
s
.40489 .60609 m
.40676 .60575 L
s
1 0 .615 r
.46627 .6251 m
.46641 .62642 L
s
.46452 .62393 m
.46627 .6251 L
s
.46695 .62369 m
.46627 .6251 L
s
.222 0 1 r
.46335 .59536 m
.46197 .59444 L
s
.46375 .5932 m
.46335 .59536 L
s
.269 0 1 r
.35012 .63122 m
.34906 .63252 L
s
.34961 .63004 m
.35012 .63122 L
s
.35073 .63181 m
.35012 .63122 L
s
.222 0 1 r
.46197 .59444 m
.46375 .5932 L
s
.683 0 1 r
.40566 .64262 m
.40548 .64184 L
s
.40548 .64184 m
.40726 .64083 L
s
.771 0 1 r
.29074 .55745 m
.29633 .5648 L
s
1 0 .456 r
.40611 .57474 m
.40414 .57363 L
s
.4064 .57188 m
.40611 .57474 L
s
1 0 .807 r
.40614 .42877 m
.40801 .42777 L
s
.40801 .42777 m
.40816 .42669 L
s
.40801 .42777 m
.40595 .42607 L
s
1 0 .456 r
.40414 .57363 m
.4064 .57188 L
s
1 0 .615 r
.46466 .62525 m
.46452 .62393 L
s
.46452 .62393 m
.46695 .62369 L
s
.452 0 1 r
.40646 .60804 m
.40489 .60712 L
s
.40676 .60575 m
.40646 .60804 L
s
0 1 .879 r
.46748 .4451 m
.46845 .44458 L
s
.46845 .44458 m
.46878 .44403 L
s
.46845 .44458 m
.46744 .44359 L
s
.269 0 1 r
.34906 .63252 m
.34855 .63133 L
s
.35073 .63181 m
.34906 .63252 L
s
1 0 .807 r
.40595 .42607 m
.40614 .42877 L
s
.40816 .42669 m
.40595 .42607 L
s
.40595 .42607 m
.4063 .42769 L
s
.41199 .43437 m
.40595 .42607 L
s
.452 0 1 r
.40489 .60712 m
.40676 .60575 L
s
0 .222 1 r
.46628 .25548 m
.46629 .25616 L
s
.46496 .25462 m
.46628 .25548 L
s
.46657 .2542 m
.46628 .25548 L
s
1 0 .807 r
.4063 .42769 m
.40614 .42877 L
s
.269 0 1 r
.34855 .63133 m
.34961 .63004 L
s
.34961 .63004 m
.35073 .63181 L
s
.683 0 1 r
.40726 .64083 m
.40751 .64327 L
s
.40566 .64262 m
.40726 .64083 L
s
0 1 .879 r
.46744 .44359 m
.46748 .4451 L
s
.46878 .44403 m
.46744 .44359 L
s
.46744 .44359 m
.46781 .44455 L
s
.47089 .44847 m
.46744 .44359 L
s
.46781 .44455 m
.46748 .4451 L
s
0 .222 1 r
.46498 .2553 m
.46496 .25462 L
s
.46496 .25462 m
.46657 .2542 L
s
.683 0 1 r
.40751 .64327 m
.40566 .64262 L
s
1 0 .615 r
.46641 .62642 m
.46466 .62525 L
s
.46695 .62369 m
.46641 .62642 L
s
.299 0 1 r
.40855 .39812 m
.41007 .39723 L
s
.41007 .39723 m
.4101 .39626 L
s
.41007 .39723 m
.40828 .3959 L
s
1 0 .524 r
.35049 .6101 m
.35948 .61348 L
s
0 1 .879 r
.46878 .44403 m
.46781 .44455 L
s
1 0 .615 r
.46466 .62525 m
.46695 .62369 L
s
.992 0 1 r
.4651 .37955 m
.46662 .37841 L
s
.46662 .37841 m
.46681 .37714 L
s
.46662 .37841 m
.46446 .37705 L
s
.269 0 1 r
.34855 .63133 m
.35073 .63181 L
s
0 .259 1 r
.46533 .4123 m
.46648 .41146 L
s
.46648 .41146 m
.46668 .41056 L
s
.46648 .41146 m
.46491 .4104 L
s
.771 0 1 r
.29611 .5633 m
.29439 .56433 L
s
.29603 .56233 m
.29611 .5633 L
s
.29633 .5648 m
.29611 .5633 L
s
.299 0 1 r
.40828 .3959 m
.40855 .39812 L
s
.4101 .39626 m
.40828 .3959 L
s
.40828 .3959 m
.40858 .39714 L
s
.41352 .40236 m
.40828 .3959 L
s
1 0 0 r
.35251 .38773 m
.3543 .38618 L
s
.3543 .38618 m
.35389 .38448 L
s
.3543 .38618 m
.3514 .38495 L
s
1 0 .807 r
.40816 .42669 m
.4063 .42769 L
s
.299 0 1 r
.40858 .39714 m
.40855 .39812 L
s
0 .222 1 r
.46629 .25616 m
.46498 .2553 L
s
.46657 .2542 m
.46629 .25616 L
s
1 0 0 r
.3514 .38495 m
.35251 .38773 L
s
.35389 .38448 m
.3514 .38495 L
s
.3514 .38495 m
.3521 .38604 L
s
.36042 .39073 m
.3514 .38495 L
s
.452 0 1 r
.40987 .36613 m
.41143 .3652 L
s
.41143 .3652 m
.41142 .36414 L
s
.41143 .3652 m
.40955 .36384 L
s
0 .222 1 r
.46498 .2553 m
.46657 .2542 L
s
.992 0 1 r
.46446 .37705 m
.4651 .37955 L
s
.46681 .37714 m
.46446 .37705 L
s
.46446 .37705 m
.46529 .37827 L
s
.47193 .38352 m
.46446 .37705 L
s
0 1 .879 r
.47089 .55153 m
.47434 .54664 L
s
0 .259 1 r
.46491 .4104 m
.46533 .4123 L
s
.46668 .41056 m
.46491 .4104 L
s
.46491 .4104 m
.46552 .41139 L
s
.47037 .41554 m
.46491 .4104 L
s
.771 0 1 r
.29439 .56433 m
.29431 .56336 L
s
.29633 .5648 m
.29439 .56433 L
s
0 .259 1 r
.46552 .41139 m
.46533 .4123 L
s
0 1 .879 r
.47396 .5476 m
.4743 .54815 L
s
.47299 .54708 m
.47396 .5476 L
s
.47434 .54664 m
.47396 .5476 L
s
.992 0 1 r
.46529 .37827 m
.4651 .37955 L
s
0 .19 1 r
.2966 .39595 m
.29667 .39519 L
s
.29667 .39519 m
.29531 .39434 L
s
.29667 .39519 m
.29504 .39631 L
s
.452 0 1 r
.40955 .36384 m
.40987 .36613 L
s
.41142 .36414 m
.40955 .36384 L
s
.40955 .36384 m
.40986 .36507 L
s
.41505 .37032 m
.40955 .36384 L
s
.40986 .36507 m
.40987 .36613 L
s
1 0 0 r
.3521 .38604 m
.35251 .38773 L
s
0 .19 1 r
.29504 .39631 m
.2966 .39595 L
s
.29531 .39434 m
.29504 .39631 L
s
.29504 .39631 m
.29523 .3951 L
s
.29961 .39047 m
.29504 .39631 L
s
.299 0 1 r
.4101 .39626 m
.40858 .39714 L
s
0 1 .879 r
.47333 .54763 m
.47299 .54708 L
s
.47299 .54708 m
.47434 .54664 L
s
0 .19 1 r
.29531 .39434 m
.29523 .3951 L
s
0 .259 1 r
.46668 .41056 m
.46552 .41139 L
s
.992 0 1 r
.46681 .37714 m
.46529 .37827 L
s
0 .846 1 r
.46375 .51912 m
.46492 .51956 L
s
.46335 .51869 m
.46375 .51912 L
s
.4647 .51792 m
.46375 .51912 L
s
.771 0 1 r
.29431 .56336 m
.29603 .56233 L
s
.29603 .56233 m
.29633 .5648 L
s
0 1 .879 r
.4743 .54815 m
.47333 .54763 L
s
.47434 .54664 m
.4743 .54815 L
s
.47333 .54763 m
.47434 .54664 L
s
.771 0 1 r
.29431 .56336 m
.29633 .5648 L
s
1 0 0 r
.35389 .38448 m
.3521 .38604 L
s
.452 0 1 r
.41142 .36414 m
.40986 .36507 L
s
0 .846 1 r
.46492 .51956 m
.46453 .51913 L
s
.4647 .51792 m
.46492 .51956 L
s
0 .19 1 r
.29523 .3951 m
.2966 .39595 L
s
1 0 0 r
.41272 .335 m
.41509 .33418 L
s
.41509 .33418 m
.41532 .33315 L
s
.41509 .33418 m
.41304 .33187 L
s
0 .846 1 r
.46335 .51869 m
.4647 .51792 L
s
.46453 .51913 m
.4647 .51792 L
s
.46188 .52393 m
.4647 .51792 L
s
1 0 .807 r
.41199 .56563 m
.41806 .55731 L
s
0 .279 1 r
.41336 .70512 m
.41467 .70428 L
s
.41467 .70428 m
.41466 .70359 L
s
.41467 .70428 m
.4131 .70318 L
s
1 0 0 r
.41295 .33397 m
.41272 .335 L
s
.41304 .33187 m
.41272 .335 L
s
0 .846 1 r
.46453 .51913 m
.46335 .51869 L
s
0 .259 1 r
.47037 .58446 m
.47585 .5793 L
s
1 0 0 r
.41532 .33315 m
.41304 .33187 L
s
.41304 .33187 m
.41295 .33397 L
s
.41795 .3429 m
.41304 .33187 L
s
1 0 .524 r
.41368 .66079 m
.41596 .66031 L
s
.41596 .66031 m
.41631 .66001 L
s
.41596 .66031 m
.41449 .65813 L
s
0 .279 1 r
.4131 .70318 m
.41336 .70512 L
s
.41466 .70359 m
.4131 .70318 L
s
.4131 .70318 m
.41335 .70443 L
s
.41765 .70907 m
.4131 .70318 L
s
1 0 .524 r
.35868 .61274 m
.35732 .6144 L
s
.35804 .61121 m
.35868 .61274 L
s
.35948 .61348 m
.35868 .61274 L
s
0 .279 1 r
.41335 .70443 m
.41336 .70512 L
s
.299 0 1 r
.41352 .59764 m
.41878 .59117 L
s
0 .846 1 r
.46188 .47607 m
.45906 .47007 L
s
1 0 .524 r
.41403 .66049 m
.41368 .66079 L
s
.41449 .65813 m
.41368 .66079 L
s
0 .846 1 r
.45884 .4717 m
.45924 .47128 L
s
.45924 .47128 m
.46041 .47083 L
s
.45924 .47128 m
.45906 .47007 L
s
0 .259 1 r
.47523 .5803 m
.47543 .58121 L
s
.47407 .57946 m
.47523 .5803 L
s
.47585 .5793 m
.47523 .5803 L
s
1 0 .807 r
.41769 .55895 m
.41786 .56002 L
s
.41583 .55794 m
.41769 .55895 L
s
.41806 .55731 m
.41769 .55895 L
s
.992 0 1 r
.47193 .61648 m
.47941 .61 L
s
.771 0 1 r
.47295 .71559 m
.47461 .71449 L
s
.47461 .71449 m
.47464 .71361 L
s
.47461 .71449 m
.47259 .71311 L
s
1 0 .524 r
.41631 .66001 m
.41449 .65813 L
s
.41449 .65813 m
.41403 .66049 L
s
.41703 .66949 m
.41449 .65813 L
s
0 .846 1 r
.46041 .47083 m
.46001 .47126 L
s
.46041 .47083 m
.45906 .47007 L
s
0 .279 1 r
.41466 .70359 m
.41335 .70443 L
s
0 .19 1 r
.29961 .60953 m
.30418 .6154 L
s
1 0 .524 r
.35732 .6144 m
.35668 .61287 L
s
.35948 .61348 m
.35732 .6144 L
s
.771 0 1 r
.47259 .71311 m
.47295 .71559 L
s
.47464 .71361 m
.47259 .71311 L
s
.47259 .71311 m
.47298 .7147 L
s
.47862 .72057 m
.47259 .71311 L
s
.452 0 1 r
.41505 .62968 m
.42057 .62319 L
s
0 .259 1 r
.47427 .58037 m
.47407 .57946 L
s
.47407 .57946 m
.47585 .5793 L
s
1 0 0 r
.41532 .33315 m
.41295 .33397 L
s
1 0 .807 r
.416 .55901 m
.41583 .55794 L
s
.41583 .55794 m
.41806 .55731 L
s
.771 0 1 r
.47298 .7147 m
.47295 .71559 L
s
0 .846 1 r
.45906 .47007 m
.45884 .4717 L
s
.45906 .47007 m
.46001 .47126 L
s
1 0 .524 r
.35668 .61287 m
.35804 .61121 L
s
.35804 .61121 m
.35948 .61348 L
s
0 .846 1 r
.46001 .47126 m
.45884 .4717 L
s
.299 0 1 r
.41847 .59242 m
.41851 .59339 L
s
.41695 .59154 m
.41847 .59242 L
s
.41878 .59117 m
.41847 .59242 L
s
0 .259 1 r
.47543 .58121 m
.47427 .58037 L
s
.47585 .5793 m
.47543 .58121 L
s
1 0 .524 r
.41631 .66001 m
.41403 .66049 L
s
.683 0 1 r
.3599 .37028 m
.3613 .36907 L
s
.3613 .36907 m
.36098 .36773 L
s
.3613 .36907 m
.35903 .36811 L
s
0 .259 1 r
.47427 .58037 m
.47585 .5793 L
s
.992 0 1 r
.47857 .61124 m
.47877 .61251 L
s
.47706 .61009 m
.47857 .61124 L
s
.47941 .61 m
.47857 .61124 L
s
.683 0 1 r
.35903 .36811 m
.3599 .37028 L
s
.36098 .36773 m
.35903 .36811 L
s
.35903 .36811 m
.35958 .36894 L
s
.36608 .37261 m
.35903 .36811 L
s
.299 0 1 r
.41699 .59251 m
.41695 .59154 L
s
.41695 .59154 m
.41878 .59117 L
s
1 0 .524 r
.42002 .32151 m
.42038 .32179 L
s
.41775 .32103 m
.42002 .32151 L
s
.41957 .31914 m
.42002 .32151 L
s
.41703 .33051 m
.41957 .31914 L
s
.771 0 1 r
.47464 .71361 m
.47298 .7147 L
s
1 0 .524 r
.35668 .61287 m
.35948 .61348 L
s
0 .19 1 r
.30398 .61418 m
.30262 .61503 L
s
.30391 .61342 m
.30398 .61418 L
s
.30418 .6154 m
.30398 .61418 L
s
1 0 .807 r
.41786 .56002 m
.416 .55901 L
s
.41806 .55731 m
.41786 .56002 L
s
.416 .55901 m
.41806 .55731 L
s
.683 0 1 r
.35958 .36894 m
.3599 .37028 L
s
0 .279 1 r
.41765 .29093 m
.42222 .28502 L
s
.452 0 1 r
.42025 .62443 m
.42025 .62548 L
s
.41869 .6235 m
.42025 .62443 L
s
.42057 .62319 m
.42025 .62443 L
s
1 0 .524 r
.4181 .32131 m
.41775 .32103 L
s
.41775 .32103 m
.41957 .31914 L
s
0 .19 1 r
.30262 .61503 m
.30255 .61427 L
s
.30418 .6154 m
.30262 .61503 L
s
.992 0 1 r
.47725 .61136 m
.47706 .61009 L
s
.47706 .61009 m
.47941 .61 L
s
1 0 0 r
.41795 .6571 m
.42287 .64604 L
s
.36042 .60927 m
.36948 .60347 L
s
.299 0 1 r
.41851 .59339 m
.41699 .59251 L
s
.41878 .59117 m
.41851 .59339 L
s
.41699 .59251 m
.41878 .59117 L
s
.452 0 1 r
.41869 .62454 m
.41869 .6235 L
s
.41869 .6235 m
.42057 .62319 L
s
.683 0 1 r
.36098 .36773 m
.35958 .36894 L
s
1 0 .282 r
.3623 .39831 m
.36435 .39713 L
s
.36435 .39713 m
.36429 .39582 L
s
.36435 .39713 m
.36194 .39536 L
s
.647 0 1 r
.4191 .44389 m
.42079 .44304 L
s
.42079 .44304 m
.42104 .44213 L
s
.42079 .44304 m
.41902 .44145 L
s
.992 0 1 r
.47877 .61251 m
.47725 .61136 L
s
.47941 .61 m
.47877 .61251 L
s
0 .19 1 r
.30255 .61427 m
.30391 .61342 L
s
.30391 .61342 m
.30418 .6154 L
s
0 1 .879 r
.48078 .42918 m
.48162 .42848 L
s
.48162 .42848 m
.48172 .42774 L
s
.48162 .42848 m
.48034 .42775 L
s
0 .19 1 r
.30255 .61427 m
.30418 .6154 L
s
1 0 .282 r
.36194 .39536 m
.3623 .39831 L
s
.36429 .39582 m
.36194 .39536 L
s
.36194 .39536 m
.36223 .39701 L
s
.36873 .4039 m
.36194 .39536 L
s
1 0 .524 r
.41957 .31914 m
.42038 .32179 L
s
.4181 .32131 m
.41957 .31914 L
s
.992 0 1 r
.47725 .61136 m
.47941 .61 L
s
1 0 0 r
.42295 .64816 m
.42319 .64917 L
s
.42057 .64733 m
.42295 .64816 L
s
.42287 .64604 m
.42295 .64816 L
s
1 0 .282 r
.36223 .39701 m
.3623 .39831 L
s
0 .279 1 r
.42197 .28628 m
.42196 .28697 L
s
.42065 .28544 m
.42197 .28628 L
s
.42222 .28502 m
.42197 .28628 L
s
0 1 .879 r
.48034 .42775 m
.48078 .42918 L
s
.48172 .42774 m
.48034 .42775 L
s
.48034 .42775 m
.48089 .42844 L
s
.4849 .4313 m
.48034 .42775 L
s
.647 0 1 r
.41902 .44145 m
.4191 .44389 L
s
.42104 .44213 m
.41902 .44145 L
s
.41902 .44145 m
.41935 .44298 L
s
.42426 .44924 m
.41902 .44145 L
s
.41935 .44298 m
.4191 .44389 L
s
.452 0 1 r
.42025 .62548 m
.41869 .62454 L
s
.42057 .62319 m
.42025 .62548 L
s
0 1 .879 r
.48089 .42844 m
.48078 .42918 L
s
1 0 .524 r
.42038 .32179 m
.4181 .32131 L
s
.452 0 1 r
.41869 .62454 m
.42057 .62319 L
s
1 0 0 r
.42081 .64834 m
.42057 .64733 L
s
.42057 .64733 m
.42287 .64604 L
s
0 .279 1 r
.42065 .28612 m
.42065 .28544 L
s
.42065 .28544 m
.42222 .28502 L
s
0 .016 1 r
.42116 .41307 m
.42257 .41226 L
s
.42257 .41226 m
.42265 .41138 L
s
.42257 .41226 m
.42093 .411 L
s
1 0 0 r
.36313 .67471 m
.36313 .67472 L
s
.36312 .67471 m
.36313 .67471 L
s
.36313 .67471 m
.36312 .67472 L
s
.36313 .67472 m
.36313 .67471 L
s
.36311 .67475 m
.36313 .67471 L
s
.36313 .67472 m
.36313 .67472 L
s
.36312 .67472 m
.36313 .67472 L
s
.36312 .67471 m
.36312 .67472 L
s
.36313 .67472 m
.36312 .67471 L
s
.36311 .32525 m
.36309 .3252 L
s
.3631 .32521 m
.3631 .32521 L
s
.36309 .32521 m
.3631 .32521 L
s
.3631 .32521 m
.36309 .3252 L
s
.36309 .32522 m
.36309 .32521 L
s
.36309 .32521 m
.36309 .3252 L
s
.3631 .32521 m
.36309 .32522 L
s
.36309 .3252 m
.3631 .32521 L
s
.36309 .3252 m
.36309 .32522 L
s
0 1 .879 r
.48172 .42774 m
.48089 .42844 L
s
.771 0 1 r
.47862 .27943 m
.48467 .27194 L
s
1 0 .282 r
.42215 .34751 m
.42414 .34631 L
s
.42414 .34631 m
.42414 .34493 L
s
.42414 .34631 m
.42171 .34458 L
s
0 .016 1 r
.42093 .411 m
.42116 .41307 L
s
.42265 .41138 m
.42093 .411 L
s
.42093 .411 m
.42124 .41219 L
s
.4258 .41713 m
.42093 .411 L
s
.407 0 1 r
.47792 .39515 m
.47913 .39408 L
s
.47913 .39408 m
.47934 .39291 L
s
.47913 .39408 m
.47719 .39298 L
s
.299 0 1 r
.4222 .38099 m
.42369 .38007 L
s
.42369 .38007 m
.4237 .37905 L
s
.42369 .38007 m
.42186 .37878 L
s
0 .016 1 r
.42124 .41219 m
.42116 .41307 L
s
.647 0 1 r
.42104 .44213 m
.41935 .44298 L
s
1 0 .282 r
.42171 .34458 m
.42215 .34751 L
s
.42414 .34493 m
.42171 .34458 L
s
.42171 .34458 m
.42214 .34613 L
s
.42888 .35282 m
.42171 .34458 L
s
.36429 .39582 m
.36223 .39701 L
s
0 .279 1 r
.42196 .28697 m
.42065 .28612 L
s
.42222 .28502 m
.42196 .28697 L
s
.299 0 1 r
.42186 .37878 m
.4222 .38099 L
s
.4237 .37905 m
.42186 .37878 L
s
.42186 .37878 m
.42221 .37997 L
s
.42734 .38499 m
.42186 .37878 L
s
0 .279 1 r
.42065 .28612 m
.42222 .28502 L
s
1 0 .282 r
.42214 .34613 m
.42215 .34751 L
s
.299 0 1 r
.42221 .37997 m
.4222 .38099 L
s
.407 0 1 r
.47719 .39298 m
.47792 .39515 L
s
.47934 .39291 m
.47719 .39298 L
s
.47719 .39298 m
.47814 .39398 L
s
.4844 .39823 m
.47719 .39298 L
s
1 .028 0 r
.36488 .35355 m
.36489 .35354 L
s
.36489 .35354 m
.3649 .35353 L
s
.36489 .35354 m
.36487 .35352 L
s
.36487 .35352 m
.36488 .35355 L
s
.3649 .35353 m
.36487 .35352 L
s
.36487 .35352 m
.36488 .35354 L
s
.36495 .3536 m
.36487 .35352 L
s
.36488 .35354 m
.36488 .35355 L
s
.3649 .35353 m
.36488 .35354 L
s
.36495 .6464 m
.36502 .64632 L
s
.36501 .64633 m
.36502 .64635 L
s
.365 .64632 m
.36501 .64633 L
s
.36502 .64632 m
.36501 .64633 L
s
.365 .64634 m
.365 .64632 L
s
.365 .64632 m
.36502 .64632 L
s
.36502 .64635 m
.365 .64634 L
s
.36502 .64632 m
.36502 .64635 L
s
.365 .64634 m
.36502 .64632 L
s
0 .016 1 r
.42265 .41138 m
.42124 .41219 L
s
1 0 0 r
.42287 .64604 m
.42319 .64917 L
s
.42081 .64834 m
.42287 .64604 L
s
.407 0 1 r
.47814 .39398 m
.47792 .39515 L
s
0 1 .879 r
.4849 .5687 m
.48947 .56514 L
s
1 0 0 r
.36875 .60457 m
.36836 .60627 L
s
.36696 .603 m
.36875 .60457 L
s
.36948 .60347 m
.36875 .60457 L
s
.42319 .64917 m
.42081 .64834 L
s
.407 0 1 r
.47934 .39291 m
.47814 .39398 L
s
.683 0 1 r
.36608 .62739 m
.37316 .62287 L
s
.299 0 1 r
.4237 .37905 m
.42221 .37997 L
s
.771 0 1 r
.48427 .27355 m
.4843 .27443 L
s
.48261 .27245 m
.48427 .27355 L
s
.48467 .27194 m
.48427 .27355 L
s
0 1 .879 r
.48892 .56583 m
.48903 .56657 L
s
.48808 .56513 m
.48892 .56583 L
s
.48947 .56514 m
.48892 .56583 L
s
1 0 .282 r
.42414 .34493 m
.42214 .34613 L
s
.647 0 1 r
.42426 .55076 m
.4295 .54295 L
s
1 0 0 r
.36657 .6047 m
.36696 .603 L
s
.36696 .603 m
.36948 .60347 L
s
.797 0 1 r
.31188 .41728 m
.31198 .4163 L
s
.31198 .4163 m
.31026 .41523 L
s
.31198 .4163 m
.30992 .41773 L
s
.771 0 1 r
.48265 .27333 m
.48261 .27245 L
s
.48261 .27245 m
.48467 .27194 L
s
0 1 .879 r
.48819 .56587 m
.48808 .56513 L
s
.48808 .56513 m
.48947 .56514 L
s
0 .264 1 r
.48358 .76925 m
.48488 .76839 L
s
.48488 .76839 m
.48491 .76773 L
s
.48488 .76839 m
.48331 .7673 L
s
.797 0 1 r
.30992 .41773 m
.31188 .41728 L
s
.31026 .41523 m
.30992 .41773 L
s
.30992 .41773 m
.31016 .41622 L
s
.31568 .41038 m
.30992 .41773 L
s
0 .264 1 r
.48331 .7673 m
.48358 .76925 L
s
.48491 .76773 m
.48331 .7673 L
s
.48331 .7673 m
.48361 .7686 L
s
.488 .77329 m
.48331 .7673 L
s
0 1 .879 r
.48903 .56657 m
.48819 .56587 L
s
.48947 .56514 m
.48903 .56657 L
s
.797 0 1 r
.31026 .41523 m
.31016 .41622 L
s
0 .016 1 r
.4258 .58287 m
.43067 .57673 L
s
0 .264 1 r
.48361 .7686 m
.48358 .76925 L
s
.647 0 1 r
.42917 .54449 m
.42942 .54539 L
s
.42748 .54363 m
.42917 .54449 L
s
.4295 .54295 m
.42917 .54449 L
s
0 1 .879 r
.48819 .56587 m
.48947 .56514 L
s
1 0 0 r
.36836 .60627 m
.36657 .6047 L
s
.36948 .60347 m
.36836 .60627 L
s
1 0 .282 r
.36873 .5961 m
.37556 .58754 L
s
.771 0 1 r
.4843 .27443 m
.48265 .27333 L
s
.48467 .27194 m
.4843 .27443 L
s
.407 0 1 r
.4844 .60177 m
.49163 .59652 L
s
.771 0 1 r
.48265 .27333 m
.48467 .27194 L
s
1 .028 0 r
.36909 .34813 m
.3691 .34812 L
s
.3691 .34812 m
.36911 .34811 L
s
.3691 .34812 m
.36908 .3481 L
s
.647 0 1 r
.42774 .54453 m
.42748 .54363 L
s
.42748 .54363 m
.4295 .54295 L
s
1 .028 0 r
.36908 .3481 m
.36909 .34813 L
s
.36911 .34811 m
.36908 .3481 L
s
.36908 .3481 m
.36909 .34812 L
s
.36916 .34818 m
.36908 .3481 L
s
.36909 .34812 m
.36909 .34813 L
s
.36911 .34811 m
.36909 .34812 L
s
.36916 .65182 m
.36924 .65175 L
s
.36923 .65176 m
.36923 .65177 L
s
.36921 .65175 m
.36923 .65176 L
s
.36924 .65175 m
.36923 .65176 L
s
.36922 .65176 m
.36921 .65175 L
s
.36921 .65175 m
.36924 .65175 L
s
.36923 .65177 m
.36922 .65176 L
s
.36924 .65175 m
.36923 .65177 L
s
.36922 .65176 m
.36924 .65175 L
s
0 .264 1 r
.48491 .76773 m
.48361 .7686 L
s
1 0 0 r
.36657 .6047 m
.36948 .60347 L
s
.299 0 1 r
.42734 .61501 m
.43283 .60879 L
s
.797 0 1 r
.31016 .41622 m
.31188 .41728 L
s
.765 0 1 r
.42874 .68455 m
.43043 .68347 L
s
.43043 .68347 m
.43043 .68258 L
s
.43043 .68347 m
.42841 .68206 L
s
.683 0 1 r
.3726 .62372 m
.37229 .62506 L
s
.37119 .6225 m
.3726 .62372 L
s
.37316 .62287 m
.3726 .62372 L
s
0 .016 1 r
.43036 .57792 m
.43044 .5788 L
s
.42895 .57711 m
.43036 .57792 L
s
.43067 .57673 m
.43036 .57792 L
s
.407 0 1 r
.49067 .59752 m
.49089 .59869 L
s
.48946 .59645 m
.49067 .59752 L
s
.49163 .59652 m
.49067 .59752 L
s
.765 0 1 r
.42841 .68206 m
.42874 .68455 L
s
.43043 .68258 m
.42841 .68206 L
s
.42841 .68206 m
.42874 .68365 L
s
.43428 .68959 m
.42841 .68206 L
s
.647 0 1 r
.42942 .54539 m
.42774 .54453 L
s
.4295 .54295 m
.42942 .54539 L
s
.42774 .54453 m
.4295 .54295 L
s
0 .016 1 r
.42903 .57799 m
.42895 .57711 L
s
.42895 .57711 m
.43067 .57673 L
s
.765 0 1 r
.42874 .68365 m
.42874 .68455 L
s
1 0 .282 r
.42888 .64718 m
.43607 .6389 L
s
.683 0 1 r
.37089 .62384 m
.37119 .6225 L
s
.37119 .6225 m
.37316 .62287 L
s
.407 0 1 r
.48969 .59762 m
.48946 .59645 L
s
.48946 .59645 m
.49163 .59652 L
s
.299 0 1 r
.43247 .60998 m
.43249 .611 L
s
.43097 .60906 m
.43247 .60998 L
s
.43283 .60879 m
.43247 .60998 L
s
1 0 .282 r
.37524 .5892 m
.37519 .5905 L
s
.37319 .58801 m
.37524 .5892 L
s
.37556 .58754 m
.37524 .5892 L
s
0 .016 1 r
.43044 .5788 m
.42903 .57799 L
s
.43067 .57673 m
.43044 .5788 L
s
.683 0 1 r
.37229 .62506 m
.37089 .62384 L
s
.37316 .62287 m
.37229 .62506 L
s
0 .264 1 r
.488 .22671 m
.49271 .22069 L
s
0 .016 1 r
.42903 .57799 m
.43067 .57673 L
s
.407 0 1 r
.49089 .59869 m
.48969 .59762 L
s
.49163 .59652 m
.49089 .59869 L
s
.765 0 1 r
.43043 .68258 m
.42874 .68365 L
s
.407 0 1 r
.48969 .59762 m
.49163 .59652 L
s
.299 0 1 r
.43099 .61008 m
.43097 .60906 L
s
.43097 .60906 m
.43283 .60879 L
s
.683 0 1 r
.37089 .62384 m
.37316 .62287 L
s
1 0 .282 r
.37313 .58931 m
.37319 .58801 L
s
.37319 .58801 m
.37556 .58754 L
s
0 1 .475 r
.47435 .46146 m
.47531 .46107 L
s
.47531 .46107 m
.47544 .46066 L
s
.47531 .46107 m
.47443 .46015 L
s
1 0 .456 r
.37485 .41303 m
.37688 .41191 L
s
.37688 .41191 m
.37681 .41069 L
s
.37688 .41191 m
.37457 .41015 L
s
.797 0 1 r
.31568 .58962 m
.32146 .59698 L
s
0 1 .475 r
.47447 .46105 m
.47435 .46146 L
s
.47443 .46015 m
.47435 .46146 L
s
.47544 .46066 m
.47443 .46015 L
s
.47443 .46015 m
.47447 .46105 L
s
.47673 .46469 m
.47443 .46015 L
s
1 0 .456 r
.37457 .41015 m
.37485 .41303 L
s
.37681 .41069 m
.37457 .41015 L
s
.37457 .41015 m
.37478 .41181 L
s
.3809 .41873 m
.37457 .41015 L
s
.299 0 1 r
.43249 .611 m
.43099 .61008 L
s
.43283 .60879 m
.43249 .611 L
s
1 0 .456 r
.37478 .41181 m
.37485 .41303 L
s
1 0 .282 r
.43562 .64048 m
.43563 .64185 L
s
.43362 .63927 m
.43562 .64048 L
s
.43607 .6389 m
.43562 .64048 L
s
0 .264 1 r
.4924 .222 m
.49244 .22265 L
s
.49109 .22114 m
.4924 .222 L
s
.49271 .22069 m
.4924 .222 L
s
.299 0 1 r
.43099 .61008 m
.43283 .60879 L
s
.4 0 1 r
.31874 .37301 m
.31928 .37178 L
s
.31928 .37178 m
.31816 .37043 L
s
.31928 .37178 m
.31701 .37228 L
s
0 1 .475 r
.47544 .46066 m
.47447 .46105 L
s
.4 0 1 r
.31701 .37228 m
.31874 .37301 L
s
.31816 .37043 m
.31701 .37228 L
s
.31701 .37228 m
.31762 .37166 L
s
.32422 .36948 m
.31701 .37228 L
s
0 .186 1 r
.49266 .41299 m
.49333 .41192 L
s
.49333 .41192 m
.49341 .41077 L
s
.49333 .41192 m
.49154 .41135 L
s
1 0 .282 r
.37519 .5905 m
.37313 .58931 L
s
.37556 .58754 m
.37519 .5905 L
s
0 .264 1 r
.49113 .22179 m
.49109 .22114 L
s
.49109 .22114 m
.49271 .22069 L
s
0 .069 1 r
.43267 .45887 m
.43411 .45831 L
s
.43411 .45831 m
.43463 .45771 L
s
.43411 .45831 m
.43291 .45681 L
s
1 0 .282 r
.43363 .64064 m
.43362 .63927 L
s
.43362 .63927 m
.43607 .6389 L
s
.37313 .58931 m
.37556 .58754 L
s
1 0 .456 r
.43447 .36254 m
.43636 .36133 L
s
.43636 .36133 m
.43638 .35997 L
s
.43636 .36133 m
.43397 .3597 L
s
0 .508 1 r
.43406 .42829 m
.4353 .4276 L
s
.4353 .4276 m
.43543 .42685 L
s
.4353 .4276 m
.43389 .42646 L
s
0 1 .475 r
.47673 .53531 m
.47902 .53076 L
s
.4 0 1 r
.31816 .37043 m
.31762 .37166 L
s
0 .186 1 r
.49154 .41135 m
.49266 .41299 L
s
.49341 .41077 m
.49154 .41135 L
s
.49154 .41135 m
.49275 .41184 L
s
.49902 .414 m
.49154 .41135 L
s
.765 0 1 r
.43428 .31041 m
.44017 .30285 L
s
.452 0 1 r
.37734 .38217 m
.37894 .38124 L
s
.37894 .38124 m
.3789 .3802 L
s
.37894 .38124 m
.37704 .37986 L
s
0 .016 1 r
.4348 .39612 m
.43617 .39525 L
s
.43617 .39525 m
.4362 .39429 L
s
.43617 .39525 m
.43445 .39407 L
s
0 .069 1 r
.43319 .45827 m
.43267 .45887 L
s
.43291 .45681 m
.43267 .45887 L
s
.797 0 1 r
.32121 .59546 m
.31949 .59653 L
s
.32112 .59448 m
.32121 .59546 L
s
.32146 .59698 m
.32121 .59546 L
s
1 0 .456 r
.43397 .3597 m
.43447 .36254 L
s
.43638 .35997 m
.43397 .3597 L
s
.43397 .3597 m
.43448 .36117 L
s
.44125 .36749 m
.43397 .3597 L
s
.37681 .41069 m
.37478 .41181 L
s
0 .186 1 r
.49275 .41184 m
.49266 .41299 L
s
0 .508 1 r
.43389 .42646 m
.43406 .42829 L
s
.43543 .42685 m
.43389 .42646 L
s
.43389 .42646 m
.43419 .42754 L
s
.43815 .432 m
.43389 .42646 L
s
0 .069 1 r
.43463 .45771 m
.43291 .45681 L
s
.43291 .45681 m
.43319 .45827 L
s
.4366 .46422 m
.43291 .45681 L
s
0 .264 1 r
.49244 .22265 m
.49113 .22179 L
s
.49271 .22069 m
.49244 .22265 L
s
.4 0 1 r
.31762 .37166 m
.31874 .37301 L
s
0 .508 1 r
.43419 .42754 m
.43406 .42829 L
s
0 .186 1 r
.49341 .41077 m
.49275 .41184 L
s
0 1 .475 r
.47898 .53166 m
.4791 .53207 L
s
.47802 .53127 m
.47898 .53166 L
s
.47902 .53076 m
.47898 .53166 L
s
0 .264 1 r
.49113 .22179 m
.49271 .22069 L
s
.452 0 1 r
.37704 .37986 m
.37734 .38217 L
s
.3789 .3802 m
.37704 .37986 L
s
.37704 .37986 m
.3773 .38113 L
s
.38242 .38647 m
.37704 .37986 L
s
1 0 .456 r
.43448 .36117 m
.43447 .36254 L
s
0 .016 1 r
.43445 .39407 m
.4348 .39612 L
s
.4362 .39429 m
.43445 .39407 L
s
.43445 .39407 m
.43483 .39516 L
s
.4397 .39976 m
.43445 .39407 L
s
.452 0 1 r
.3773 .38113 m
.37734 .38217 L
s
0 .016 1 r
.43483 .39516 m
.4348 .39612 L
s
0 1 .475 r
.47814 .53168 m
.47802 .53127 L
s
.47802 .53127 m
.47902 .53076 L
s
.797 0 1 r
.31949 .59653 m
.3194 .59555 L
s
.32146 .59698 m
.31949 .59653 L
s
0 .069 1 r
.43463 .45771 m
.43319 .45827 L
s
1 0 .282 r
.43563 .64185 m
.43363 .64064 L
s
.43607 .6389 m
.43563 .64185 L
s
0 .508 1 r
.43543 .42685 m
.43419 .42754 L
s
1 0 .282 r
.43363 .64064 m
.43607 .6389 L
s
0 1 .475 r
.47902 .53076 m
.4791 .53207 L
s
.47814 .53168 m
.47902 .53076 L
s
.4791 .53207 m
.47814 .53168 L
s
0 .016 1 r
.4362 .39429 m
.43483 .39516 L
s
0 .069 1 r
.4366 .53578 m
.4403 .52837 L
s
.44002 .52984 m
.44054 .53043 L
s
.43858 .52928 m
.44002 .52984 L
s
.4403 .52837 m
.44002 .52984 L
s
1 0 .456 r
.43638 .35997 m
.43448 .36117 L
s
.452 0 1 r
.3789 .3802 m
.3773 .38113 L
s
0 .186 1 r
.49902 .586 m
.50652 .58335 L
s
.797 0 1 r
.3194 .59555 m
.32112 .59448 L
s
.32112 .59448 m
.32146 .59698 L
s
.765 0 1 r
.43983 .30446 m
.43984 .30535 L
s
.43815 .30338 m
.43983 .30446 L
s
.44017 .30285 m
.43983 .30446 L
s
.269 0 1 r
.37988 .67227 m
.38167 .67189 L
s
.38167 .67189 m
.38191 .67166 L
s
.38167 .67189 m
.3805 .67018 L
s
.797 0 1 r
.3194 .59555 m
.32146 .59698 L
s
0 .186 1 r
.5053 .58384 m
.50539 .58499 L
s
.50464 .58277 m
.5053 .58384 L
s
.50652 .58335 m
.5053 .58384 L
s
.683 0 1 r
.38043 .34273 m
.3823 .34208 L
s
.3823 .34208 m
.38246 .34128 L
s
.3823 .34208 m
.38068 .34027 L
s
1 0 .528 r
.32419 .3931 m
.32485 .39156 L
s
.32485 .39156 m
.32346 .3899 L
s
.32485 .39156 m
.32204 .3922 L
s
0 .069 1 r
.4391 .52987 m
.43858 .52928 L
s
.43858 .52928 m
.4403 .52837 L
s
.269 0 1 r
.38011 .67204 m
.37988 .67227 L
s
.3805 .67018 m
.37988 .67227 L
s
1 0 .528 r
.32204 .3922 m
.32419 .3931 L
s
.32346 .3899 m
.32204 .3922 L
s
.32204 .3922 m
.32279 .39144 L
s
.331 .38871 m
.32204 .3922 L
s
0 .508 1 r
.43815 .568 m
.44242 .56245 L
s
.765 0 1 r
.43815 .30427 m
.43815 .30338 L
s
.43815 .30338 m
.44017 .30285 L
s
.683 0 1 r
.38059 .34193 m
.38043 .34273 L
s
.38068 .34027 m
.38043 .34273 L
s
.269 0 1 r
.38191 .67166 m
.3805 .67018 L
s
.3805 .67018 m
.38011 .67204 L
s
.38247 .67911 m
.3805 .67018 L
s
0 .295 1 r
.43922 .73847 m
.44052 .73762 L
s
.44052 .73762 m
.44052 .73694 L
s
.44052 .73762 m
.43894 .73653 L
s
.683 0 1 r
.38246 .34128 m
.38068 .34027 L
s
.38068 .34027 m
.38059 .34193 L
s
.38453 .34895 m
.38068 .34027 L
s
0 .069 1 r
.4403 .52837 m
.44054 .53043 L
s
.4391 .52987 m
.4403 .52837 L
s
.44054 .53043 m
.4391 .52987 L
s
1 0 .456 r
.3809 .58127 m
.38725 .57266 L
s
0 .295 1 r
.43894 .73653 m
.43922 .73847 L
s
.44052 .73694 m
.43894 .73653 L
s
.43894 .73653 m
.43922 .7378 L
s
.44358 .74243 m
.43894 .73653 L
s
0 .186 1 r
.50473 .58392 m
.50464 .58277 L
s
.50464 .58277 m
.50652 .58335 L
s
0 .295 1 r
.43922 .7378 m
.43922 .73847 L
s
0 .186 1 r
.50539 .58499 m
.50473 .58392 L
s
.50652 .58335 m
.50539 .58499 L
s
1 0 .528 r
.32346 .3899 m
.32279 .39144 L
s
0 .186 1 r
.50473 .58392 m
.50652 .58335 L
s
0 .016 1 r
.4397 .60024 m
.44497 .59454 L
s
0 .508 1 r
.44212 .56354 m
.44225 .56428 L
s
.44088 .56284 m
.44212 .56354 L
s
.44242 .56245 m
.44212 .56354 L
s
.765 0 1 r
.43984 .30535 m
.43815 .30427 L
s
.44017 .30285 m
.43984 .30535 L
s
.269 0 1 r
.38191 .67166 m
.38011 .67204 L
s
1 0 .528 r
.32279 .39144 m
.32419 .3931 L
s
.4 0 1 r
.32422 .63052 m
.33147 .63334 L
s
.765 0 1 r
.43815 .30427 m
.44017 .30285 L
s
.452 0 1 r
.38242 .61353 m
.38782 .6069 L
s
.729 0 1 r
.49936 .74895 m
.50101 .74786 L
s
.50101 .74786 m
.50106 .74701 L
s
.50101 .74786 m
.49901 .74647 L
s
.683 0 1 r
.38246 .34128 m
.38059 .34193 L
s
.269 0 1 r
.38247 .32089 m
.38444 .31195 L
s
.38483 .31382 m
.38506 .31404 L
s
.38303 .31344 m
.38483 .31382 L
s
.38444 .31195 m
.38483 .31382 L
s
0 .508 1 r
.44101 .56359 m
.44088 .56284 L
s
.44088 .56284 m
.44242 .56245 L
s
0 .295 1 r
.44052 .73694 m
.43922 .7378 L
s
.269 0 1 r
.38327 .31366 m
.38303 .31344 L
s
.38303 .31344 m
.38444 .31195 L
s
.729 0 1 r
.49901 .74647 m
.49936 .74895 L
s
.50106 .74701 m
.49901 .74647 L
s
.49901 .74647 m
.49941 .7481 L
s
.50501 .75404 m
.49901 .74647 L
s
1 0 .456 r
.44125 .63251 m
.44857 .62469 L
s
.729 0 1 r
.49941 .7481 m
.49936 .74895 L
s
0 .508 1 r
.44225 .56428 m
.44101 .56359 L
s
.44242 .56245 m
.44225 .56428 L
s
.44101 .56359 m
.44242 .56245 L
s
0 .016 1 r
.44458 .59564 m
.44462 .59659 L
s
.44321 .59477 m
.44458 .59564 L
s
.44497 .59454 m
.44458 .59564 L
s
1 0 .456 r
.38703 .57435 m
.38697 .57556 L
s
.38499 .57322 m
.38703 .57435 L
s
.38725 .57266 m
.38703 .57435 L
s
.269 0 1 r
.38444 .31195 m
.38506 .31404 L
s
.38327 .31366 m
.38444 .31195 L
s
.683 0 1 r
.38453 .65105 m
.3884 .64235 L
s
1 .011 0 r
.32694 .65475 m
.32694 .65476 L
s
.32694 .65475 m
.32694 .65475 L
s
.32694 .65475 m
.32693 .65476 L
s
.32695 .65476 m
.32694 .65475 L
s
.32693 .65479 m
.32694 .65475 L
s
.32694 .65476 m
.32695 .65476 L
s
.32693 .65476 m
.32694 .65476 L
s
.32694 .65475 m
.32693 .65476 L
s
.32695 .65476 m
.32694 .65475 L
s
0 .016 1 r
.44325 .59572 m
.44321 .59477 L
s
.44321 .59477 m
.44497 .59454 L
s
1 .011 0 r
.32693 .34521 m
.32692 .34516 L
s
.32692 .34516 m
.32693 .34517 L
s
.32691 .34517 m
.32692 .34516 L
s
.32692 .34516 m
.32692 .34516 L
s
.729 0 1 r
.50106 .74701 m
.49941 .7481 L
s
1 .011 0 r
.32692 .34518 m
.32691 .34517 L
s
.32691 .34517 m
.32692 .34516 L
s
.32693 .34517 m
.32692 .34518 L
s
.32692 .34516 m
.32693 .34517 L
s
.32692 .34516 m
.32692 .34518 L
s
.269 0 1 r
.38506 .31404 m
.38327 .31366 L
s
.452 0 1 r
.38756 .60818 m
.38752 .60921 L
s
.38596 .60724 m
.38756 .60818 L
s
.38782 .6069 m
.38756 .60818 L
s
1 0 .456 r
.38493 .57443 m
.38499 .57322 L
s
.38499 .57322 m
.38725 .57266 L
s
0 .295 1 r
.44358 .25757 m
.44824 .25165 L
s
.683 0 1 r
.38847 .64402 m
.38864 .64482 L
s
.3866 .64337 m
.38847 .64402 L
s
.3884 .64235 m
.38847 .64402 L
s
.452 0 1 r
.38592 .60828 m
.38596 .60724 L
s
.38596 .60724 m
.38782 .6069 L
s
0 .016 1 r
.44462 .59659 m
.44325 .59572 L
s
.44497 .59454 m
.44462 .59659 L
s
1 0 .807 r
.38772 .42802 m
.38967 .427 L
s
.38967 .427 m
.38959 .42591 L
s
.38967 .427 m
.38753 .42529 L
s
.4 0 1 r
.33084 .63271 m
.32973 .63406 L
s
.33031 .63148 m
.33084 .63271 L
s
.33147 .63334 m
.33084 .63271 L
s
0 .016 1 r
.44325 .59572 m
.44497 .59454 L
s
1 0 .456 r
.44804 .62619 m
.44807 .62754 L
s
.44614 .62498 m
.44804 .62619 L
s
.44857 .62469 m
.44804 .62619 L
s
.683 0 1 r
.38677 .64416 m
.3866 .64337 L
s
.3866 .64337 m
.3884 .64235 L
s
0 1 .883 r
.44367 .47176 m
.44461 .47138 L
s
.44461 .47138 m
.44525 .47099 L
s
.44461 .47138 m
.44393 .47025 L
s
1 0 .807 r
.38753 .42529 m
.38772 .42802 L
s
.38959 .42591 m
.38753 .42529 L
s
.38753 .42529 m
.38764 .42693 L
s
.39315 .43366 m
.38753 .42529 L
s
.38764 .42693 m
.38772 .42802 L
s
1 0 .456 r
.38697 .57556 m
.38493 .57443 L
s
.38725 .57266 m
.38697 .57556 L
s
.452 0 1 r
.38752 .60921 m
.38592 .60828 L
s
.38782 .6069 m
.38752 .60921 L
s
1 0 .456 r
.38493 .57443 m
.38725 .57266 L
s
0 1 .883 r
.44884 .51965 m
.44948 .52004 L
s
.44789 .51927 m
.44884 .51965 L
s
.44921 .51853 m
.44884 .51965 L
s
0 1 .475 r
.48927 .44377 m
.49002 .44313 L
s
.49002 .44313 m
.48993 .44245 L
s
.49002 .44313 m
.48883 .44257 L
s
.4 0 1 r
.32973 .63406 m
.32919 .63283 L
s
.33147 .63334 m
.32973 .63406 L
s
1 0 .456 r
.44617 .62633 m
.44614 .62498 L
s
.44614 .62498 m
.44857 .62469 L
s
0 .295 1 r
.44796 .25293 m
.44796 .25361 L
s
.44665 .25207 m
.44796 .25293 L
s
.44824 .25165 m
.44796 .25293 L
s
0 1 .883 r
.44431 .47136 m
.44367 .47176 L
s
.44393 .47025 m
.44367 .47176 L
s
.44525 .47099 m
.44393 .47025 L
s
.44393 .47025 m
.44431 .47136 L
s
.44657 .47586 m
.44393 .47025 L
s
.452 0 1 r
.38592 .60828 m
.38782 .6069 L
s
0 1 .475 r
.48883 .44257 m
.48927 .44377 L
s
.48993 .44245 m
.48883 .44257 L
s
.48883 .44257 m
.48917 .4431 L
s
.49265 .44528 m
.48883 .44257 L
s
0 1 .883 r
.44525 .47099 m
.44431 .47136 L
s
0 1 .475 r
.48917 .4431 m
.48927 .44377 L
s
.4 0 1 r
.32919 .63283 m
.33031 .63148 L
s
.33031 .63148 m
.33147 .63334 L
s
.683 0 1 r
.3884 .64235 m
.38864 .64482 L
s
.38677 .64416 m
.3884 .64235 L
s
1 0 .807 r
.44708 .37786 m
.44881 .37669 L
s
.44881 .37669 m
.44883 .37538 L
s
.44881 .37669 m
.44652 .37522 L
s
0 1 .883 r
.44657 .52414 m
.44921 .51853 L
s
0 .295 1 r
.44665 .25274 m
.44665 .25207 L
s
.44665 .25207 m
.44824 .25165 L
s
.683 0 1 r
.38864 .64482 m
.38677 .64416 L
s
0 1 .883 r
.44854 .51966 m
.44789 .51927 L
s
.44789 .51927 m
.44921 .51853 L
s
.299 0 1 r
.38984 .39703 m
.3914 .39613 L
s
.3914 .39613 m
.39136 .39515 L
s
.3914 .39613 m
.38958 .39478 L
s
.729 0 1 r
.50501 .24596 m
.51103 .23836 L
s
0 1 .475 r
.48993 .44245 m
.48917 .4431 L
s
0 1 .883 r
.44921 .51853 m
.44948 .52004 L
s
.44854 .51966 m
.44921 .51853 L
s
1 0 .528 r
.331 .61129 m
.34 .61479 L
s
0 1 .883 r
.44948 .52004 m
.44854 .51966 L
s
1 0 .807 r
.38959 .42591 m
.38764 .42693 L
s
.44652 .37522 m
.44708 .37786 L
s
.44883 .37538 m
.44652 .37522 L
s
.44652 .37522 m
.4471 .37656 L
s
.45372 .38225 m
.44652 .37522 L
s
0 .508 1 r
.44769 .41153 m
.44886 .41075 L
s
.44886 .41075 m
.44891 .4099 L
s
.44886 .41075 m
.44734 .40974 L
s
.299 0 1 r
.38958 .39478 m
.38984 .39703 L
s
.39136 .39515 m
.38958 .39478 L
s
.38958 .39478 m
.38979 .39604 L
s
.39468 .4013 m
.38958 .39478 L
s
0 1 .741 r
.4475 .44371 m
.4485 .44322 L
s
.4485 .44322 m
.4487 .44269 L
s
.4485 .44322 m
.44748 .44226 L
s
.4 0 1 r
.32919 .63283 m
.33147 .63334 L
s
1 0 .456 r
.44807 .62754 m
.44617 .62633 L
s
.44857 .62469 m
.44807 .62754 L
s
.299 0 1 r
.38979 .39604 m
.38984 .39703 L
s
1 0 .807 r
.4471 .37656 m
.44708 .37786 L
s
1 0 .072 r
.33307 .38671 m
.33485 .38514 L
s
.33485 .38514 m
.33441 .38343 L
s
.33485 .38514 m
.33194 .38396 L
s
0 .508 1 r
.44734 .40974 m
.44769 .41153 L
s
.44891 .4099 m
.44734 .40974 L
s
.44734 .40974 m
.44774 .41068 L
s
.45215 .41463 m
.44734 .40974 L
s
0 .295 1 r
.44796 .25361 m
.44665 .25274 L
s
.44824 .25165 m
.44796 .25361 L
s
1 0 .456 r
.44617 .62633 m
.44857 .62469 L
s
.452 0 1 r
.39107 .36468 m
.39266 .36374 L
s
.39266 .36374 m
.39261 .36268 L
s
.39266 .36374 m
.39075 .36237 L
s
0 1 .741 r
.44748 .44226 m
.4475 .44371 L
s
.4487 .44269 m
.44748 .44226 L
s
.44748 .44226 m
.4477 .44318 L
s
.45059 .44697 m
.44748 .44226 L
s
0 .295 1 r
.44665 .25274 m
.44824 .25165 L
s
0 1 .741 r
.4477 .44318 m
.4475 .44371 L
s
1 0 .072 r
.33194 .38396 m
.33307 .38671 L
s
.33441 .38343 m
.33194 .38396 L
s
.33194 .38396 m
.33264 .385 L
s
.34098 .38954 m
.33194 .38396 L
s
0 .508 1 r
.44774 .41068 m
.44769 .41153 L
s
.452 0 1 r
.39075 .36237 m
.39107 .36468 L
s
.39261 .36268 m
.39075 .36237 L
s
.39075 .36237 m
.39102 .36362 L
s
.39622 .36891 m
.39075 .36237 L
s
.39102 .36362 m
.39107 .36468 L
s
0 .015 1 r
.50839 .79544 m
.50949 .79424 L
s
.50949 .79424 m
.50923 .79327 L
s
.50949 .79424 m
.5075 .79355 L
s
0 1 .741 r
.4487 .44269 m
.4477 .44318 L
s
.299 0 1 r
.39136 .39515 m
.38979 .39604 L
s
1 0 .807 r
.44883 .37538 m
.4471 .37656 L
s
0 .508 1 r
.44891 .4099 m
.44774 .41068 L
s
0 .015 1 r
.5075 .79355 m
.50839 .79544 L
s
.50923 .79327 m
.5075 .79355 L
s
.5075 .79355 m
.50813 .79448 L
s
.51405 .79759 m
.5075 .79355 L
s
1 0 .072 r
.33264 .385 m
.33307 .38671 L
s
0 1 .475 r
.49265 .55472 m
.49648 .55202 L
s
.729 0 1 r
.51062 .24001 m
.51068 .24085 L
s
.50896 .23891 m
.51062 .24001 L
s
.51103 .23836 m
.51062 .24001 L
s
0 .015 1 r
.50813 .79448 m
.50839 .79544 L
s
0 1 .741 r
.45059 .55303 m
.45371 .5483 L
s
.452 0 1 r
.39261 .36268 m
.39102 .36362 L
s
1 0 .072 r
.33441 .38343 m
.33264 .385 L
s
.729 0 1 r
.50902 .23975 m
.50896 .23891 L
s
.50896 .23891 m
.51103 .23836 L
s
0 .015 1 r
.50923 .79327 m
.50813 .79448 L
s
1 0 0 r
.39384 .33321 m
.39623 .33238 L
s
.39623 .33238 m
.39647 .33134 L
s
.39623 .33238 m
.39416 .33005 L
s
1 0 .807 r
.39315 .56634 m
.39878 .55795 L
s
0 1 .741 r
.45348 .54923 m
.45369 .54976 L
s
.45249 .54874 m
.45348 .54923 L
s
.45371 .5483 m
.45348 .54923 L
s
0 1 .475 r
.49614 .55254 m
.49605 .55322 L
s
.49539 .5519 m
.49614 .55254 L
s
.49648 .55202 m
.49614 .55254 L
s
0 .279 1 r
.39452 .70734 m
.39585 .70649 L
s
.39585 .70649 m
.39584 .70579 L
s
.39585 .70649 m
.39426 .70537 L
s
0 1 .741 r
.45269 .54926 m
.45249 .54874 L
s
.45249 .54874 m
.45371 .5483 L
s
1 0 0 r
.39408 .33217 m
.39384 .33321 L
s
.39416 .33005 m
.39384 .33321 L
s
0 .508 1 r
.45215 .58537 m
.45698 .58047 L
s
0 .846 1 r
.49838 .42453 m
.49879 .42362 L
s
.49879 .42362 m
.49885 .42264 L
s
.49879 .42362 m
.49731 .42327 L
s
1 0 .524 r
.39488 .66252 m
.39719 .66204 L
s
.39719 .66204 m
.39749 .66174 L
s
.39719 .66204 m
.39568 .65984 L
s
0 1 .475 r
.4953 .55257 m
.49539 .5519 L
s
.49539 .5519 m
.49648 .55202 L
s
1 0 0 r
.39647 .33134 m
.39416 .33005 L
s
.39416 .33005 m
.39408 .33217 L
s
.39913 .3412 m
.39416 .33005 L
s
0 .279 1 r
.39426 .70537 m
.39452 .70734 L
s
.39584 .70579 m
.39426 .70537 L
s
.39426 .70537 m
.3945 .70665 L
s
.39884 .71134 m
.39426 .70537 L
s
.729 0 1 r
.51068 .24085 m
.50902 .23975 L
s
.51103 .23836 m
.51068 .24085 L
s
1 0 .528 r
.33922 .61402 m
.33783 .6157 L
s
.33857 .61248 m
.33922 .61402 L
s
.34 .61479 m
.33922 .61402 L
s
0 .279 1 r
.3945 .70665 m
.39452 .70734 L
s
.729 0 1 r
.50902 .23975 m
.51103 .23836 L
s
.299 0 1 r
.39468 .5987 m
.3998 .59217 L
s
0 1 .741 r
.45369 .54976 m
.45269 .54926 L
s
.45371 .5483 m
.45369 .54976 L
s
.45269 .54926 m
.45371 .5483 L
s
0 1 .475 r
.49605 .55322 m
.4953 .55257 L
s
.49648 .55202 m
.49605 .55322 L
s
1 0 .524 r
.39518 .66223 m
.39488 .66252 L
s
.39568 .65984 m
.39488 .66252 L
s
0 .846 1 r
.49731 .42327 m
.49838 .42453 L
s
.49885 .42264 m
.49731 .42327 L
s
.49731 .42327 m
.49844 .42356 L
s
.50382 .42487 m
.49731 .42327 L
s
0 1 .475 r
.4953 .55257 m
.49648 .55202 L
s
0 .846 1 r
.49844 .42356 m
.49838 .42453 L
s
1 0 .807 r
.45372 .61775 m
.46094 .61069 L
s
0 .846 1 r
.49885 .42264 m
.49844 .42356 L
s
1 0 .524 r
.39749 .66174 m
.39568 .65984 L
s
.39568 .65984 m
.39518 .66223 L
s
.39821 .67132 m
.39568 .65984 L
s
.73 0 1 r
.45481 .71796 m
.45647 .71686 L
s
.45647 .71686 m
.45648 .71598 L
s
.45647 .71686 m
.45445 .71547 L
s
0 .279 1 r
.39584 .70579 m
.3945 .70665 L
s
0 .508 1 r
.45657 .58142 m
.45662 .58227 L
s
.4554 .58063 m
.45657 .58142 L
s
.45698 .58047 m
.45657 .58142 L
s
1 0 .528 r
.33783 .6157 m
.33717 .61415 L
s
.34 .61479 m
.33783 .6157 L
s
1 0 .93 r
.514 .77481 m
.51538 .77328 L
s
.51538 .77328 m
.51505 .77203 L
s
.51538 .77328 m
.51285 .77242 L
s
.452 0 1 r
.39622 .63109 m
.40172 .62453 L
s
.73 0 1 r
.45445 .71547 m
.45481 .71796 L
s
.45648 .71598 m
.45445 .71547 L
s
.45445 .71547 m
.45482 .71708 L
s
.46045 .72296 m
.45445 .71547 L
s
1 0 .807 r
.39866 .5596 m
.3986 .56069 L
s
.39671 .55857 m
.39866 .5596 L
s
.39878 .55795 m
.39866 .5596 L
s
1 0 .93 r
.51285 .77242 m
.514 .77481 L
s
.51505 .77203 m
.51285 .77242 L
s
.51285 .77242 m
.51366 .77356 L
s
.52121 .77744 m
.51285 .77242 L
s
1 0 0 r
.39647 .33134 m
.39408 .33217 L
s
.73 0 1 r
.45482 .71708 m
.45481 .71796 L
s
0 .508 1 r
.45545 .58148 m
.4554 .58063 L
s
.4554 .58063 m
.45698 .58047 L
s
1 0 .528 r
.33717 .61415 m
.33857 .61248 L
s
.33857 .61248 m
.34 .61479 L
s
0 .846 1 r
.5092 .57381 m
.50927 .57479 L
s
.50881 .57289 m
.5092 .57381 L
s
.51034 .57352 m
.5092 .57381 L
s
.50382 .57513 m
.51034 .57352 L
s
1 0 .807 r
.39664 .55966 m
.39671 .55857 L
s
.39671 .55857 m
.39878 .55795 L
s
.859 0 1 r
.34019 .36888 m
.34166 .3676 L
s
.34166 .3676 m
.34131 .36619 L
s
.34166 .3676 m
.33927 .36661 L
s
.299 0 1 r
.39958 .59343 m
.39954 .59441 L
s
.39802 .59253 m
.39958 .59343 L
s
.3998 .59217 m
.39958 .59343 L
s
1 0 .524 r
.39749 .66174 m
.39518 .66223 L
s
.859 0 1 r
.33927 .36661 m
.34019 .36888 L
s
.34131 .36619 m
.33927 .36661 L
s
.33927 .36661 m
.33984 .36746 L
s
.34668 .37123 m
.33927 .36661 L
s
1 0 .93 r
.51366 .77356 m
.514 .77481 L
s
0 .015 1 r
.51405 .20241 m
.52061 .19837 L
s
0 .508 1 r
.45662 .58227 m
.45545 .58148 L
s
.45698 .58047 m
.45662 .58227 L
s
.45545 .58148 m
.45698 .58047 L
s
0 .846 1 r
.50887 .57387 m
.50881 .57289 L
s
.50881 .57289 m
.51034 .57352 L
s
.299 0 1 r
.39797 .59352 m
.39802 .59253 L
s
.39802 .59253 m
.3998 .59217 L
s
1 0 .524 r
.39821 .32868 m
.40074 .31717 L
s
.40124 .31958 m
.40155 .31986 L
s
.39893 .31909 m
.40124 .31958 L
s
.40074 .31717 m
.40124 .31958 L
s
1 0 .528 r
.33717 .61415 m
.34 .61479 L
s
.73 0 1 r
.45648 .71598 m
.45482 .71708 L
s
0 .846 1 r
.50927 .57479 m
.50887 .57387 L
s
.51034 .57352 m
.50927 .57479 L
s
.859 0 1 r
.33984 .36746 m
.34019 .36888 L
s
0 .846 1 r
.50887 .57387 m
.51034 .57352 L
s
1 0 .93 r
.51505 .77203 m
.51366 .77356 L
s
1 .285 0 r
.51511 .82064 m
.51522 .82057 L
s
.51522 .82057 m
.51522 .82052 L
s
.51522 .82057 m
.51509 .82048 L
s
.51509 .82048 m
.51511 .82064 L
s
.51522 .82052 m
.51509 .82048 L
s
.51509 .82048 m
.51511 .82059 L
s
.51548 .82098 m
.51509 .82048 L
s
.51511 .82059 m
.51511 .82064 L
s
1 0 .807 r
.46034 .61204 m
.46037 .61334 L
s
.45861 .61086 m
.46034 .61204 L
s
.46094 .61069 m
.46034 .61204 L
s
1 .285 0 r
.51522 .82052 m
.51511 .82059 L
s
0 .279 1 r
.39884 .28866 m
.40343 .28269 L
s
1 0 .524 r
.39924 .31937 m
.39893 .31909 L
s
.39893 .31909 m
.40074 .31717 L
s
1 .285 0 r
.51548 .17902 m
.51587 .17852 L
s
.452 0 1 r
.40143 .62578 m
.40139 .62684 L
s
.39984 .62484 m
.40143 .62578 L
s
.40172 .62453 m
.40143 .62578 L
s
1 0 0 r
.39913 .6588 m
.40412 .64762 L
s
1 .285 0 r
.51584 .17863 m
.51585 .17868 L
s
.51574 .17855 m
.51584 .17863 L
s
.51587 .17852 m
.51584 .17863 L
s
.51574 .17861 m
.51574 .17855 L
s
.51574 .17855 m
.51587 .17852 L
s
1 0 .072 r
.34098 .61046 m
.35007 .60484 L
s
1 0 .807 r
.3986 .56069 m
.39664 .55966 L
s
.39878 .55795 m
.3986 .56069 L
s
1 .285 0 r
.51585 .17868 m
.51574 .17861 L
s
.51587 .17852 m
.51585 .17868 L
s
.51574 .17861 m
.51587 .17852 L
s
.647 0 1 r
.40092 .4433 m
.40271 .44243 L
s
.40271 .44243 m
.40263 .44151 L
s
.40271 .44243 m
.40085 .44084 L
s
1 0 .807 r
.39664 .55966 m
.39878 .55795 L
s
.859 0 1 r
.34131 .36619 m
.33984 .36746 L
s
.299 0 1 r
.39954 .59441 m
.39797 .59352 L
s
.3998 .59217 m
.39954 .59441 L
s
1 0 .807 r
.45865 .61216 m
.45861 .61086 L
s
.45861 .61086 m
.46094 .61069 L
s
.647 0 1 r
.40085 .44084 m
.40092 .4433 L
s
.40263 .44151 m
.40085 .44084 L
s
.40085 .44084 m
.40083 .44238 L
s
.40548 .44869 m
.40085 .44084 L
s
.452 0 1 r
.3998 .6259 m
.39984 .62484 L
s
.39984 .62484 m
.40172 .62453 L
s
.647 0 1 r
.40083 .44238 m
.40092 .4433 L
s
1 0 .399 r
.34312 .39731 m
.34517 .39614 L
s
.34517 .39614 m
.34504 .39485 L
s
.34517 .39614 m
.34277 .39439 L
s
.299 0 1 r
.39797 .59352 m
.3998 .59217 L
s
1 0 .399 r
.34277 .39439 m
.34312 .39731 L
s
.34504 .39485 m
.34277 .39439 L
s
.34277 .39439 m
.34299 .39602 L
s
.34934 .40285 m
.34277 .39439 L
s
1 0 .524 r
.40074 .31717 m
.40155 .31986 L
s
.39924 .31937 m
.40074 .31717 L
s
1 0 0 r
.4042 .64976 m
.40445 .65079 L
s
.4018 .64893 m
.4042 .64976 L
s
.40412 .64762 m
.4042 .64976 L
s
1 0 .399 r
.34299 .39602 m
.34312 .39731 L
s
0 .279 1 r
.40319 .28397 m
.40317 .28465 L
s
.40185 .28311 m
.40319 .28397 L
s
.40343 .28269 m
.40319 .28397 L
s
0 .015 1 r
.51997 .1993 m
.51972 .20026 L
s
.51888 .19809 m
.51997 .1993 L
s
.52061 .19837 m
.51997 .1993 L
s
1 0 .807 r
.46037 .61334 m
.45865 .61216 L
s
.46094 .61069 m
.46037 .61334 L
s
.647 0 1 r
.46003 .39352 m
.46151 .39242 L
s
.46151 .39242 m
.46153 .39121 L
s
.46151 .39242 m
.45941 .39118 L
s
.452 0 1 r
.40139 .62684 m
.3998 .6259 L
s
.40172 .62453 m
.40139 .62684 L
s
0 .016 1 r
.40262 .41214 m
.40409 .41132 L
s
.40409 .41132 m
.40404 .41042 L
s
.40409 .41132 m
.40241 .41005 L
s
1 0 .524 r
.40155 .31986 m
.39924 .31937 L
s
1 0 0 r
.40204 .64995 m
.4018 .64893 L
s
.4018 .64893 m
.40412 .64762 L
s
.452 0 1 r
.3998 .6259 m
.40172 .62453 L
s
0 .279 1 r
.40183 .2838 m
.40185 .28311 L
s
.40185 .28311 m
.40343 .28269 L
s
1 0 .807 r
.45865 .61216 m
.46094 .61069 L
s
1 .011 0 r
.34374 .67667 m
.34374 .67668 L
s
.34375 .67666 m
.34374 .67667 L
s
.34376 .67667 m
.34374 .67667 L
s
.34376 .67667 m
.34374 .67668 L
s
.34375 .67666 m
.34376 .67667 L
s
.34375 .67667 m
.34376 .67667 L
s
.34369 .67665 m
.34376 .67667 L
s
.34375 .67667 m
.34375 .67666 L
s
.34374 .67668 m
.34375 .67667 L
s
0 .016 1 r
.40241 .41005 m
.40262 .41214 L
s
.40404 .41042 m
.40241 .41005 L
s
.40241 .41005 m
.40257 .41125 L
s
.40703 .41623 m
.40241 .41005 L
s
1 .011 0 r
.34369 .32335 m
.34362 .32338 L
s
.34364 .32338 m
.34363 .32337 L
s
.34363 .32337 m
.34363 .32336 L
s
.34363 .32337 m
.34362 .32338 L
s
.34364 .32337 m
.34364 .32338 L
s
.34362 .32338 m
.34364 .32338 L
s
.34363 .32336 m
.34364 .32337 L
s
.34363 .32336 m
.34362 .32338 L
s
.647 0 1 r
.40263 .44151 m
.40083 .44238 L
s
1 .011 0 r
.34362 .32338 m
.34364 .32337 L
s
.647 0 1 r
.45941 .39118 m
.46003 .39352 L
s
.46153 .39121 m
.45941 .39118 L
s
.45941 .39118 m
.46005 .39231 L
s
.46626 .39712 m
.45941 .39118 L
s
.73 0 1 r
.46045 .27704 m
.46647 .26952 L
s
1 0 .282 r
.40344 .34586 m
.40547 .34465 L
s
.40547 .34465 m
.40542 .34326 L
s
.40547 .34465 m
.40301 .3429 L
s
0 .016 1 r
.40257 .41125 m
.40262 .41214 L
s
0 .015 1 r
.51862 .19905 m
.51888 .19809 L
s
.51888 .19809 m
.52061 .19837 L
s
.299 0 1 r
.40357 .37971 m
.4051 .37878 L
s
.4051 .37878 m
.40503 .37775 L
s
.4051 .37878 m
.40323 .37748 L
s
0 1 .741 r
.46092 .42753 m
.46177 .42686 L
s
.46177 .42686 m
.46179 .42615 L
s
.46177 .42686 m
.46052 .42615 L
s
.647 0 1 r
.46005 .39231 m
.46003 .39352 L
s
.128 1 0 r
.46113 .4622 m
.46181 .46185 L
s
.46181 .46185 m
.46194 .46148 L
s
.46181 .46185 m
.4611 .4612 L
s
1 0 .282 r
.40301 .3429 m
.40344 .34586 L
s
.40542 .34326 m
.40301 .3429 L
s
.40301 .3429 m
.40338 .34447 L
s
.41013 .35122 m
.40301 .3429 L
s
0 1 .741 r
.46052 .42615 m
.46092 .42753 L
s
.46179 .42615 m
.46052 .42615 L
s
.46052 .42615 m
.46094 .42682 L
s
.46469 .4296 m
.46052 .42615 L
s
.299 0 1 r
.40323 .37748 m
.40357 .37971 L
s
.40503 .37775 m
.40323 .37748 L
s
.40323 .37748 m
.4035 .37867 L
s
.40858 .38374 m
.40323 .37748 L
s
1 0 .399 r
.34504 .39485 m
.34299 .39602 L
s
0 .015 1 r
.51972 .20026 m
.51862 .19905 L
s
.52061 .19837 m
.51972 .20026 L
s
0 .279 1 r
.40317 .28465 m
.40183 .2838 L
s
.40343 .28269 m
.40317 .28465 L
s
.128 1 0 r
.4611 .4612 m
.46113 .4622 L
s
.46194 .46148 m
.4611 .4612 L
s
.4611 .4612 m
.46125 .46183 L
s
.46328 .46441 m
.4611 .4612 L
s
.46125 .46183 m
.46113 .4622 L
s
0 1 .741 r
.46094 .42682 m
.46092 .42753 L
s
1 0 .282 r
.40338 .34447 m
.40344 .34586 L
s
.299 0 1 r
.4035 .37867 m
.40357 .37971 L
s
0 .279 1 r
.40183 .2838 m
.40343 .28269 L
s
1 .033 0 r
.34549 .64806 m
.3455 .64806 L
s
.34549 .64803 m
.34549 .64806 L
s
.34549 .64806 m
.34548 .64805 L
s
.34551 .64805 m
.34549 .64806 L
s
.34553 .64799 m
.34549 .64806 L
s
.34549 .64803 m
.34548 .64805 L
s
.34551 .64805 m
.34549 .64803 L
s
.3455 .64806 m
.34551 .64805 L
s
0 .016 1 r
.40404 .41042 m
.40257 .41125 L
s
1 .033 0 r
.34548 .64805 m
.3455 .64806 L
s
.34553 .35201 m
.34558 .35209 L
s
.647 0 1 r
.46153 .39121 m
.46005 .39231 L
s
.128 1 0 r
.46194 .46148 m
.46125 .46183 L
s
1 .033 0 r
.34557 .35209 m
.34556 .35208 L
s
.34559 .35208 m
.34557 .35209 L
s
.34558 .35209 m
.34557 .35209 L
s
.34558 .35206 m
.34559 .35208 L
s
.34558 .35209 m
.34559 .35208 L
s
0 .015 1 r
.51862 .19905 m
.52061 .19837 L
s
1 .033 0 r
.34556 .35208 m
.34558 .35206 L
s
.34556 .35208 m
.34558 .35209 L
s
.34558 .35206 m
.34558 .35209 L
s
0 1 .741 r
.46179 .42615 m
.46094 .42682 L
s
1 0 0 r
.40412 .64762 m
.40445 .65079 L
s
.40204 .64995 m
.40412 .64762 L
s
1 0 .072 r
.34934 .6059 m
.34892 .60761 L
s
.34757 .60433 m
.34934 .6059 L
s
.35007 .60484 m
.34934 .6059 L
s
1 0 0 r
.40445 .65079 m
.40204 .64995 L
s
1 0 .93 r
.52121 .22256 m
.52961 .21752 L
s
.299 0 1 r
.40503 .37775 m
.4035 .37867 L
s
.128 1 0 r
.46328 .53559 m
.46546 .53238 L
s
.859 0 1 r
.34668 .62877 m
.35411 .62414 L
s
.73 0 1 r
.46609 .27114 m
.46611 .27202 L
s
.46442 .27004 m
.46609 .27114 L
s
.46647 .26952 m
.46609 .27114 L
s
1 0 .282 r
.40542 .34326 m
.40338 .34447 L
s
.647 0 1 r
.40548 .55131 m
.41013 .54343 L
s
.128 1 0 r
.4653 .53301 m
.46543 .53338 L
s
.46462 .53266 m
.4653 .53301 L
s
.46546 .53238 m
.4653 .53301 L
s
1 0 .072 r
.34715 .60603 m
.34757 .60433 L
s
.34757 .60433 m
.35007 .60484 L
s
.128 1 0 r
.46474 .53303 m
.46462 .53266 L
s
.46462 .53266 m
.46546 .53238 L
s
.73 0 1 r
.46444 .27092 m
.46442 .27004 L
s
.46442 .27004 m
.46647 .26952 L
s
0 1 .741 r
.46469 .5704 m
.46887 .56695 L
s
0 .326 1 r
.46551 .77225 m
.46681 .77139 L
s
.46681 .77139 m
.46683 .77074 L
s
.46681 .77139 m
.46524 .7703 L
s
.128 1 0 r
.46543 .53338 m
.46474 .53303 L
s
.46546 .53238 m
.46543 .53338 L
s
.46474 .53303 m
.46546 .53238 L
s
0 .326 1 r
.46524 .7703 m
.46551 .77225 L
s
.46683 .77074 m
.46524 .7703 L
s
.46524 .7703 m
.46553 .77159 L
s
.46989 .77627 m
.46524 .7703 L
s
0 .016 1 r
.40703 .58377 m
.41166 .57757 L
s
0 .326 1 r
.46553 .77159 m
.46551 .77225 L
s
1 0 .072 r
.34892 .60761 m
.34715 .60603 L
s
.35007 .60484 m
.34892 .60761 L
s
1 0 .93 r
.52653 .7828 m
.52686 .78118 L
s
.52686 .78118 m
.52547 .77986 L
s
.52686 .78118 m
.52432 .78209 L
s
.52432 .78209 m
.52653 .7828 L
s
.52547 .77986 m
.52432 .78209 L
s
.52432 .78209 m
.52515 .78148 L
s
.53274 .77829 m
.52432 .78209 L
s
.73 0 1 r
.46611 .27202 m
.46444 .27092 L
s
.46647 .26952 m
.46611 .27202 L
s
1 0 .399 r
.34934 .59715 m
.35594 .58865 L
s
.647 0 1 r
.46626 .60288 m
.47314 .59691 L
s
0 1 .741 r
.46845 .56762 m
.46847 .56833 L
s
.46759 .56694 m
.46845 .56762 L
s
.46887 .56695 m
.46845 .56762 L
s
1 .033 0 r
.34972 .65355 m
.34974 .65355 L
s
.34973 .65352 m
.34972 .65355 L
s
.34972 .65355 m
.34972 .65354 L
s
.34975 .65353 m
.34972 .65355 L
s
.34977 .65347 m
.34972 .65355 L
s
.34973 .65352 m
.34972 .65354 L
s
.34975 .65353 m
.34973 .65352 L
s
.34974 .65355 m
.34975 .65353 L
s
.73 0 1 r
.46444 .27092 m
.46647 .26952 L
s
1 .033 0 r
.34972 .65354 m
.34974 .65355 L
s
.34977 .34653 m
.34981 .34661 L
s
.3498 .34661 m
.34979 .34659 L
s
.34982 .3466 m
.3498 .34661 L
s
.34981 .34661 m
.3498 .34661 L
s
.34981 .34658 m
.34982 .3466 L
s
.34981 .34661 m
.34982 .3466 L
s
.34979 .34659 m
.34981 .34658 L
s
.34979 .34659 m
.34981 .34661 L
s
.34981 .34658 m
.34981 .34661 L
s
.647 0 1 r
.41014 .54499 m
.41006 .5459 L
s
.40834 .54412 m
.41014 .54499 L
s
.41013 .54343 m
.41014 .54499 L
s
1 0 .072 r
.34715 .60603 m
.35007 .60484 L
s
0 .326 1 r
.46683 .77074 m
.46553 .77159 L
s
.299 0 1 r
.40858 .61626 m
.41394 .60998 L
s
0 1 .741 r
.46761 .56766 m
.46759 .56694 L
s
.46759 .56694 m
.46887 .56695 L
s
1 0 .93 r
.52547 .77986 m
.52515 .78148 L
s
.647 0 1 r
.40826 .54503 m
.40834 .54412 L
s
.40834 .54412 m
.41013 .54343 L
s
.765 0 1 r
.40998 .68655 m
.41169 .68547 L
s
.41169 .68547 m
.41168 .68456 L
s
.41169 .68547 m
.40965 .68404 L
s
1 0 .93 r
.52879 .21867 m
.52846 .21992 L
s
.5274 .21713 m
.52879 .21867 L
s
.52961 .21752 m
.52879 .21867 L
s
.859 0 1 r
.35352 .62501 m
.35318 .62642 L
s
.35206 .62372 m
.35352 .62501 L
s
.35411 .62414 m
.35352 .62501 L
s
0 1 .741 r
.46847 .56833 m
.46761 .56766 L
s
.46887 .56695 m
.46847 .56833 L
s
0 .016 1 r
.41149 .57878 m
.41144 .57967 L
s
.41002 .57796 m
.41149 .57878 L
s
.41166 .57757 m
.41149 .57878 L
s
.765 0 1 r
.40965 .68404 m
.40998 .68655 L
s
.41168 .68456 m
.40965 .68404 L
s
.40965 .68404 m
.40997 .68565 L
s
.41556 .69165 m
.40965 .68404 L
s
0 1 .741 r
.46761 .56766 m
.46887 .56695 L
s
1 0 .93 r
.52515 .78148 m
.52653 .7828 L
s
.765 0 1 r
.40997 .68565 m
.40998 .68655 L
s
1 0 .282 r
.41013 .64878 m
.41727 .64042 L
s
0 .016 1 r
.40997 .57885 m
.41002 .57796 L
s
.41002 .57796 m
.41166 .57757 L
s
.859 0 1 r
.35172 .62513 m
.35206 .62372 L
s
.35206 .62372 m
.35411 .62414 L
s
1 0 .93 r
.52708 .21838 m
.5274 .21713 L
s
.5274 .21713 m
.52961 .21752 L
s
.647 0 1 r
.47249 .59806 m
.47251 .59927 L
s
.47101 .59695 m
.47249 .59806 L
s
.47314 .59691 m
.47249 .59806 L
s
.41006 .5459 m
.40826 .54503 L
s
.41013 .54343 m
.41006 .5459 L
s
.40826 .54503 m
.41013 .54343 L
s
1 0 .399 r
.3557 .5903 m
.35559 .59159 L
s
.35365 .58912 m
.3557 .5903 L
s
.35594 .58865 m
.3557 .5903 L
s
0 .326 1 r
.46989 .22373 m
.47454 .21775 L
s
.299 0 1 r
.41366 .61119 m
.4136 .61222 L
s
.41212 .61026 m
.41366 .61119 L
s
.41394 .60998 m
.41366 .61119 L
s
1 0 .93 r
.52846 .21992 m
.52708 .21838 L
s
.52961 .21752 m
.52846 .21992 L
s
.859 0 1 r
.35318 .62642 m
.35172 .62513 L
s
.35411 .62414 m
.35318 .62642 L
s
.765 0 1 r
.41168 .68456 m
.40997 .68565 L
s
0 .016 1 r
.41144 .57967 m
.40997 .57885 L
s
.41166 .57757 m
.41144 .57967 L
s
.647 0 1 r
.47103 .59816 m
.47101 .59695 L
s
.47101 .59695 m
.47314 .59691 L
s
0 .016 1 r
.40997 .57885 m
.41166 .57757 L
s
.299 0 1 r
.41206 .61129 m
.41212 .61026 L
s
.41212 .61026 m
.41394 .60998 L
s
1 0 .399 r
.35353 .59041 m
.35365 .58912 L
s
.35365 .58912 m
.35594 .58865 L
s
1 0 .615 r
.35603 .41218 m
.35807 .41109 L
s
.35807 .41109 m
.35787 .4099 L
s
.35807 .41109 m
.3558 .40934 L
s
.859 0 1 r
.35172 .62513 m
.35411 .62414 L
s
1 0 .93 r
.52708 .21838 m
.52961 .21752 L
s
1 0 .615 r
.3558 .40934 m
.35603 .41218 L
s
.35787 .4099 m
.3558 .40934 L
s
.3558 .40934 m
.35583 .41099 L
s
.36157 .41784 m
.3558 .40934 L
s
.647 0 1 r
.47251 .59927 m
.47103 .59816 L
s
.47314 .59691 m
.47251 .59927 L
s
0 .069 1 r
.41504 .45844 m
.41666 .45787 L
s
.41666 .45787 m
.41646 .45727 L
s
.41666 .45787 m
.41522 .45636 L
s
1 0 .615 r
.35583 .41099 m
.35603 .41218 L
s
0 .069 1 r
.41484 .45784 m
.41504 .45844 L
s
.41522 .45636 m
.41504 .45844 L
s
.41646 .45727 m
.41522 .45636 L
s
.41522 .45636 m
.41484 .45784 L
s
.4179 .46383 m
.41522 .45636 L
s
.647 0 1 r
.47103 .59816 m
.47314 .59691 L
s
0 .326 1 r
.47425 .21906 m
.47427 .21971 L
s
.47295 .2182 m
.47425 .21906 L
s
.47454 .21775 m
.47425 .21906 L
s
1 0 .282 r
.41688 .64201 m
.41684 .6434 L
s
.41484 .64079 m
.41688 .64201 L
s
.41727 .64042 m
.41688 .64201 L
s
.299 0 1 r
.4136 .61222 m
.41206 .61129 L
s
.41394 .60998 m
.4136 .61222 L
s
.41206 .61129 m
.41394 .60998 L
s
0 .326 1 r
.47297 .21884 m
.47295 .2182 L
s
.47295 .2182 m
.47454 .21775 L
s
1 0 .399 r
.35559 .59159 m
.35353 .59041 L
s
.35594 .58865 m
.35559 .59159 L
s
1 0 .456 r
.416 .36106 m
.41796 .35984 L
s
.41796 .35984 m
.41785 .35846 L
s
.41796 .35984 m
.41552 .35819 L
s
0 .508 1 r
.41572 .42753 m
.41703 .42682 L
s
.41703 .42682 m
.41697 .42606 L
s
.41703 .42682 m
.41556 .42568 L
s
0 .069 1 r
.47302 .41013 m
.47409 .40908 L
s
.47409 .40908 m
.47402 .40795 L
s
.47409 .40908 m
.47218 .40828 L
s
1 0 .399 r
.35353 .59041 m
.35594 .58865 L
s
1 0 .282 r
.4148 .64218 m
.41484 .64079 L
s
.41484 .64079 m
.41727 .64042 L
s
0 .508 1 r
.41556 .42568 m
.41572 .42753 L
s
.41697 .42606 m
.41556 .42568 L
s
.41556 .42568 m
.41565 .42677 L
s
.41945 .43126 m
.41556 .42568 L
s
1 0 .456 r
.41552 .35819 m
.416 .36106 L
s
.41785 .35846 m
.41552 .35819 L
s
.41552 .35819 m
.41589 .35968 L
s
.42257 .36604 m
.41552 .35819 L
s
0 .508 1 r
.41565 .42677 m
.41572 .42753 L
s
0 .016 1 r
.41634 .395 m
.41776 .39412 L
s
.41776 .39412 m
.41767 .39315 L
s
.41776 .39412 m
.416 .39293 L
s
.655 0 1 r
.35779 .38071 m
.35949 .37972 L
s
.35949 .37972 m
.35941 .37862 L
s
.35949 .37972 m
.35748 .37827 L
s
0 .069 1 r
.47218 .40828 m
.47302 .41013 L
s
.47402 .40795 m
.47218 .40828 L
s
.47218 .40828 m
.47296 .409 L
s
.4789 .41209 m
.47218 .40828 L
s
1 0 .615 r
.35787 .4099 m
.35583 .41099 L
s
.765 0 1 r
.41556 .30835 m
.4215 .3007 L
s
0 .016 1 r
.416 .39293 m
.41634 .395 L
s
.41767 .39315 m
.416 .39293 L
s
.416 .39293 m
.41625 .39403 L
s
.42101 .39867 m
.416 .39293 L
s
0 .069 1 r
.41646 .45727 m
.41484 .45784 L
s
1 0 .456 r
.41589 .35968 m
.416 .36106 L
s
1 0 .93 r
.53274 .22171 m
.54119 .22551 L
s
0 .326 1 r
.47427 .21971 m
.47297 .21884 L
s
.47454 .21775 m
.47427 .21971 L
s
.655 0 1 r
.35748 .37827 m
.35779 .38071 L
s
.35941 .37862 m
.35748 .37827 L
s
.35748 .37827 m
.35771 .3796 L
s
.36311 .38523 m
.35748 .37827 L
s
0 .069 1 r
.47296 .409 m
.47302 .41013 L
s
0 .016 1 r
.41625 .39403 m
.41634 .395 L
s
0 .326 1 r
.47297 .21884 m
.47454 .21775 L
s
0 .015 1 r
.5351 .80322 m
.53534 .80193 L
s
.53534 .80193 m
.53425 .8009 L
s
.53534 .80193 m
.53335 .80266 L
s
.655 0 1 r
.35771 .3796 m
.35779 .38071 L
s
0 .015 1 r
.53335 .80266 m
.5351 .80322 L
s
.53425 .8009 m
.53335 .80266 L
s
.53335 .80266 m
.534 .80218 L
s
.53998 .79965 m
.53335 .80266 L
s
0 .508 1 r
.41697 .42606 m
.41565 .42677 L
s
0 .069 1 r
.47402 .40795 m
.47296 .409 L
s
1 0 .282 r
.41684 .6434 m
.4148 .64218 L
s
.41727 .64042 m
.41684 .6434 L
s
0 .015 1 r
.53425 .8009 m
.534 .80218 L
s
0 .016 1 r
.41767 .39315 m
.41625 .39403 L
s
1 0 .282 r
.4148 .64218 m
.41727 .64042 L
s
1 0 .456 r
.41785 .35846 m
.41589 .35968 L
s
.655 0 1 r
.35941 .37862 m
.35771 .3796 L
s
0 .069 1 r
.4179 .53617 m
.42058 .52869 L
s
0 .015 1 r
.534 .80218 m
.5351 .80322 L
s
.128 1 0 r
.47671 .44335 m
.47731 .44289 L
s
.47731 .44289 m
.47732 .44241 L
s
.47731 .44289 m
.47645 .44239 L
s
.47645 .44239 m
.47671 .44335 L
s
.47732 .44241 m
.47645 .44239 L
s
.47645 .44239 m
.47673 .44287 L
s
.47927 .44484 m
.47645 .44239 L
s
.4 0 1 r
.36047 .67393 m
.36234 .67354 L
s
.36234 .67354 m
.36256 .6733 L
s
.36234 .67354 m
.36111 .67176 L
s
.765 0 1 r
.42116 .30233 m
.42116 .30323 L
s
.41945 .30124 m
.42116 .30233 L
s
.4215 .3007 m
.42116 .30233 L
s
.128 1 0 r
.47673 .44287 m
.47671 .44335 L
s
.859 0 1 r
.361 .34073 m
.36297 .34006 L
s
.36297 .34006 m
.36314 .33923 L
s
.36297 .34006 m
.36128 .33815 L
s
.4 0 1 r
.36068 .6737 m
.36047 .67393 L
s
.36111 .67176 m
.36047 .67393 L
s
.128 1 0 r
.47732 .44241 m
.47673 .44287 L
s
.765 0 1 r
.41945 .30214 m
.41945 .30124 L
s
.41945 .30124 m
.4215 .3007 L
s
0 .508 1 r
.41945 .56874 m
.42335 .56315 L
s
.859 0 1 r
.36116 .3399 m
.361 .34073 L
s
.36128 .33815 m
.361 .34073 L
s
.4 0 1 r
.36256 .6733 m
.36111 .67176 L
s
.36111 .67176 m
.36068 .6737 L
s
.36315 .68106 m
.36111 .67176 L
s
0 .295 1 r
.42052 .74107 m
.42185 .74021 L
s
.42185 .74021 m
.42184 .73952 L
s
.42185 .74021 m
.42025 .73911 L
s
.859 0 1 r
.36314 .33923 m
.36128 .33815 L
s
.36128 .33815 m
.36116 .3399 L
s
.36523 .3473 m
.36128 .33815 L
s
0 .069 1 r
.42096 .53018 m
.42076 .53078 L
s
.41933 .5296 m
.42096 .53018 L
s
.42058 .52869 m
.42096 .53018 L
s
1 0 .615 r
.36157 .58216 m
.36737 .57363 L
s
0 .069 1 r
.41913 .5302 m
.41933 .5296 L
s
.41933 .5296 m
.42058 .52869 L
s
0 .295 1 r
.42025 .73911 m
.42052 .74107 L
s
.42184 .73952 m
.42025 .73911 L
s
.42025 .73911 m
.42051 .74039 L
s
.42492 .74507 m
.42025 .73911 L
s
0 .069 1 r
.4789 .58791 m
.48563 .58408 L
s
1 0 .93 r
.54035 .2249 m
.53897 .22623 L
s
.54003 .22327 m
.54035 .2249 L
s
.54119 .22551 m
.54035 .2249 L
s
0 .295 1 r
.42051 .74039 m
.42052 .74107 L
s
.128 1 0 r
.47927 .55516 m
.4821 .55271 L
s
1 .285 0 r
.53827 .82338 m
.53826 .8233 L
s
.53826 .8233 m
.53815 .82324 L
s
.53826 .8233 m
.53813 .8234 L
s
.53813 .8234 m
.53827 .82338 L
s
.53815 .82324 m
.53813 .8234 L
s
.53813 .8234 m
.53816 .82332 L
s
.53853 .82296 m
.53813 .8234 L
s
.53815 .82324 m
.53816 .82332 L
s
0 .016 1 r
.42101 .60133 m
.42604 .59558 L
s
1 .285 0 r
.53816 .82332 m
.53827 .82338 L
s
.765 0 1 r
.42116 .30323 m
.41945 .30214 L
s
.4215 .3007 m
.42116 .30323 L
s
.4 0 1 r
.36256 .6733 m
.36068 .6737 L
s
1 .285 0 r
.53853 .17704 m
.53893 .17748 L
s
.765 0 1 r
.41945 .30214 m
.4215 .3007 L
s
1 .285 0 r
.5389 .1774 m
.53879 .17746 L
s
.5389 .17732 m
.5389 .1774 L
s
.53893 .17748 m
.5389 .1774 L
s
.53879 .17746 m
.5388 .17738 L
s
.53893 .17748 m
.53879 .17746 L
s
.5388 .17738 m
.5389 .17732 L
s
.5389 .17732 m
.53893 .17748 L
s
.5388 .17738 m
.53893 .17748 L
s
.655 0 1 r
.36311 .61477 m
.36876 .60778 L
s
1 0 .93 r
.53897 .22623 m
.53865 .22461 L
s
.54119 .22551 m
.53897 .22623 L
s
.4 0 1 r
.36315 .31894 m
.3652 .30963 L
s
.859 0 1 r
.36314 .33923 m
.36116 .3399 L
s
.702 0 1 r
.48135 .75169 m
.48301 .7506 L
s
.48301 .7506 m
.48305 .74974 L
s
.48301 .7506 m
.481 .7492 L
s
.128 1 0 r
.48183 .55319 m
.48185 .55367 L
s
.48123 .55274 m
.48183 .55319 L
s
.4821 .55271 m
.48183 .55319 L
s
0 .508 1 r
.42326 .56424 m
.4232 .565 L
s
.42194 .56353 m
.42326 .56424 L
s
.42335 .56315 m
.42326 .56424 L
s
.4 0 1 r
.36562 .31158 m
.36584 .3118 L
s
.36374 .31118 m
.36562 .31158 L
s
.3652 .30963 m
.36562 .31158 L
s
0 .295 1 r
.42184 .73952 m
.42051 .74039 L
s
0 .069 1 r
.42058 .52869 m
.42076 .53078 L
s
.41913 .5302 m
.42058 .52869 L
s
.128 1 0 r
.48125 .55321 m
.48123 .55274 L
s
.48123 .55274 m
.4821 .55271 L
s
0 .508 1 r
.42188 .56429 m
.42194 .56353 L
s
.42194 .56353 m
.42335 .56315 L
s
.702 0 1 r
.481 .7492 m
.48135 .75169 L
s
.48305 .74974 m
.481 .7492 L
s
.481 .7492 m
.48138 .75084 L
s
.487 .75682 m
.481 .7492 L
s
.4 0 1 r
.36396 .31141 m
.36374 .31118 L
s
.36374 .31118 m
.3652 .30963 L
s
0 .069 1 r
.42076 .53078 m
.41913 .5302 L
s
1 0 .456 r
.42257 .63396 m
.42966 .62608 L
s
0 .015 1 r
.53998 .20035 m
.54663 .20337 L
s
.702 0 1 r
.48138 .75084 m
.48135 .75169 L
s
0 .069 1 r
.48484 .58481 m
.48478 .58594 L
s
.48378 .58376 m
.48484 .58481 L
s
.48563 .58408 m
.48484 .58481 L
s
1 0 .93 r
.53865 .22461 m
.54003 .22327 L
s
.54003 .22327 m
.54119 .22551 L
s
.128 1 0 r
.48185 .55367 m
.48125 .55321 L
s
.4821 .55271 m
.48185 .55367 L
s
.48125 .55321 m
.4821 .55271 L
s
0 .508 1 r
.4232 .565 m
.42188 .56429 L
s
.42335 .56315 m
.4232 .565 L
s
.859 0 1 r
.36523 .6527 m
.36918 .64352 L
s
1 0 .93 r
.53865 .22461 m
.54119 .22551 L
s
.4 0 1 r
.3652 .30963 m
.36584 .3118 L
s
.36396 .31141 m
.3652 .30963 L
s
0 .016 1 r
.42579 .5967 m
.4257 .59766 L
s
.42436 .59581 m
.42579 .5967 L
s
.42604 .59558 m
.42579 .5967 L
s
0 .069 1 r
.48372 .58489 m
.48378 .58376 L
s
.48378 .58376 m
.48563 .58408 L
s
0 .508 1 r
.42188 .56429 m
.42335 .56315 L
s
1 0 .615 r
.36733 .5753 m
.36713 .57648 L
s
.36529 .5742 m
.36733 .5753 L
s
.36737 .57363 m
.36733 .5753 L
s
0 1 .883 r
.42646 .47147 m
.42764 .47108 L
s
.42607 .47107 m
.42646 .47147 L
s
.42659 .46995 m
.42646 .47147 L
s
.702 0 1 r
.48305 .74974 m
.48138 .75084 L
s
0 1 .883 r
.42764 .47108 m
.42725 .47068 L
s
.42764 .47108 m
.42659 .46995 L
s
.42725 .47068 m
.42659 .46995 L
s
.42659 .46995 m
.42607 .47107 L
s
.42792 .47559 m
.42659 .46995 L
s
.4 0 1 r
.36584 .3118 m
.36396 .31141 L
s
0 .016 1 r
.42428 .59677 m
.42436 .59581 L
s
.42436 .59581 m
.42604 .59558 L
s
0 .069 1 r
.48478 .58594 m
.48372 .58489 L
s
.48563 .58408 m
.48478 .58594 L
s
.655 0 1 r
.36851 .60913 m
.36844 .61022 L
s
.36681 .60813 m
.36851 .60913 L
s
.36876 .60778 m
.36851 .60913 L
s
1 0 .615 r
.36509 .57538 m
.36529 .5742 L
s
.36529 .5742 m
.36737 .57363 L
s
0 .295 1 r
.42492 .25493 m
.4296 .24894 L
s
.729 0 1 r
.54516 .76362 m
.54508 .76239 L
s
.54508 .76239 m
.54341 .76142 L
s
.54508 .76239 m
.54306 .76389 L
s
.859 0 1 r
.36929 .64528 m
.36947 .6461 L
s
.36732 .64461 m
.36929 .64528 L
s
.36918 .64352 m
.36929 .64528 L
s
0 .069 1 r
.48372 .58489 m
.48563 .58408 L
s
.992 0 1 r
.36931 .42734 m
.37126 .42636 L
s
.37126 .42636 m
.37094 .42532 L
s
.37126 .42636 m
.36919 .42469 L
s
.655 0 1 r
.36674 .60923 m
.36681 .60813 L
s
.36681 .60813 m
.36876 .60778 L
s
.992 0 1 r
.36919 .42469 m
.36931 .42734 L
s
.37094 .42532 m
.36919 .42469 L
s
.36919 .42469 m
.36899 .4263 L
s
.37389 .43293 m
.36919 .42469 L
s
.729 0 1 r
.54306 .76389 m
.54516 .76362 L
s
.54341 .76142 m
.54306 .76389 L
s
.54306 .76389 m
.54349 .76265 L
s
.54919 .75705 m
.54306 .76389 L
s
.992 0 1 r
.36899 .4263 m
.36931 .42734 L
s
0 1 .883 r
.42725 .47068 m
.42607 .47107 L
s
.859 0 1 r
.36749 .64543 m
.36732 .64461 L
s
.36732 .64461 m
.36918 .64352 L
s
.729 0 1 r
.54341 .76142 m
.54349 .76265 L
s
0 .016 1 r
.4257 .59766 m
.42428 .59677 L
s
.42604 .59558 m
.4257 .59766 L
s
0 1 .883 r
.48412 .42311 m
.48478 .4223 L
s
.48478 .4223 m
.48476 .42145 L
s
.48478 .4223 m
.48337 .4218 L
s
0 .015 1 r
.54597 .20289 m
.54487 .20393 L
s
.54573 .2016 m
.54597 .20289 L
s
.54663 .20337 m
.54597 .20289 L
s
0 .016 1 r
.42428 .59677 m
.42604 .59558 L
s
1 0 .456 r
.42927 .62758 m
.42917 .62896 L
s
.42731 .62635 m
.42927 .62758 L
s
.42966 .62608 m
.42927 .62758 L
s
0 .186 1 r
.55312 .41561 m
.55433 .41612 L
s
.55385 .41391 m
.55312 .41561 L
s
.55312 .41561 m
.55316 .41499 L
s
.55502 .41504 m
.55312 .41561 L
s
.55797 .41264 m
.55312 .41561 L
s
0 1 .883 r
.48337 .4218 m
.48412 .42311 L
s
.48476 .42145 m
.48337 .4218 L
s
.48337 .4218 m
.4841 .42225 L
s
.48872 .42419 m
.48337 .4218 L
s
1 0 .615 r
.36713 .57648 m
.36509 .57538 L
s
.36737 .57363 m
.36713 .57648 L
s
1 0 .807 r
.42886 .37656 m
.43067 .37537 L
s
.43067 .37537 m
.43051 .37405 L
s
.43067 .37537 m
.42833 .37389 L
s
0 1 .883 r
.4841 .42225 m
.48412 .42311 L
s
0 .295 1 r
.42933 .25024 m
.42932 .25092 L
s
.428 .24937 m
.42933 .25024 L
s
.4296 .24894 m
.42933 .25024 L
s
.655 0 1 r
.36844 .61022 m
.36674 .60923 L
s
.36876 .60778 m
.36844 .61022 L
s
1 0 .615 r
.36509 .57538 m
.36737 .57363 L
s
0 .015 1 r
.54487 .20393 m
.54463 .20264 L
s
.54663 .20337 m
.54487 .20393 L
s
0 .186 1 r
.55433 .41612 m
.55502 .41504 L
s
.55502 .41504 m
.55385 .41391 L
s
0 1 .883 r
.48476 .42145 m
.4841 .42225 L
s
1 0 .456 r
.42721 .62773 m
.42731 .62635 L
s
.42731 .62635 m
.42966 .62608 L
s
1 0 .807 r
.42833 .37389 m
.42886 .37656 L
s
.43051 .37405 m
.42833 .37389 L
s
.42833 .37389 m
.42869 .37524 L
s
.43511 .38097 m
.42833 .37389 L
s
.655 0 1 r
.36674 .60923 m
.36876 .60778 L
s
.729 0 1 r
.54349 .76265 m
.54516 .76362 L
s
.528 0 1 r
.37045 .39568 m
.37213 .39473 L
s
.37213 .39473 m
.372 .39368 L
s
.37213 .39473 m
.37018 .3933 L
s
.859 0 1 r
.36918 .64352 m
.36947 .6461 L
s
.36749 .64543 m
.36918 .64352 L
s
0 1 .883 r
.42792 .52441 m
.42926 .51875 L
s
0 .295 1 r
.428 .25004 m
.428 .24937 L
s
.428 .24937 m
.4296 .24894 L
s
0 .186 1 r
.55385 .41391 m
.55316 .41499 L
s
.859 0 1 r
.36947 .6461 m
.36749 .64543 L
s
0 .846 1 r
.54086 .42588 m
.54174 .42646 L
s
.54147 .42457 m
.54086 .42588 L
s
.54086 .42588 m
.54079 .4255 L
s
.54242 .42553 m
.54086 .42588 L
s
.54457 .42405 m
.54086 .42588 L
s
1 0 .807 r
.42869 .37524 m
.42886 .37656 L
s
.528 0 1 r
.37018 .3933 m
.37045 .39568 L
s
.372 .39368 m
.37018 .3933 L
s
.37018 .3933 m
.37032 .39463 L
s
.37543 .40022 m
.37018 .3933 L
s
0 .508 1 r
.42941 .41059 m
.43066 .40979 L
s
.43066 .40979 m
.43054 .40893 L
s
.43066 .40979 m
.42909 .40877 L
s
.992 0 1 r
.37094 .42532 m
.36899 .4263 L
s
.702 0 1 r
.487 .24318 m
.49301 .23554 L
s
0 1 .741 r
.42934 .44311 m
.43042 .44261 L
s
.43042 .44261 m
.43036 .44207 L
s
.43042 .44261 m
.42932 .44164 L
s
0 .015 1 r
.54463 .20264 m
.54573 .2016 L
s
.54573 .2016 m
.54663 .20337 L
s
0 .508 1 r
.42909 .40877 m
.42941 .41059 L
s
.43054 .40893 m
.42909 .40877 L
s
.42909 .40877 m
.4293 .40973 L
s
.43354 .41369 m
.42909 .40877 L
s
.528 0 1 r
.37032 .39463 m
.37045 .39568 L
s
0 1 .741 r
.42932 .44164 m
.42934 .44311 L
s
.43036 .44207 m
.42932 .44164 L
s
.42932 .44164 m
.42927 .44258 L
s
.43197 .44639 m
.42932 .44164 L
s
.42927 .44258 m
.42934 .44311 L
s
0 .508 1 r
.4293 .40973 m
.42941 .41059 L
s
0 .846 1 r
.54174 .42646 m
.54242 .42553 L
s
.54242 .42553 m
.54147 .42457 L
s
0 .186 1 r
.55316 .41499 m
.55433 .41612 L
s
0 .015 1 r
.54463 .20264 m
.54663 .20337 L
s
.655 0 1 r
.3716 .363 m
.3733 .36201 L
s
.3733 .36201 m
.37322 .36088 L
s
.3733 .36201 m
.37127 .36056 L
s
0 .295 1 r
.42932 .25092 m
.428 .25004 L
s
.4296 .24894 m
.42932 .25092 L
s
0 .846 1 r
.54147 .42457 m
.54079 .4255 L
s
1 0 .456 r
.42917 .62896 m
.42721 .62773 L
s
.42966 .62608 m
.42917 .62896 L
s
0 .295 1 r
.428 .25004 m
.4296 .24894 L
s
0 1 .883 r
.42859 .51949 m
.42977 .51988 L
s
.42821 .51988 m
.42859 .51949 L
s
.42859 .51949 m
.42926 .51875 L
s
.655 0 1 r
.37127 .36056 m
.3716 .363 L
s
.37322 .36088 m
.37127 .36056 L
s
.37127 .36056 m
.37153 .36187 L
s
.37698 .36748 m
.37127 .36056 L
s
0 1 .741 r
.43036 .44207 m
.42927 .44258 L
s
0 1 .883 r
.42977 .51988 m
.42939 .52027 L
s
.42926 .51875 m
.42977 .51988 L
s
.48872 .57581 m
.49408 .57342 L
s
1 0 .807 r
.43051 .37405 m
.42869 .37524 L
s
1 0 .456 r
.42721 .62773 m
.42966 .62608 L
s
0 .846 1 r
.54079 .4255 m
.54174 .42646 L
s
0 .508 1 r
.43054 .40893 m
.4293 .40973 L
s
.655 0 1 r
.37153 .36187 m
.3716 .363 L
s
.528 0 1 r
.372 .39368 m
.37032 .39463 L
s
0 .066 1 r
.49046 .79876 m
.49155 .79755 L
s
.49155 .79755 m
.49128 .79658 L
s
.49155 .79755 m
.48957 .79688 L
s
.48957 .79688 m
.49046 .79876 L
s
.49128 .79658 m
.48957 .79688 L
s
.48957 .79688 m
.49019 .79779 L
s
.49609 .80084 m
.48957 .79688 L
s
.702 0 1 r
.49262 .2372 m
.49266 .23805 L
s
.49095 .2361 m
.49262 .2372 L
s
.49301 .23554 m
.49262 .2372 L
s
0 1 .883 r
.49335 .57388 m
.49333 .57474 L
s
.49268 .57307 m
.49335 .57388 L
s
.49408 .57342 m
.49335 .57388 L
s
.42926 .51875 m
.42939 .52027 L
s
.42821 .51988 m
.42926 .51875 L
s
.42939 .52027 m
.42821 .51988 L
s
.729 0 1 r
.54919 .24295 m
.55533 .2498 L
s
0 .066 1 r
.49019 .79779 m
.49046 .79876 L
s
.655 0 1 r
.37322 .36088 m
.37153 .36187 L
s
0 1 .741 r
.43197 .55361 m
.43462 .54884 L
s
.702 0 1 r
.49099 .23694 m
.49095 .2361 L
s
.49095 .2361 m
.49301 .23554 L
s
0 1 .883 r
.49266 .57393 m
.49268 .57307 L
s
.49268 .57307 m
.49408 .57342 L
s
0 .066 1 r
.49128 .79658 m
.49019 .79779 L
s
.992 0 1 r
.37389 .56707 m
.37861 .55879 L
s
1 0 .072 r
.37473 .33138 m
.37714 .33057 L
s
.37714 .33057 m
.37738 .32956 L
s
.37714 .33057 m
.3751 .32822 L
s
0 1 .883 r
.49333 .57474 m
.49266 .57393 L
s
.49408 .57342 m
.49333 .57474 L
s
.49266 .57393 m
.49408 .57342 L
s
0 .19 1 r
.37519 .70949 m
.37658 .70861 L
s
.37658 .70861 m
.37654 .7079 L
s
.37658 .70861 m
.37493 .70746 L
s
0 .508 1 r
.43354 .58631 m
.438 .58137 L
s
1 0 .528 r
.37557 .66434 m
.3779 .66384 L
s
.3779 .66384 m
.3782 .66353 L
s
.3779 .66384 m
.37636 .66162 L
s
1 0 .072 r
.37497 .33036 m
.37473 .33138 L
s
.3751 .32822 m
.37473 .33138 L
s
0 .19 1 r
.37493 .70746 m
.37519 .70949 L
s
.37654 .7079 m
.37493 .70746 L
s
.37493 .70746 m
.37515 .70878 L
s
.37961 .71365 m
.37493 .70746 L
s
0 1 .741 r
.43466 .54978 m
.4346 .55032 L
s
.43358 .54928 m
.43466 .54978 L
s
.43462 .54884 m
.43466 .54978 L
s
.702 0 1 r
.49266 .23805 m
.49099 .23694 L
s
.49301 .23554 m
.49266 .23805 L
s
0 .19 1 r
.37515 .70878 m
.37519 .70949 L
s
1 0 .072 r
.37738 .32956 m
.3751 .32822 L
s
.3751 .32822 m
.37497 .33036 L
s
.37991 .33946 m
.3751 .32822 L
s
0 1 .741 r
.43351 .54981 m
.43358 .54928 L
s
.43358 .54928 m
.43462 .54884 L
s
.702 0 1 r
.49099 .23694 m
.49301 .23554 L
s
.528 0 1 r
.37543 .59978 m
.38071 .59284 L
s
1 0 .528 r
.37587 .66403 m
.37557 .66434 L
s
.37636 .66162 m
.37557 .66434 L
s
.729 0 1 r
.55489 .24855 m
.55323 .24953 L
s
.55498 .24733 m
.55489 .24855 L
s
.55533 .2498 m
.55489 .24855 L
s
1 0 .807 r
.43511 .61903 m
.44192 .61193 L
s
1 0 .528 r
.3782 .66353 m
.37636 .66162 L
s
.37636 .66162 m
.37587 .66403 L
s
.37898 .6732 m
.37636 .66162 L
s
.73 0 1 r
.43621 .72035 m
.4379 .71924 L
s
.4379 .71924 m
.43789 .71834 L
s
.4379 .71924 m
.43585 .71783 L
s
0 .19 1 r
.37654 .7079 m
.37515 .70878 L
s
0 1 .741 r
.4346 .55032 m
.43351 .54981 L
s
.43462 .54884 m
.4346 .55032 L
s
.43351 .54981 m
.43462 .54884 L
s
.729 0 1 r
.55323 .24953 m
.55331 .24831 L
s
.55533 .2498 m
.55323 .24953 L
s
1 0 .945 r
.49604 .77789 m
.49744 .77634 L
s
.49744 .77634 m
.49708 .77508 L
s
.49744 .77634 m
.49488 .77548 L
s
.655 0 1 r
.37698 .63252 m
.38271 .62558 L
s
.73 0 1 r
.43585 .71783 m
.43621 .72035 L
s
.43789 .71834 m
.43585 .71783 L
s
.43585 .71783 m
.4362 .71945 L
s
.44188 .72541 m
.43585 .71783 L
s
0 .186 1 r
.55797 .58736 m
.56284 .59035 L
s
1 0 .945 r
.49488 .77548 m
.49604 .77789 L
s
.49708 .77508 m
.49488 .77548 L
s
.49488 .77548 m
.49569 .77663 L
s
.5033 .78048 m
.49488 .77548 L
s
.73 0 1 r
.4362 .71945 m
.43621 .72035 L
s
1 0 .072 r
.37738 .32956 m
.37497 .33036 L
s
0 .508 1 r
.43778 .58233 m
.43767 .58319 L
s
.43654 .58153 m
.43778 .58233 L
s
.438 .58137 m
.43778 .58233 L
s
0 .846 1 r
.54457 .57595 m
.5483 .57778 L
s
.992 0 1 r
.3788 .56042 m
.37848 .56145 L
s
.37684 .55944 m
.3788 .56042 L
s
.37861 .55879 m
.3788 .56042 L
s
0 .508 1 r
.43642 .58239 m
.43654 .58153 L
s
.43654 .58153 m
.438 .58137 L
s
1 0 .528 r
.3782 .66353 m
.37587 .66403 L
s
.992 0 1 r
.37653 .56047 m
.37684 .55944 L
s
.37684 .55944 m
.37861 .55879 L
s
1 0 .945 r
.49569 .77663 m
.49604 .77789 L
s
0 .066 1 r
.49609 .19916 m
.50263 .19518 L
s
.729 0 1 r
.55331 .24831 m
.55498 .24733 L
s
.55498 .24733 m
.55533 .2498 L
s
.528 0 1 r
.38055 .59418 m
.38044 .59523 L
s
.37887 .59322 m
.38055 .59418 L
s
.38071 .59284 m
.38055 .59418 L
s
.729 0 1 r
.55331 .24831 m
.55533 .2498 L
s
1 0 .528 r
.37898 .3268 m
.3816 .3152 L
s
.73 0 1 r
.43789 .71834 m
.4362 .71945 L
s
1 0 .528 r
.38209 .31763 m
.3824 .31792 L
s
.37976 .31712 m
.38209 .31763 L
s
.3816 .3152 m
.38209 .31763 L
s
1 0 .945 r
.49708 .77508 m
.49569 .77663 L
s
.528 0 1 r
.37875 .59427 m
.37887 .59322 L
s
.37887 .59322 m
.38071 .59284 L
s
0 .508 1 r
.43767 .58319 m
.43642 .58239 L
s
.438 .58137 m
.43767 .58319 L
s
1 .195 0 r
.49726 .82425 m
.49734 .8242 L
s
.49734 .8242 m
.49734 .82416 L
s
.49734 .8242 m
.49725 .82414 L
s
.49725 .82414 m
.49726 .82425 L
s
.49734 .82416 m
.49725 .82414 L
s
.49725 .82414 m
.49727 .82422 L
s
.49753 .8245 m
.49725 .82414 L
s
.49727 .82422 m
.49726 .82425 L
s
.49734 .82416 m
.49727 .82422 L
s
0 .19 1 r
.37961 .28635 m
.38431 .28014 L
s
0 .508 1 r
.43642 .58239 m
.438 .58137 L
s
1 .195 0 r
.49753 .1755 m
.49781 .17514 L
s
1 0 .528 r
.38006 .31742 m
.37976 .31712 L
s
.37976 .31712 m
.3816 .3152 L
s
.407 0 1 r
.3829 .44051 m
.38293 .44287 L
s
.38423 .44119 m
.3829 .44051 L
s
.3829 .44051 m
.38247 .44201 L
s
.38469 .44205 m
.3829 .44051 L
s
.38629 .44813 m
.3829 .44051 L
s
.38293 .44287 m
.38469 .44205 L
s
.38469 .44205 m
.38423 .44119 L
s
.38247 .44201 m
.38293 .44287 L
s
1 .195 0 r
.49779 .17522 m
.49779 .17526 L
s
.49771 .17517 m
.49779 .17522 L
s
.49781 .17514 m
.49779 .17522 L
s
1 0 .072 r
.37991 .66054 m
.38473 .64927 L
s
1 .195 0 r
.49771 .17521 m
.49771 .17517 L
s
.49771 .17517 m
.49781 .17514 L
s
.655 0 1 r
.38244 .62691 m
.38237 .62803 L
s
.38075 .62591 m
.38244 .62691 L
s
.38271 .62558 m
.38244 .62691 L
s
1 .195 0 r
.49779 .17526 m
.49771 .17521 L
s
.49781 .17514 m
.49779 .17526 L
s
.49771 .17521 m
.49781 .17514 L
s
1 0 .807 r
.44154 .61329 m
.44138 .61461 L
s
.43972 .61209 m
.44154 .61329 L
s
.44192 .61193 m
.44154 .61329 L
s
.992 0 1 r
.37848 .56145 m
.37653 .56047 L
s
.37861 .55879 m
.37848 .56145 L
s
.37653 .56047 m
.37861 .55879 L
s
.655 0 1 r
.38068 .62703 m
.38075 .62591 L
s
.38075 .62591 m
.38271 .62558 L
s
.528 0 1 r
.38044 .59523 m
.37875 .59427 L
s
.38071 .59284 m
.38044 .59523 L
s
1 0 .807 r
.43956 .61341 m
.43972 .61209 L
s
.43972 .61209 m
.44192 .61193 L
s
.647 0 1 r
.44203 .39239 m
.44362 .39127 L
s
.44362 .39127 m
.4434 .39004 L
s
.44362 .39127 m
.44146 .39003 L
s
.528 0 1 r
.37875 .59427 m
.38071 .59284 L
s
1 0 .072 r
.38485 .65144 m
.3851 .65243 L
s
.38244 .65063 m
.38485 .65144 L
s
.38473 .64927 m
.38485 .65144 L
s
.647 0 1 r
.44146 .39003 m
.44203 .39239 L
s
.4434 .39004 m
.44146 .39003 L
s
.44146 .39003 m
.4418 .39117 L
s
.44773 .39599 m
.44146 .39003 L
s
1 0 .528 r
.3816 .3152 m
.3824 .31792 L
s
.38006 .31742 m
.3816 .3152 L
s
.222 0 1 r
.38339 .41095 m
.38499 .41006 L
s
.38499 .41006 m
.38482 .4091 L
s
.38499 .41006 m
.38317 .40871 L
s
0 .066 1 r
.502 .1961 m
.50173 .19706 L
s
.50091 .19488 m
.502 .1961 L
s
.50263 .19518 m
.502 .1961 L
s
0 .19 1 r
.38408 .28147 m
.38405 .28218 L
s
.38269 .28059 m
.38408 .28147 L
s
.38431 .28014 m
.38408 .28147 L
s
.222 0 1 r
.38317 .40871 m
.38339 .41095 L
s
.38482 .4091 m
.38317 .40871 L
s
.38317 .40871 m
.38322 .40999 L
s
.38785 .41531 m
.38317 .40871 L
s
.647 0 1 r
.4418 .39117 m
.44203 .39239 L
s
.222 0 1 r
.38322 .40999 m
.38339 .41095 L
s
.407 0 1 r
.38423 .44119 m
.38247 .44201 L
s
1 0 .072 r
.38269 .65162 m
.38244 .65063 L
s
.38244 .65063 m
.38473 .64927 L
s
1 0 .528 r
.3824 .31792 m
.38006 .31742 L
s
.655 0 1 r
.38237 .62803 m
.38068 .62703 L
s
.38271 .62558 m
.38237 .62803 L
s
0 1 .741 r
.44279 .42676 m
.44373 .42607 L
s
.44373 .42607 m
.44357 .42535 L
s
.44373 .42607 m
.44244 .42536 L
s
0 .19 1 r
.38266 .2813 m
.38269 .28059 L
s
.38269 .28059 m
.38431 .28014 L
s
0 1 .741 r
.44244 .42536 m
.44279 .42676 L
s
.44357 .42535 m
.44244 .42536 L
s
.44244 .42536 m
.44262 .42604 L
s
.44615 .42883 m
.44244 .42536 L
s
.528 0 1 r
.38423 .37819 m
.38589 .3772 L
s
.38589 .3772 m
.38575 .37609 L
s
.38589 .3772 m
.38389 .37581 L
s
.655 0 1 r
.38068 .62703 m
.38271 .62558 L
s
.73 0 1 r
.44188 .27459 m
.44793 .26699 L
s
1 0 .399 r
.38446 .34431 m
.3865 .34311 L
s
.3865 .34311 m
.38638 .34172 L
s
.3865 .34311 m
.38404 .34138 L
s
0 .066 1 r
.50064 .19585 m
.50091 .19488 L
s
.50091 .19488 m
.50263 .19518 L
s
1 0 .807 r
.44138 .61461 m
.43956 .61341 L
s
.44192 .61193 m
.44138 .61461 L
s
0 1 .741 r
.44262 .42604 m
.44279 .42676 L
s
.528 0 1 r
.38389 .37581 m
.38423 .37819 L
s
.38575 .37609 m
.38389 .37581 L
s
.38389 .37581 m
.38409 .37709 L
s
.3894 .38246 m
.38389 .37581 L
s
.128 1 0 r
.44285 .46179 m
.44359 .46144 L
s
.44359 .46144 m
.44355 .46106 L
s
.44359 .46144 m
.44282 .46078 L
s
0 .846 1 r
.54837 .5774 m
.54742 .57837 L
s
.54768 .57647 m
.54837 .5774 L
s
.5483 .57778 m
.54837 .5774 L
s
0 .186 1 r
.5628 .58973 m
.56162 .59086 L
s
.56211 .58864 m
.5628 .58973 L
s
.56284 .59035 m
.5628 .58973 L
s
.128 1 0 r
.44282 .46078 m
.44285 .46179 L
s
.44355 .46106 m
.44282 .46078 L
s
.44282 .46078 m
.44282 .46142 L
s
.44472 .46402 m
.44282 .46078 L
s
.44282 .46142 m
.44285 .46179 L
s
.528 0 1 r
.38409 .37709 m
.38423 .37819 L
s
1 0 .399 r
.38404 .34138 m
.38446 .34431 L
s
.38638 .34172 m
.38404 .34138 L
s
.38404 .34138 m
.38435 .34293 L
s
.39096 .34959 m
.38404 .34138 L
s
1 0 .807 r
.43956 .61341 m
.44192 .61193 L
s
.647 0 1 r
.4434 .39004 m
.4418 .39117 L
s
0 .066 1 r
.50173 .19706 m
.50064 .19585 L
s
.50263 .19518 m
.50173 .19706 L
s
0 .846 1 r
.54742 .57837 m
.54673 .57743 L
s
.5483 .57778 m
.54742 .57837 L
s
0 .186 1 r
.56162 .59086 m
.56093 .58978 L
s
.56284 .59035 m
.56162 .59086 L
s
1 0 .399 r
.38435 .34293 m
.38446 .34431 L
s
0 1 .741 r
.44357 .42535 m
.44262 .42604 L
s
.222 0 1 r
.38482 .4091 m
.38322 .40999 L
s
0 .19 1 r
.38405 .28218 m
.38266 .2813 L
s
.38431 .28014 m
.38405 .28218 L
s
.128 1 0 r
.44355 .46106 m
.44282 .46142 L
s
0 .19 1 r
.38266 .2813 m
.38431 .28014 L
s
0 .846 1 r
.54673 .57743 m
.54768 .57647 L
s
.54768 .57647 m
.5483 .57778 L
s
0 .264 1 r
.56355 .7843 m
.56347 .78332 L
s
.56347 .78332 m
.56215 .78255 L
s
.56347 .78332 m
.56187 .78451 L
s
1 0 .072 r
.38473 .64927 m
.3851 .65243 L
s
.38269 .65162 m
.38473 .64927 L
s
0 .066 1 r
.50064 .19585 m
.50263 .19518 L
s
.407 0 1 r
.56489 .40158 m
.56657 .40155 L
s
.56546 .39933 m
.56489 .40158 L
s
.56489 .40158 m
.56505 .4004 L
s
.56699 .40048 m
.56489 .40158 L
s
.57052 .39586 m
.56489 .40158 L
s
0 .186 1 r
.56093 .58978 m
.56211 .58864 L
s
.56211 .58864 m
.56284 .59035 L
s
0 .846 1 r
.54673 .57743 m
.5483 .57778 L
s
0 .264 1 r
.56187 .78451 m
.56355 .7843 L
s
.56215 .78255 m
.56187 .78451 L
s
.56187 .78451 m
.56222 .78354 L
s
.56676 .7791 m
.56187 .78451 L
s
1 0 .072 r
.3851 .65243 m
.38269 .65162 L
s
.407 0 1 r
.56657 .40155 m
.56699 .40048 L
s
.56699 .40048 m
.56546 .39933 L
s
0 .264 1 r
.56215 .78255 m
.56222 .78354 L
s
.528 0 1 r
.38575 .37609 m
.38409 .37709 L
s
1 0 .945 r
.5033 .21952 m
.51175 .2145 L
s
0 .186 1 r
.56093 .58978 m
.56284 .59035 L
s
.407 0 1 r
.56546 .39933 m
.56505 .4004 L
s
.128 1 0 r
.44472 .53598 m
.44663 .53274 L
s
.73 0 1 r
.44757 .26863 m
.44757 .26952 L
s
.44588 .26751 m
.44757 .26863 L
s
.44793 .26699 m
.44757 .26863 L
s
0 1 .879 r
.56884 .43347 m
.56999 .43343 L
s
.5692 .43199 m
.56884 .43347 L
s
.56884 .43347 m
.569 .43269 L
s
.5702 .43273 m
.56884 .43347 L
s
.57265 .42968 m
.56884 .43347 L
s
.56999 .43343 m
.5702 .43273 L
s
.5702 .43273 m
.5692 .43199 L
s
1 0 .399 r
.38638 .34172 m
.38435 .34293 L
s
.407 0 1 r
.38629 .55187 m
.38969 .54423 L
s
0 1 .879 r
.5692 .43199 m
.569 .43269 L
s
0 .264 1 r
.56222 .78354 m
.56355 .7843 L
s
0 1 .475 r
.5497 .44734 m
.54979 .4467 L
s
.54979 .4467 m
.54903 .44602 L
s
.54979 .4467 m
.54859 .44726 L
s
.73 0 1 r
.44587 .2684 m
.44588 .26751 L
s
.44588 .26751 m
.44793 .26699 L
s
0 1 .475 r
.54859 .44726 m
.5497 .44734 L
s
.54903 .44602 m
.54859 .44726 L
s
.54859 .44726 m
.54894 .44667 L
s
.55249 .4444 m
.54859 .44726 L
s
.128 1 0 r
.44663 .53338 m
.4466 .53375 L
s
.44589 .53302 m
.44663 .53338 L
s
.44663 .53274 m
.44663 .53338 L
s
0 1 .741 r
.44615 .57117 m
.44987 .5677 L
s
.128 1 0 r
.44586 .53339 m
.44589 .53302 L
s
.44589 .53302 m
.44663 .53274 L
s
0 .326 1 r
.44697 .77523 m
.44829 .77437 L
s
.44829 .77437 m
.4483 .77371 L
s
.44829 .77437 m
.4467 .77327 L
s
.407 0 1 r
.56505 .4004 m
.56657 .40155 L
s
0 1 .475 r
.54903 .44602 m
.54894 .44667 L
s
0 1 .879 r
.569 .43269 m
.56999 .43343 L
s
0 .326 1 r
.4467 .77327 m
.44697 .77523 L
s
.4483 .77371 m
.4467 .77327 L
s
.4467 .77327 m
.44698 .77458 L
s
.45137 .7793 m
.4467 .77327 L
s
.222 0 1 r
.38785 .58469 m
.39253 .57807 L
s
0 .326 1 r
.44698 .77458 m
.44697 .77523 L
s
0 1 .475 r
.54894 .44667 m
.5497 .44734 L
s
.128 1 0 r
.4466 .53375 m
.44586 .53339 L
s
.44663 .53274 m
.4466 .53375 L
s
.44586 .53339 m
.44663 .53274 L
s
1 0 .945 r
.50864 .78584 m
.50899 .7842 L
s
.50899 .7842 m
.5076 .78286 L
s
.50899 .7842 m
.50643 .7851 L
s
.50643 .7851 m
.50864 .78584 L
s
.5076 .78286 m
.50643 .7851 L
s
.50643 .7851 m
.50725 .7845 L
s
.51489 .78136 m
.50643 .7851 L
s
.73 0 1 r
.44757 .26952 m
.44587 .2684 L
s
.44793 .26699 m
.44757 .26952 L
s
.647 0 1 r
.44773 .60401 m
.45402 .59802 L
s
.73 0 1 r
.44587 .2684 m
.44793 .26699 L
s
0 .326 1 r
.4483 .77371 m
.44698 .77458 L
s
.528 0 1 r
.3894 .61754 m
.39493 .61087 L
s
1 0 .945 r
.5076 .78286 m
.50725 .7845 L
s
0 .264 1 r
.56676 .2209 m
.57166 .22633 L
s
0 1 .741 r
.44967 .56838 m
.44951 .5691 L
s
.44873 .56769 m
.44967 .56838 L
s
.44987 .5677 m
.44967 .56838 L
s
.797 0 1 r
.39079 .68853 m
.39253 .68743 L
s
.39253 .68743 m
.39252 .68652 L
s
.39253 .68743 m
.39046 .68597 L
s
1 0 .945 r
.51093 .21565 m
.51058 .21691 L
s
.50954 .21409 m
.51093 .21565 L
s
.51175 .2145 m
.51093 .21565 L
s
0 1 .741 r
.44857 .56841 m
.44873 .56769 L
s
.44873 .56769 m
.44987 .5677 L
s
.407 0 1 r
.39012 .54574 m
.38966 .54659 L
s
.38836 .54492 m
.39012 .54574 L
s
.38969 .54423 m
.39012 .54574 L
s
.3879 .54577 m
.38836 .54492 L
s
.38836 .54492 m
.38969 .54423 L
s
1 0 .945 r
.50725 .7845 m
.50864 .78584 L
s
.797 0 1 r
.39046 .68597 m
.39079 .68853 L
s
.39252 .68652 m
.39046 .68597 L
s
.39046 .68597 m
.39077 .68762 L
s
.39643 .69376 m
.39046 .68597 L
s
0 1 .475 r
.55249 .5556 m
.55641 .55847 L
s
.797 0 1 r
.39077 .68762 m
.39079 .68853 L
s
1 0 .399 r
.39096 .65041 m
.39791 .64217 L
s
.222 0 1 r
.39248 .57936 m
.39231 .58031 L
s
.39088 .57847 m
.39248 .57936 L
s
.39253 .57807 m
.39248 .57936 L
s
0 1 .879 r
.57265 .57032 m
.57648 .57413 L
s
0 1 .741 r
.44951 .5691 m
.44857 .56841 L
s
.44987 .5677 m
.44951 .5691 L
s
1 0 .945 r
.50919 .21535 m
.50954 .21409 L
s
.50954 .21409 m
.51175 .2145 L
s
0 1 .741 r
.44857 .56841 m
.44987 .5677 L
s
.222 0 1 r
.39071 .57943 m
.39088 .57847 L
s
.39088 .57847 m
.39253 .57807 L
s
0 .264 1 r
.5713 .22535 m
.56998 .22612 L
s
.57138 .22437 m
.5713 .22535 L
s
.57166 .22633 m
.5713 .22535 L
s
0 .326 1 r
.45137 .2207 m
.45605 .21465 L
s
.771 0 1 r
.57241 .73307 m
.57232 .73183 L
s
.57232 .73183 m
.57065 .73082 L
s
.57232 .73183 m
.57026 .73333 L
s
1 0 .945 r
.51058 .21691 m
.50919 .21535 L
s
.51175 .2145 m
.51058 .21691 L
s
.797 0 1 r
.39252 .68652 m
.39077 .68762 L
s
0 .264 1 r
.56998 .22612 m
.57006 .22514 L
s
.57166 .22633 m
.56998 .22612 L
s
.528 0 1 r
.39472 .61215 m
.39459 .61325 L
s
.39307 .61115 m
.39472 .61215 L
s
.39493 .61087 m
.39472 .61215 L
s
.647 0 1 r
.45367 .59917 m
.45345 .60039 L
s
.45207 .59804 m
.45367 .59917 L
s
.45402 .59802 m
.45367 .59917 L
s
.407 0 1 r
.38966 .54659 m
.3879 .54577 L
s
.38969 .54423 m
.38966 .54659 L
s
.3879 .54577 m
.38969 .54423 L
s
0 1 .475 r
.55605 .55788 m
.55529 .55856 L
s
.55596 .55724 m
.55605 .55788 L
s
.55641 .55847 m
.55605 .55788 L
s
.771 0 1 r
.57026 .73333 m
.57241 .73307 L
s
.57065 .73082 m
.57026 .73333 L
s
.57026 .73333 m
.57073 .73206 L
s
.57659 .72641 m
.57026 .73333 L
s
.407 0 1 r
.57052 .60414 m
.57618 .60988 L
s
.771 0 1 r
.57065 .73082 m
.57073 .73206 L
s
.222 0 1 r
.39231 .58031 m
.39071 .57943 L
s
.39253 .57807 m
.39231 .58031 L
s
0 1 .475 r
.55529 .55856 m
.5552 .55791 L
s
.55641 .55847 m
.55529 .55856 L
s
1 0 .945 r
.50919 .21535 m
.51175 .2145 L
s
.528 0 1 r
.39293 .61225 m
.39307 .61115 L
s
.39307 .61115 m
.39493 .61087 L
s
.647 0 1 r
.45185 .59926 m
.45207 .59804 L
s
.45207 .59804 m
.45402 .59802 L
s
.222 0 1 r
.39071 .57943 m
.39253 .57807 L
s
0 .069 1 r
.4547 .40732 m
.45542 .40919 L
s
.45627 .40698 m
.4547 .40732 L
s
.4547 .40732 m
.45503 .40805 L
s
.45666 .40812 m
.4547 .40732 L
s
.46044 .41112 m
.4547 .40732 L
s
0 .264 1 r
.57006 .22514 m
.57138 .22437 L
s
.57138 .22437 m
.57166 .22633 L
s
0 .069 1 r
.45542 .40919 m
.45666 .40812 L
s
.45666 .40812 m
.45627 .40698 L
s
0 1 .475 r
.5552 .55791 m
.55596 .55724 L
s
.55596 .55724 m
.55641 .55847 L
s
0 1 .879 r
.57631 .57335 m
.57532 .57409 L
s
.57611 .57264 m
.57631 .57335 L
s
.57648 .57413 m
.57631 .57335 L
s
0 .264 1 r
.57006 .22514 m
.57166 .22633 L
s
0 1 .475 r
.5552 .55791 m
.55641 .55847 L
s
0 .326 1 r
.45577 .21597 m
.45579 .21662 L
s
.45445 .2151 m
.45577 .21597 L
s
.45605 .21465 m
.45577 .21597 L
s
0 .259 1 r
.39674 .4265 m
.39819 .42573 L
s
.39819 .42573 m
.39794 .4249 L
s
.39819 .42573 m
.39659 .4245 L
s
0 1 .879 r
.57532 .57409 m
.57511 .57338 L
s
.57648 .57413 m
.57532 .57409 L
s
0 .259 1 r
.39659 .4245 m
.39674 .4265 L
s
.39794 .4249 m
.39659 .4245 L
s
.39659 .4245 m
.39648 .42568 L
s
.40034 .4305 m
.39659 .4245 L
s
1 0 .399 r
.39759 .64374 m
.39749 .64512 L
s
.39555 .64252 m
.39759 .64374 L
s
.39791 .64217 m
.39759 .64374 L
s
0 .069 1 r
.45503 .40805 m
.45542 .40919 L
s
.771 0 1 r
.57073 .73206 m
.57241 .73307 L
s
0 .259 1 r
.39648 .42568 m
.39674 .4265 L
s
1 0 .615 r
.3973 .35982 m
.39925 .3586 L
s
.39925 .3586 m
.399 .35723 L
s
.39925 .3586 m
.39682 .35702 L
s
.647 0 1 r
.45345 .60039 m
.45185 .59926 L
s
.45402 .59802 m
.45345 .60039 L
s
.528 0 1 r
.39459 .61325 m
.39293 .61225 L
s
.39493 .61087 m
.39459 .61325 L
s
0 .326 1 r
.45446 .21575 m
.45445 .2151 L
s
.45445 .2151 m
.45605 .21465 L
s
.222 0 1 r
.39715 .39366 m
.3987 .39271 L
s
.3987 .39271 m
.3985 .39167 L
s
.3987 .39271 m
.3968 .39145 L
s
1 0 .615 r
.39682 .35702 m
.3973 .35982 L
s
.399 .35723 m
.39682 .35702 L
s
.39682 .35702 m
.39704 .35845 L
s
.40348 .36457 m
.39682 .35702 L
s
.528 0 1 r
.39293 .61225 m
.39493 .61087 L
s
.222 0 1 r
.3968 .39145 m
.39715 .39366 L
s
.3985 .39167 m
.3968 .39145 L
s
.3968 .39145 m
.39695 .39262 L
s
.40191 .39755 m
.3968 .39145 L
s
0 1 .879 r
.57511 .57338 m
.57611 .57264 L
s
.57611 .57264 m
.57648 .57413 L
s
1 0 .399 r
.39545 .6439 m
.39555 .64252 L
s
.39555 .64252 m
.39791 .64217 L
s
.647 0 1 r
.45185 .59926 m
.45402 .59802 L
s
0 .069 1 r
.45627 .40698 m
.45503 .40805 L
s
1 0 .615 r
.39704 .35845 m
.3973 .35982 L
s
.222 0 1 r
.39695 .39262 m
.39715 .39366 L
s
0 1 .879 r
.57511 .57338 m
.57648 .57413 L
s
.797 0 1 r
.39643 .30624 m
.40242 .29842 L
s
1 0 .945 r
.51489 .21864 m
.5234 .2224 L
s
0 .186 1 r
.39736 .45897 m
.39873 .45841 L
s
.39637 .4584 m
.39736 .45897 L
s
.39741 .45693 m
.39736 .45897 L
s
0 .326 1 r
.45579 .21662 m
.45446 .21575 L
s
.45605 .21465 m
.45579 .21662 L
s
0 .259 1 r
.39794 .4249 m
.39648 .42568 L
s
0 .326 1 r
.45446 .21575 m
.45605 .21465 L
s
0 .066 1 r
.5173 .80646 m
.51756 .80517 L
s
.51756 .80517 m
.51647 .80414 L
s
.51756 .80517 m
.51556 .80588 L
s
0 .186 1 r
.39775 .45784 m
.39741 .45693 L
s
.39741 .45693 m
.39637 .4584 L
s
.39873 .45841 m
.39741 .45693 L
s
.39811 .46432 m
.39741 .45693 L
s
0 .066 1 r
.51556 .80588 m
.5173 .80646 L
s
.51647 .80414 m
.51556 .80588 L
s
.51556 .80588 m
.51621 .80542 L
s
.52218 .80295 m
.51556 .80588 L
s
.992 0 1 r
.57919 .38687 m
.57946 .38573 L
s
.57946 .38573 m
.57771 .38449 L
s
.57946 .38573 m
.57715 .3871 L
s
.57715 .3871 m
.57919 .38687 L
s
.57771 .38449 m
.57715 .3871 L
s
.57715 .3871 m
.57744 .38562 L
s
.58367 .37999 m
.57715 .3871 L
s
0 .846 1 r
.41222 .47093 m
.41315 .47046 L
s
.41117 .47046 m
.41222 .47093 L
s
.4122 .46924 m
.41222 .47093 L
s
0 .186 1 r
.39873 .45841 m
.39775 .45784 L
s
0 .846 1 r
.4121 .47 m
.4122 .46924 L
s
.4122 .46924 m
.41117 .47046 L
s
.41315 .47046 m
.4122 .46924 L
s
.41199 .47537 m
.4122 .46924 L
s
.222 0 1 r
.3985 .39167 m
.39695 .39262 L
s
1 0 .399 r
.39749 .64512 m
.39545 .6439 L
s
.39791 .64217 m
.39749 .64512 L
s
.992 0 1 r
.57771 .38449 m
.57744 .38562 L
s
0 .066 1 r
.51647 .80414 m
.51621 .80542 L
s
1 0 .615 r
.399 .35723 m
.39704 .35845 L
s
1 0 .399 r
.39545 .6439 m
.39791 .64217 L
s
0 .186 1 r
.39775 .45784 m
.39637 .4584 L
s
.407 0 1 r
.57602 .60869 m
.57449 .60984 L
s
.57561 .60762 m
.57602 .60869 L
s
.57618 .60988 m
.57602 .60869 L
s
.128 1 0 r
.4585 .44273 m
.45915 .44227 L
s
.45915 .44227 m
.45905 .44178 L
s
.45915 .44227 m
.45826 .44176 L
s
.45826 .44176 m
.4585 .44273 L
s
.45905 .44178 m
.45826 .44176 L
s
.45826 .44176 m
.4584 .44225 L
s
.46082 .44423 m
.45826 .44176 L
s
0 .846 1 r
.4121 .47 m
.41117 .47046 L
s
.41315 .47046 m
.4121 .47 L
s
.128 1 0 r
.4584 .44225 m
.4585 .44273 L
s
0 .066 1 r
.51621 .80542 m
.5173 .80646 L
s
.771 0 1 r
.57659 .27359 m
.58295 .28053 L
s
.407 0 1 r
.57449 .60984 m
.57408 .60877 L
s
.57618 .60988 m
.57449 .60984 L
s
.797 0 1 r
.4021 .30009 m
.40209 .30099 L
s
.40035 .29898 m
.4021 .30009 L
s
.40242 .29842 m
.4021 .30009 L
s
.128 1 0 r
.45905 .44178 m
.4584 .44225 L
s
.992 0 1 r
.57744 .38562 m
.57919 .38687 L
s
.797 0 1 r
.40034 .29988 m
.40035 .29898 L
s
.40035 .29898 m
.40242 .29842 L
s
0 .259 1 r
.40034 .5695 m
.40411 .56348 L
s
0 .222 1 r
.40133 .74365 m
.4027 .74276 L
s
.4027 .74276 m
.40268 .74205 L
s
.4027 .74276 m
.40105 .74162 L
s
.407 0 1 r
.57408 .60877 m
.57561 .60762 L
s
.57561 .60762 m
.57618 .60988 L
s
0 1 .879 r
.5858 .45148 m
.58593 .45096 L
s
.58593 .45096 m
.58478 .45041 L
s
.58593 .45096 m
.58475 .45197 L
s
0 .222 1 r
.40105 .74162 m
.40133 .74365 L
s
.40268 .74205 m
.40105 .74162 L
s
.40105 .74162 m
.40131 .74295 L
s
.40584 .74778 m
.40105 .74162 L
s
0 .259 1 r
.58217 .41821 m
.58236 .41737 L
s
.58236 .41737 m
.58101 .41647 L
s
.58236 .41737 m
.58065 .41845 L
s
.58065 .41845 m
.58217 .41821 L
s
.58101 .41647 m
.58065 .41845 L
s
.58065 .41845 m
.58081 .41731 L
s
.58532 .41291 m
.58065 .41845 L
s
0 1 .879 r
.58475 .45197 m
.5858 .45148 L
s
.58478 .45041 m
.58475 .45197 L
s
.58475 .45197 m
.58465 .45094 L
s
.58745 .44685 m
.58475 .45197 L
s
.58478 .45041 m
.58465 .45094 L
s
0 .069 1 r
.46044 .58888 m
.46619 .58506 L
s
1 0 .945 r
.52256 .2218 m
.52117 .22314 L
s
.52222 .22016 m
.52256 .2218 L
s
.5234 .2224 m
.52256 .2218 L
s
.407 0 1 r
.57408 .60877 m
.57618 .60988 L
s
0 .222 1 r
.40131 .74295 m
.40133 .74365 L
s
0 .259 1 r
.58101 .41647 m
.58081 .41731 L
s
.128 1 0 r
.46082 .55577 m
.46337 .5533 L
s
1 .195 0 r
.52053 .82682 m
.52053 .82676 L
s
.52053 .82676 m
.52045 .82672 L
s
.52053 .82676 m
.52043 .82683 L
s
.222 0 1 r
.40191 .60245 m
.40704 .59633 L
s
1 .195 0 r
.52043 .82683 m
.52053 .82682 L
s
.52045 .82672 m
.52043 .82683 L
s
.52043 .82683 m
.52045 .82678 L
s
.52072 .82652 m
.52043 .82683 L
s
.52045 .82672 m
.52045 .82678 L
s
.52045 .82678 m
.52053 .82682 L
s
.797 0 1 r
.40209 .30099 m
.40034 .29988 L
s
.40242 .29842 m
.40209 .30099 L
s
.771 0 1 r
.58247 .27925 m
.58079 .28026 L
s
.58256 .27802 m
.58247 .27925 L
s
.58295 .28053 m
.58247 .27925 L
s
1 .195 0 r
.52072 .17348 m
.52101 .17379 L
s
.52099 .17374 m
.52091 .17378 L
s
.52099 .17368 m
.52099 .17374 L
s
.52101 .17379 m
.52099 .17374 L
s
0 .846 1 r
.41199 .52463 m
.41177 .51848 L
s
.797 0 1 r
.40034 .29988 m
.40242 .29842 L
s
1 .195 0 r
.52091 .17378 m
.52091 .17372 L
s
.52101 .17379 m
.52091 .17378 L
s
0 .186 1 r
.39811 .53568 m
.39881 .52827 L
s
1 .195 0 r
.52091 .17372 m
.52099 .17368 L
s
.52099 .17368 m
.52101 .17379 L
s
.52091 .17372 m
.52101 .17379 L
s
1 0 .945 r
.52117 .22314 m
.52083 .2215 L
s
.5234 .2224 m
.52117 .22314 L
s
.702 0 1 r
.4629 .75447 m
.4646 .75336 L
s
.4646 .75336 m
.46462 .7525 L
s
.4646 .75336 m
.46256 .75194 L
s
0 .222 1 r
.40268 .74205 m
.40131 .74295 L
s
0 1 .879 r
.58465 .45094 m
.5858 .45148 L
s
.771 0 1 r
.58079 .28026 m
.58088 .27903 L
s
.58295 .28053 m
.58079 .28026 L
s
0 .259 1 r
.58081 .41731 m
.58217 .41821 L
s
.128 1 0 r
.46323 .55379 m
.46314 .55427 L
s
.46258 .55332 m
.46323 .55379 L
s
.46337 .5533 m
.46323 .55379 L
s
.702 0 1 r
.46256 .75194 m
.4629 .75447 L
s
.46462 .7525 m
.46256 .75194 L
s
.46256 .75194 m
.46292 .75361 L
s
.46858 .75965 m
.46256 .75194 L
s
1 0 .615 r
.40348 .63543 m
.41018 .62785 L
s
0 .259 1 r
.40421 .56466 m
.40396 .56548 L
s
.40275 .56388 m
.40421 .56466 L
s
.40411 .56348 m
.40421 .56466 L
s
.702 0 1 r
.46292 .75361 m
.4629 .75447 L
s
0 .066 1 r
.52218 .19705 m
.52882 .19998 L
s
.128 1 0 r
.46249 .55381 m
.46258 .55332 L
s
.46258 .55332 m
.46337 .5533 L
s
1 0 .945 r
.52083 .2215 m
.52222 .22016 L
s
.52222 .22016 m
.5234 .2224 L
s
0 1 .475 r
.56775 .46797 m
.56761 .46758 L
s
.56761 .46758 m
.56663 .46717 L
s
.56761 .46758 m
.56671 .46851 L
s
0 .259 1 r
.4025 .56471 m
.40275 .56388 L
s
.40275 .56388 m
.40411 .56348 L
s
0 1 .475 r
.56663 .46717 m
.56677 .46756 L
s
.56663 .46717 m
.56671 .46851 L
s
.56671 .46851 m
.56775 .46797 L
s
.56671 .46851 m
.56677 .46756 L
s
.56908 .46381 m
.56671 .46851 L
s
.128 1 0 r
.46314 .55427 m
.46249 .55381 L
s
.46337 .5533 m
.46314 .55427 L
s
.46249 .55381 m
.46337 .5533 L
s
.771 0 1 r
.58088 .27903 m
.58256 .27802 L
s
.58256 .27802 m
.58295 .28053 L
s
0 .846 1 r
.41187 .51925 m
.41281 .51971 L
s
.41082 .51971 m
.41187 .51925 L
s
.41187 .51925 m
.41177 .51848 L
s
1 0 .945 r
.52083 .2215 m
.5234 .2224 L
s
0 1 .883 r
.52551 .42595 m
.52659 .42626 L
s
.52609 .42461 m
.52551 .42595 L
s
.52551 .42595 m
.5257 .42541 L
s
.52698 .42545 m
.52551 .42595 L
s
.52968 .42335 m
.52551 .42595 L
s
.46625 .421 m
.46681 .42231 L
s
.46731 .42063 m
.46625 .421 L
s
.46625 .421 m
.46641 .42145 L
s
.46771 .42149 m
.46625 .421 L
s
.47032 .42335 m
.46625 .421 L
s
.771 0 1 r
.58088 .27903 m
.58295 .28053 L
s
0 1 .883 r
.52659 .42626 m
.52698 .42545 L
s
.52698 .42545 m
.52609 .42461 L
s
.46681 .42231 m
.46771 .42149 L
s
.46771 .42149 m
.46731 .42063 L
s
0 1 .879 r
.58745 .55315 m
.59016 .55829 L
s
0 1 .475 r
.56677 .46756 m
.56775 .46797 L
s
0 .186 1 r
.39848 .52919 m
.39985 .52975 L
s
.39749 .52975 m
.39848 .52919 L
s
.39848 .52919 m
.39881 .52827 L
s
.702 0 1 r
.46462 .7525 m
.46292 .75361 L
s
.222 0 1 r
.40688 .59751 m
.40669 .59855 L
s
.40533 .59656 m
.40688 .59751 L
s
.40704 .59633 m
.40688 .59751 L
s
0 .069 1 r
.46585 .58579 m
.46547 .58694 L
s
.46461 .58472 m
.46585 .58579 L
s
.46619 .58506 m
.46585 .58579 L
s
0 1 .883 r
.52609 .42461 m
.5257 .42541 L
s
.46641 .42145 m
.46681 .42231 L
s
0 .259 1 r
.40396 .56548 m
.4025 .56471 L
s
.40411 .56348 m
.40396 .56548 L
s
.992 0 1 r
.58367 .62001 m
.59023 .62714 L
s
0 .222 1 r
.40584 .25222 m
.41064 .24605 L
s
0 .259 1 r
.4025 .56471 m
.40411 .56348 L
s
0 .846 1 r
.41175 .52017 m
.41082 .51971 L
s
.41082 .51971 m
.41177 .51848 L
s
.702 0 1 r
.52741 .76649 m
.52734 .76526 L
s
.52734 .76526 m
.52566 .76428 L
s
.52734 .76526 m
.52531 .76676 L
s
.222 0 1 r
.40514 .5976 m
.40533 .59656 L
s
.40533 .59656 m
.40704 .59633 L
s
0 .846 1 r
.41281 .51971 m
.41175 .52017 L
s
.41177 .51848 m
.41281 .51971 L
s
0 1 .883 r
.5257 .42541 m
.52659 .42626 L
s
0 .186 1 r
.39985 .52975 m
.39887 .53031 L
s
.39881 .52827 m
.39985 .52975 L
s
0 1 .883 r
.46731 .42063 m
.46641 .42145 L
s
0 .069 1 r
.46422 .58586 m
.46461 .58472 L
s
.46461 .58472 m
.46619 .58506 L
s
0 1 .475 r
.56908 .53619 m
.57145 .54089 L
s
.702 0 1 r
.52531 .76676 m
.52741 .76649 L
s
.52566 .76428 m
.52531 .76676 L
s
.52531 .76676 m
.52573 .76552 L
s
.53145 .75989 m
.52531 .76676 L
s
0 .846 1 r
.41177 .51848 m
.41175 .52017 L
s
.702 0 1 r
.52566 .76428 m
.52573 .76552 L
s
0 .186 1 r
.39887 .53031 m
.39749 .52975 L
s
.39749 .52975 m
.39881 .52827 L
s
0 .066 1 r
.52816 .19952 m
.52707 .20056 L
s
.5279 .19823 m
.52816 .19952 L
s
.52882 .19998 m
.52816 .19952 L
s
0 .259 1 r
.58532 .58709 m
.59001 .59264 L
s
0 1 .475 r
.5714 .53994 m
.57042 .54035 L
s
.57154 .53955 m
.5714 .53994 L
s
.57145 .54089 m
.5714 .53994 L
s
0 1 .879 r
.59025 .55724 m
.5891 .55779 L
s
.59013 .55673 m
.59025 .55724 L
s
.59016 .55829 m
.59025 .55724 L
s
0 .069 1 r
.46547 .58694 m
.46422 .58586 L
s
.46619 .58506 m
.46547 .58694 L
s
.992 0 1 r
.41046 .37565 m
.41225 .37445 L
s
.41225 .37445 m
.41186 .37314 L
s
.41225 .37445 m
.40993 .37308 L
s
.40993 .37308 m
.41046 .37565 L
s
.41186 .37314 m
.40993 .37308 L
s
.40993 .37308 m
.41007 .37433 L
s
.41609 .37965 m
.40993 .37308 L
s
0 1 .879 r
.5891 .55779 m
.58897 .55727 L
s
.59016 .55829 m
.5891 .55779 L
s
.222 0 1 r
.40669 .59855 m
.40514 .5976 L
s
.40704 .59633 m
.40669 .59855 L
s
0 1 .475 r
.57042 .54035 m
.57056 .53996 L
s
.57145 .54089 m
.57042 .54035 L
s
0 .186 1 r
.39881 .52827 m
.39887 .53031 L
s
1 0 .615 r
.40994 .6293 m
.40969 .63067 L
s
.40798 .62807 m
.40994 .6293 L
s
.41018 .62785 m
.40994 .6293 L
s
.222 0 1 r
.40514 .5976 m
.40704 .59633 L
s
0 .222 1 r
.41037 .24739 m
.41036 .24809 L
s
.409 .24649 m
.41037 .24739 L
s
.41064 .24605 m
.41037 .24739 L
s
0 .259 1 r
.41045 .40945 m
.41183 .40857 L
s
.41183 .40857 m
.41154 .40763 L
s
.41183 .40857 m
.41012 .40749 L
s
.41012 .40749 m
.41045 .40945 L
s
.41154 .40763 m
.41012 .40749 L
s
.41012 .40749 m
.41016 .40851 L
s
.41451 .41274 m
.41012 .40749 L
s
0 .066 1 r
.52707 .20056 m
.52681 .19927 L
s
.52882 .19998 m
.52707 .20056 L
s
0 .069 1 r
.46422 .58586 m
.46619 .58506 L
s
.992 0 1 r
.41007 .37433 m
.41046 .37565 L
s
.702 0 1 r
.52573 .76552 m
.52741 .76649 L
s
0 .259 1 r
.41016 .40851 m
.41045 .40945 L
s
1 0 .615 r
.40773 .62944 m
.40798 .62807 L
s
.40798 .62807 m
.41018 .62785 L
s
0 1 .475 r
.57154 .53955 m
.57145 .54089 L
s
.57056 .53996 m
.57145 .54089 L
s
0 .222 1 r
.40898 .24719 m
.409 .24649 L
s
.409 .24649 m
.41064 .24605 L
s
0 1 .475 r
.57056 .53996 m
.57154 .53955 L
s
0 .066 1 r
.52681 .19927 m
.5279 .19823 L
s
.5279 .19823 m
.52882 .19998 L
s
.702 0 1 r
.46858 .24035 m
.47463 .23261 L
s
0 1 .879 r
.58897 .55727 m
.59013 .55673 L
s
.59013 .55673 m
.59016 .55829 L
s
.58897 .55727 m
.59016 .55829 L
s
1 0 .615 r
.59212 .37178 m
.59222 .37063 L
s
.59222 .37063 m
.59031 .36933 L
s
.59222 .37063 m
.58979 .37219 L
s
0 .066 1 r
.52681 .19927 m
.52882 .19998 L
s
1 0 .615 r
.58979 .37219 m
.59212 .37178 L
s
.59031 .36933 m
.58979 .37219 L
s
.58979 .37219 m
.59021 .37049 L
s
.59691 .36401 m
.58979 .37219 L
s
0 .259 1 r
.41154 .40763 m
.41016 .40851 L
s
.992 0 1 r
.41186 .37314 m
.41007 .37433 L
s
0 .222 1 r
.41036 .24809 m
.40898 .24719 L
s
.41064 .24605 m
.41036 .24809 L
s
.40898 .24719 m
.41064 .24605 L
s
.59109 .75378 m
.591 .75278 L
s
.591 .75278 m
.58967 .75199 L
s
.591 .75278 m
.58937 .75399 L
s
.992 0 1 r
.58993 .62565 m
.58817 .62691 L
s
.58967 .62452 m
.58993 .62565 L
s
.59023 .62714 m
.58993 .62565 L
s
1 0 .615 r
.59031 .36933 m
.59021 .37049 L
s
0 1 .883 r
.52968 .57665 m
.53387 .57926 L
s
.47032 .57665 m
.47441 .57429 L
s
1 0 .615 r
.40969 .63067 m
.40773 .62944 L
s
.41018 .62785 m
.40969 .63067 L
s
0 .259 1 r
.58985 .5915 m
.58849 .5924 L
s
.58965 .59066 m
.58985 .5915 L
s
.59001 .59264 m
.58985 .5915 L
s
0 .222 1 r
.58937 .75399 m
.59109 .75378 L
s
.58967 .75199 m
.58937 .75399 L
s
.58937 .75399 m
.58976 .75298 L
s
.59442 .74847 m
.58937 .75399 L
s
.58967 .75199 m
.58976 .75298 L
s
.992 0 1 r
.58817 .62691 m
.58791 .62577 L
s
.59023 .62714 m
.58817 .62691 L
s
0 .259 1 r
.58849 .5924 m
.5883 .59156 L
s
.59001 .59264 m
.58849 .5924 L
s
1 0 .615 r
.40773 .62944 m
.41018 .62785 L
s
0 .066 1 r
.47207 .80206 m
.47318 .80083 L
s
.47318 .80083 m
.47289 .79986 L
s
.47318 .80083 m
.47117 .80016 L
s
.47117 .80016 m
.47207 .80206 L
s
.47289 .79986 m
.47117 .80016 L
s
.47117 .80016 m
.47178 .80108 L
s
.47773 .80417 m
.47117 .80016 L
s
.702 0 1 r
.47425 .2343 m
.47428 .23515 L
s
.47256 .23318 m
.47425 .2343 L
s
.47463 .23261 m
.47425 .2343 L
s
0 1 .475 r
.42838 .4604 m
.42939 .46001 L
s
.42939 .46001 m
.42947 .45959 L
s
.42939 .46001 m
.42847 .45906 L
s
0 1 .879 r
.40979 .44322 m
.41095 .44268 L
s
.41095 .44268 m
.41074 .44211 L
s
.41095 .44268 m
.40976 .44166 L
s
.40976 .44166 m
.40979 .44322 L
s
.41074 .44211 m
.40976 .44166 L
s
.40976 .44166 m
.40958 .44265 L
s
.41227 .44668 m
.40976 .44166 L
s
.40958 .44265 m
.40979 .44322 L
s
.702 0 1 r
.53145 .24011 m
.5376 .247 L
s
0 .066 1 r
.47178 .80108 m
.47207 .80206 L
s
0 1 .475 r
.42846 .45998 m
.42838 .4604 L
s
.42847 .45906 m
.42838 .4604 L
s
0 .222 1 r
.58976 .75298 m
.59109 .75378 L
s
0 1 .475 r
.42947 .45959 m
.42847 .45906 L
s
.42847 .45906 m
.42846 .45998 L
s
.43075 .46373 m
.42847 .45906 L
s
1 0 .615 r
.59021 .37049 m
.59212 .37178 L
s
0 .259 1 r
.5883 .59156 m
.58965 .59066 L
s
.58965 .59066 m
.59001 .59264 L
s
.702 0 1 r
.47259 .23403 m
.47256 .23318 L
s
.47256 .23318 m
.47463 .23261 L
s
0 .069 1 r
.53385 .41482 m
.53548 .41507 L
s
.5346 .4129 m
.53385 .41482 L
s
.53385 .41482 m
.53425 .41396 L
s
.53583 .41402 m
.53385 .41482 L
s
.53978 .41065 m
.53385 .41482 L
s
.222 0 1 r
.59492 .40318 m
.59499 .40227 L
s
.59499 .40227 m
.59347 .40128 L
s
.59499 .40227 m
.5931 .40353 L
s
.992 0 1 r
.58791 .62577 m
.58967 .62452 L
s
.58967 .62452 m
.59023 .62714 L
s
0 .069 1 r
.53548 .41507 m
.53583 .41402 L
s
.53583 .41402 m
.5346 .4129 L
s
0 .066 1 r
.47289 .79986 m
.47178 .80108 L
s
0 .186 1 r
.60128 .46965 m
.6004 .47018 L
s
.60272 .47018 m
.60128 .46965 L
s
.60128 .46965 m
.60136 .47169 L
s
0 .259 1 r
.5883 .59156 m
.59001 .59264 L
s
.222 0 1 r
.5931 .40353 m
.59492 .40318 L
s
.59347 .40128 m
.5931 .40353 L
s
.5931 .40353 m
.5934 .40219 L
s
.59858 .39704 m
.5931 .40353 L
s
0 .186 1 r
.60136 .47169 m
.60184 .47072 L
s
.60136 .47169 m
.6004 .47018 L
s
.60272 .47018 m
.60136 .47169 L
s
.60237 .46415 m
.60136 .47169 L
s
0 1 .475 r
.42947 .45959 m
.42846 .45998 L
s
.222 0 1 r
.59347 .40128 m
.5934 .40219 L
s
0 1 .879 r
.41074 .44211 m
.40958 .44265 L
s
.992 0 1 r
.58791 .62577 m
.59023 .62714 L
s
0 .069 1 r
.5346 .4129 m
.53425 .41396 L
s
0 .846 1 r
.58842 .47979 m
.58743 .48023 L
s
.58942 .48023 m
.58842 .47979 L
s
.58842 .47979 m
.58842 .48148 L
s
0 .259 1 r
.41451 .58726 m
.41891 .58199 L
s
0 .186 1 r
.60184 .47072 m
.60272 .47018 L
s
0 1 .883 r
.53366 .57872 m
.53277 .57957 L
s
.53328 .57791 m
.53366 .57872 L
s
.53387 .57926 m
.53366 .57872 L
s
.702 0 1 r
.47428 .23515 m
.47259 .23403 L
s
.47463 .23261 m
.47428 .23515 L
s
0 .846 1 r
.58842 .48148 m
.58842 .48068 L
s
.58842 .48148 m
.58743 .48023 L
s
.58942 .48023 m
.58842 .48148 L
s
.58843 .47525 m
.58842 .48148 L
s
0 1 .883 r
.47424 .57475 m
.47384 .57561 L
s
.47334 .57392 m
.47424 .57475 L
s
.47441 .57429 m
.47424 .57475 L
s
.702 0 1 r
.47259 .23403 m
.47463 .23261 L
s
0 1 .475 r
.43075 .53627 m
.43304 .5316 L
s
0 .069 1 r
.53425 .41396 m
.53548 .41507 L
s
0 1 .883 r
.53277 .57957 m
.53239 .57876 L
s
.53387 .57926 m
.53277 .57957 L
s
0 .186 1 r
.6004 .47018 m
.60184 .47072 L
s
0 1 .883 r
.47294 .57479 m
.47334 .57392 L
s
.47334 .57392 m
.47441 .57429 L
s
.702 0 1 r
.53717 .24574 m
.53549 .24672 L
s
.53725 .24451 m
.53717 .24574 L
s
.5376 .247 m
.53717 .24574 L
s
0 .846 1 r
.58743 .48023 m
.58842 .48068 L
s
.222 0 1 r
.5934 .40219 m
.59492 .40318 L
s
0 .259 1 r
.59762 .43587 m
.59776 .43512 L
s
.59776 .43512 m
.59632 .43433 L
s
.59776 .43512 m
.59615 .43635 L
s
0 .846 1 r
.58842 .48068 m
.58942 .48023 L
s
0 .259 1 r
.59615 .43635 m
.59762 .43587 L
s
.59632 .43433 m
.59615 .43635 L
s
.59615 .43635 m
.59618 .43508 L
s
.60024 .4301 m
.59615 .43635 L
s
0 .222 1 r
.59442 .25153 m
.59949 .25706 L
s
.992 0 1 r
.41609 .62035 m
.42227 .61375 L
s
0 .259 1 r
.59632 .43433 m
.59618 .43508 L
s
0 1 .883 r
.53239 .57876 m
.53328 .57791 L
s
.53328 .57791 m
.53387 .57926 L
s
0 1 .475 r
.43304 .53253 m
.43313 .53295 L
s
.43204 .53213 m
.43304 .53253 L
s
.43304 .5316 m
.43304 .53253 L
s
.771 0 1 r
.41716 .72274 m
.41888 .72161 L
s
.41888 .72161 m
.41886 .7207 L
s
.41888 .72161 m
.41679 .72018 L
s
0 1 .883 r
.47384 .57561 m
.47294 .57479 L
s
.47441 .57429 m
.47384 .57561 L
s
.702 0 1 r
.53549 .24672 m
.53557 .24549 L
s
.5376 .247 m
.53549 .24672 L
s
0 1 .475 r
.43212 .53255 m
.43204 .53213 L
s
.43204 .53213 m
.43304 .5316 L
s
0 1 .879 r
.41227 .55332 m
.41479 .54829 L
s
0 1 .883 r
.53239 .57876 m
.53387 .57926 L
s
.47294 .57479 m
.47441 .57429 L
s
1 0 .945 r
.47769 .78096 m
.4791 .77939 L
s
.4791 .77939 m
.47873 .77812 L
s
.4791 .77939 m
.47652 .77853 L
s
.771 0 1 r
.41679 .72018 m
.41716 .72274 L
s
.41886 .7207 m
.41679 .72018 L
s
.41679 .72018 m
.41713 .72183 L
s
.4229 .72791 m
.41679 .72018 L
s
1 0 .945 r
.47652 .77853 m
.47769 .78096 L
s
.47873 .77812 m
.47652 .77853 L
s
.47652 .77853 m
.47732 .77969 L
s
.48499 .78359 m
.47652 .77853 L
s
.771 0 1 r
.41713 .72183 m
.41716 .72274 L
s
.128 1 0 r
.53757 .44646 m
.53764 .44601 L
s
.53764 .44601 m
.53699 .44553 L
s
.53764 .44601 m
.53676 .44651 L
s
.53676 .44651 m
.53757 .44646 L
s
.53699 .44553 m
.53676 .44651 L
s
.53676 .44651 m
.53692 .44599 L
s
.53939 .44394 m
.53676 .44651 L
s
.53699 .44553 m
.53692 .44599 L
s
0 1 .475 r
.43304 .5316 m
.43313 .53295 L
s
.43212 .53255 m
.43304 .5316 L
s
.43313 .53295 m
.43212 .53255 L
s
0 .259 1 r
.59618 .43508 m
.59762 .43587 L
s
1 0 .945 r
.47732 .77969 m
.47769 .78096 L
s
.128 1 0 r
.53692 .44599 m
.53757 .44646 L
s
0 .066 1 r
.47773 .19583 m
.48432 .19179 L
s
.702 0 1 r
.53557 .24549 m
.53725 .24451 L
s
.53725 .24451 m
.5376 .247 L
s
0 .259 1 r
.41886 .58302 m
.41857 .58396 L
s
.41748 .58214 m
.41886 .58302 L
s
.41891 .58199 m
.41886 .58302 L
s
1 0 .615 r
.59691 .63599 m
.60407 .64421 L
s
0 .222 1 r
.5991 .25605 m
.59776 .25685 L
s
.59919 .25506 m
.5991 .25605 L
s
.59949 .25706 m
.5991 .25605 L
s
.702 0 1 r
.53557 .24549 m
.5376 .247 L
s
0 .259 1 r
.41719 .58308 m
.41748 .58214 L
s
.41748 .58214 m
.41891 .58199 L
s
.797 0 1 r
.60024 .7022 m
.6001 .70099 L
s
.6001 .70099 m
.59839 .69998 L
s
.6001 .70099 m
.59804 .70253 L
s
.771 0 1 r
.41886 .7207 m
.41713 .72183 L
s
0 1 .879 r
.41497 .54928 m
.41476 .54985 L
s
.41381 .54874 m
.41497 .54928 L
s
.41479 .54829 m
.41497 .54928 L
s
.4136 .54931 m
.41381 .54874 L
s
.41381 .54874 m
.41479 .54829 L
s
0 .222 1 r
.59776 .25685 m
.59786 .25586 L
s
.59949 .25706 m
.59776 .25685 L
s
1 0 .945 r
.47873 .77812 m
.47732 .77969 L
s
1 .195 0 r
.47891 .82784 m
.47899 .82779 L
s
.47899 .82779 m
.47899 .82775 L
s
.47899 .82779 m
.4789 .82773 L
s
.4789 .82773 m
.47891 .82784 L
s
.47899 .82775 m
.4789 .82773 L
s
.4789 .82773 m
.47891 .82781 L
s
.47918 .82809 m
.4789 .82773 L
s
.47891 .82781 m
.47891 .82784 L
s
0 .186 1 r
.60237 .53585 m
.60338 .5434 L
s
1 .195 0 r
.47899 .82775 m
.47891 .82781 L
s
.797 0 1 r
.59804 .70253 m
.60024 .7022 L
s
.59839 .69998 m
.59804 .70253 L
s
.59804 .70253 m
.59853 .70119 L
s
.6044 .69532 m
.59804 .70253 L
s
0 .846 1 r
.58843 .52475 m
.58844 .53099 L
s
1 .195 0 r
.47918 .17191 m
.47947 .17155 L
s
.47945 .17163 m
.47945 .17167 L
s
.47937 .17157 m
.47945 .17163 L
s
.47947 .17155 m
.47945 .17163 L
s
.797 0 1 r
.59839 .69998 m
.59853 .70119 L
s
1 .195 0 r
.47937 .17161 m
.47937 .17157 L
s
.47937 .17157 m
.47947 .17155 L
s
.47945 .17167 m
.47937 .17161 L
s
.47947 .17155 m
.47945 .17167 L
s
.47937 .17161 m
.47947 .17155 L
s
.222 0 1 r
.59858 .60296 m
.60407 .60947 L
s
.407 0 1 r
.42343 .38955 m
.42397 .39178 L
s
.42502 .38944 m
.42343 .38955 L
s
.42343 .38955 m
.42346 .39057 L
s
.42553 .39065 m
.42343 .38955 L
s
.42878 .39484 m
.42343 .38955 L
s
.128 1 0 r
.53939 .55606 m
.54202 .55863 L
s
0 .259 1 r
.41857 .58396 m
.41719 .58308 L
s
.41891 .58199 m
.41857 .58396 L
s
0 .222 1 r
.59786 .25586 m
.59919 .25506 L
s
.59919 .25506 m
.59949 .25706 L
s
.407 0 1 r
.42397 .39178 m
.42553 .39065 L
s
.42553 .39065 m
.42502 .38944 L
s
0 .069 1 r
.53978 .58935 m
.54572 .59355 L
s
0 1 .879 r
.41476 .54985 m
.4136 .54931 L
s
.41479 .54829 m
.41476 .54985 L
s
.4136 .54931 m
.41479 .54829 L
s
0 .259 1 r
.41719 .58308 m
.41891 .58199 L
s
0 .222 1 r
.59786 .25586 m
.59949 .25706 L
s
.407 0 1 r
.42346 .39057 m
.42397 .39178 L
s
.992 0 1 r
.42213 .61502 m
.42174 .61633 L
s
.42033 .61382 m
.42213 .61502 L
s
.42227 .61375 m
.42213 .61502 L
s
0 .259 1 r
.60024 .5699 m
.60434 .57618 L
s
.797 0 1 r
.59853 .70119 m
.60024 .7022 L
s
0 .066 1 r
.48369 .19273 m
.48341 .19371 L
s
.48259 .1915 m
.48369 .19273 L
s
.48432 .19179 m
.48369 .19273 L
s
.992 0 1 r
.41994 .61513 m
.42033 .61382 L
s
.42033 .61382 m
.42227 .61375 L
s
0 .846 1 r
.58843 .53018 m
.58744 .52974 L
s
.58943 .52974 m
.58843 .53018 L
s
.58844 .53099 m
.58843 .53018 L
s
.128 1 0 r
.54185 .55811 m
.5412 .55858 L
s
.54178 .55765 m
.54185 .55811 L
s
.54202 .55863 m
.54185 .55811 L
s
0 .186 1 r
.60289 .54242 m
.60201 .54189 L
s
.60434 .54188 m
.60289 .54242 L
s
.60338 .5434 m
.60289 .54242 L
s
.128 1 0 r
.5412 .55858 m
.54113 .55813 L
s
.54202 .55863 m
.5412 .55858 L
s
.407 0 1 r
.42502 .38944 m
.42346 .39057 L
s
1 0 .615 r
.60364 .64248 m
.60172 .64379 L
s
.60355 .64133 m
.60364 .64248 L
s
.60407 .64421 m
.60364 .64248 L
s
.771 0 1 r
.4229 .27209 m
.42903 .26434 L
s
1 0 .399 r
.60532 .35629 m
.60525 .35515 L
s
.60525 .35515 m
.60325 .35384 L
s
.60525 .35515 m
.6028 .35684 L
s
0 .066 1 r
.4823 .19247 m
.48259 .1915 L
s
.48259 .1915 m
.48432 .19179 L
s
.128 1 0 r
.54113 .55813 m
.54178 .55765 L
s
.54178 .55765 m
.54202 .55863 L
s
0 .846 1 r
.58744 .52974 m
.58844 .52929 L
s
.58744 .52974 m
.58844 .53099 L
s
.58844 .52929 m
.58943 .52974 L
s
.58844 .53099 m
.58943 .52974 L
s
.128 1 0 r
.54113 .55813 m
.54202 .55863 L
s
0 .186 1 r
.60346 .54136 m
.60434 .54188 L
s
.60338 .5434 m
.60434 .54188 L
s
.222 0 1 r
.60377 .60812 m
.60224 .60912 L
s
.6037 .60721 m
.60377 .60812 L
s
.60407 .60947 m
.60377 .60812 L
s
1 0 .399 r
.6028 .35684 m
.60532 .35629 L
s
.60325 .35384 m
.6028 .35684 L
s
.6028 .35684 m
.60333 .35498 L
s
.61025 .34792 m
.6028 .35684 L
s
1 0 .615 r
.60172 .64379 m
.60163 .64264 L
s
.60407 .64421 m
.60172 .64379 L
s
0 .066 1 r
.48341 .19371 m
.4823 .19247 L
s
.48432 .19179 m
.48341 .19371 L
s
.992 0 1 r
.42174 .61633 m
.41994 .61513 L
s
.42227 .61375 m
.42174 .61633 L
s
1 0 .399 r
.60325 .35384 m
.60333 .35498 L
s
.222 0 1 r
.60224 .60912 m
.60217 .60821 L
s
.60407 .60947 m
.60224 .60912 L
s
0 .846 1 r
.58844 .52929 m
.58844 .53099 L
s
0 .186 1 r
.60201 .54189 m
.60346 .54136 L
s
.60201 .54189 m
.60338 .5434 L
s
0 .326 1 r
.54595 .78737 m
.54588 .78639 L
s
.54588 .78639 m
.54456 .78562 L
s
.54588 .78639 m
.54429 .78757 L
s
.992 0 1 r
.41994 .61513 m
.42227 .61375 L
s
0 .066 1 r
.4823 .19247 m
.48432 .19179 L
s
0 .259 1 r
.60431 .57489 m
.60286 .57569 L
s
.60417 .57415 m
.60431 .57489 L
s
.60434 .57618 m
.60431 .57489 L
s
0 .186 1 r
.60346 .54136 m
.60338 .5434 L
s
0 .326 1 r
.54429 .78757 m
.54595 .78737 L
s
.54456 .78562 m
.54429 .78757 L
s
.54429 .78757 m
.54463 .78661 L
s
.54913 .78219 m
.54429 .78757 L
s
0 .069 1 r
.54532 .59267 m
.54409 .59379 L
s
.54497 .59162 m
.54532 .59267 L
s
.54572 .59355 m
.54532 .59267 L
s
0 .259 1 r
.60286 .57569 m
.60272 .57494 L
s
.60434 .57618 m
.60286 .57569 L
s
0 .326 1 r
.54456 .78562 m
.54463 .78661 L
s
1 0 .945 r
.48499 .21641 m
.49349 .21132 L
s
.797 0 1 r
.6044 .30468 m
.61078 .31192 L
s
0 1 .879 r
.4229 .42527 m
.42325 .42675 L
s
.424 .42525 m
.4229 .42527 L
s
.4229 .42527 m
.42298 .42598 L
s
.42427 .42602 m
.4229 .42527 L
s
.42655 .4289 m
.4229 .42527 L
s
.42325 .42675 m
.42427 .42602 L
s
.42427 .42602 m
.424 .42525 L
s
.647 0 1 r
.54839 .40102 m
.54854 .39992 L
s
.54854 .39992 m
.54695 .39873 L
s
.54854 .39992 m
.54636 .40117 L
s
.222 0 1 r
.60217 .60821 m
.6037 .60721 L
s
.6037 .60721 m
.60407 .60947 L
s
1 0 .615 r
.60163 .64264 m
.60355 .64133 L
s
.60355 .64133 m
.60407 .64421 L
s
.528 0 1 r
.60797 .38777 m
.60795 .38682 L
s
.60795 .38682 m
.60633 .38577 L
s
.60795 .38682 m
.60596 .38819 L
s
0 .069 1 r
.54409 .59379 m
.54374 .59274 L
s
.54572 .59355 m
.54409 .59379 L
s
.771 0 1 r
.42868 .26601 m
.42866 .26692 L
s
.42695 .26487 m
.42868 .26601 L
s
.42903 .26434 m
.42868 .26601 L
s
.647 0 1 r
.54636 .40117 m
.54839 .40102 L
s
.54695 .39873 m
.54636 .40117 L
s
.54636 .40117 m
.5468 .39983 L
s
.55292 .39471 m
.54636 .40117 L
s
1 0 .399 r
.60333 .35498 m
.60532 .35629 L
s
0 1 .879 r
.42298 .42598 m
.42325 .42675 L
s
.222 0 1 r
.60217 .60821 m
.60407 .60947 L
s
.528 0 1 r
.60596 .38819 m
.60797 .38777 L
s
.60633 .38577 m
.60596 .38819 L
s
.60596 .38819 m
.60634 .38672 L
s
.61192 .38105 m
.60596 .38819 L
s
1 0 .615 r
.60163 .64264 m
.60407 .64421 L
s
0 .326 1 r
.54463 .78661 m
.54595 .78737 L
s
.528 0 1 r
.60633 .38577 m
.60634 .38672 L
s
.647 0 1 r
.54695 .39873 m
.5468 .39983 L
s
0 .259 1 r
.60272 .57494 m
.60417 .57415 L
s
.60417 .57415 m
.60434 .57618 L
s
.771 0 1 r
.42693 .26578 m
.42695 .26487 L
s
.42695 .26487 m
.42903 .26434 L
s
0 .069 1 r
.54374 .59274 m
.54497 .59162 L
s
.54497 .59162 m
.54572 .59355 L
s
0 .264 1 r
.42795 .77822 m
.42931 .77732 L
s
.42931 .77732 m
.42931 .77665 L
s
.42931 .77732 m
.42768 .77619 L
s
0 .259 1 r
.60272 .57494 m
.60434 .57618 L
s
0 1 .475 r
.44352 .44223 m
.4443 .44157 L
s
.4443 .44157 m
.44418 .44087 L
s
.4443 .44157 m
.44308 .441 L
s
0 1 .879 r
.424 .42525 m
.42298 .42598 L
s
0 1 .475 r
.44308 .441 m
.44352 .44223 L
s
.44418 .44087 m
.44308 .441 L
s
.44308 .441 m
.44339 .44154 L
s
.44692 .44377 m
.44308 .441 L
s
0 .264 1 r
.42768 .77619 m
.42795 .77822 L
s
.42931 .77665 m
.42768 .77619 L
s
.42768 .77619 m
.42795 .77754 L
s
.43245 .78241 m
.42768 .77619 L
s
0 1 .475 r
.44339 .44154 m
.44352 .44223 L
s
0 .069 1 r
.54374 .59274 m
.54572 .59355 L
s
0 .264 1 r
.42795 .77754 m
.42795 .77822 L
s
.222 0 1 r
.61029 .42068 m
.61032 .41983 L
s
.61032 .41983 m
.60873 .41891 L
s
.61032 .41983 m
.60849 .42119 L
s
1 0 .945 r
.49036 .78901 m
.49072 .78735 L
s
.49072 .78735 m
.48931 .786 L
s
.49072 .78735 m
.48813 .78826 L
s
.222 0 1 r
.60849 .42119 m
.61029 .42068 L
s
.60873 .41891 m
.60849 .42119 L
s
.60849 .42119 m
.60871 .41976 L
s
.6136 .41422 m
.60849 .42119 L
s
.647 0 1 r
.5468 .39983 m
.54839 .40102 L
s
.528 0 1 r
.60634 .38672 m
.60797 .38777 L
s
1 0 .945 r
.48813 .78826 m
.49036 .78901 L
s
.48931 .786 m
.48813 .78826 L
s
.48813 .78826 m
.48894 .78766 L
s
.49665 .78449 m
.48813 .78826 L
s
.797 0 1 r
.61028 .31057 m
.60858 .31158 L
s
.61043 .30936 m
.61028 .31057 L
s
.61078 .31192 m
.61028 .31057 L
s
0 1 .475 r
.44418 .44087 m
.44339 .44154 L
s
.222 0 1 r
.60873 .41891 m
.60871 .41976 L
s
.771 0 1 r
.42866 .26692 m
.42693 .26578 L
s
.42903 .26434 m
.42866 .26692 L
s
.407 0 1 r
.42878 .60516 m
.43416 .59985 L
s
.771 0 1 r
.42693 .26578 m
.42903 .26434 L
s
.407 0 1 r
.61142 .45533 m
.61293 .45456 L
s
.61145 .45294 m
.61142 .45533 L
s
.61142 .45533 m
.61114 .45373 L
s
.61323 .45377 m
.61142 .45533 L
s
.61527 .44742 m
.61142 .45533 L
s
.61293 .45456 m
.61323 .45377 L
s
.61323 .45377 m
.61145 .45294 L
s
.61145 .45294 m
.61114 .45373 L
s
0 .264 1 r
.42931 .77665 m
.42795 .77754 L
s
.797 0 1 r
.60858 .31158 m
.60872 .31037 L
s
.61078 .31192 m
.60858 .31158 L
s
1 0 .945 r
.48931 .786 m
.48894 .78766 L
s
0 .326 1 r
.54913 .21781 m
.55399 .2232 L
s
1 0 .945 r
.49268 .21249 m
.49231 .21377 L
s
.49126 .21092 m
.49268 .21249 L
s
.49349 .21132 m
.49268 .21249 L
s
0 1 .741 r
.55186 .43153 m
.55198 .43085 L
s
.55198 .43085 m
.55104 .43014 L
s
.55198 .43085 m
.55067 .43157 L
s
.222 0 1 r
.60871 .41976 m
.61029 .42068 L
s
0 1 .741 r
.55067 .43157 m
.55186 .43153 L
s
.55104 .43014 m
.55067 .43157 L
s
.55067 .43157 m
.55092 .43082 L
s
.55457 .42788 m
.55067 .43157 L
s
1 0 .945 r
.48894 .78766 m
.49036 .78901 L
s
0 1 .741 r
.55104 .43014 m
.55092 .43082 L
s
0 1 .879 r
.42655 .5711 m
.43021 .56746 L
s
1 0 .399 r
.61025 .65208 m
.61773 .66104 L
s
.797 0 1 r
.60872 .31037 m
.61043 .30936 L
s
.61043 .30936 m
.61078 .31192 L
s
0 1 .475 r
.44692 .55623 m
.45076 .55345 L
s
.797 0 1 r
.60872 .31037 m
.61078 .31192 L
s
1 0 .945 r
.4909 .21219 m
.49126 .21092 L
s
.49126 .21092 m
.49349 .21132 L
s
.407 0 1 r
.61114 .45373 m
.61293 .45456 L
s
0 1 .741 r
.55092 .43082 m
.55186 .43153 L
s
0 .326 1 r
.55364 .22223 m
.55232 .22299 L
s
.55371 .22124 m
.55364 .22223 L
s
.55399 .2232 m
.55364 .22223 L
s
0 .264 1 r
.43245 .21759 m
.43723 .21137 L
s
1 0 .945 r
.49231 .21377 m
.4909 .21219 L
s
.49349 .21132 m
.49231 .21377 L
s
.73 0 1 r
.55485 .7356 m
.55477 .73436 L
s
.55477 .73436 m
.55309 .73335 L
s
.55477 .73436 m
.5527 .73586 L
s
.528 0 1 r
.61192 .61895 m
.61791 .62611 L
s
0 .326 1 r
.55232 .22299 m
.55239 .22201 L
s
.55399 .2232 m
.55232 .22299 L
s
.73 0 1 r
.5527 .73586 m
.55485 .7356 L
s
.55309 .73335 m
.5527 .73586 L
s
.5527 .73586 m
.55316 .7346 L
s
.55903 .72893 m
.5527 .73586 L
s
.647 0 1 r
.55292 .60529 m
.5595 .61178 L
s
0 1 .475 r
.45045 .55399 m
.45033 .55468 L
s
.44966 .55333 m
.45045 .55399 L
s
.45076 .55345 m
.45045 .55399 L
s
.73 0 1 r
.55309 .73335 m
.55316 .7346 L
s
1 0 .945 r
.4909 .21219 m
.49349 .21132 L
s
.128 1 0 r
.55482 .46654 m
.55482 .46619 L
s
.55482 .46619 m
.55408 .46582 L
s
.55482 .46619 m
.55405 .46685 L
s
.55405 .46685 m
.55482 .46654 L
s
.55408 .46582 m
.55405 .46685 L
s
.55405 .46685 m
.55408 .46617 L
s
.55605 .46351 m
.55405 .46685 L
s
.55408 .46582 m
.55408 .46617 L
s
0 1 .475 r
.44954 .55402 m
.44966 .55333 L
s
.44966 .55333 m
.45076 .55345 L
s
0 1 .879 r
.43012 .56817 m
.42985 .56894 L
s
.4291 .56744 m
.43012 .56817 L
s
.43021 .56746 m
.43012 .56817 L
s
0 .326 1 r
.55239 .22201 m
.55371 .22124 L
s
.55371 .22124 m
.55399 .2232 L
s
.407 0 1 r
.43412 .60088 m
.43362 .60209 L
s
.43255 .59975 m
.43412 .60088 L
s
.43416 .59985 m
.43412 .60088 L
s
.222 0 1 r
.6136 .58578 m
.61871 .59277 L
s
0 .326 1 r
.55239 .22201 m
.55399 .2232 L
s
0 1 .879 r
.42883 .56821 m
.4291 .56744 L
s
.4291 .56744 m
.43021 .56746 L
s
0 1 .475 r
.45033 .55468 m
.44954 .55402 L
s
.45076 .55345 m
.45033 .55468 L
s
.407 0 1 r
.43205 .60095 m
.43255 .59975 L
s
.43255 .59975 m
.43416 .59985 L
s
0 .264 1 r
.43696 .21273 m
.43696 .2134 L
s
.43559 .21183 m
.43696 .21273 L
s
.43723 .21137 m
.43696 .21273 L
s
.128 1 0 r
.55408 .46617 m
.55482 .46654 L
s
0 1 .741 r
.55457 .57212 m
.55847 .57581 L
s
1 0 .399 r
.61719 .65916 m
.61519 .66047 L
s
.61727 .65803 m
.61719 .65916 L
s
.61773 .66104 m
.61719 .65916 L
s
0 1 .475 r
.44954 .55402 m
.45076 .55345 L
s
.73 0 1 r
.55316 .7346 m
.55485 .7356 L
s
0 .264 1 r
.43559 .2125 m
.43559 .21183 L
s
.43559 .21183 m
.43723 .21137 L
s
0 1 .879 r
.42985 .56894 m
.42883 .56821 L
s
.43021 .56746 m
.42985 .56894 L
s
.407 0 1 r
.61527 .55258 m
.61914 .56053 L
s
0 .186 1 r
.4363 .40841 m
.43699 .41007 L
s
.43746 .40777 m
.4363 .40841 L
s
.4363 .40841 m
.43624 .40889 L
s
.43821 .40895 m
.4363 .40841 L
s
.44093 .41098 m
.4363 .40841 L
s
1 0 .399 r
.61519 .66047 m
.61527 .65934 L
s
.61773 .66104 m
.61519 .66047 L
s
.528 0 1 r
.61751 .62462 m
.61589 .62568 L
s
.61753 .62367 m
.61751 .62462 L
s
.61791 .62611 m
.61751 .62462 L
s
0 1 .879 r
.42883 .56821 m
.43021 .56746 L
s
1 0 .072 r
.61944 .34697 m
.61895 .34626 L
s
.61895 .34626 m
.61656 .34536 L
s
.61895 .34626 m
.61696 .34854 L
s
0 .846 1 r
.45102 .42112 m
.45161 .4224 L
s
.45186 .42045 m
.45102 .42112 L
s
.45102 .42112 m
.45088 .42141 L
s
.45259 .42144 m
.45102 .42112 L
s
.45459 .42263 m
.45102 .42112 L
s
.128 1 0 r
.55605 .53649 m
.55806 .53982 L
s
.407 0 1 r
.43362 .60209 m
.43205 .60095 L
s
.43416 .59985 m
.43362 .60209 L
s
0 .186 1 r
.43699 .41007 m
.43821 .40895 L
s
.43821 .40895 m
.43746 .40777 L
s
1 0 .945 r
.49665 .21551 m
.50521 .21931 L
s
.528 0 1 r
.61589 .62568 m
.6159 .62473 L
s
.61791 .62611 m
.61589 .62568 L
s
0 .264 1 r
.43696 .2134 m
.43559 .2125 L
s
.43723 .21137 m
.43696 .2134 L
s
.407 0 1 r
.43205 .60095 m
.43416 .59985 L
s
1 0 .072 r
.61656 .34536 m
.61705 .34607 L
s
.61656 .34536 m
.61696 .34854 L
s
0 .264 1 r
.43559 .2125 m
.43723 .21137 L
s
0 .066 1 r
.49907 .80987 m
.49935 .80857 L
s
.49935 .80857 m
.49824 .80752 L
s
.49935 .80857 m
.49733 .80929 L
s
0 .846 1 r
.45161 .4224 m
.45259 .42144 L
s
.45259 .42144 m
.45186 .42045 L
s
0 .186 1 r
.43624 .40889 m
.43699 .41007 L
s
0 .19 1 r
.61916 .72286 m
.61905 .72188 L
s
.61905 .72188 m
.61769 .72108 L
s
.61905 .72188 m
.61741 .72312 L
s
0 .066 1 r
.49733 .80929 m
.49907 .80987 L
s
.49824 .80752 m
.49733 .80929 L
s
.49733 .80929 m
.49796 .80883 L
s
.50398 .80633 m
.49733 .80929 L
s
.222 0 1 r
.61849 .59133 m
.6169 .59226 L
s
.61847 .59048 m
.61849 .59133 L
s
.61871 .59277 m
.61849 .59133 L
s
.647 0 1 r
.55905 .61043 m
.55746 .61162 L
s
.55891 .60934 m
.55905 .61043 L
s
.5595 .61178 m
.55905 .61043 L
s
1 0 .072 r
.61696 .34854 m
.61944 .34697 L
s
.61696 .34854 m
.61705 .34607 L
s
.62218 .33667 m
.61696 .34854 L
s
0 1 .741 r
.55822 .57505 m
.55728 .57576 L
s
.5581 .57438 m
.55822 .57505 L
s
.55847 .57581 m
.55822 .57505 L
s
.128 1 0 r
.55803 .53915 m
.55728 .53951 L
s
.55803 .53879 m
.55803 .53915 L
s
.55806 .53982 m
.55803 .53915 L
s
0 .846 1 r
.45088 .42141 m
.45161 .4224 L
s
0 .19 1 r
.61741 .72312 m
.61916 .72286 L
s
.61769 .72108 m
.61741 .72312 L
s
.61741 .72312 m
.6178 .72206 L
s
.6225 .71739 m
.61741 .72312 L
s
.128 1 0 r
.55728 .53951 m
.55729 .53916 L
s
.55806 .53982 m
.55728 .53951 L
s
1 0 .807 r
.56128 .38605 m
.56134 .38489 L
s
.56134 .38489 m
.55953 .38361 L
s
.56134 .38489 m
.55897 .38637 L
s
0 .19 1 r
.61769 .72108 m
.6178 .72206 L
s
.222 0 1 r
.6169 .59226 m
.61689 .59141 L
s
.61871 .59277 m
.6169 .59226 L
s
0 1 .741 r
.55728 .57576 m
.55716 .57509 L
s
.55847 .57581 m
.55728 .57576 L
s
1 0 .399 r
.61527 .65934 m
.61727 .65803 L
s
.61727 .65803 m
.61773 .66104 L
s
0 .186 1 r
.43746 .40777 m
.43624 .40889 L
s
0 .846 1 r
.45186 .42045 m
.45088 .42141 L
s
0 .066 1 r
.49824 .80752 m
.49796 .80883 L
s
.647 0 1 r
.55746 .61162 m
.55731 .61053 L
s
.5595 .61178 m
.55746 .61162 L
s
1 0 .807 r
.55897 .38637 m
.56128 .38605 L
s
.55953 .38361 m
.55897 .38637 L
s
.55897 .38637 m
.55946 .38477 L
s
.56615 .37865 m
.55897 .38637 L
s
1 0 .399 r
.61527 .65934 m
.61773 .66104 L
s
.528 0 1 r
.6159 .62473 m
.61753 .62367 L
s
.61753 .62367 m
.61791 .62611 L
s
.655 0 1 r
.62126 .37198 m
.62115 .37102 L
s
.62115 .37102 m
.61949 .36995 L
s
.62115 .37102 m
.61913 .37246 L
s
.128 1 0 r
.55729 .53916 m
.55803 .53879 L
s
.55803 .53879 m
.55806 .53982 L
s
.55729 .53916 m
.55806 .53982 L
s
.528 0 1 r
.6159 .62473 m
.61791 .62611 L
s
0 1 .741 r
.55716 .57509 m
.5581 .57438 L
s
.5581 .57438 m
.55847 .57581 L
s
1 0 .528 r
.62234 .68607 m
.6218 .68542 L
s
.6218 .68542 m
.61948 .68498 L
s
.6218 .68542 m
.62034 .68783 L
s
1 0 .807 r
.55953 .38361 m
.55946 .38477 L
s
0 .066 1 r
.49796 .80883 m
.49907 .80987 L
s
.73 0 1 r
.55903 .27107 m
.56537 .27803 L
s
.655 0 1 r
.61913 .37246 m
.62126 .37198 L
s
.61949 .36995 m
.61913 .37246 L
s
.61913 .37246 m
.61959 .3709 L
s
.62536 .36496 m
.61913 .37246 L
s
0 1 .741 r
.55716 .57509 m
.55847 .57581 L
s
0 .19 1 r
.6178 .72206 m
.61916 .72286 L
s
.655 0 1 r
.61949 .36995 m
.61959 .3709 L
s
1 0 .528 r
.61948 .68498 m
.62002 .68563 L
s
.61948 .68498 m
.62034 .68783 L
s
1 0 .072 r
.61705 .34607 m
.61944 .34697 L
s
.407 0 1 r
.61941 .55892 m
.61762 .55975 L
s
.61911 .55813 m
.61941 .55892 L
s
.61914 .56053 m
.61941 .55892 L
s
.61762 .55975 m
.61732 .55896 L
s
.61914 .56053 m
.61762 .55975 L
s
.222 0 1 r
.61689 .59141 m
.61847 .59048 L
s
.61847 .59048 m
.61871 .59277 L
s
.647 0 1 r
.55731 .61053 m
.55891 .60934 L
s
.55891 .60934 m
.5595 .61178 L
s
.222 0 1 r
.61689 .59141 m
.61871 .59277 L
s
.528 0 1 r
.62327 .40513 m
.62322 .4042 L
s
.62322 .4042 m
.62156 .40318 L
s
.62322 .4042 m
.62126 .40563 L
s
1 0 .528 r
.62034 .68783 m
.62234 .68607 L
s
.62034 .68783 m
.62002 .68563 L
s
.62319 .6763 m
.62034 .68783 L
s
.647 0 1 r
.55731 .61053 m
.5595 .61178 L
s
.528 0 1 r
.62126 .40563 m
.62327 .40513 L
s
.62156 .40318 m
.62126 .40563 L
s
.62126 .40563 m
.62161 .40411 L
s
.62705 .39823 m
.62126 .40563 L
s
1 0 .807 r
.55946 .38477 m
.56128 .38605 L
s
.528 0 1 r
.62156 .40318 m
.62161 .40411 L
s
.992 0 1 r
.62541 .43947 m
.62554 .43852 L
s
.62554 .43852 m
.62357 .43751 L
s
.62554 .43852 m
.62343 .44022 L
s
.655 0 1 r
.61959 .3709 m
.62126 .37198 L
s
.992 0 1 r
.62343 .44022 m
.62541 .43947 L
s
.62357 .43751 m
.62343 .44022 L
s
.62343 .44022 m
.62345 .43846 L
s
.62873 .43154 m
.62343 .44022 L
s
1 0 .945 r
.50438 .2187 m
.50297 .22006 L
s
.50403 .21704 m
.50438 .2187 L
s
.50521 .21931 m
.50438 .2187 L
s
.992 0 1 r
.62357 .43751 m
.62345 .43846 L
s
1 .195 0 r
.50233 .83046 m
.50232 .8304 L
s
.50232 .8304 m
.50225 .83036 L
s
.50232 .8304 m
.50223 .83047 L
s
.50223 .83047 m
.50233 .83046 L
s
.50225 .83036 m
.50223 .83047 L
s
.50223 .83047 m
.50225 .83042 L
s
.50251 .83016 m
.50223 .83047 L
s
.50225 .83036 m
.50225 .83042 L
s
0 .508 1 r
.56463 .41697 m
.56468 .41619 L
s
.56468 .41619 m
.56343 .41534 L
s
.56468 .41619 m
.56308 .41721 L
s
.73 0 1 r
.5649 .27674 m
.56322 .27776 L
s
.56499 .27551 m
.5649 .27674 L
s
.56537 .27803 m
.5649 .27674 L
s
1 .195 0 r
.50225 .83042 m
.50233 .83046 L
s
1 0 .072 r
.62218 .66333 m
.62741 .67522 L
s
.407 0 1 r
.61732 .55896 m
.61911 .55813 L
s
.61911 .55813 m
.61914 .56053 L
s
.61732 .55896 m
.61914 .56053 L
s
1 0 .528 r
.62002 .68563 m
.62234 .68607 L
s
1 .195 0 r
.50251 .16984 m
.5028 .17016 L
s
0 .508 1 r
.56308 .41721 m
.56463 .41697 L
s
.56343 .41534 m
.56308 .41721 L
s
.56308 .41721 m
.56338 .41613 L
s
.56781 .41194 m
.56308 .41721 L
s
0 .19 1 r
.6225 .28261 m
.6276 .28834 L
s
1 .195 0 r
.50278 .1701 m
.5027 .17015 L
s
.50278 .17004 m
.50278 .1701 L
s
.5028 .17016 m
.50278 .1701 L
s
.5027 .17015 m
.5027 .17009 L
s
.5028 .17016 m
.5027 .17015 L
s
.5027 .17009 m
.50278 .17004 L
s
.50278 .17004 m
.5028 .17016 L
s
.5027 .17009 m
.5028 .17016 L
s
0 .508 1 r
.56343 .41534 m
.56338 .41613 L
s
.729 0 1 r
.44402 .75727 m
.44575 .75614 L
s
.44575 .75614 m
.44575 .75527 L
s
.44575 .75614 m
.44367 .75471 L
s
.528 0 1 r
.62161 .40411 m
.62327 .40513 L
s
1 0 .945 r
.50297 .22006 m
.50261 .2184 L
s
.50521 .21931 m
.50297 .22006 L
s
.73 0 1 r
.56322 .27776 m
.5633 .27652 L
s
.56537 .27803 m
.56322 .27776 L
s
1 0 .528 r
.62319 .3237 m
.62604 .33525 L
s
.62635 .33304 m
.62403 .33348 L
s
.6269 .3324 m
.62635 .33304 L
s
.62604 .33525 m
.62635 .33304 L
s
.729 0 1 r
.44367 .75471 m
.44402 .75727 L
s
.44575 .75527 m
.44367 .75471 L
s
.44367 .75471 m
.44402 .7564 L
s
.44976 .76255 m
.44367 .75471 L
s
.44402 .7564 m
.44402 .75727 L
s
1 0 .072 r
.62731 .67273 m
.62492 .67364 L
s
.6278 .67204 m
.62731 .67273 L
s
.62741 .67522 m
.62731 .67273 L
s
0 .066 1 r
.50398 .19367 m
.51066 .19663 L
s
1 0 .945 r
.50261 .2184 m
.50403 .21704 L
s
.50403 .21704 m
.50521 .21931 L
s
.992 0 1 r
.62345 .43846 m
.62541 .43947 L
s
1 0 .528 r
.62403 .33348 m
.62458 .33284 L
s
.62604 .33525 m
.62403 .33348 L
s
0 .508 1 r
.56338 .41613 m
.56463 .41697 L
s
0 .846 1 r
.45459 .57737 m
.45818 .57585 L
s
1 0 .072 r
.62492 .67364 m
.62541 .67295 L
s
.62741 .67522 m
.62492 .67364 L
s
.73 0 1 r
.5633 .27652 m
.56499 .27551 L
s
.56499 .27551 m
.56537 .27803 L
s
0 .19 1 r
.6272 .28728 m
.62584 .28809 L
s
.62732 .2863 m
.6272 .28728 L
s
.6276 .28834 m
.6272 .28728 L
s
1 0 .945 r
.50261 .2184 m
.50521 .21931 L
s
0 .186 1 r
.44093 .58902 m
.44559 .58643 L
s
.73 0 1 r
.5633 .27652 m
.56537 .27803 L
s
.655 0 1 r
.62536 .63504 m
.63161 .64257 L
s
0 1 .741 r
.56775 .44974 m
.56776 .44924 L
s
.56776 .44924 m
.56666 .44871 L
s
.56776 .44924 m
.56664 .45022 L
s
.729 0 1 r
.44575 .75527 m
.44402 .7564 L
s
0 1 .741 r
.56664 .45022 m
.56775 .44974 L
s
.56666 .44871 m
.56664 .45022 L
s
.56664 .45022 m
.56666 .44921 L
s
.56948 .44526 m
.56664 .45022 L
s
.56666 .44871 m
.56666 .44921 L
s
0 .19 1 r
.62584 .28809 m
.62595 .28711 L
s
.6276 .28834 m
.62584 .28809 L
s
1 0 .528 r
.6269 .3324 m
.62604 .33525 L
s
.62458 .33284 m
.62604 .33525 L
s
1 0 .807 r
.56615 .62135 m
.57337 .62909 L
s
.702 0 1 r
.50924 .76947 m
.50919 .76822 L
s
.50919 .76822 m
.50749 .76723 L
s
.50919 .76822 m
.50713 .76974 L
s
1 0 .528 r
.62458 .33284 m
.6269 .3324 L
s
.528 0 1 r
.62705 .60177 m
.63285 .60919 L
s
.702 0 1 r
.50713 .76974 m
.50924 .76947 L
s
.50749 .76723 m
.50713 .76974 L
s
.50713 .76974 m
.50754 .76848 L
s
.51331 .7628 m
.50713 .76974 L
s
0 1 .741 r
.56666 .44921 m
.56775 .44974 L
s
1 0 .072 r
.6278 .67204 m
.62741 .67522 L
s
.62541 .67295 m
.62741 .67522 L
s
0 .19 1 r
.62595 .28711 m
.62732 .2863 L
s
.62732 .2863 m
.6276 .28834 L
s
.702 0 1 r
.50749 .76723 m
.50754 .76848 L
s
0 1 .883 r
.50747 .4254 m
.50748 .42458 L
s
.50748 .42458 m
.50681 .42371 L
s
.50748 .42458 m
.50604 .42507 L
s
0 .19 1 r
.62595 .28711 m
.6276 .28834 L
s
1 0 .072 r
.62541 .67295 m
.6278 .67204 L
s
0 .066 1 r
.51001 .19617 m
.50891 .19722 L
s
.50974 .19486 m
.51001 .19617 L
s
.51066 .19663 m
.51001 .19617 L
s
0 .508 1 r
.56781 .58806 m
.57256 .59334 L
s
0 1 .883 r
.50604 .42507 m
.50747 .4254 L
s
.50681 .42371 m
.50604 .42507 L
s
.50604 .42507 m
.50679 .42453 L
s
.51153 .42249 m
.50604 .42507 L
s
.655 0 1 r
.63113 .64099 m
.62947 .64208 L
s
.63125 .64005 m
.63113 .64099 L
s
.63161 .64257 m
.63113 .64099 L
s
0 1 .883 r
.50681 .42371 m
.50679 .42453 L
s
.992 0 1 r
.62873 .56846 m
.63405 .57718 L
s
0 .066 1 r
.50891 .19722 m
.50863 .19591 L
s
.51066 .19663 m
.50891 .19722 L
s
0 1 .883 r
.50679 .42453 m
.50747 .4254 L
s
.702 0 1 r
.50754 .76848 m
.50924 .76947 L
s
0 1 .741 r
.56948 .55474 m
.57232 .55971 L
s
.655 0 1 r
.62947 .64208 m
.62958 .64113 L
s
.63161 .64257 m
.62947 .64208 L
s
0 .066 1 r
.50863 .19591 m
.50974 .19486 L
s
.50974 .19486 m
.51066 .19663 L
s
0 1 .883 r
.57212 .47929 m
.5718 .47968 L
s
.57334 .47969 m
.57212 .47929 L
s
.57212 .47929 m
.57227 .48085 L
s
.729 0 1 r
.44976 .23745 m
.45587 .22958 L
s
0 1 .883 r
.57302 .48007 m
.57334 .47969 L
s
.57334 .47969 m
.57227 .48085 L
s
.57227 .48085 m
.57302 .48007 L
s
.57227 .48085 m
.5718 .47968 L
s
.57377 .47502 m
.57227 .48085 L
s
.528 0 1 r
.63249 .60765 m
.63083 .60868 L
s
.63255 .60673 m
.63249 .60765 L
s
.63285 .60919 m
.63249 .60765 L
s
1 0 .807 r
.57286 .62747 m
.57104 .62876 L
s
.5728 .62632 m
.57286 .62747 L
s
.57337 .62909 m
.57286 .62747 L
s
0 .066 1 r
.50863 .19591 m
.51066 .19663 L
s
0 .508 1 r
.57225 .59225 m
.57101 .5931 L
s
.57221 .59147 m
.57225 .59225 L
s
.57256 .59334 m
.57225 .59225 L
s
1 0 .456 r
.57441 .37065 m
.57439 .36947 L
s
.57439 .36947 m
.57242 .36814 L
s
.57439 .36947 m
.5719 .37112 L
s
0 .846 1 r
.45832 .57614 m
.45759 .57714 L
s
.45733 .57517 m
.45832 .57614 L
s
.45818 .57585 m
.45832 .57614 L
s
.528 0 1 r
.63083 .60868 m
.63089 .60775 L
s
.63285 .60919 m
.63083 .60868 L
s
0 1 .741 r
.5723 .5587 m
.5712 .55922 L
s
.57229 .5582 m
.5723 .5587 L
s
.57232 .55971 m
.5723 .5587 L
s
.655 0 1 r
.62958 .64113 m
.63125 .64005 L
s
.63125 .64005 m
.63161 .64257 L
s
0 .508 1 r
.57101 .5931 m
.57096 .59232 L
s
.57256 .59334 m
.57101 .5931 L
s
0 .846 1 r
.45661 .57617 m
.45733 .57517 L
s
.45733 .57517 m
.45818 .57585 L
s
1 0 .456 r
.5719 .37112 m
.57441 .37065 L
s
.57242 .36814 m
.5719 .37112 L
s
.5719 .37112 m
.57244 .36932 L
s
.57948 .36249 m
.5719 .37112 L
s
0 .295 1 r
.57369 .75651 m
.57361 .75552 L
s
.57361 .75552 m
.57228 .75474 L
s
.57361 .75552 m
.57199 .75672 L
s
1 0 .807 r
.57104 .62876 m
.57098 .62761 L
s
.57337 .62909 m
.57104 .62876 L
s
0 1 .883 r
.51153 .57751 m
.51703 .58009 L
s
.5718 .47968 m
.57302 .48007 L
s
0 1 .741 r
.5712 .55922 m
.5712 .55873 L
s
.57232 .55971 m
.5712 .55922 L
s
.655 0 1 r
.62958 .64113 m
.63161 .64257 L
s
0 .186 1 r
.44565 .58692 m
.44489 .58811 L
s
.44443 .58579 m
.44565 .58692 L
s
.44559 .58643 m
.44565 .58692 L
s
0 .295 1 r
.57199 .75672 m
.57369 .75651 L
s
.57228 .75474 m
.57199 .75672 L
s
.57199 .75672 m
.57236 .75573 L
s
.57697 .75125 m
.57199 .75672 L
s
1 0 .456 r
.57242 .36814 m
.57244 .36932 L
s
0 .846 1 r
.45759 .57714 m
.45661 .57617 L
s
.45818 .57585 m
.45759 .57714 L
s
0 .015 1 r
.45321 .80535 m
.45436 .8041 L
s
.45436 .8041 m
.45406 .8031 L
s
.45436 .8041 m
.45231 .80339 L
s
0 .295 1 r
.57228 .75474 m
.57236 .75573 L
s
0 .015 1 r
.45231 .80339 m
.45321 .80535 L
s
.45406 .8031 m
.45231 .80339 L
s
.45231 .80339 m
.45291 .80436 L
s
.45896 .80758 m
.45231 .80339 L
s
0 .186 1 r
.44367 .58697 m
.44443 .58579 L
s
.44443 .58579 m
.44559 .58643 L
s
0 .846 1 r
.45661 .57617 m
.45818 .57585 L
s
.859 0 1 r
.63594 .35183 m
.63554 .35124 L
s
.63554 .35124 m
.63358 .35048 L
s
.63554 .35124 m
.63389 .3531 L
s
0 .508 1 r
.57096 .59232 m
.57221 .59147 L
s
.57221 .59147 m
.57256 .59334 L
s
.992 0 1 r
.63403 .5754 m
.63206 .57642 L
s
.63392 .57445 m
.63403 .5754 L
s
.63405 .57718 m
.63403 .5754 L
s
.729 0 1 r
.45551 .23129 m
.45552 .23216 L
s
.45378 .23015 m
.45551 .23129 L
s
.45587 .22958 m
.45551 .23129 L
s
0 1 .883 r
.51627 .57954 m
.5156 .58041 L
s
.51626 .57873 m
.51627 .57954 L
s
.51703 .58009 m
.51627 .57954 L
s
0 1 .741 r
.5712 .55873 m
.57229 .5582 L
s
.57229 .5582 m
.57232 .55971 L
s
.5712 .55873 m
.57232 .55971 L
s
.528 0 1 r
.63089 .60775 m
.63255 .60673 L
s
.63255 .60673 m
.63285 .60919 L
s
0 .508 1 r
.57096 .59232 m
.57256 .59334 L
s
0 .015 1 r
.45291 .80436 m
.45321 .80535 L
s
.702 0 1 r
.51331 .2372 m
.51951 .24416 L
s
.992 0 1 r
.63206 .57642 m
.63195 .57547 L
s
.63405 .57718 m
.63206 .57642 L
s
.655 0 1 r
.63649 .38918 m
.63637 .38822 L
s
.63637 .38822 m
.6347 .38715 L
s
.63637 .38822 m
.63434 .38967 L
s
.528 0 1 r
.63089 .60775 m
.63285 .60919 L
s
1 0 .807 r
.57098 .62761 m
.5728 .62632 L
s
.5728 .62632 m
.57337 .62909 L
s
.859 0 1 r
.63358 .35048 m
.63398 .35108 L
s
.63358 .35048 m
.63389 .3531 L
s
0 .186 1 r
.44489 .58811 m
.44367 .58697 L
s
.44559 .58643 m
.44489 .58811 L
s
0 .295 1 r
.57236 .75573 m
.57369 .75651 L
s
0 1 .883 r
.57377 .52498 m
.57528 .53082 L
s
.859 0 1 r
.63389 .3531 m
.63594 .35183 L
s
.63389 .3531 m
.63398 .35108 L
s
.63825 .34337 m
.63389 .3531 L
s
1 0 .615 r
.63811 .42393 m
.63809 .42285 L
s
.63809 .42285 m
.63605 .42169 L
s
.63809 .42285 m
.63578 .42462 L
s
.729 0 1 r
.45379 .23102 m
.45378 .23015 L
s
.45378 .23015 m
.45587 .22958 L
s
.655 0 1 r
.63434 .38967 m
.63649 .38918 L
s
.6347 .38715 m
.63434 .38967 L
s
.63434 .38967 m
.63482 .38811 L
s
.64059 .38213 m
.63434 .38967 L
s
1 0 .807 r
.57098 .62761 m
.57337 .62909 L
s
1 0 .456 r
.57244 .36932 m
.57441 .37065 L
s
0 1 .883 r
.5156 .58041 m
.51559 .5796 L
s
.51703 .58009 m
.5156 .58041 L
s
0 .186 1 r
.44367 .58697 m
.44559 .58643 L
s
0 .015 1 r
.45406 .8031 m
.45291 .80436 L
s
1 0 .615 r
.63578 .42462 m
.63811 .42393 L
s
.63605 .42169 m
.63578 .42462 L
s
.63578 .42462 m
.63608 .42277 L
s
.64229 .41555 m
.63578 .42462 L
s
.655 0 1 r
.6347 .38715 m
.63482 .38811 L
s
0 1 .883 r
.51559 .5796 m
.51626 .57873 L
s
.51626 .57873 m
.51703 .58009 L
s
1 0 .615 r
.63605 .42169 m
.63608 .42277 L
s
0 .016 1 r
.57755 .40176 m
.57755 .40089 L
s
.57755 .40089 m
.57612 .39994 L
s
.57755 .40089 m
.57576 .40209 L
s
0 1 .883 r
.51559 .5796 m
.51703 .58009 L
s
0 .016 1 r
.57576 .40209 m
.57755 .40176 L
s
.57612 .39994 m
.57576 .40209 L
s
.57576 .40209 m
.57613 .40081 L
s
.58115 .39589 m
.57576 .40209 L
s
0 1 .883 r
.57453 .53004 m
.5742 .52965 L
s
.57575 .52964 m
.57453 .53004 L
s
.57528 .53082 m
.57453 .53004 L
s
0 .016 1 r
.57612 .39994 m
.57613 .40081 L
s
.729 0 1 r
.45552 .23216 m
.45379 .23102 L
s
.45587 .22958 m
.45552 .23216 L
s
.859 0 1 r
.63398 .35108 m
.63594 .35183 L
s
0 .069 1 r
.51664 .41409 m
.51668 .41302 L
s
.51668 .41302 m
.5156 .41188 L
s
.51668 .41302 m
.51473 .41382 L
s
0 1 .883 r
.57543 .52926 m
.57575 .52964 L
s
.57528 .53082 m
.57575 .52964 L
s
.992 0 1 r
.63195 .57547 m
.63392 .57445 L
s
.63392 .57445 m
.63405 .57718 L
s
.729 0 1 r
.45379 .23102 m
.45587 .22958 L
s
.992 0 1 r
.63195 .57547 m
.63405 .57718 L
s
.655 0 1 r
.63482 .38811 m
.63649 .38918 L
s
.702 0 1 r
.51908 .2429 m
.51738 .24389 L
s
.51915 .24165 m
.51908 .2429 L
s
.51951 .24416 m
.51908 .2429 L
s
0 .069 1 r
.51473 .41382 m
.51664 .41409 L
s
.5156 .41188 m
.51473 .41382 L
s
.51473 .41382 m
.51556 .41295 L
s
.52169 .40965 m
.51473 .41382 L
s
.4 0 1 r
.63989 .69385 m
.63945 .69332 L
s
.63945 .69332 m
.63757 .69298 L
s
.63945 .69332 m
.63828 .69528 L
s
0 .295 1 r
.57697 .24875 m
.58198 .25423 L
s
1 0 .615 r
.63608 .42277 m
.63811 .42393 L
s
0 .069 1 r
.5156 .41188 m
.51556 .41295 L
s
0 .016 1 r
.57613 .40081 m
.57755 .40176 L
s
.4 0 1 r
.63757 .69298 m
.63801 .6935 L
s
.63757 .69298 m
.63828 .69528 L
s
0 1 .883 r
.57543 .52926 m
.57528 .53082 L
s
.5742 .52965 m
.57528 .53082 L
s
.5742 .52965 m
.57543 .52926 L
s
.702 0 1 r
.51738 .24389 m
.51744 .24264 L
s
.51951 .24416 m
.51738 .24389 L
s
0 .508 1 r
.58014 .43477 m
.58011 .43407 L
s
.58011 .43407 m
.57879 .43332 L
s
.58011 .43407 m
.57862 .43523 L
s
1 0 .93 r
.45891 .78404 m
.46036 .78245 L
s
.46036 .78245 m
.45998 .78117 L
s
.46036 .78245 m
.45774 .78156 L
s
0 .508 1 r
.57862 .43523 m
.58014 .43477 L
s
.57879 .43332 m
.57862 .43523 L
s
.57862 .43523 m
.57881 .43402 L
s
.58283 .42931 m
.57862 .43523 L
s
0 .069 1 r
.51556 .41295 m
.51664 .41409 L
s
.4 0 1 r
.63828 .69528 m
.63989 .69385 L
s
.63828 .69528 m
.63801 .6935 L
s
.64054 .68595 m
.63828 .69528 L
s
1 0 .93 r
.45774 .78156 m
.45891 .78404 L
s
.45998 .78117 m
.45774 .78156 L
s
.45774 .78156 m
.45853 .78276 L
s
.46626 .78677 m
.45774 .78156 L
s
.859 0 1 r
.63825 .65663 m
.64262 .6664 L
s
0 .508 1 r
.57879 .43332 m
.57881 .43402 L
s
.128 1 0 r
.51927 .44586 m
.51924 .44539 L
s
.51924 .44539 m
.51863 .44491 L
s
.51924 .44539 m
.51837 .4459 L
s
.51837 .4459 m
.51927 .44586 L
s
.51863 .44491 m
.51837 .4459 L
s
.51837 .4459 m
.51866 .44537 L
s
.5213 .44331 m
.51837 .4459 L
s
.51863 .44491 m
.51866 .44537 L
s
1 0 .93 r
.45853 .78276 m
.45891 .78404 L
s
.702 0 1 r
.51744 .24264 m
.51915 .24165 L
s
.51915 .24165 m
.51951 .24416 L
s
0 .015 1 r
.45896 .19242 m
.46565 .18822 L
s
0 .295 1 r
.5816 .25323 m
.58027 .25402 L
s
.58168 .25225 m
.5816 .25323 L
s
.58198 .25423 m
.5816 .25323 L
s
1 0 .456 r
.57948 .63751 m
.58709 .64618 L
s
0 .069 1 r
.58292 .46957 m
.58301 .469 L
s
.58301 .469 m
.58135 .4684 L
s
.58301 .469 m
.58154 .47054 L
s
.859 0 1 r
.64252 .66436 m
.64056 .66511 L
s
.64293 .66377 m
.64252 .66436 L
s
.64262 .6664 m
.64252 .66436 L
s
0 .069 1 r
.58135 .4684 m
.58125 .46898 L
s
.58135 .4684 m
.58154 .47054 L
s
.4 0 1 r
.63801 .6935 m
.63989 .69385 L
s
.702 0 1 r
.51744 .24264 m
.51951 .24416 L
s
0 .508 1 r
.57881 .43402 m
.58014 .43477 L
s
.128 1 0 r
.51866 .44537 m
.51927 .44586 L
s
0 .069 1 r
.58154 .47054 m
.58292 .46957 L
s
.58154 .47054 m
.58125 .46898 L
s
.5845 .46277 m
.58154 .47054 L
s
.765 0 1 r
.58283 .70439 m
.58271 .70317 L
s
.58271 .70317 m
.581 .70215 L
s
.58271 .70317 m
.58064 .70471 L
s
0 .295 1 r
.58027 .25402 m
.58035 .25304 L
s
.58198 .25423 m
.58027 .25402 L
s
.859 0 1 r
.64056 .66511 m
.64096 .66453 L
s
.64262 .6664 m
.64056 .66511 L
s
.4 0 1 r
.64054 .31405 m
.64281 .3234 L
s
1 .285 0 r
.46004 .83141 m
.46016 .83134 L
s
.46016 .83134 m
.46016 .83128 L
s
.46016 .83134 m
.46002 .83124 L
s
1 0 .93 r
.45998 .78117 m
.45853 .78276 L
s
.4 0 1 r
.64308 .32161 m
.6412 .32196 L
s
.64352 .32109 m
.64308 .32161 L
s
.64281 .3234 m
.64308 .32161 L
s
.655 0 1 r
.64059 .61787 m
.64686 .62543 L
s
1 .285 0 r
.46002 .83124 m
.46004 .83141 L
s
.46016 .83128 m
.46002 .83124 L
s
.46002 .83124 m
.46005 .83136 L
s
.46042 .83176 m
.46002 .83124 L
s
.46005 .83136 m
.46004 .83141 L
s
.46016 .83128 m
.46005 .83136 L
s
.765 0 1 r
.58064 .70471 m
.58283 .70439 L
s
.581 .70215 m
.58064 .70471 L
s
.58064 .70471 m
.58111 .70337 L
s
.58702 .69751 m
.58064 .70471 L
s
1 .285 0 r
.46042 .16824 m
.46082 .16772 L
s
.4 0 1 r
.6412 .32196 m
.64163 .32144 L
s
.64281 .3234 m
.6412 .32196 L
s
.765 0 1 r
.581 .70215 m
.58111 .70337 L
s
1 .285 0 r
.4608 .16783 m
.4608 .16789 L
s
.46069 .16776 m
.4608 .16783 L
s
.46082 .16772 m
.4608 .16783 L
s
.46069 .16781 m
.46069 .16776 L
s
.46069 .16776 m
.46082 .16772 L
s
0 .016 1 r
.58115 .60411 m
.58656 .61034 L
s
1 .285 0 r
.4608 .16789 m
.46069 .16781 L
s
.46082 .16772 m
.4608 .16789 L
s
.46069 .16781 m
.46082 .16772 L
s
.128 1 0 r
.5213 .55669 m
.52423 .55928 L
s
0 .295 1 r
.58035 .25304 m
.58168 .25225 L
s
.58168 .25225 m
.58198 .25423 L
s
0 .069 1 r
.52169 .59035 m
.52867 .59454 L
s
0 .295 1 r
.58035 .25304 m
.58198 .25423 L
s
0 .069 1 r
.58125 .46898 m
.58292 .46957 L
s
1 0 .615 r
.64229 .58445 m
.64883 .59356 L
s
.859 0 1 r
.64293 .66377 m
.64262 .6664 L
s
.64096 .66453 m
.64262 .6664 L
s
.4 0 1 r
.64352 .32109 m
.64281 .3234 L
s
.64163 .32144 m
.64281 .3234 L
s
.859 0 1 r
.64096 .66453 m
.64293 .66377 L
s
.128 1 0 r
.52393 .55875 m
.52332 .55923 L
s
.52396 .55829 m
.52393 .55875 L
s
.52423 .55928 m
.52393 .55875 L
s
0 .508 1 r
.58283 .57069 m
.58704 .57662 L
s
.765 0 1 r
.58111 .70337 m
.58283 .70439 L
s
0 .015 1 r
.46503 .18919 m
.46474 .19018 L
s
.46388 .18794 m
.46503 .18919 L
s
.46565 .18822 m
.46503 .18919 L
s
.128 1 0 r
.52332 .55923 m
.52336 .55877 L
s
.52423 .55928 m
.52332 .55923 L
s
.4 0 1 r
.64163 .32144 m
.64352 .32109 L
s
.655 0 1 r
.64637 .62386 m
.6447 .62493 L
s
.6465 .6229 m
.64637 .62386 L
s
.64686 .62543 m
.64637 .62386 L
s
1 0 .456 r
.58653 .64436 m
.58456 .6457 L
s
.58657 .64318 m
.58653 .64436 L
s
.58709 .64618 m
.58653 .64436 L
s
.128 1 0 r
.52336 .55877 m
.52396 .55829 L
s
.52396 .55829 m
.52423 .55928 L
s
.52336 .55877 m
.52423 .55928 L
s
0 .016 1 r
.58619 .60905 m
.58476 .61 L
s
.5862 .60818 m
.58619 .60905 L
s
.58656 .61034 m
.58619 .60905 L
s
1 0 .282 r
.58779 .35486 m
.58768 .35368 L
s
.58768 .35368 m
.58563 .35233 L
s
.58768 .35368 m
.58517 .35544 L
s
0 .015 1 r
.46359 .18893 m
.46388 .18794 L
s
.46388 .18794 m
.46565 .18822 L
s
0 .069 1 r
.5845 .53723 m
.58747 .54502 L
s
.52783 .59366 m
.52675 .5948 L
s
.52779 .5926 m
.52783 .59366 L
s
.52867 .59454 m
.52783 .59366 L
s
.655 0 1 r
.6447 .62493 m
.64483 .62398 L
s
.64686 .62543 m
.6447 .62493 L
s
1 0 .456 r
.58456 .6457 m
.5846 .64452 L
s
.58709 .64618 m
.58456 .6457 L
s
1 0 .282 r
.58517 .35544 m
.58779 .35486 L
s
.58563 .35233 m
.58517 .35544 L
s
.58517 .35544 m
.58574 .35351 L
s
.5929 .34621 m
.58517 .35544 L
s
0 .016 1 r
.58476 .61 m
.58477 .60914 L
s
.58656 .61034 m
.58476 .61 L
s
0 .015 1 r
.46474 .19018 m
.46359 .18893 L
s
.46565 .18822 m
.46474 .19018 L
s
0 .508 1 r
.58685 .5754 m
.58552 .57615 L
s
.58688 .5747 m
.58685 .5754 L
s
.58704 .57662 m
.58685 .5754 L
s
1 0 .282 r
.58563 .35233 m
.58574 .35351 L
s
0 .069 1 r
.52675 .5948 m
.52672 .59374 L
s
.52867 .59454 m
.52675 .5948 L
s
0 .508 1 r
.58552 .57615 m
.58555 .57546 L
s
.58704 .57662 m
.58552 .57615 L
s
0 .326 1 r
.5279 .79059 m
.52784 .7896 L
s
.52784 .7896 m
.52651 .78883 L
s
.52784 .7896 m
.52623 .7908 L
s
1 0 .615 r
.64852 .59169 m
.64648 .59286 L
s
.64856 .59062 m
.64852 .59169 L
s
.64883 .59356 m
.64852 .59169 L
s
0 .015 1 r
.46359 .18893 m
.46565 .18822 L
s
.655 0 1 r
.64483 .62398 m
.6465 .6229 L
s
.6465 .6229 m
.64686 .62543 L
s
0 .326 1 r
.52623 .7908 m
.5279 .79059 L
s
.52651 .78883 m
.52623 .7908 L
s
.52623 .7908 m
.52656 .78982 L
s
.53111 .78536 m
.52623 .7908 L
s
0 .016 1 r
.58477 .60914 m
.5862 .60818 L
s
.5862 .60818 m
.58656 .61034 L
s
0 .069 1 r
.52672 .59374 m
.52779 .5926 L
s
.52779 .5926 m
.52867 .59454 L
s
.655 0 1 r
.64483 .62398 m
.64686 .62543 L
s
0 .326 1 r
.52651 .78883 m
.52656 .78982 L
s
1 0 .93 r
.46626 .21323 m
.47482 .20799 L
s
0 .069 1 r
.58776 .54344 m
.58609 .54404 L
s
.58767 .54288 m
.58776 .54344 L
s
.58747 .54502 m
.58776 .54344 L
s
1 0 .456 r
.5846 .64452 m
.58657 .64318 L
s
.58657 .64318 m
.58709 .64618 L
s
0 .069 1 r
.58609 .54404 m
.586 .54347 L
s
.58747 .54502 m
.58609 .54404 L
s
0 .016 1 r
.58477 .60914 m
.58656 .61034 L
s
.765 0 1 r
.58702 .30249 m
.59342 .30971 L
s
1 0 .615 r
.64648 .59286 m
.64651 .59179 L
s
.64883 .59356 m
.64648 .59286 L
s
1 0 .399 r
.65109 .40799 m
.65095 .40683 L
s
.65095 .40683 m
.64891 .40556 L
s
.65095 .40683 m
.64852 .4086 L
s
0 .069 1 r
.52672 .59374 m
.52867 .59454 L
s
0 .508 1 r
.58555 .57546 m
.58688 .5747 L
s
.58688 .5747 m
.58704 .57662 L
s
1 0 .456 r
.5846 .64452 m
.58709 .64618 L
s
0 .508 1 r
.58555 .57546 m
.58704 .57662 L
s
1 0 .282 r
.58574 .35351 m
.58779 .35486 L
s
1 0 .399 r
.64852 .4086 m
.65109 .40799 L
s
.64891 .40556 m
.64852 .4086 L
s
.64852 .4086 m
.64905 .40672 L
s
.65594 .39944 m
.64852 .4086 L
s
.299 0 1 r
.59073 .38617 m
.59067 .38526 L
s
.59067 .38526 m
.58912 .38424 L
s
.59067 .38526 m
.58876 .38657 L
s
1 0 .399 r
.64891 .40556 m
.64905 .40672 L
s
0 .326 1 r
.52656 .78982 m
.5279 .79059 L
s
.647 0 1 r
.52994 .39988 m
.52987 .39877 L
s
.52987 .39877 m
.52836 .39756 L
s
.52987 .39877 m
.52771 .40002 L
s
.299 0 1 r
.58876 .38657 m
.59073 .38617 L
s
.58912 .38424 m
.58876 .38657 L
s
.58876 .38657 m
.58918 .38515 L
s
.59459 .37972 m
.58876 .38657 L
s
.58912 .38424 m
.58918 .38515 L
s
.647 0 1 r
.52771 .40002 m
.52994 .39988 L
s
.52836 .39756 m
.52771 .40002 L
s
.52771 .40002 m
.52843 .39867 L
s
.53492 .39352 m
.52771 .40002 L
s
0 .069 1 r
.58767 .54288 m
.58747 .54502 L
s
.586 .54347 m
.58747 .54502 L
s
.586 .54347 m
.58767 .54288 L
s
1 0 .615 r
.64651 .59179 m
.64856 .59062 L
s
.64856 .59062 m
.64883 .59356 L
s
.647 0 1 r
.52836 .39756 m
.52843 .39867 L
s
1 0 .93 r
.47168 .79233 m
.47206 .79065 L
s
.47206 .79065 m
.4706 .78928 L
s
.47206 .79065 m
.46943 .79158 L
s
1 0 .615 r
.64651 .59179 m
.64883 .59356 L
s
.859 0 1 r
.65289 .37214 m
.65304 .37085 L
s
.65304 .37085 m
.65164 .36943 L
s
.65304 .37085 m
.6506 .37185 L
s
1 0 .93 r
.46943 .79158 m
.47168 .79233 L
s
.4706 .78928 m
.46943 .79158 L
s
.46943 .79158 m
.47023 .79096 L
s
.478 .78769 m
.46943 .79158 L
s
.765 0 1 r
.59293 .30837 m
.59122 .30939 L
s
.59306 .30715 m
.59293 .30837 L
s
.59342 .30971 m
.59293 .30837 L
s
.859 0 1 r
.6506 .37185 m
.65289 .37214 L
s
.65164 .36943 m
.6506 .37185 L
s
.6506 .37185 m
.65149 .37072 L
s
.65894 .36651 m
.6506 .37185 L
s
0 .016 1 r
.593 .41942 m
.59294 .41861 L
s
.59294 .41861 m
.59145 .41772 L
s
.59294 .41861 m
.59122 .4199 L
s
1 0 .399 r
.64905 .40672 m
.65109 .40799 L
s
.299 0 1 r
.58918 .38515 m
.59073 .38617 L
s
0 .016 1 r
.59122 .4199 m
.593 .41942 L
s
.59145 .41772 m
.59122 .4199 L
s
.59122 .4199 m
.59152 .41854 L
s
.59627 .41326 m
.59122 .4199 L
s
.647 0 1 r
.52843 .39867 m
.52994 .39988 L
s
0 .016 1 r
.59145 .41772 m
.59152 .41854 L
s
.765 0 1 r
.59122 .30939 m
.59134 .30817 L
s
.59342 .30971 m
.59122 .30939 L
s
.647 0 1 r
.59482 .45437 m
.59476 .45349 L
s
.59476 .45349 m
.59293 .45258 L
s
.59476 .45349 m
.59285 .45513 L
s
.859 0 1 r
.65164 .36943 m
.65149 .37072 L
s
1 0 .93 r
.4706 .78928 m
.47023 .79096 L
s
0 .326 1 r
.53111 .21464 m
.53599 .22009 L
s
.647 0 1 r
.59285 .45513 m
.59482 .45437 L
s
.59293 .45258 m
.59285 .45513 L
s
.59285 .45513 m
.59298 .45345 L
s
.59796 .44682 m
.59285 .45513 L
s
1 0 .93 r
.47402 .2092 m
.47365 .21048 L
s
.47257 .2076 m
.47402 .2092 L
s
.47482 .20799 m
.47402 .2092 L
s
.647 0 1 r
.59293 .45258 m
.59298 .45345 L
s
1 0 .93 r
.47023 .79096 m
.47168 .79233 L
s
.859 0 1 r
.65149 .37072 m
.65289 .37214 L
s
0 .016 1 r
.59152 .41854 m
.593 .41942 L
s
1 0 .282 r
.5929 .65379 m
.60067 .66305 L
s
0 1 .741 r
.53353 .43074 m
.53348 .43006 L
s
.53348 .43006 m
.53261 .42934 L
s
.53348 .43006 m
.53219 .43078 L
s
.765 0 1 r
.59134 .30817 m
.59306 .30715 L
s
.59306 .30715 m
.59342 .30971 L
s
1 0 .93 r
.4722 .20888 m
.47257 .2076 L
s
.47257 .2076 m
.47482 .20799 L
s
0 1 .741 r
.53219 .43078 m
.53353 .43074 L
s
.53261 .42934 m
.53219 .43078 L
s
.53219 .43078 m
.53266 .43002 L
s
.53658 .42707 m
.53219 .43078 L
s
.765 0 1 r
.59134 .30817 m
.59342 .30971 L
s
0 1 .741 r
.53261 .42934 m
.53266 .43002 L
s
0 .326 1 r
.53565 .21911 m
.53432 .21988 L
s
.53571 .21811 m
.53565 .21911 L
s
.53599 .22009 m
.53565 .21911 L
s
.647 0 1 r
.59298 .45345 m
.59482 .45437 L
s
1 0 .072 r
.65794 .3919 m
.65812 .39031 L
s
.65812 .39031 m
.65642 .38858 L
s
.65812 .39031 m
.65514 .39152 L
s
1 0 .93 r
.47365 .21048 m
.4722 .20888 L
s
.47482 .20799 m
.47365 .21048 L
s
.73 0 1 r
.53686 .73825 m
.53679 .73699 L
s
.53679 .73699 m
.53508 .73598 L
s
.53679 .73699 m
.5347 .73851 L
s
0 1 .741 r
.53266 .43002 m
.53353 .43074 L
s
.299 0 1 r
.59459 .62028 m
.60043 .62716 L
s
0 .326 1 r
.53432 .21988 m
.53438 .21888 L
s
.53599 .22009 m
.53432 .21988 L
s
1 0 .072 r
.65514 .39152 m
.65794 .3919 L
s
.65642 .38858 m
.65514 .39152 L
s
.65514 .39152 m
.65624 .39017 L
s
.66539 .38512 m
.65514 .39152 L
s
1 .033 0 r
.65541 .65872 m
.65541 .65875 L
s
.65542 .65873 m
.65541 .65872 L
s
.65541 .65872 m
.6554 .65874 L
s
.65543 .65874 m
.65541 .65872 L
s
.65546 .65881 m
.65541 .65872 L
s
.65541 .65875 m
.65543 .65874 L
s
.6554 .65874 m
.65541 .65875 L
s
.65543 .65874 m
.65542 .65873 L
s
.65542 .65873 m
.6554 .65874 L
s
.65546 .34119 m
.65552 .34109 L
s
.6555 .3411 m
.65552 .34111 L
s
.65549 .34111 m
.6555 .3411 L
s
.6555 .3411 m
.65552 .34109 L
s
.65552 .34111 m
.65551 .34112 L
s
.65552 .34109 m
.65552 .34111 L
s
.73 0 1 r
.5347 .73851 m
.53686 .73825 L
s
.53508 .73598 m
.5347 .73851 L
s
.5347 .73851 m
.53515 .73724 L
s
.54107 .73151 m
.5347 .73851 L
s
1 .033 0 r
.65551 .34112 m
.65549 .34111 L
s
.65549 .34111 m
.65552 .34109 L
s
.65552 .34109 m
.65551 .34112 L
s
.647 0 1 r
.53492 .60648 m
.54214 .613 L
s
1 0 .399 r
.65594 .60056 m
.6634 .60975 L
s
.73 0 1 r
.53508 .73598 m
.53515 .73724 L
s
1 0 .93 r
.4722 .20888 m
.47482 .20799 L
s
1 0 .072 r
.65642 .38858 m
.65624 .39017 L
s
0 .326 1 r
.53438 .21888 m
.53571 .21811 L
s
.53571 .21811 m
.53599 .22009 L
s
.128 1 0 r
.53666 .46616 m
.53651 .4658 L
s
.53651 .4658 m
.53581 .46543 L
s
.53651 .4658 m
.53578 .46647 L
s
0 .016 1 r
.59627 .58674 m
.60134 .59341 L
s
0 .326 1 r
.53438 .21888 m
.53599 .22009 L
s
.128 1 0 r
.53578 .46647 m
.53666 .46616 L
s
.53581 .46543 m
.53578 .46647 L
s
.53578 .46647 m
.53596 .46579 L
s
.53807 .4631 m
.53578 .46647 L
s
.53581 .46543 m
.53596 .46579 L
s
1 0 .282 r
.60008 .6611 m
.59803 .66246 L
s
.6002 .65994 m
.60008 .6611 L
s
.60067 .66305 m
.60008 .6611 L
s
0 1 .741 r
.53658 .57293 m
.54097 .57664 L
s
.73 0 1 r
.53515 .73724 m
.53686 .73825 L
s
.128 1 0 r
.53596 .46579 m
.53666 .46616 L
s
1 0 .072 r
.65624 .39017 m
.65794 .3919 L
s
.299 0 1 r
.6 .62573 m
.59846 .62675 L
s
.60006 .62482 m
.6 .62573 L
s
.60043 .62716 m
.6 .62573 L
s
.647 0 1 r
.59796 .55318 m
.60309 .56151 L
s
1 0 .282 r
.59803 .66246 m
.59815 .6613 L
s
.60067 .66305 m
.59803 .66246 L
s
1 0 0 r
.60199 .34533 m
.60153 .34458 L
s
.60153 .34458 m
.59909 .34363 L
s
.60153 .34458 m
.59945 .34689 L
s
.647 0 1 r
.54141 .61163 m
.5399 .61285 L
s
.54149 .61053 m
.54141 .61163 L
s
.54214 .613 m
.54141 .61163 L
s
.859 0 1 r
.65894 .63349 m
.66732 .63886 L
s
.128 1 0 r
.53807 .5369 m
.54037 .54026 L
s
.299 0 1 r
.59846 .62675 m
.59852 .62584 L
s
.60043 .62716 m
.59846 .62675 L
s
0 1 .741 r
.5405 .57588 m
.53963 .5766 L
s
.54055 .5752 m
.5405 .57588 L
s
.54097 .57664 m
.5405 .57588 L
s
1 0 .93 r
.478 .21231 m
.48661 .21623 L
s
0 .016 1 r
.60103 .59204 m
.59955 .59292 L
s
.60111 .59122 m
.60103 .59204 L
s
.60134 .59341 m
.60103 .59204 L
s
1 0 0 r
.59909 .34363 m
.59955 .34438 L
s
.59909 .34363 m
.59945 .34689 L
s
.128 1 0 r
.54018 .53958 m
.53948 .53995 L
s
.54034 .53922 m
.54018 .53958 L
s
.54037 .54026 m
.54018 .53958 L
s
0 .015 1 r
.4804 .81346 m
.48068 .81213 L
s
.48068 .81213 m
.47953 .81106 L
s
.48068 .81213 m
.47862 .81288 L
s
1 0 .399 r
.66285 .60785 m
.66081 .60913 L
s
.663 .60669 m
.66285 .60785 L
s
.6634 .60975 m
.66285 .60785 L
s
1 0 0 r
.59945 .34689 m
.60199 .34533 L
s
.59945 .34689 m
.59955 .34438 L
s
.60491 .33483 m
.59945 .34689 L
s
0 1 .741 r
.53963 .5766 m
.53968 .57592 L
s
.54097 .57664 m
.53963 .5766 L
s
1 .033 0 r
.66017 .65342 m
.66018 .65345 L
s
.66019 .65342 m
.66017 .65342 L
s
.66017 .65342 m
.66017 .65344 L
s
.6602 .65344 m
.66017 .65342 L
s
.66023 .65351 m
.66017 .65342 L
s
.66018 .65345 m
.6602 .65344 L
s
.66017 .65344 m
.66018 .65345 L
s
.6602 .65344 m
.66019 .65342 L
s
0 .015 1 r
.47862 .81288 m
.4804 .81346 L
s
.47953 .81106 m
.47862 .81288 L
s
.47862 .81288 m
.47925 .81239 L
s
.48538 .80978 m
.47862 .81288 L
s
1 .033 0 r
.66019 .65342 m
.66017 .65344 L
s
0 .279 1 r
.60193 .72524 m
.60183 .72426 L
s
.60183 .72426 m
.60048 .72347 L
s
.60183 .72426 m
.6002 .72548 L
s
.128 1 0 r
.53948 .53995 m
.53964 .5396 L
s
.54037 .54026 m
.53948 .53995 L
s
.647 0 1 r
.5399 .61285 m
.53998 .61175 L
s
.54214 .613 m
.5399 .61285 L
s
1 .033 0 r
.66023 .34649 m
.66029 .3464 L
s
.66027 .34641 m
.66029 .34642 L
s
.66026 .34642 m
.66027 .34641 L
s
.66027 .34641 m
.66029 .3464 L
s
.66029 .34642 m
.66028 .34643 L
s
.66029 .3464 m
.66029 .34642 L
s
0 .016 1 r
.59955 .59292 m
.59962 .59211 L
s
.60134 .59341 m
.59955 .59292 L
s
1 .033 0 r
.66028 .34643 m
.66026 .34642 L
s
.66026 .34642 m
.66029 .3464 L
s
.66029 .3464 m
.66028 .34643 L
s
0 .279 1 r
.6002 .72548 m
.60193 .72524 L
s
.60048 .72347 m
.6002 .72548 L
s
.6002 .72548 m
.60058 .72444 L
s
.60523 .71984 m
.6002 .72548 L
s
.299 0 1 r
.59852 .62584 m
.60006 .62482 L
s
.60006 .62482 m
.60043 .62716 L
s
1 0 .282 r
.59815 .6613 m
.6002 .65994 L
s
.6002 .65994 m
.60067 .66305 L
s
0 1 .741 r
.53968 .57592 m
.54055 .5752 L
s
.54055 .5752 m
.54097 .57664 L
s
.128 1 0 r
.53964 .5396 m
.54034 .53922 L
s
.54034 .53922 m
.54037 .54026 L
s
.53964 .5396 m
.54037 .54026 L
s
0 .279 1 r
.60048 .72347 m
.60058 .72444 L
s
0 .015 1 r
.47953 .81106 m
.47925 .81239 L
s
1 0 .399 r
.66081 .60913 m
.66096 .60797 L
s
.6634 .60975 m
.66081 .60913 L
s
.299 0 1 r
.59852 .62584 m
.60043 .62716 L
s
0 1 .741 r
.53968 .57592 m
.54097 .57664 L
s
1 0 .282 r
.59815 .6613 m
.60067 .66305 L
s
1 0 .807 r
.54303 .38475 m
.54293 .38357 L
s
.54293 .38357 m
.54116 .38227 L
s
.54293 .38357 m
.54056 .38506 L
s
.647 0 1 r
.60294 .55981 m
.60111 .56073 L
s
.60301 .55895 m
.60294 .55981 L
s
.60309 .56151 m
.60294 .55981 L
s
.53998 .61175 m
.54149 .61053 L
s
.54149 .61053 m
.54214 .613 L
s
.452 0 1 r
.60413 .37021 m
.60403 .36929 L
s
.60403 .36929 m
.60242 .36825 L
s
.60403 .36929 m
.60207 .37068 L
s
1 0 .524 r
.60514 .68818 m
.60462 .68753 L
s
.60462 .68753 m
.60226 .6871 L
s
.60462 .68753 m
.60314 .68998 L
s
0 .015 1 r
.47925 .81239 m
.4804 .81346 L
s
0 .016 1 r
.59962 .59211 m
.60111 .59122 L
s
.60111 .59122 m
.60134 .59341 L
s
.73 0 1 r
.54107 .26849 m
.54746 .27552 L
s
.647 0 1 r
.53998 .61175 m
.54214 .613 L
s
1 .011 0 r
.66236 .68341 m
.66237 .68342 L
s
.66236 .6834 m
.66236 .68341 L
s
.66238 .6834 m
.66236 .68341 L
s
.66238 .6834 m
.66237 .68342 L
s
.66236 .6834 m
.66238 .6834 L
s
.66237 .68341 m
.66238 .6834 L
s
.66231 .68343 m
.66238 .6834 L
s
.647 0 1 r
.60111 .56073 m
.60117 .55987 L
s
.60309 .56151 m
.60111 .56073 L
s
1 .011 0 r
.66237 .68342 m
.66237 .68341 L
s
.66237 .68341 m
.66236 .6834 L
s
.66231 .31657 m
.66225 .31654 L
s
0 .016 1 r
.59962 .59211 m
.60134 .59341 L
s
1 .011 0 r
.66226 .31655 m
.66226 .31654 L
s
.66226 .31654 m
.66226 .31653 L
s
.66226 .31654 m
.66225 .31654 L
s
.66226 .31653 m
.66227 .31654 L
s
.66226 .31653 m
.66225 .31654 L
s
.66227 .31654 m
.66226 .31655 L
s
.66225 .31654 m
.66226 .31655 L
s
.66225 .31654 m
.66227 .31654 L
s
1 0 .807 r
.54056 .38506 m
.54303 .38475 L
s
.54116 .38227 m
.54056 .38506 L
s
.54056 .38506 m
.54126 .38344 L
s
.54824 .37729 m
.54056 .38506 L
s
0 .279 1 r
.60058 .72444 m
.60193 .72524 L
s
.452 0 1 r
.60207 .37068 m
.60413 .37021 L
s
.60242 .36825 m
.60207 .37068 L
s
.60207 .37068 m
.60253 .36917 L
s
.60812 .36344 m
.60207 .37068 L
s
1 0 0 r
.59955 .34438 m
.60199 .34533 L
s
1 0 .524 r
.60226 .6871 m
.60278 .68775 L
s
.60226 .6871 m
.60314 .68998 L
s
.452 0 1 r
.60242 .36825 m
.60253 .36917 L
s
1 0 .807 r
.54116 .38227 m
.54126 .38344 L
s
1 0 .399 r
.66096 .60797 m
.663 .60669 L
s
.663 .60669 m
.6634 .60975 L
s
.859 0 1 r
.66642 .63771 m
.66501 .63914 L
s
.66627 .63643 m
.66642 .63771 L
s
.66732 .63886 m
.66642 .63771 L
s
1 0 .524 r
.60314 .68998 m
.60514 .68818 L
s
.60314 .68998 m
.60278 .68775 L
s
.60593 .67828 m
.60314 .68998 L
s
1 0 .399 r
.66096 .60797 m
.6634 .60975 L
s
.299 0 1 r
.60613 .4037 m
.60603 .40281 L
s
.60603 .40281 m
.60445 .40184 L
s
.60603 .40281 m
.60416 .40419 L
s
1 0 .807 r
.60755 .43901 m
.60744 .43798 L
s
.60744 .43798 m
.60546 .43689 L
s
.60744 .43798 m
.60525 .43974 L
s
.299 0 1 r
.60416 .40419 m
.60613 .4037 L
s
.60445 .40184 m
.60416 .40419 L
s
.60416 .40419 m
.60455 .40273 L
s
.60981 .39709 m
.60416 .40419 L
s
.647 0 1 r
.60117 .55987 m
.60301 .55895 L
s
.60301 .55895 m
.60309 .56151 L
s
1 0 .93 r
.4858 .2156 m
.48434 .21697 L
s
.48543 .21391 m
.4858 .2156 L
s
.48661 .21623 m
.4858 .2156 L
s
.452 0 1 r
.60253 .36917 m
.60413 .37021 L
s
.647 0 1 r
.60117 .55987 m
.60309 .56151 L
s
1 0 .807 r
.54126 .38344 m
.54303 .38475 L
s
.299 0 1 r
.60445 .40184 m
.60455 .40273 L
s
0 .846 1 r
.49084 .42414 m
.49078 .42319 L
s
.49078 .42319 m
.49036 .42218 L
s
.49078 .42319 m
.48924 .42351 L
s
.859 0 1 r
.66501 .63914 m
.66487 .63786 L
s
.66732 .63886 m
.66501 .63914 L
s
1 0 .807 r
.60525 .43974 m
.60755 .43901 L
s
.60546 .43689 m
.60525 .43974 L
s
.60525 .43974 m
.60556 .43791 L
s
.61151 .43076 m
.60525 .43974 L
s
1 .285 0 r
.48363 .83431 m
.48363 .83423 L
s
.48363 .83423 m
.48352 .83416 L
s
.48363 .83423 m
.4835 .83433 L
s
.4835 .83433 m
.48363 .83431 L
s
.48352 .83416 m
.4835 .83433 L
s
.4835 .83433 m
.48352 .83425 L
s
.4839 .83388 m
.4835 .83433 L
s
.48352 .83416 m
.48352 .83425 L
s
1 0 .807 r
.60546 .43689 m
.60556 .43791 L
s
1 0 .072 r
.66539 .61488 m
.67569 .62131 L
s
1 .285 0 r
.48352 .83425 m
.48363 .83431 L
s
.73 0 1 r
.54699 .27423 m
.54528 .27525 L
s
.54707 .27298 m
.54699 .27423 L
s
.54746 .27552 m
.54699 .27423 L
s
1 0 0 r
.60491 .66517 m
.61039 .67725 L
s
1 .285 0 r
.4839 .16612 m
.4843 .16657 L
s
1 0 .524 r
.60278 .68775 m
.60514 .68818 L
s
0 .279 1 r
.60523 .28016 m
.61028 .2858 L
s
1 .285 0 r
.48428 .16649 m
.48416 .16656 L
s
.48428 .16641 m
.48428 .16649 L
s
.4843 .16657 m
.48428 .16649 L
s
.48416 .16656 m
.48417 .16647 L
s
.4843 .16657 m
.48416 .16656 L
s
0 .508 1 r
.54645 .41602 m
.54634 .41523 L
s
.54634 .41523 m
.54515 .41437 L
s
.54634 .41523 m
.54477 .41625 L
s
1 .285 0 r
.48417 .16647 m
.48428 .16641 L
s
.48428 .16641 m
.4843 .16657 L
s
.48417 .16647 m
.4843 .16657 L
s
1 0 .93 r
.48434 .21697 m
.48398 .21529 L
s
.48661 .21623 m
.48434 .21697 L
s
0 .846 1 r
.48924 .42351 m
.49084 .42414 L
s
.49036 .42218 m
.48924 .42351 L
s
.48924 .42351 m
.49041 .42313 L
s
.49602 .42176 m
.48924 .42351 L
s
.859 0 1 r
.66487 .63786 m
.66627 .63643 L
s
.66627 .63643 m
.66732 .63886 L
s
1 0 .528 r
.66813 .38285 m
.66942 .38123 L
s
.66942 .38123 m
.66896 .37946 L
s
.66942 .38123 m
.66649 .38055 L
s
0 .846 1 r
.49036 .42218 m
.49041 .42313 L
s
.73 0 1 r
.54528 .27525 m
.54536 .274 L
s
.54746 .27552 m
.54528 .27525 L
s
1 0 .528 r
.66649 .38055 m
.66813 .38285 L
s
.66896 .37946 m
.66649 .38055 L
s
.66649 .38055 m
.66767 .38109 L
s
.67678 .38359 m
.66649 .38055 L
s
1 0 .524 r
.60593 .32172 m
.60872 .33343 L
s
.60908 .33118 m
.60672 .33161 L
s
.6096 .33055 m
.60908 .33118 L
s
.60872 .33343 m
.60908 .33118 L
s
.299 0 1 r
.60455 .40273 m
.60613 .4037 L
s
0 .846 1 r
.49041 .42313 m
.49084 .42414 L
s
0 .508 1 r
.54477 .41625 m
.54645 .41602 L
s
.54515 .41437 m
.54477 .41625 L
s
.54477 .41625 m
.54525 .41516 L
s
.54991 .41095 m
.54477 .41625 L
s
.54515 .41437 m
.54525 .41516 L
s
0 .015 1 r
.48538 .19022 m
.49216 .19332 L
s
1 0 .93 r
.48398 .21529 m
.48543 .21391 L
s
.48543 .21391 m
.48661 .21623 L
s
.859 0 1 r
.66487 .63786 m
.66732 .63886 L
s
1 0 .524 r
.60672 .33161 m
.60724 .33098 L
s
.60872 .33343 m
.60672 .33161 L
s
1 0 0 r
.61028 .67472 m
.60783 .67568 L
s
.61074 .67399 m
.61028 .67472 L
s
.61039 .67725 m
.61028 .67472 L
s
1 0 .807 r
.60556 .43791 m
.60755 .43901 L
s
0 .846 1 r
.50162 .57961 m
.5012 .58062 L
s
.50168 .57865 m
.50162 .57961 L
s
.5028 .57999 m
.50162 .57961 L
s
.49602 .57824 m
.5028 .57999 L
s
1 0 .528 r
.66767 .38109 m
.66813 .38285 L
s
0 .508 1 r
.54525 .41516 m
.54645 .41602 L
s
.73 0 1 r
.54536 .274 m
.54707 .27298 L
s
.54707 .27298 m
.54746 .27552 L
s
0 .279 1 r
.60989 .28476 m
.60854 .28556 L
s
.60999 .28379 m
.60989 .28476 L
s
.61028 .2858 m
.60989 .28476 L
s
1 0 0 r
.60783 .67568 m
.6083 .67495 L
s
.61039 .67725 m
.60783 .67568 L
s
1 0 .93 r
.48398 .21529 m
.48661 .21623 L
s
.73 0 1 r
.54536 .274 m
.54746 .27552 L
s
.452 0 1 r
.60812 .63656 m
.61418 .64383 L
s
1 0 .528 r
.66896 .37946 m
.66767 .38109 L
s
0 .279 1 r
.60854 .28556 m
.60865 .28459 L
s
.61028 .2858 m
.60854 .28556 L
s
1 0 .524 r
.6096 .33055 m
.60872 .33343 L
s
.60724 .33098 m
.60872 .33343 L
s
0 .846 1 r
.5012 .58062 m
.50127 .57967 L
s
.5028 .57999 m
.5012 .58062 L
s
1 0 .807 r
.54824 .62271 m
.55594 .63052 L
s
0 .846 1 r
.50127 .57967 m
.50168 .57865 L
s
.50168 .57865 m
.5028 .57999 L
s
0 1 .475 r
.50481 .44587 m
.5049 .44521 L
s
.5049 .44521 m
.50412 .44451 L
s
.5049 .44521 m
.50366 .44578 L
s
0 1 .741 r
.54957 .44916 m
.54931 .44866 L
s
.54931 .44866 m
.54829 .44812 L
s
.54931 .44866 m
.54826 .44964 L
s
.729 0 1 r
.49064 .77255 m
.4906 .77127 L
s
.4906 .77127 m
.48886 .77027 L
s
.4906 .77127 m
.4885 .77282 L
s
0 1 .475 r
.50366 .44578 m
.50481 .44587 L
s
.50412 .44451 m
.50366 .44578 L
s
.50366 .44578 m
.50403 .44518 L
s
.50767 .44284 m
.50366 .44578 L
s
0 .846 1 r
.50127 .57967 m
.5028 .57999 L
s
1 0 .524 r
.60724 .33098 m
.6096 .33055 L
s
0 1 .475 r
.50412 .44451 m
.50403 .44518 L
s
0 1 .741 r
.54826 .44964 m
.54957 .44916 L
s
.54829 .44812 m
.54826 .44964 L
s
.54826 .44964 m
.54854 .44862 L
s
.55158 .44464 m
.54826 .44964 L
s
.54829 .44812 m
.54854 .44862 L
s
.299 0 1 r
.60981 .60291 m
.61548 .61004 L
s
.729 0 1 r
.4885 .77282 m
.49064 .77255 L
s
.48886 .77027 m
.4885 .77282 L
s
.4885 .77282 m
.48891 .77155 L
s
.49476 .76577 m
.4885 .77282 L
s
0 .279 1 r
.60865 .28459 m
.60999 .28379 L
s
.60999 .28379 m
.61028 .2858 L
s
.729 0 1 r
.48886 .77027 m
.48891 .77155 L
s
0 .279 1 r
.60865 .28459 m
.61028 .2858 L
s
1 0 0 r
.61074 .67399 m
.61039 .67725 L
s
.6083 .67495 m
.61039 .67725 L
s
0 1 .475 r
.50403 .44518 m
.50481 .44587 L
s
1 0 .072 r
.67456 .61994 m
.67286 .62168 L
s
.67439 .61836 m
.67456 .61994 L
s
.67569 .62131 m
.67456 .61994 L
s
0 .015 1 r
.49152 .19283 m
.49037 .1939 L
s
.49124 .19149 m
.49152 .19283 L
s
.49216 .19332 m
.49152 .19283 L
s
0 .508 1 r
.54991 .58905 m
.55506 .59437 L
s
1 0 0 r
.6083 .67495 m
.61074 .67399 L
s
0 1 .741 r
.54854 .44862 m
.54957 .44916 L
s
.452 0 1 r
.61371 .64231 m
.61211 .64336 L
s
.61382 .64139 m
.61371 .64231 L
s
.61418 .64383 m
.61371 .64231 L
s
1 0 .807 r
.61151 .56924 m
.61779 .57824 L
s
0 .015 1 r
.49037 .1939 m
.49009 .19257 L
s
.49216 .19332 m
.49037 .1939 L
s
.729 0 1 r
.48891 .77155 m
.49064 .77255 L
s
1 0 .072 r
.67286 .62168 m
.67269 .6201 L
s
.67569 .62131 m
.67286 .62168 L
s
.452 0 1 r
.61211 .64336 m
.61222 .64244 L
s
.61418 .64383 m
.61211 .64336 L
s
0 1 .741 r
.55158 .55536 m
.5549 .56037 L
s
1 0 .807 r
.55523 .62888 m
.55346 .63019 L
s
.55534 .62771 m
.55523 .62888 L
s
.55594 .63052 m
.55523 .62888 L
s
0 .015 1 r
.49009 .19257 m
.49124 .19149 L
s
.49124 .19149 m
.49216 .19332 L
s
0 .508 1 r
.55457 .59327 m
.55338 .59413 L
s
.55468 .59248 m
.55457 .59327 L
s
.55506 .59437 m
.55457 .59327 L
s
.299 0 1 r
.61509 .60857 m
.61351 .60955 L
s
.61519 .60768 m
.61509 .60857 L
s
.61548 .61004 m
.61509 .60857 L
s
0 1 .741 r
.55462 .55935 m
.5536 .55988 L
s
.55488 .55885 m
.55462 .55935 L
s
.5549 .56037 m
.55462 .55935 L
s
0 1 .475 r
.50767 .55716 m
.51169 .56011 L
s
1 0 .072 r
.67269 .6201 m
.67439 .61836 L
s
.67439 .61836 m
.67569 .62131 L
s
0 .015 1 r
.49009 .19257 m
.49216 .19332 L
s
0 .508 1 r
.55338 .59413 m
.55348 .59334 L
s
.55506 .59437 m
.55338 .59413 L
s
1 0 .807 r
.55346 .63019 m
.55357 .62903 L
s
.55594 .63052 m
.55346 .63019 L
s
.299 0 1 r
.61351 .60955 m
.61361 .60866 L
s
.61548 .61004 m
.61351 .60955 L
s
0 1 .741 r
.5536 .55988 m
.55386 .55938 L
s
.5549 .56037 m
.5536 .55988 L
s
.452 0 1 r
.61222 .64244 m
.61382 .64139 L
s
.61382 .64139 m
.61418 .64383 L
s
1 0 .456 r
.55638 .36918 m
.55626 .36798 L
s
.55626 .36798 m
.55431 .36663 L
s
.55626 .36798 m
.55377 .36964 L
s
.452 0 1 r
.61222 .64244 m
.61418 .64383 L
s
0 .295 1 r
.55582 .75941 m
.55575 .75841 L
s
.55575 .75841 m
.55441 .75762 L
s
.55575 .75841 m
.55411 .75962 L
s
0 1 .883 r
.55451 .47984 m
.5538 .47945 L
s
.5538 .47945 m
.55285 .47904 L
s
.5538 .47945 m
.55312 .48062 L
s
0 .508 1 r
.55348 .59334 m
.55468 .59248 L
s
.55468 .59248 m
.55506 .59437 L
s
1 0 .072 r
.67269 .6201 m
.67569 .62131 L
s
0 1 .741 r
.55386 .55938 m
.55488 .55885 L
s
.55488 .55885 m
.5549 .56037 L
s
0 .295 1 r
.55411 .75962 m
.55582 .75941 L
s
.55441 .75762 m
.55411 .75962 L
s
.55411 .75962 m
.55447 .75862 L
s
.55913 .75409 m
.55411 .75962 L
s
0 1 .741 r
.55386 .55938 m
.5549 .56037 L
s
1 0 .456 r
.55377 .36964 m
.55638 .36918 L
s
.55431 .36663 m
.55377 .36964 L
s
.55377 .36964 m
.55443 .36782 L
s
.56165 .36093 m
.55377 .36964 L
s
1 0 .807 r
.61747 .5764 m
.61549 .5775 L
s
.61759 .57538 m
.61747 .5764 L
s
.61779 .57824 m
.61747 .5764 L
s
0 .295 1 r
.55441 .75762 m
.55447 .75862 L
s
0 .508 1 r
.55348 .59334 m
.55506 .59437 L
s
.4 0 1 r
.67758 .36241 m
.67861 .3611 L
s
.67861 .3611 m
.67824 .35966 L
s
.67861 .3611 m
.67624 .36056 L
s
1 0 .807 r
.55357 .62903 m
.55534 .62771 L
s
.55534 .62771 m
.55594 .63052 L
s
.299 0 1 r
.61361 .60866 m
.61519 .60768 L
s
.61519 .60768 m
.61548 .61004 L
s
0 1 .475 r
.51132 .5595 m
.51054 .5602 L
s
.51123 .55884 m
.51132 .5595 L
s
.51169 .56011 m
.51132 .5595 L
s
1 0 .456 r
.55431 .36663 m
.55443 .36782 L
s
.4 0 1 r
.67624 .36056 m
.67758 .36241 L
s
.67824 .35966 m
.67624 .36056 L
s
.67624 .36056 m
.67721 .36097 L
s
.68458 .36294 m
.67624 .36056 L
s
.683 0 1 r
.61878 .34982 m
.61842 .34923 L
s
.61842 .34923 m
.61651 .34848 L
s
.61842 .34923 m
.61678 .35104 L
s
.299 0 1 r
.61361 .60866 m
.61548 .61004 L
s
0 1 .883 r
.55825 .52995 m
.5573 .53036 L
s
.55897 .52956 m
.55825 .52995 L
s
.55869 .53114 m
.55825 .52995 L
s
1 0 .807 r
.55357 .62903 m
.55594 .63052 L
s
.61549 .5775 m
.6156 .57648 L
s
.61779 .57824 m
.61549 .5775 L
s
0 1 .883 r
.55285 .47904 m
.55356 .47943 L
s
.55285 .47904 m
.55312 .48062 L
s
1 0 .528 r
.67678 .61641 m
.68712 .61335 L
s
0 1 .883 r
.55312 .48062 m
.55451 .47984 L
s
.55312 .48062 m
.55356 .47943 L
s
.55591 .47474 m
.55312 .48062 L
s
0 1 .475 r
.51054 .5602 m
.51045 .55953 L
s
.51169 .56011 m
.51054 .5602 L
s
.729 0 1 r
.49476 .23423 m
.50104 .24131 L
s
0 1 .883 r
.55356 .47943 m
.55451 .47984 L
s
.683 0 1 r
.61651 .34848 m
.61687 .34908 L
s
.61651 .34848 m
.61678 .35104 L
s
0 .295 1 r
.55447 .75862 m
.55582 .75941 L
s
0 1 .883 r
.55591 .52526 m
.55869 .53114 L
s
.452 0 1 r
.61949 .38763 m
.61937 .3867 L
s
.61937 .3867 m
.61775 .38567 L
s
.61937 .3867 m
.61742 .38811 L
s
.683 0 1 r
.61678 .35104 m
.61878 .34982 L
s
.61678 .35104 m
.61687 .34908 L
s
.62109 .34159 m
.61678 .35104 L
s
.4 0 1 r
.67721 .36097 m
.67758 .36241 L
s
0 1 .475 r
.51045 .55953 m
.51123 .55884 L
s
.51123 .55884 m
.51169 .56011 L
s
1 0 .456 r
.62056 .42325 m
.62041 .42211 L
s
.62041 .42211 m
.61835 .42088 L
s
.62041 .42211 m
.61803 .42393 L
s
0 1 .883 r
.5573 .53036 m
.55802 .52997 L
s
.55869 .53114 m
.5573 .53036 L
s
0 1 .475 r
.51045 .55953 m
.51169 .56011 L
s
.452 0 1 r
.61742 .38811 m
.61949 .38763 L
s
.61775 .38567 m
.61742 .38811 L
s
.61742 .38811 m
.61787 .3866 L
s
.62345 .3808 m
.61742 .38811 L
s
0 1 .883 r
.55897 .52956 m
.55869 .53114 L
s
.55802 .52997 m
.55869 .53114 L
s
.55802 .52997 m
.55897 .52956 L
s
1 0 .456 r
.55443 .36782 m
.55638 .36918 L
s
.4 0 1 r
.67824 .35966 m
.67721 .36097 L
s
1 0 .456 r
.61803 .42393 m
.62056 .42325 L
s
.61835 .42088 m
.61803 .42393 L
s
.61803 .42393 m
.61849 .42202 L
s
.62516 .41459 m
.61803 .42393 L
s
.452 0 1 r
.61775 .38567 m
.61787 .3866 L
s
1 0 .456 r
.61835 .42088 m
.61849 .42202 L
s
0 .016 1 r
.55954 .40064 m
.55943 .39976 L
s
.55943 .39976 m
.55803 .3988 L
s
.55943 .39976 m
.55765 .40097 L
s
1 0 .807 r
.6156 .57648 m
.61759 .57538 L
s
.61759 .57538 m
.61779 .57824 L
s
.6156 .57648 m
.61779 .57824 L
s
.683 0 1 r
.61687 .34908 m
.61878 .34982 L
s
0 .016 1 r
.55765 .40097 m
.55954 .40064 L
s
.55803 .3988 m
.55765 .40097 L
s
.55765 .40097 m
.55814 .39967 L
s
.56334 .39471 m
.55765 .40097 L
s
.55803 .3988 m
.55814 .39967 L
s
.452 0 1 r
.61787 .3866 m
.61949 .38763 L
s
.729 0 1 r
.50062 .24002 m
.49889 .24103 L
s
.50068 .23875 m
.50062 .24002 L
s
.50104 .24131 m
.50062 .24002 L
s
.269 0 1 r
.62277 .69581 m
.62234 .69529 L
s
.62234 .69529 m
.6205 .69496 L
s
.62234 .69529 m
.62119 .69722 L
s
0 .295 1 r
.55913 .24591 m
.56416 .25145 L
s
1 0 .456 r
.61849 .42202 m
.62056 .42325 L
s
.269 0 1 r
.6205 .69496 m
.62092 .69547 L
s
.6205 .69496 m
.62119 .69722 L
s
1 .011 0 r
.68146 .66233 m
.68146 .66233 L
s
.68146 .66231 m
.68146 .66233 L
s
.68146 .66233 m
.68145 .66232 L
s
.68147 .66232 m
.68146 .66233 L
s
.68146 .66229 m
.68146 .66233 L
s
.68146 .66231 m
.68145 .66232 L
s
.68147 .66232 m
.68146 .66231 L
s
.68145 .66232 m
.68146 .66233 L
s
.68146 .66233 m
.68147 .66232 L
s
.729 0 1 r
.49889 .24103 m
.49894 .23976 L
s
.50104 .24131 m
.49889 .24103 L
s
1 .011 0 r
.68146 .33771 m
.68145 .33775 L
s
0 .016 1 r
.55814 .39967 m
.55954 .40064 L
s
1 .011 0 r
.68145 .33775 m
.68144 .33774 L
s
.68146 .33774 m
.68145 .33775 L
s
.68145 .33775 m
.68145 .33775 L
s
.68144 .33774 m
.68145 .33773 L
s
.68144 .33774 m
.68145 .33775 L
s
.68145 .33773 m
.68146 .33774 L
s
.68145 .33775 m
.68146 .33774 L
s
.68145 .33773 m
.68145 .33775 L
s
.683 0 1 r
.62109 .65841 m
.62541 .66787 L
s
.269 0 1 r
.62119 .69722 m
.62277 .69581 L
s
.62119 .69722 m
.62092 .69547 L
s
.6234 .68805 m
.62119 .69722 L
s
0 .508 1 r
.56207 .43402 m
.56187 .43331 L
s
.56187 .43331 m
.56059 .43255 L
s
.56187 .43331 m
.56041 .43448 L
s
1 0 .528 r
.68591 .61389 m
.68546 .61567 L
s
.68462 .61225 m
.68591 .61389 L
s
.68712 .61335 m
.68591 .61389 L
s
0 .508 1 r
.56041 .43448 m
.56207 .43402 L
s
.56059 .43255 m
.56041 .43448 L
s
.56041 .43448 m
.5608 .43326 L
s
.56502 .42851 m
.56041 .43448 L
s
.56059 .43255 m
.5608 .43326 L
s
.729 0 1 r
.49894 .23976 m
.50068 .23875 L
s
.50068 .23875 m
.50104 .24131 L
s
0 .295 1 r
.56379 .25044 m
.56244 .25124 L
s
.56386 .24944 m
.56379 .25044 L
s
.56416 .25145 m
.56379 .25044 L
s
1 0 .456 r
.56165 .63907 m
.56957 .64781 L
s
.683 0 1 r
.62532 .6659 m
.6234 .66665 L
s
.62569 .66531 m
.62532 .6659 L
s
.62541 .66787 m
.62532 .6659 L
s
.729 0 1 r
.49894 .23976 m
.50104 .24131 L
s
.269 0 1 r
.62092 .69547 m
.62277 .69581 L
s
.765 0 1 r
.56503 .70671 m
.56493 .70547 L
s
.56493 .70547 m
.56319 .70444 L
s
.56493 .70547 m
.56283 .70703 L
s
0 .186 1 r
.49512 .41302 m
.49503 .41191 L
s
.49503 .41191 m
.49433 .41071 L
s
.49503 .41191 m
.49315 .41245 L
s
0 .295 1 r
.56244 .25124 m
.56252 .25024 L
s
.56416 .25145 m
.56244 .25124 L
s
0 .508 1 r
.5608 .43326 m
.56207 .43402 L
s
.269 0 1 r
.6234 .31195 m
.62561 .32112 L
s
.683 0 1 r
.6234 .66665 m
.62377 .66606 L
s
.62541 .66787 m
.6234 .66665 L
s
.269 0 1 r
.62588 .31937 m
.62403 .31971 L
s
.62631 .31886 m
.62588 .31937 L
s
.62561 .32112 m
.62588 .31937 L
s
.452 0 1 r
.62345 .6192 m
.6295 .62654 L
s
.765 0 1 r
.56283 .70703 m
.56503 .70671 L
s
.56319 .70444 m
.56283 .70703 L
s
.56283 .70703 m
.56329 .70568 L
s
.56924 .69975 m
.56283 .70703 L
s
.4 0 1 r
.68458 .63706 m
.69296 .63468 L
s
1 0 .528 r
.68418 .61403 m
.68462 .61225 L
s
.68462 .61225 m
.68712 .61335 L
s
0 .069 1 r
.56459 .46921 m
.56396 .46863 L
s
.56396 .46863 m
.56248 .46802 L
s
.56396 .46863 m
.56274 .47019 L
s
.269 0 1 r
.62403 .31971 m
.62446 .3192 L
s
.62561 .32112 m
.62403 .31971 L
s
.765 0 1 r
.56319 .70444 m
.56329 .70568 L
s
0 .016 1 r
.56334 .60529 m
.56904 .61157 L
s
0 .186 1 r
.49315 .41245 m
.49512 .41302 L
s
.49433 .41071 m
.49315 .41245 L
s
.49315 .41245 m
.49442 .41182 L
s
.50103 .40952 m
.49315 .41245 L
s
1 0 .528 r
.68546 .61567 m
.68418 .61403 L
s
.68712 .61335 m
.68546 .61567 L
s
0 .186 1 r
.49433 .41071 m
.49442 .41182 L
s
0 .295 1 r
.56252 .25024 m
.56386 .24944 L
s
.56386 .24944 m
.56416 .25145 L
s
0 .186 1 r
.49442 .41182 m
.49512 .41302 L
s
0 .295 1 r
.56252 .25024 m
.56416 .25145 L
s
1 0 .456 r
.62516 .58541 m
.63232 .59479 L
s
0 .069 1 r
.56248 .46802 m
.56311 .4686 L
s
.56248 .46802 m
.56274 .47019 L
s
.56274 .47019 m
.56459 .46921 L
s
.56274 .47019 m
.56311 .4686 L
s
.56671 .46235 m
.56274 .47019 L
s
.683 0 1 r
.62569 .66531 m
.62541 .66787 L
s
.62377 .66606 m
.62541 .66787 L
s
.269 0 1 r
.62631 .31886 m
.62561 .32112 L
s
.62446 .3192 m
.62561 .32112 L
s
.683 0 1 r
.62377 .66606 m
.62569 .66531 L
s
.765 0 1 r
.56329 .70568 m
.56503 .70671 L
s
0 .508 1 r
.56502 .57149 m
.56964 .57747 L
s
.797 0 1 r
.68818 .40061 m
.68989 .39954 L
s
.68989 .39954 m
.69007 .39836 L
s
.68989 .39954 m
.68778 .398 L
s
1 0 .528 r
.68418 .61403 m
.68712 .61335 L
s
1 0 .456 r
.56889 .64597 m
.56694 .64734 L
s
.56902 .64478 m
.56889 .64597 L
s
.56957 .64781 m
.56889 .64597 L
s
.269 0 1 r
.62446 .3192 m
.62631 .31886 L
s
0 .069 1 r
.56311 .4686 m
.56459 .46921 L
s
.452 0 1 r
.62903 .62501 m
.62742 .62605 L
s
.62916 .62409 m
.62903 .62501 L
s
.6295 .62654 m
.62903 .62501 L
s
.797 0 1 r
.68778 .398 m
.68818 .40061 L
s
.69007 .39836 m
.68778 .398 L
s
.68778 .398 m
.68836 .39943 L
s
.69451 .40543 m
.68778 .398 L
s
0 .016 1 r
.56854 .61027 m
.56714 .61124 L
s
.56866 .60939 m
.56854 .61027 L
s
.56904 .61157 m
.56854 .61027 L
s
.797 0 1 r
.68836 .39943 m
.68818 .40061 L
s
0 .186 1 r
.50103 .59048 m
.50891 .59341 L
s
.452 0 1 r
.62742 .62605 m
.62755 .62513 L
s
.6295 .62654 m
.62742 .62605 L
s
1 0 .282 r
.56996 .3532 m
.56983 .35202 L
s
.56983 .35202 m
.56777 .35065 L
s
.56983 .35202 m
.56729 .35379 L
s
0 1 .475 r
.52315 .46707 m
.523 .46667 L
s
.523 .46667 m
.52199 .46625 L
s
.523 .46667 m
.52208 .46763 L
s
1 0 .456 r
.56694 .64734 m
.56707 .64615 L
s
.56957 .64781 m
.56694 .64734 L
s
0 .069 1 r
.56671 .53765 m
.57068 .5455 L
s
0 .508 1 r
.56925 .57624 m
.56797 .57701 L
s
.56946 .57553 m
.56925 .57624 L
s
.56964 .57747 m
.56925 .57624 L
s
0 .069 1 r
.5703 .54391 m
.56883 .54452 L
s
.57094 .54334 m
.5703 .54391 L
s
.57068 .5455 m
.5703 .54391 L
s
0 .016 1 r
.56714 .61124 m
.56725 .61036 L
s
.56904 .61157 m
.56714 .61124 L
s
0 .186 1 r
.50763 .59278 m
.50694 .59398 L
s
.50773 .59167 m
.50763 .59278 L
s
.50891 .59341 m
.50763 .59278 L
s
0 1 .475 r
.52199 .46625 m
.52214 .46665 L
s
.52199 .46625 m
.52208 .46763 L
s
.52208 .46763 m
.52315 .46707 L
s
.52208 .46763 m
.52214 .46665 L
s
.52453 .4628 m
.52208 .46763 L
s
1 0 .282 r
.56729 .35379 m
.56996 .3532 L
s
.56777 .35065 m
.56729 .35379 L
s
.56729 .35379 m
.5679 .35184 L
s
.57516 .34446 m
.56729 .35379 L
s
.4 0 1 r
.69197 .63509 m
.69162 .63653 L
s
.69095 .63378 m
.69197 .63509 L
s
.69296 .63468 m
.69197 .63509 L
s
0 .508 1 r
.56797 .57701 m
.56818 .5763 L
s
.56964 .57747 m
.56797 .57701 L
s
1 0 .282 r
.56777 .35065 m
.5679 .35184 L
s
0 .069 1 r
.56883 .54452 m
.56946 .54395 L
s
.57068 .5455 m
.56883 .54452 L
s
1 0 .456 r
.63185 .59285 m
.62978 .59409 L
s
.632 .59173 m
.63185 .59285 L
s
.63232 .59479 m
.63185 .59285 L
s
.797 0 1 r
.69007 .39836 m
.68836 .39943 L
s
0 .264 1 r
.50939 .79398 m
.50934 .79295 L
s
.50934 .79295 m
.50796 .79216 L
s
.50934 .79295 m
.50768 .79419 L
s
0 1 .475 r
.52214 .46665 m
.52315 .46707 L
s
0 .016 1 r
.56725 .61036 m
.56866 .60939 L
s
.56866 .60939 m
.56904 .61157 L
s
.452 0 1 r
.62755 .62513 m
.62916 .62409 L
s
.62916 .62409 m
.6295 .62654 L
s
0 .016 1 r
.56725 .61036 m
.56904 .61157 L
s
1 0 .456 r
.56707 .64615 m
.56902 .64478 L
s
.56902 .64478 m
.56957 .64781 L
s
.452 0 1 r
.62755 .62513 m
.6295 .62654 L
s
0 .264 1 r
.50768 .79419 m
.50939 .79398 L
s
.50796 .79216 m
.50768 .79419 L
s
.50768 .79419 m
.50801 .79319 L
s
.51267 .7886 m
.50768 .79419 L
s
0 .186 1 r
.50694 .59398 m
.50703 .59287 L
s
.50891 .59341 m
.50694 .59398 L
s
0 .508 1 r
.56818 .5763 m
.56946 .57553 L
s
.56946 .57553 m
.56964 .57747 L
s
.4 0 1 r
.69059 .63522 m
.69095 .63378 L
s
.69095 .63378 m
.69296 .63468 L
s
0 .264 1 r
.50796 .79216 m
.50801 .79319 L
s
0 .069 1 r
.57094 .54334 m
.57068 .5455 L
s
.56946 .54395 m
.57068 .5455 L
s
0 .508 1 r
.56818 .5763 m
.56964 .57747 L
s
0 .186 1 r
.50703 .59287 m
.50773 .59167 L
s
.50773 .59167 m
.50891 .59341 L
s
1 0 .456 r
.62978 .59409 m
.62993 .59296 L
s
.63232 .59479 m
.62978 .59409 L
s
.56707 .64615 m
.56957 .64781 L
s
0 .069 1 r
.56946 .54395 m
.57094 .54334 L
s
.765 0 1 r
.56924 .30025 m
.57568 .30755 L
s
1 0 .282 r
.63384 .40711 m
.63366 .40591 L
s
.63366 .40591 m
.63158 .40459 L
s
.63366 .40591 m
.63117 .40774 L
s
0 .186 1 r
.50703 .59287 m
.50891 .59341 L
s
.4 0 1 r
.69162 .63653 m
.69059 .63522 L
s
.69296 .63468 m
.69162 .63653 L
s
0 1 .475 r
.52453 .5372 m
.52697 .54204 L
s
1 0 .282 r
.63117 .40774 m
.63384 .40711 L
s
.63158 .40459 m
.63117 .40774 L
s
.63117 .40774 m
.63176 .40579 L
s
.63891 .3983 m
.63117 .40774 L
s
.5679 .35184 m
.56996 .3532 L
s
0 .264 1 r
.50801 .79319 m
.50939 .79398 L
s
1 0 .282 r
.63158 .40459 m
.63176 .40579 L
s
.299 0 1 r
.57287 .38487 m
.57275 .38395 L
s
.57275 .38395 m
.57121 .38292 L
s
.57275 .38395 m
.57084 .38528 L
s
0 1 .475 r
.52691 .54106 m
.5259 .54148 L
s
.52706 .54067 m
.52691 .54106 L
s
.52697 .54204 m
.52691 .54106 L
s
.4 0 1 r
.69059 .63522 m
.69296 .63468 L
s
0 1 .475 r
.5259 .54148 m
.52605 .54108 L
s
.52697 .54204 m
.5259 .54148 L
s
.299 0 1 r
.57084 .38528 m
.57287 .38487 L
s
.57121 .38292 m
.57084 .38528 L
s
.57084 .38528 m
.57133 .38384 L
s
.57686 .37835 m
.57084 .38528 L
s
1 0 .456 r
.62993 .59296 m
.632 .59173 L
s
.632 .59173 m
.63232 .59479 L
s
.299 0 1 r
.57121 .38292 m
.57133 .38384 L
s
1 0 .456 r
.62993 .59296 m
.63232 .59479 L
s
.407 0 1 r
.51113 .39811 m
.51088 .39701 L
s
.51088 .39701 m
.50962 .39579 L
s
.51088 .39701 m
.50884 .39811 L
s
0 1 .475 r
.52706 .54067 m
.52697 .54204 L
s
.52605 .54108 m
.52697 .54204 L
s
.52605 .54108 m
.52706 .54067 L
s
.797 0 1 r
.69451 .59457 m
.70128 .58712 L
s
.765 0 1 r
.5752 .30619 m
.57346 .30722 L
s
.57531 .30496 m
.5752 .30619 L
s
.57568 .30755 m
.5752 .30619 L
s
.683 0 1 r
.63611 .37055 m
.63626 .36931 L
s
.63626 .36931 m
.63487 .36793 L
s
.63626 .36931 m
.63388 .3703 L
s
1 0 .282 r
.63176 .40579 m
.63384 .40711 L
s
.683 0 1 r
.63388 .3703 m
.63611 .37055 L
s
.63487 .36793 m
.63388 .3703 L
s
.63388 .3703 m
.63472 .36918 L
s
.64193 .36499 m
.63388 .3703 L
s
0 .016 1 r
.5751 .4185 m
.57491 .41768 L
s
.57491 .41768 m
.57346 .41678 L
s
.57491 .41768 m
.57321 .41898 L
s
.299 0 1 r
.57133 .38384 m
.57287 .38487 L
s
.407 0 1 r
.50884 .39811 m
.51113 .39811 L
s
.50962 .39579 m
.50884 .39811 L
s
.50884 .39811 m
.50987 .3969 L
s
.51651 .39231 m
.50884 .39811 L
s
.765 0 1 r
.57346 .30722 m
.57357 .30599 L
s
.57568 .30755 m
.57346 .30722 L
s
.407 0 1 r
.50962 .39579 m
.50987 .3969 L
s
0 .016 1 r
.57321 .41898 m
.5751 .4185 L
s
.57346 .41678 m
.57321 .41898 L
s
.57321 .41898 m
.57364 .4176 L
s
.57855 .41227 m
.57321 .41898 L
s
0 .264 1 r
.51267 .2114 m
.51767 .217 L
s
.683 0 1 r
.63487 .36793 m
.63472 .36918 L
s
0 .016 1 r
.57346 .41678 m
.57364 .4176 L
s
.647 0 1 r
.57672 .45384 m
.57634 .45295 L
s
.57634 .45295 m
.5746 .45202 L
s
.57634 .45295 m
.57451 .4546 L
s
.407 0 1 r
.50987 .3969 m
.51113 .39811 L
s
.683 0 1 r
.63472 .36918 m
.63611 .37055 L
s
1 0 .282 r
.57516 .65554 m
.58306 .6649 L
s
.765 0 1 r
.57357 .30599 m
.57531 .30496 L
s
.57531 .30496 m
.57568 .30755 L
s
0 .016 1 r
.57364 .4176 m
.5751 .4185 L
s
.647 0 1 r
.57451 .4546 m
.57672 .45384 L
s
.5746 .45202 m
.57451 .4546 L
s
.57451 .4546 m
.57498 .4529 L
s
.58025 .44622 m
.57451 .4546 L
s
.5746 .45202 m
.57498 .4529 L
s
.765 0 1 r
.57357 .30599 m
.57568 .30755 L
s
.797 0 1 r
.70068 .58857 m
.70087 .58974 L
s
.69897 .58749 m
.70068 .58857 L
s
.70128 .58712 m
.70068 .58857 L
s
0 .264 1 r
.51733 .21599 m
.51596 .21679 L
s
.51739 .21497 m
.51733 .21599 L
s
.51767 .217 m
.51733 .21599 L
s
1 0 0 r
.64093 .39089 m
.64111 .38927 L
s
.64111 .38927 m
.63934 .38752 L
s
.64111 .38927 m
.63807 .39055 L
s
.771 0 1 r
.51841 .74102 m
.51835 .73973 L
s
.51835 .73973 m
.51661 .7387 L
s
.51835 .73973 m
.51622 .74129 L
s
.797 0 1 r
.69916 .58866 m
.69897 .58749 L
s
.69897 .58749 m
.70128 .58712 L
s
.299 0 1 r
.57686 .62165 m
.5829 .62859 L
s
1 0 0 r
.63807 .39055 m
.64093 .39089 L
s
.63934 .38752 m
.63807 .39055 L
s
.63807 .39055 m
.63915 .38913 L
s
.64842 .38381 m
.63807 .39055 L
s
0 .264 1 r
.51596 .21679 m
.51601 .21576 L
s
.51767 .217 m
.51596 .21679 L
s
1 .028 0 r
.63837 .33946 m
.63836 .33945 L
s
.63836 .33945 m
.63834 .33943 L
s
.63836 .33945 m
.63834 .33946 L
s
.63834 .33946 m
.63837 .33946 L
s
.63834 .33943 m
.63834 .33946 L
s
.63834 .33946 m
.63835 .33945 L
s
.63842 .33938 m
.63834 .33946 L
s
.63834 .33943 m
.63835 .33945 L
s
.63835 .33945 m
.63837 .33946 L
s
.63842 .66062 m
.63851 .6607 L
s
.6385 .66068 m
.63848 .6607 L
s
.6385 .66067 m
.6385 .66068 L
s
.63851 .6607 m
.6385 .66068 L
s
.63848 .6607 m
.63849 .66069 L
s
.63851 .6607 m
.63848 .6607 L
s
.63849 .66069 m
.6385 .66067 L
s
.6385 .66067 m
.63851 .6607 L
s
.63849 .66069 m
.63851 .6607 L
s
.647 0 1 r
.57498 .4529 m
.57672 .45384 L
s
.771 0 1 r
.51622 .74129 m
.51841 .74102 L
s
.51661 .7387 m
.51622 .74129 L
s
.51622 .74129 m
.51667 .73998 L
s
.52269 .73414 m
.51622 .74129 L
s
.407 0 1 r
.51651 .60769 m
.52419 .6135 L
s
0 1 .879 r
.51262 .43102 m
.51249 .43029 L
s
.51249 .43029 m
.51162 .42952 L
s
.51249 .43029 m
.51115 .43105 L
s
.771 0 1 r
.51661 .7387 m
.51667 .73998 L
s
1 0 .282 r
.63891 .6017 m
.64668 .61117 L
s
1 0 0 r
.63934 .38752 m
.63915 .38913 L
s
0 1 .879 r
.51115 .43105 m
.51262 .43102 L
s
.51162 .42952 m
.51115 .43105 L
s
.51115 .43105 m
.51174 .43025 L
s
.51601 .42716 m
.51115 .43105 L
s
0 .264 1 r
.51601 .21576 m
.51739 .21497 L
s
.51739 .21497 m
.51767 .217 L
s
0 .016 1 r
.57855 .58773 m
.58392 .59446 L
s
.797 0 1 r
.70087 .58974 m
.69916 .58866 L
s
.70128 .58712 m
.70087 .58974 L
s
0 1 .879 r
.51162 .42952 m
.51174 .43025 L
s
0 .264 1 r
.51601 .21576 m
.51767 .217 L
s
1 0 .282 r
.58244 .66292 m
.58038 .6643 L
s
.58258 .66175 m
.58244 .66292 L
s
.58306 .6649 m
.58244 .66292 L
s
.797 0 1 r
.69916 .58866 m
.70128 .58712 L
s
.407 0 1 r
.52315 .61228 m
.52189 .6135 L
s
.52341 .61118 m
.52315 .61228 L
s
.52419 .6135 m
.52315 .61228 L
s
0 1 .879 r
.51174 .43025 m
.51262 .43102 L
s
.771 0 1 r
.51667 .73998 m
.51841 .74102 L
s
.299 0 1 r
.5824 .62714 m
.58086 .62818 L
s
.58252 .62623 m
.5824 .62714 L
s
.5829 .62859 m
.5824 .62714 L
s
1 0 0 r
.63915 .38913 m
.64093 .39089 L
s
.647 0 1 r
.58025 .55378 m
.58601 .56219 L
s
1 0 .282 r
.58038 .6643 m
.58052 .66313 L
s
.58306 .6649 m
.58038 .6643 L
s
1 0 0 r
.58433 .34357 m
.58391 .34281 L
s
.58391 .34281 m
.58143 .34185 L
s
.58391 .34281 m
.58179 .34515 L
s
.299 0 1 r
.58086 .62818 m
.58098 .62726 L
s
.5829 .62859 m
.58086 .62818 L
s
.683 0 1 r
.64193 .63501 m
.65001 .64035 L
s
0 .016 1 r
.58348 .59307 m
.58202 .59397 L
s
.58366 .59225 m
.58348 .59307 L
s
.58392 .59446 m
.58348 .59307 L
s
.407 0 1 r
.52189 .6135 m
.52215 .6124 L
s
.52419 .6135 m
.52189 .6135 L
s
1 0 0 r
.58143 .34185 m
.58185 .34261 L
s
.58143 .34185 m
.58179 .34515 L
s
1 0 .282 r
.64607 .60921 m
.64399 .61053 L
s
.64626 .60801 m
.64607 .60921 L
s
.64668 .61117 m
.64607 .60921 L
s
0 1 .879 r
.51601 .57284 m
.52088 .57674 L
s
.407 0 1 r
.52215 .6124 m
.52341 .61118 L
s
.52341 .61118 m
.52419 .6135 L
s
1 0 0 r
.58179 .34515 m
.58433 .34357 L
s
.58179 .34515 m
.58185 .34261 L
s
.58725 .33295 m
.58179 .34515 L
s
0 .016 1 r
.58202 .59397 m
.58221 .59315 L
s
.58392 .59446 m
.58202 .59397 L
s
1 .028 0 r
.64317 .34482 m
.64316 .34481 L
s
.64316 .34481 m
.64315 .3448 L
s
.64316 .34481 m
.64314 .34483 L
s
0 .279 1 r
.58425 .7278 m
.58415 .72682 L
s
.58415 .72682 m
.58279 .72601 L
s
.58415 .72682 m
.58251 .72804 L
s
1 .028 0 r
.64314 .34483 m
.64317 .34482 L
s
.64315 .3448 m
.64314 .34483 L
s
.64314 .34483 m
.64315 .34481 L
s
.64322 .34474 m
.64314 .34483 L
s
.64315 .3448 m
.64315 .34481 L
s
.64315 .34481 m
.64317 .34482 L
s
.647 0 1 r
.58553 .56047 m
.58379 .56141 L
s
.58592 .5596 m
.58553 .56047 L
s
.58601 .56219 m
.58553 .56047 L
s
1 .028 0 r
.64322 .65526 m
.64331 .65534 L
s
.64329 .65532 m
.64328 .65534 L
s
.6433 .65531 m
.64329 .65532 L
s
.64331 .65534 m
.64329 .65532 L
s
.64328 .65534 m
.64329 .65532 L
s
.64331 .65534 m
.64328 .65534 L
s
.64329 .65532 m
.6433 .65531 L
s
.6433 .65531 m
.64331 .65534 L
s
.64329 .65532 m
.64331 .65534 L
s
.407 0 1 r
.52215 .6124 m
.52419 .6135 L
s
.299 0 1 r
.58098 .62726 m
.58252 .62623 L
s
.58252 .62623 m
.5829 .62859 L
s
1 0 .282 r
.58052 .66313 m
.58258 .66175 L
s
.58258 .66175 m
.58306 .6649 L
s
0 .279 1 r
.58251 .72804 m
.58425 .7278 L
s
.58279 .72601 m
.58251 .72804 L
s
.58251 .72804 m
.58288 .727 L
s
.58757 .72235 m
.58251 .72804 L
s
.299 0 1 r
.58098 .62726 m
.5829 .62859 L
s
0 .279 1 r
.58279 .72601 m
.58288 .727 L
s
1 0 .282 r
.64399 .61053 m
.64417 .60934 L
s
.64668 .61117 m
.64399 .61053 L
s
.58052 .66313 m
.58306 .6649 L
s
0 1 .879 r
.52028 .57593 m
.5194 .57671 L
s
.52041 .57521 m
.52028 .57593 L
s
.52088 .57674 m
.52028 .57593 L
s
.647 0 1 r
.58379 .56141 m
.58418 .56054 L
s
.58601 .56219 m
.58379 .56141 L
s
0 .016 1 r
.58221 .59315 m
.58366 .59225 L
s
.58366 .59225 m
.58392 .59446 L
s
.58221 .59315 m
.58392 .59446 L
s
1 0 .524 r
.58747 .69032 m
.58693 .68967 L
s
.58693 .68967 m
.58455 .68924 L
s
.58693 .68967 m
.58545 .69214 L
s
.452 0 1 r
.58643 .36873 m
.58631 .3678 L
s
.58631 .3678 m
.58469 .36674 L
s
.58631 .3678 m
.58433 .3692 L
s
.771 0 1 r
.52269 .26586 m
.52919 .27302 L
s
0 1 .879 r
.5194 .57671 m
.51953 .57598 L
s
.52088 .57674 m
.5194 .57671 L
s
1 0 0 r
.64534 .68557 m
.64533 .68556 L
s
.64534 .68555 m
.64534 .68557 L
s
.64534 .68557 m
.64533 .68556 L
s
.64534 .68556 m
.64534 .68557 L
s
.64532 .68552 m
.64534 .68557 L
s
.64534 .68555 m
.64533 .68556 L
s
.64534 .68556 m
.64534 .68555 L
s
.64533 .68556 m
.64533 .68556 L
s
.64533 .68556 m
.64534 .68556 L
s
.64532 .31448 m
.6453 .31452 L
s
.64531 .31452 m
.6453 .31451 L
s
.64532 .31451 m
.64531 .31452 L
s
.6453 .31452 m
.64531 .31452 L
s
.6453 .31451 m
.6453 .31451 L
s
.6453 .31451 m
.6453 .31452 L
s
.6453 .31451 m
.64532 .31451 L
s
.6453 .31452 m
.64532 .31451 L
s
.6453 .31451 m
.6453 .31452 L
s
0 .279 1 r
.58288 .727 m
.58425 .7278 L
s
1 0 0 r
.58185 .34261 m
.58433 .34357 L
s
.992 0 1 r
.5244 .38293 m
.52415 .38176 L
s
.52415 .38176 m
.52256 .38045 L
s
.52415 .38176 m
.52187 .38314 L
s
.452 0 1 r
.58433 .3692 m
.58643 .36873 L
s
.58469 .36674 m
.58433 .3692 L
s
.58433 .3692 m
.58481 .36767 L
s
.59048 .36188 m
.58433 .3692 L
s
1 0 .524 r
.58455 .68924 m
.58509 .68989 L
s
.58455 .68924 m
.58545 .69214 L
s
0 1 .879 r
.51953 .57598 m
.52041 .57521 L
s
.52041 .57521 m
.52088 .57674 L
s
.452 0 1 r
.58469 .36674 m
.58481 .36767 L
s
.647 0 1 r
.58418 .56054 m
.58592 .5596 L
s
.58592 .5596 m
.58601 .56219 L
s
.58418 .56054 m
.58601 .56219 L
s
0 1 .879 r
.51953 .57598 m
.52088 .57674 L
s
0 .19 1 r
.70836 .37948 m
.70972 .37863 L
s
.70972 .37863 m
.70989 .37768 L
s
.70972 .37863 m
.70804 .3774 L
s
1 0 .282 r
.64417 .60934 m
.64626 .60801 L
s
.64626 .60801 m
.64668 .61117 L
s
.683 0 1 r
.64915 .63921 m
.64776 .64059 L
s
.64901 .63797 m
.64915 .63921 L
s
.65001 .64035 m
.64915 .63921 L
s
.992 0 1 r
.52187 .38314 m
.5244 .38293 L
s
.52256 .38045 m
.52187 .38314 L
s
.52187 .38314 m
.5228 .38162 L
s
.52991 .37589 m
.52187 .38314 L
s
1 0 .524 r
.58545 .69214 m
.58747 .69032 L
s
.58545 .69214 m
.58509 .68989 L
s
.58827 .68032 m
.58545 .69214 L
s
1 0 .282 r
.64417 .60934 m
.64668 .61117 L
s
0 .19 1 r
.70804 .3774 m
.70836 .37948 L
s
.70989 .37768 m
.70804 .3774 L
s
.70804 .3774 m
.70853 .37853 L
s
.71347 .38332 m
.70804 .3774 L
s
.70853 .37853 m
.70836 .37948 L
s
.299 0 1 r
.58837 .4026 m
.58821 .4017 L
s
.58821 .4017 m
.58664 .40071 L
s
.58821 .4017 m
.58634 .40309 L
s
.992 0 1 r
.52256 .38045 m
.5228 .38162 L
s
.683 0 1 r
.64776 .64059 m
.64762 .63935 L
s
.65001 .64035 m
.64776 .64059 L
s
.452 0 1 r
.58481 .36767 m
.58643 .36873 L
s
.299 0 1 r
.58634 .40309 m
.58837 .4026 L
s
.58664 .40071 m
.58634 .40309 L
s
.58634 .40309 m
.5868 .40161 L
s
.59219 .39591 m
.58634 .40309 L
s
1 0 .807 r
.58963 .4383 m
.58931 .43726 L
s
.58931 .43726 m
.58738 .43615 L
s
.58931 .43726 m
.58716 .43904 L
s
.299 0 1 r
.58664 .40071 m
.5868 .40161 L
s
1 0 0 r
.64842 .61619 m
.65882 .62296 L
s
.771 0 1 r
.52873 .27171 m
.52698 .27275 L
s
.5288 .27043 m
.52873 .27171 L
s
.52919 .27302 m
.52873 .27171 L
s
1 0 0 r
.58725 .66705 m
.59273 .67928 L
s
.992 0 1 r
.5228 .38162 m
.5244 .38293 L
s
0 .19 1 r
.70989 .37768 m
.70853 .37853 L
s
1 0 .524 r
.58509 .68989 m
.58747 .69032 L
s
0 .279 1 r
.58757 .27765 m
.59266 .28336 L
s
.683 0 1 r
.64762 .63935 m
.64901 .63797 L
s
.64901 .63797 m
.65001 .64035 L
s
1 0 .807 r
.58716 .43904 m
.58963 .4383 L
s
.58738 .43615 m
.58716 .43904 L
s
.58716 .43904 m
.5877 .43719 L
s
.5939 .42997 m
.58716 .43904 L
s
1 0 .524 r
.65116 .38159 m
.65246 .37994 L
s
.65246 .37994 m
.65198 .37814 L
s
.65246 .37994 m
.64949 .37927 L
s
0 .259 1 r
.52761 .41537 m
.52737 .41451 L
s
.52737 .41451 m
.52615 .41356 L
s
.52737 .41451 m
.52571 .4156 L
s
1 0 .807 r
.58738 .43615 m
.5877 .43719 L
s
1 0 .524 r
.59146 .32926 m
.58907 .3297 L
s
.592 .32862 m
.59146 .32926 L
s
.5911 .33153 m
.59146 .32926 L
s
.64949 .37927 m
.65116 .38159 L
s
.65198 .37814 m
.64949 .37927 L
s
.64949 .37927 m
.65067 .37979 L
s
.65989 .38226 m
.64949 .37927 L
s
.771 0 1 r
.52698 .27275 m
.52705 .27147 L
s
.52919 .27302 m
.52698 .27275 L
s
1 0 .524 r
.58827 .31968 m
.5911 .33153 L
s
.299 0 1 r
.5868 .40161 m
.58837 .4026 L
s
.683 0 1 r
.64762 .63935 m
.65001 .64035 L
s
0 .846 1 r
.54256 .53059 m
.54218 .53107 L
s
.54382 .53013 m
.54256 .53059 L
s
.54359 .53187 m
.54256 .53059 L
s
0 .259 1 r
.52571 .4156 m
.52761 .41537 L
s
.52615 .41356 m
.52571 .4156 L
s
.52571 .4156 m
.5264 .41443 L
s
.53159 .40993 m
.52571 .4156 L
s
1 0 .524 r
.58907 .3297 m
.58962 .32906 L
s
.5911 .33153 m
.58907 .3297 L
s
1 0 0 r
.59266 .67672 m
.59017 .67769 L
s
.59308 .67598 m
.59266 .67672 L
s
.59273 .67928 m
.59266 .67672 L
s
0 .259 1 r
.52615 .41356 m
.5264 .41443 L
s
0 .846 1 r
.54344 .53061 m
.54382 .53013 L
s
.54382 .53013 m
.54359 .53187 L
s
1 0 .524 r
.65067 .37979 m
.65116 .38159 L
s
0 .846 1 r
.54359 .53187 m
.54218 .53107 L
s
.54344 .53061 m
.54359 .53187 L
s
.54063 .5255 m
.54359 .53187 L
s
.771 0 1 r
.52705 .27147 m
.5288 .27043 L
s
.5288 .27043 m
.52919 .27302 L
s
0 .279 1 r
.59227 .28231 m
.59091 .28311 L
s
.59237 .28132 m
.59227 .28231 L
s
.59266 .28336 m
.59227 .28231 L
s
1 0 .807 r
.5877 .43719 m
.58963 .4383 L
s
1 0 0 r
.59017 .67769 m
.5906 .67695 L
s
.59273 .67928 m
.59017 .67769 L
s
0 .259 1 r
.5264 .41443 m
.52761 .41537 L
s
.452 0 1 r
.59048 .63812 m
.59664 .64547 L
s
.771 0 1 r
.52705 .27147 m
.52919 .27302 L
s
1 0 .524 r
.65198 .37814 m
.65067 .37979 L
s
0 .19 1 r
.71347 .61668 m
.71891 .61075 L
s
0 .279 1 r
.59091 .28311 m
.59101 .28213 L
s
.59266 .28336 m
.59091 .28311 L
s
0 .846 1 r
.54218 .53107 m
.54344 .53061 L
s
1 0 .524 r
.592 .32862 m
.5911 .33153 L
s
.58962 .32906 m
.5911 .33153 L
s
.992 0 1 r
.52991 .62411 m
.53798 .63139 L
s
1 0 .524 r
.58962 .32906 m
.592 .32862 L
s
0 .846 1 r
.54063 .4745 m
.53766 .48088 L
s
.299 0 1 r
.59219 .60409 m
.59805 .61129 L
s
0 .846 1 r
.53908 .48007 m
.53782 .47961 L
s
.53782 .47961 m
.53743 .47913 L
s
.53782 .47961 m
.53766 .48088 L
s
0 .279 1 r
.59101 .28213 m
.59237 .28132 L
s
.59237 .28132 m
.59266 .28336 L
s
.59101 .28213 m
.59266 .28336 L
s
1 0 0 r
.65771 .62152 m
.65593 .62329 L
s
.65754 .61991 m
.65771 .62152 L
s
.65882 .62296 m
.65771 .62152 L
s
.59308 .67598 m
.59273 .67928 L
s
.5906 .67695 m
.59273 .67928 L
s
0 .259 1 r
.53159 .59007 m
.5375 .59575 L
s
0 .846 1 r
.5387 .47959 m
.53908 .48007 L
s
.53766 .48088 m
.53908 .48007 L
s
1 0 0 r
.5906 .67695 m
.59308 .67598 L
s
0 .19 1 r
.71842 .61189 m
.71859 .61284 L
s
.71706 .61103 m
.71842 .61189 L
s
.71891 .61075 m
.71842 .61189 L
s
.452 0 1 r
.59615 .64393 m
.59453 .64499 L
s
.59628 .643 m
.59615 .64393 L
s
.59664 .64547 m
.59615 .64393 L
s
.992 0 1 r
.53703 .62986 m
.53544 .63118 L
s
.53728 .62869 m
.53703 .62986 L
s
.53798 .63139 m
.53703 .62986 L
s
1 0 .807 r
.5939 .57003 m
.60066 .57912 L
s
.771 0 1 r
.71775 .43346 m
.71947 .4324 L
s
.71947 .4324 m
.7197 .43126 L
s
.71947 .4324 m
.71739 .43083 L
s
0 1 .879 r
.52884 .44972 m
.52846 .44918 L
s
.52846 .44918 m
.52743 .4486 L
s
.52846 .44918 m
.52739 .45022 L
s
0 .846 1 r
.53743 .47913 m
.53766 .48088 L
s
.53766 .48088 m
.5387 .47959 L
s
0 .19 1 r
.71723 .61198 m
.71706 .61103 L
s
.71706 .61103 m
.71891 .61075 L
s
0 .846 1 r
.53743 .47913 m
.5387 .47959 L
s
.452 0 1 r
.59453 .64499 m
.59466 .64407 L
s
.59664 .64547 m
.59453 .64499 L
s
1 0 0 r
.65593 .62329 m
.65576 .62168 L
s
.65882 .62296 m
.65593 .62329 L
s
0 .259 1 r
.5368 .59457 m
.53558 .59552 L
s
.53705 .59371 m
.5368 .59457 L
s
.5375 .59575 m
.5368 .59457 L
s
.771 0 1 r
.71739 .43083 m
.71775 .43346 L
s
.7197 .43126 m
.71739 .43083 L
s
.71739 .43083 m
.71798 .43233 L
s
.72408 .43849 m
.71739 .43083 L
s
.299 0 1 r
.59758 .60979 m
.59601 .61079 L
s
.59775 .6089 m
.59758 .60979 L
s
.59805 .61129 m
.59758 .60979 L
s
0 1 .879 r
.52739 .45022 m
.52884 .44972 L
s
.52743 .4486 m
.52739 .45022 L
s
.52739 .45022 m
.52782 .44914 L
s
.53111 .44494 m
.52739 .45022 L
s
.52743 .4486 m
.52782 .44914 L
s
.771 0 1 r
.71798 .43233 m
.71775 .43346 L
s
.992 0 1 r
.53544 .63118 m
.53569 .63001 L
s
.53798 .63139 m
.53544 .63118 L
s
0 .259 1 r
.53558 .59552 m
.53583 .59466 L
s
.5375 .59575 m
.53558 .59552 L
s
0 .19 1 r
.71859 .61284 m
.71723 .61198 L
s
.71891 .61075 m
.71859 .61284 L
s
0 1 .879 r
.52782 .44914 m
.52884 .44972 L
s
.299 0 1 r
.59601 .61079 m
.59617 .6099 L
s
.59805 .61129 m
.59601 .61079 L
s
0 .19 1 r
.71723 .61198 m
.71891 .61075 L
s
1 0 0 r
.65576 .62168 m
.65754 .61991 L
s
.65754 .61991 m
.65882 .62296 L
s
.452 0 1 r
.59466 .64407 m
.59628 .643 L
s
.59628 .643 m
.59664 .64547 L
s
1 0 .807 r
.6001 .57725 m
.59817 .57837 L
s
.60043 .57622 m
.6001 .57725 L
s
.60066 .57912 m
.6001 .57725 L
s
.452 0 1 r
.59466 .64407 m
.59664 .64547 L
s
.992 0 1 r
.53569 .63001 m
.53728 .62869 L
s
.53728 .62869 m
.53798 .63139 L
s
0 .222 1 r
.53748 .76248 m
.53742 .76145 L
s
.53742 .76145 m
.53603 .76063 L
s
.53742 .76145 m
.53573 .76269 L
s
0 .259 1 r
.53583 .59466 m
.53705 .59371 L
s
.53705 .59371 m
.5375 .59575 L
s
.771 0 1 r
.7197 .43126 m
.71798 .43233 L
s
0 .259 1 r
.53583 .59466 m
.5375 .59575 L
s
0 1 .879 r
.53111 .55506 m
.53483 .56035 L
s
.992 0 1 r
.53569 .63001 m
.53798 .63139 L
s
0 .222 1 r
.53573 .76269 m
.53748 .76248 L
s
.53603 .76063 m
.53573 .76269 L
s
.53573 .76269 m
.53609 .76166 L
s
.54088 .757 m
.53573 .76269 L
s
1 0 .615 r
.53798 .36734 m
.53777 .36615 L
s
.53777 .36615 m
.53592 .36479 L
s
.53777 .36615 m
.53534 .36774 L
s
1 0 0 r
.65576 .62168 m
.65882 .62296 L
s
0 1 .879 r
.5344 .55927 m
.53338 .55985 L
s
.53479 .55873 m
.5344 .55927 L
s
.53483 .56035 m
.5344 .55927 L
s
0 .222 1 r
.53603 .76063 m
.53609 .76166 L
s
.299 0 1 r
.59617 .6099 m
.59775 .6089 L
s
.59775 .6089 m
.59805 .61129 L
s
1 0 .807 r
.59817 .57837 m
.5985 .57734 L
s
.60066 .57912 m
.59817 .57837 L
s
.299 0 1 r
.59617 .6099 m
.59805 .61129 L
s
.269 0 1 r
.66091 .36087 m
.66192 .35959 L
s
.66192 .35959 m
.66155 .35817 L
s
.66192 .35959 m
.6596 .35906 L
s
.683 0 1 r
.60122 .34811 m
.60087 .34751 L
s
.60087 .34751 m
.59893 .34675 L
s
.60087 .34751 m
.59921 .34934 L
s
.269 0 1 r
.6596 .35906 m
.66091 .36087 L
s
.66155 .35817 m
.6596 .35906 L
s
.6596 .35906 m
.66053 .35945 L
s
.66775 .36137 m
.6596 .35906 L
s
1 0 .615 r
.53534 .36774 m
.53798 .36734 L
s
.53592 .36479 m
.53534 .36774 L
s
.53534 .36774 m
.53613 .36598 L
s
.54341 .35934 m
.53534 .36774 L
s
0 1 .879 r
.53338 .55985 m
.53377 .55931 L
s
.53483 .56035 m
.53338 .55985 L
s
1 0 .524 r
.65989 .61774 m
.67034 .61473 L
s
1 0 .615 r
.53592 .36479 m
.53613 .36598 L
s
.683 0 1 r
.59893 .34675 m
.59928 .34735 L
s
.59893 .34675 m
.59921 .34934 L
s
0 .222 1 r
.53609 .76166 m
.53748 .76248 L
s
0 1 .879 r
.53377 .55931 m
.53479 .55873 L
s
.53479 .55873 m
.53483 .56035 L
s
.53377 .55931 m
.53483 .56035 L
s
.683 0 1 r
.59921 .34934 m
.60122 .34811 L
s
.59921 .34934 m
.59928 .34735 L
s
.60354 .33978 m
.59921 .34934 L
s
.452 0 1 r
.60189 .38634 m
.60175 .38541 L
s
.60175 .38541 m
.60013 .38436 L
s
.60175 .38541 m
.59979 .38683 L
s
.269 0 1 r
.66053 .35945 m
.66091 .36087 L
s
1 0 .456 r
.60284 .42236 m
.60258 .42121 L
s
.60258 .42121 m
.60054 .41997 L
s
.60258 .42121 m
.6002 .42305 L
s
1 0 .807 r
.5985 .57734 m
.60043 .57622 L
s
.60043 .57622 m
.60066 .57912 L
s
.452 0 1 r
.59979 .38683 m
.60189 .38634 L
s
.60013 .38436 m
.59979 .38683 L
s
.59979 .38683 m
.60026 .38529 L
s
.60592 .37943 m
.59979 .38683 L
s
1 0 .807 r
.5985 .57734 m
.60066 .57912 L
s
.269 0 1 r
.66155 .35817 m
.66053 .35945 L
s
.452 0 1 r
.60013 .38436 m
.60026 .38529 L
s
1 0 .615 r
.53613 .36598 m
.53798 .36734 L
s
1 0 .456 r
.6002 .42305 m
.60284 .42236 L
s
.60054 .41997 m
.6002 .42305 L
s
.6002 .42305 m
.60079 .42112 L
s
.60764 .41361 m
.6002 .42305 L
s
.222 0 1 r
.54091 .39983 m
.54072 .39889 L
s
.54072 .39889 m
.53926 .39785 L
s
.54072 .39889 m
.53883 .40017 L
s
1 0 .456 r
.60054 .41997 m
.60079 .42112 L
s
.771 0 1 r
.72408 .56151 m
.7308 .55383 L
s
.683 0 1 r
.59928 .34735 m
.60122 .34811 L
s
.222 0 1 r
.53883 .40017 m
.54091 .39983 L
s
.53926 .39785 m
.53883 .40017 L
s
.53883 .40017 m
.53945 .39879 L
s
.54511 .3935 m
.53883 .40017 L
s
.53926 .39785 m
.53945 .39879 L
s
.452 0 1 r
.60026 .38529 m
.60189 .38634 L
s
.269 0 1 r
.60523 .69805 m
.6048 .69753 L
s
.6048 .69753 m
.60293 .69719 L
s
.6048 .69753 m
.60364 .69947 L
s
0 .222 1 r
.54088 .243 m
.54604 .24871 L
s
.269 0 1 r
.60293 .69719 m
.60336 .69771 L
s
.60293 .69719 m
.60364 .69947 L
s
1 0 0 r
.66464 .66415 m
.66464 .66416 L
s
.66464 .66414 m
.66464 .66415 L
s
.66466 .66415 m
.66464 .66415 L
s
.66456 .33586 m
.66455 .33585 L
s
.66455 .33585 m
.66456 .33584 L
s
.66455 .33585 m
.66454 .33585 L
s
.66466 .66415 m
.66464 .66416 L
s
.66464 .66414 m
.66466 .66415 L
s
.66465 .66415 m
.66466 .66415 L
s
.6646 .66415 m
.66466 .66415 L
s
.66465 .66415 m
.66464 .66414 L
s
.66464 .66416 m
.66465 .66415 L
s
.6646 .33585 m
.66454 .33585 L
s
.66456 .33585 m
.66456 .33586 L
s
.66454 .33585 m
.66456 .33586 L
s
.66456 .33584 m
.66456 .33585 L
s
.66456 .33584 m
.66454 .33585 L
s
.66454 .33585 m
.66456 .33585 L
s
1 0 .456 r
.60079 .42112 m
.60284 .42236 L
s
.222 0 1 r
.53945 .39879 m
.54091 .39983 L
s
.683 0 1 r
.60354 .66022 m
.60789 .6698 L
s
.269 0 1 r
.60364 .69947 m
.60523 .69805 L
s
.60364 .69947 m
.60336 .69771 L
s
.60587 .69021 m
.60364 .69947 L
s
0 .259 1 r
.54342 .43364 m
.54303 .43286 L
s
.54303 .43286 m
.54173 .43203 L
s
.54303 .43286 m
.54152 .43412 L
s
.771 0 1 r
.73019 .55534 m
.73044 .55647 L
s
.72847 .55427 m
.73019 .55534 L
s
.7308 .55383 m
.73019 .55534 L
s
1 0 .524 r
.66913 .61526 m
.66866 .61706 L
s
.66783 .6136 m
.66913 .61526 L
s
.67034 .61473 m
.66913 .61526 L
s
1 0 .615 r
.54341 .64066 m
.55152 .64909 L
s
0 .259 1 r
.54152 .43412 m
.54342 .43364 L
s
.54173 .43203 m
.54152 .43412 L
s
.54152 .43412 m
.54212 .4328 L
s
.54681 .42769 m
.54152 .43412 L
s
0 .222 1 r
.54567 .24767 m
.54428 .24849 L
s
.54573 .24664 m
.54567 .24767 L
s
.54604 .24871 m
.54567 .24767 L
s
.683 0 1 r
.60781 .66779 m
.60587 .66856 L
s
.60817 .66721 m
.60781 .66779 L
s
.60789 .6698 m
.60781 .66779 L
s
0 .259 1 r
.54173 .43203 m
.54212 .4328 L
s
.269 0 1 r
.60336 .69771 m
.60523 .69805 L
s
.771 0 1 r
.72872 .5554 m
.72847 .55427 L
s
.72847 .55427 m
.7308 .55383 L
s
.797 0 1 r
.54682 .70915 m
.54673 .70789 L
s
.54673 .70789 m
.54495 .70685 L
s
.54673 .70789 m
.5446 .70949 L
s
.269 0 1 r
.60837 .3173 m
.6065 .31764 L
s
.6088 .31679 m
.60837 .3173 L
s
.6081 .31907 m
.60837 .3173 L
s
0 .222 1 r
.54428 .24849 m
.54434 .24746 L
s
.54604 .24871 m
.54428 .24849 L
s
.269 0 1 r
.60587 .30979 m
.6081 .31907 L
s
.683 0 1 r
.60587 .66856 m
.60622 .66797 L
s
.60789 .6698 m
.60587 .66856 L
s
.452 0 1 r
.60592 .62057 m
.61207 .62798 L
s
.797 0 1 r
.5446 .70949 m
.54682 .70915 L
s
.54495 .70685 m
.5446 .70949 L
s
.5446 .70949 m
.54504 .70811 L
s
.55105 .70204 m
.5446 .70949 L
s
.269 0 1 r
.66775 .63863 m
.67593 .63631 L
s
1 0 .524 r
.66736 .6154 m
.66783 .6136 L
s
.66783 .6136 m
.67034 .61473 L
s
0 .259 1 r
.54212 .4328 m
.54342 .43364 L
s
.797 0 1 r
.54495 .70685 m
.54504 .70811 L
s
.269 0 1 r
.6065 .31764 m
.60693 .31713 L
s
.6081 .31907 m
.6065 .31764 L
s
.222 0 1 r
.54511 .6065 m
.55141 .61319 L
s
1 0 .524 r
.66866 .61706 m
.66736 .6154 L
s
.67034 .61473 m
.66866 .61706 L
s
.771 0 1 r
.73044 .55647 m
.72872 .5554 L
s
.7308 .55383 m
.73044 .55647 L
s
0 .222 1 r
.54434 .24746 m
.54573 .24664 L
s
.54573 .24664 m
.54604 .24871 L
s
.771 0 1 r
.72872 .5554 m
.7308 .55383 L
s
1 0 .456 r
.60764 .58639 m
.6151 .59586 L
s
0 .222 1 r
.54434 .24746 m
.54604 .24871 L
s
.683 0 1 r
.60817 .66721 m
.60789 .6698 L
s
.60622 .66797 m
.60789 .6698 L
s
1 0 .615 r
.55071 .64731 m
.54886 .64868 L
s
.55093 .64613 m
.55071 .64731 L
s
.55152 .64909 m
.55071 .64731 L
s
.269 0 1 r
.6088 .31679 m
.6081 .31907 L
s
.60693 .31713 m
.6081 .31907 L
s
.683 0 1 r
.60622 .66797 m
.60817 .66721 L
s
.797 0 1 r
.54504 .70811 m
.54682 .70915 L
s
0 .259 1 r
.54681 .57231 m
.5521 .57874 L
s
1 0 .524 r
.66736 .6154 m
.67034 .61473 L
s
.765 0 1 r
.67142 .39947 m
.67315 .39839 L
s
.67315 .39839 m
.67333 .39721 L
s
.67315 .39839 m
.67104 .39684 L
s
.269 0 1 r
.60693 .31713 m
.6088 .31679 L
s
.452 0 1 r
.61158 .62644 m
.60995 .62749 L
s
.61172 .6255 m
.61158 .62644 L
s
.61207 .62798 m
.61158 .62644 L
s
.222 0 1 r
.55077 .61179 m
.54931 .61284 L
s
.55098 .61086 m
.55077 .61179 L
s
.55141 .61319 m
.55077 .61179 L
s
.765 0 1 r
.67104 .39684 m
.67142 .39947 L
s
.67333 .39721 m
.67104 .39684 L
s
.67104 .39684 m
.6716 .39829 L
s
.67775 .40434 m
.67104 .39684 L
s
0 .259 1 r
.5515 .57742 m
.5502 .57826 L
s
.55189 .57665 m
.5515 .57742 L
s
.5521 .57874 m
.5515 .57742 L
s
1 0 .615 r
.54886 .64868 m
.54908 .6475 L
s
.55152 .64909 m
.54886 .64868 L
s
.765 0 1 r
.6716 .39829 m
.67142 .39947 L
s
0 .186 1 r
.54923 .54332 m
.54838 .54391 L
s
.55055 .54277 m
.54923 .54332 L
s
.55025 .54489 m
.54923 .54332 L
s
.452 0 1 r
.60995 .62749 m
.61009 .62656 L
s
.61207 .62798 m
.60995 .62749 L
s
.222 0 1 r
.54931 .61284 m
.54951 .6119 L
s
.55141 .61319 m
.54931 .61284 L
s
1 0 .399 r
.55181 .35132 m
.55165 .35015 L
s
.55165 .35015 m
.54962 .34879 L
s
.55165 .35015 m
.54914 .35189 L
s
0 .259 1 r
.5502 .57826 m
.55059 .57749 L
s
.5521 .57874 m
.5502 .57826 L
s
.269 0 1 r
.67498 .63671 m
.67461 .63813 L
s
.67396 .63542 m
.67498 .63671 L
s
.67593 .63631 m
.67498 .63671 L
s
1 0 .456 r
.6145 .5939 m
.61245 .59516 L
s
.61477 .59276 m
.6145 .5939 L
s
.6151 .59586 m
.6145 .5939 L
s
1 0 .399 r
.54914 .35189 m
.55181 .35132 L
s
.54962 .34879 m
.54914 .35189 L
s
.54914 .35189 m
.54978 .34996 L
s
.55701 .34268 m
.54914 .35189 L
s
1 0 .615 r
.54908 .6475 m
.55093 .64613 L
s
.55093 .64613 m
.55152 .64909 L
s
0 .186 1 r
.5497 .54336 m
.55055 .54277 L
s
.55055 .54277 m
.55025 .54489 L
s
.5443 .46963 m
.54297 .46908 L
s
.54297 .46908 m
.54212 .46849 L
s
.54297 .46908 m
.54242 .47061 L
s
.55025 .54489 m
.54838 .54391 L
s
.5497 .54336 m
.55025 .54489 L
s
.54634 .53714 m
.55025 .54489 L
s
.222 0 1 r
.54951 .6119 m
.55098 .61086 L
s
.55098 .61086 m
.55141 .61319 L
s
.452 0 1 r
.61009 .62656 m
.61172 .6255 L
s
.61172 .6255 m
.61207 .62798 L
s
.765 0 1 r
.67333 .39721 m
.6716 .39829 L
s
0 .259 1 r
.55059 .57749 m
.55189 .57665 L
s
.55189 .57665 m
.5521 .57874 L
s
1 0 .399 r
.54962 .34879 m
.54978 .34996 L
s
1 0 .615 r
.54908 .6475 m
.55152 .64909 L
s
0 .259 1 r
.55059 .57749 m
.5521 .57874 L
s
.222 0 1 r
.54951 .6119 m
.55141 .61319 L
s
.452 0 1 r
.61009 .62656 m
.61207 .62798 L
s
0 .186 1 r
.54838 .54391 m
.5497 .54336 L
s
1 0 .456 r
.61245 .59516 m
.61272 .59402 L
s
.6151 .59586 m
.61245 .59516 L
s
.269 0 1 r
.6736 .63684 m
.67396 .63542 L
s
.67396 .63542 m
.67593 .63631 L
s
0 .186 1 r
.54634 .46286 m
.54242 .47061 L
s
.797 0 1 r
.55105 .29796 m
.55753 .30543 L
s
1 0 .282 r
.61633 .40604 m
.61612 .40483 L
s
.61612 .40483 m
.61403 .40349 L
s
.61612 .40483 m
.6136 .40667 L
s
.269 0 1 r
.67461 .63813 m
.6736 .63684 L
s
.67593 .63631 m
.67461 .63813 L
s
0 .186 1 r
.54344 .46905 m
.5443 .46963 L
s
.54242 .47061 m
.5443 .46963 L
s
.54212 .46849 m
.54242 .47061 L
s
.54242 .47061 m
.54344 .46905 L
s
.54212 .46849 m
.54344 .46905 L
s
1 0 .282 r
.6136 .40667 m
.61633 .40604 L
s
.61403 .40349 m
.6136 .40667 L
s
.6136 .40667 m
.61423 .40471 L
s
.62148 .39713 m
.6136 .40667 L
s
1 0 .399 r
.54978 .34996 m
.55181 .35132 L
s
.528 0 1 r
.5544 .38389 m
.55423 .3829 L
s
.55423 .3829 m
.55262 .3818 L
s
.55423 .3829 m
.55221 .38431 L
s
0 .222 1 r
.73824 .41242 m
.73961 .41157 L
s
.73961 .41157 m
.7398 .41065 L
s
.73961 .41157 m
.73795 .41033 L
s
1 0 .282 r
.61403 .40349 m
.61423 .40471 L
s
.269 0 1 r
.6736 .63684 m
.67593 .63631 L
s
1 0 .456 r
.61272 .59402 m
.61477 .59276 L
s
.61477 .59276 m
.6151 .59586 L
s
0 .222 1 r
.73795 .41033 m
.73824 .41242 L
s
.7398 .41065 m
.73795 .41033 L
s
.73795 .41033 m
.73844 .4115 L
s
.74333 .41637 m
.73795 .41033 L
s
1 0 .456 r
.61272 .59402 m
.6151 .59586 L
s
.528 0 1 r
.55221 .38431 m
.5544 .38389 L
s
.55262 .3818 m
.55221 .38431 L
s
.55221 .38431 m
.55278 .38278 L
s
.55872 .37695 m
.55221 .38431 L
s
0 .222 1 r
.73844 .4115 m
.73824 .41242 L
s
.528 0 1 r
.55262 .3818 m
.55278 .38278 L
s
.765 0 1 r
.67775 .59566 m
.68449 .58813 L
s
.797 0 1 r
.55708 .30404 m
.55529 .30508 L
s
.55717 .30279 m
.55708 .30404 L
s
.55753 .30543 m
.55708 .30404 L
s
.683 0 1 r
.61867 .36906 m
.61883 .36781 L
s
.61883 .36781 m
.61742 .36642 L
s
.61883 .36781 m
.61643 .36881 L
s
0 .222 1 r
.7398 .41065 m
.73844 .4115 L
s
.683 0 1 r
.61643 .36881 m
.61867 .36906 L
s
.61742 .36642 m
.61643 .36881 L
s
.61643 .36881 m
.61725 .36767 L
s
.62452 .36343 m
.61643 .36881 L
s
1 0 .282 r
.61423 .40471 m
.61633 .40604 L
s
.222 0 1 r
.55661 .41793 m
.55633 .41704 L
s
.55633 .41704 m
.55481 .41608 L
s
.55633 .41704 m
.55453 .41844 L
s
.528 0 1 r
.55278 .38278 m
.5544 .38389 L
s
.797 0 1 r
.55529 .30508 m
.55539 .30383 L
s
.55753 .30543 m
.55529 .30508 L
s
.683 0 1 r
.61742 .36642 m
.61725 .36767 L
s
.222 0 1 r
.55453 .41844 m
.55661 .41793 L
s
.55481 .41608 m
.55453 .41844 L
s
.55453 .41844 m
.55509 .41696 L
s
.56043 .41126 m
.55453 .41844 L
s
.55481 .41608 m
.55509 .41696 L
s
.683 0 1 r
.61725 .36767 m
.61867 .36906 L
s
1 0 .399 r
.55701 .65732 m
.56492 .66658 L
s
.797 0 1 r
.55539 .30383 m
.55717 .30279 L
s
.55717 .30279 m
.55753 .30543 L
s
.222 0 1 r
.55509 .41696 m
.55661 .41793 L
s
.765 0 1 r
.68391 .58959 m
.6841 .59076 L
s
.68218 .58851 m
.68391 .58959 L
s
.68449 .58813 m
.68391 .58959 L
s
.797 0 1 r
.55539 .30383 m
.55753 .30543 L
s
0 .222 1 r
.74333 .58363 m
.74872 .57758 L
s
.407 0 1 r
.5586 .45296 m
.55785 .45214 L
s
.55785 .45214 m
.55636 .45126 L
s
.55785 .45214 m
.55632 .45374 L
s
1 0 0 r
.62354 .38963 m
.62375 .388 L
s
.62375 .388 m
.62195 .38623 L
s
.62375 .388 m
.62067 .38929 L
s
.765 0 1 r
.68237 .58968 m
.68218 .58851 L
s
.68218 .58851 m
.68449 .58813 L
s
.528 0 1 r
.55872 .62305 m
.56525 .63043 L
s
1 0 0 r
.62067 .38929 m
.62354 .38963 L
s
.62195 .38623 m
.62067 .38929 L
s
.62067 .38929 m
.62173 .38786 L
s
.63105 .38247 m
.62067 .38929 L
s
1 .028 0 r
.62093 .33762 m
.62095 .33762 L
s
.62094 .33759 m
.62093 .33762 L
s
.62093 .33762 m
.62093 .3376 L
s
.62096 .3376 m
.62093 .33762 L
s
.62099 .33753 m
.62093 .33762 L
s
.62095 .33762 m
.62096 .3376 L
s
.62096 .3376 m
.62094 .33759 L
s
.62094 .33759 m
.62093 .3376 L
s
.62093 .3376 m
.62095 .33762 L
s
.62099 .66247 m
.62105 .66255 L
s
.62105 .66253 m
.62103 .66255 L
s
.62105 .66252 m
.62105 .66253 L
s
.62105 .66255 m
.62105 .66253 L
s
.62103 .66255 m
.62103 .66254 L
s
.62105 .66255 m
.62103 .66255 L
s
.62103 .66254 m
.62105 .66252 L
s
.62105 .66252 m
.62105 .66255 L
s
.62103 .66254 m
.62105 .66255 L
s
.407 0 1 r
.55632 .45374 m
.5586 .45296 L
s
.55636 .45126 m
.55632 .45374 L
s
.55632 .45374 m
.55711 .45208 L
s
.56214 .4456 m
.55632 .45374 L
s
.55636 .45126 m
.55711 .45208 L
s
1 0 .282 r
.62148 .60287 m
.62939 .61245 L
s
1 0 0 r
.62195 .38623 m
.62173 .38786 L
s
.765 0 1 r
.6841 .59076 m
.68237 .58968 L
s
.68449 .58813 m
.6841 .59076 L
s
.222 0 1 r
.56043 .58874 m
.56634 .59593 L
s
0 .222 1 r
.74823 .57876 m
.74843 .57967 L
s
.74686 .5779 m
.74823 .57876 L
s
.74872 .57758 m
.74823 .57876 L
s
.407 0 1 r
.55711 .45208 m
.5586 .45296 L
s
1 0 .399 r
.56427 .66462 m
.56224 .66599 L
s
.56444 .66346 m
.56427 .66462 L
s
.56492 .66658 m
.56427 .66462 L
s
.765 0 1 r
.68237 .58968 m
.68449 .58813 L
s
.729 0 1 r
.74768 .46705 m
.74938 .46596 L
s
.74938 .46596 m
.74963 .46485 L
s
.74938 .46596 m
.7473 .46442 L
s
0 .222 1 r
.74706 .57882 m
.74686 .5779 L
s
.74686 .5779 m
.74872 .57758 L
s
.528 0 1 r
.56467 .62889 m
.56305 .62999 L
s
.56484 .62791 m
.56467 .62889 L
s
.56525 .63043 m
.56467 .62889 L
s
1 0 0 r
.62173 .38786 m
.62354 .38963 L
s
.729 0 1 r
.7473 .46442 m
.74768 .46705 L
s
.74963 .46485 m
.7473 .46442 L
s
.7473 .46442 m
.74793 .46593 L
s
.7541 .47205 m
.7473 .46442 L
s
1 0 .399 r
.56224 .66599 m
.5624 .66483 L
s
.56492 .66658 m
.56224 .66599 L
s
.407 0 1 r
.56717 .56088 m
.56568 .56177 L
s
.56793 .56006 m
.56717 .56088 L
s
.56797 .56255 m
.56717 .56088 L
s
.729 0 1 r
.74793 .46593 m
.74768 .46705 L
s
.407 0 1 r
.56214 .5544 m
.56797 .56255 L
s
.222 0 1 r
.56577 .59445 m
.56425 .59542 L
s
.56606 .59357 m
.56577 .59445 L
s
.56634 .59593 m
.56577 .59445 L
s
1 0 .072 r
.56642 .34169 m
.56602 .34096 L
s
.56602 .34096 m
.56353 .34003 L
s
.56602 .34096 m
.56392 .34331 L
s
.528 0 1 r
.56305 .62999 m
.56322 .62902 L
s
.56525 .63043 m
.56305 .62999 L
s
.683 0 1 r
.62452 .63657 m
.63265 .64197 L
s
0 .222 1 r
.74843 .57967 m
.74706 .57882 L
s
.74872 .57758 m
.74843 .57967 L
s
.74706 .57882 m
.74872 .57758 L
s
1 0 .282 r
.62875 .61046 m
.62665 .6118 L
s
.62896 .60925 m
.62875 .61046 L
s
.62939 .61245 m
.62875 .61046 L
s
1 0 .072 r
.56353 .34003 m
.56392 .34075 L
s
.56353 .34003 m
.56392 .34331 L
s
.222 0 1 r
.56425 .59542 m
.56454 .59454 L
s
.56634 .59593 m
.56425 .59542 L
s
.407 0 1 r
.56568 .56177 m
.56644 .56095 L
s
.56797 .56255 m
.56568 .56177 L
s
0 .19 1 r
.56609 .73057 m
.56599 .72955 L
s
.56599 .72955 m
.56458 .72872 L
s
.56599 .72955 m
.56429 .73083 L
s
1 0 .072 r
.56392 .34331 m
.56642 .34169 L
s
.56392 .34331 m
.56392 .34075 L
s
.56918 .33103 m
.56392 .34331 L
s
1 .028 0 r
.62577 .34305 m
.62579 .34304 L
s
.62577 .34302 m
.62577 .34305 L
s
.62577 .34305 m
.62577 .34303 L
s
.62579 .34303 m
.62577 .34305 L
s
.62583 .34296 m
.62577 .34305 L
s
.62579 .34304 m
.62579 .34303 L
s
.62579 .34303 m
.62577 .34302 L
s
.62577 .34302 m
.62577 .34303 L
s
.62577 .34303 m
.62579 .34304 L
s
.62583 .65704 m
.62588 .65713 L
s
.729 0 1 r
.74963 .46485 m
.74793 .46593 L
s
1 0 .399 r
.5624 .66483 m
.56444 .66346 L
s
.56444 .66346 m
.56492 .66658 L
s
1 .028 0 r
.62589 .65711 m
.62586 .65713 L
s
.62588 .6571 m
.62589 .65711 L
s
.62588 .65713 m
.62589 .65711 L
s
.62586 .65713 m
.62586 .65711 L
s
.62588 .65713 m
.62586 .65713 L
s
.62586 .65711 m
.62588 .6571 L
s
.62588 .6571 m
.62588 .65713 L
s
.62586 .65711 m
.62588 .65713 L
s
.528 0 1 r
.56322 .62902 m
.56484 .62791 L
s
.56484 .62791 m
.56525 .63043 L
s
0 .19 1 r
.56429 .73083 m
.56609 .73057 L
s
.56458 .72872 m
.56429 .73083 L
s
.56429 .73083 m
.56467 .72974 L
s
.56951 .72491 m
.56429 .73083 L
s
1 0 .399 r
.5624 .66483 m
.56492 .66658 L
s
.528 0 1 r
.56322 .62902 m
.56525 .63043 L
s
0 .19 1 r
.56458 .72872 m
.56467 .72974 L
s
1 0 .282 r
.62665 .6118 m
.62686 .6106 L
s
.62939 .61245 m
.62665 .6118 L
s
.407 0 1 r
.56644 .56095 m
.56793 .56006 L
s
.56793 .56006 m
.56797 .56255 L
s
.56644 .56095 m
.56797 .56255 L
s
.222 0 1 r
.56454 .59454 m
.56606 .59357 L
s
.56606 .59357 m
.56634 .59593 L
s
.56454 .59454 m
.56634 .59593 L
s
.655 0 1 r
.56816 .36754 m
.56803 .36656 L
s
.56803 .36656 m
.56632 .36544 L
s
.56803 .36656 m
.56595 .36804 L
s
1 0 .528 r
.56935 .6925 m
.56884 .69182 L
s
.56884 .69182 m
.56643 .69137 L
s
.56884 .69182 m
.56731 .69432 L
s
1 0 0 r
.62796 .31239 m
.62795 .31238 L
s
.62796 .31237 m
.62796 .31239 L
s
.62796 .31239 m
.62795 .31238 L
s
.62796 .31238 m
.62796 .31239 L
s
.62794 .31234 m
.62796 .31239 L
s
.62796 .31237 m
.62795 .31238 L
s
.62796 .31238 m
.62796 .31237 L
s
.62795 .31238 m
.62795 .31238 L
s
.62795 .31238 m
.62796 .31238 L
s
.62794 .68766 m
.62793 .68771 L
s
.62793 .6877 m
.62792 .6877 L
s
.62794 .6877 m
.62793 .6877 L
s
.62793 .68771 m
.62793 .6877 L
s
.62792 .6877 m
.62793 .68769 L
s
.62792 .6877 m
.62793 .68771 L
s
.62793 .68769 m
.62794 .6877 L
s
.62793 .68771 m
.62794 .6877 L
s
.62793 .68769 m
.62793 .68771 L
s
0 .19 1 r
.56467 .72974 m
.56609 .73057 L
s
.655 0 1 r
.56595 .36804 m
.56816 .36754 L
s
.56632 .36544 m
.56595 .36804 L
s
.56595 .36804 m
.56645 .36642 L
s
.57243 .36028 m
.56595 .36804 L
s
1 0 .072 r
.56392 .34075 m
.56642 .34169 L
s
1 0 .528 r
.56643 .69137 m
.56694 .69205 L
s
.56643 .69137 m
.56731 .69432 L
s
.655 0 1 r
.56632 .36544 m
.56645 .36642 L
s
1 0 .282 r
.62686 .6106 m
.62896 .60925 L
s
.62896 .60925 m
.62939 .61245 L
s
0 .279 1 r
.69184 .37817 m
.69319 .37733 L
s
.69319 .37733 m
.69335 .37639 L
s
.69319 .37733 m
.69153 .37611 L
s
.683 0 1 r
.63181 .64081 m
.63039 .64221 L
s
.63165 .63956 m
.63181 .64081 L
s
.63265 .64197 m
.63181 .64081 L
s
1 0 .282 r
.62686 .6106 m
.62939 .61245 L
s
1 0 .528 r
.56731 .69432 m
.56935 .6925 L
s
.56731 .69432 m
.56694 .69205 L
s
.57021 .6824 m
.56731 .69432 L
s
0 .279 1 r
.69153 .37611 m
.69184 .37817 L
s
.69335 .37639 m
.69153 .37611 L
s
.69153 .37611 m
.69199 .37723 L
s
.69684 .38197 m
.69153 .37611 L
s
.528 0 1 r
.57002 .40183 m
.5698 .40087 L
s
.5698 .40087 m
.56815 .39981 L
s
.5698 .40087 m
.56782 .40234 L
s
0 .279 1 r
.69199 .37723 m
.69184 .37817 L
s
.729 0 1 r
.7541 .52795 m
.76093 .5203 L
s
.655 0 1 r
.56645 .36642 m
.56816 .36754 L
s
.683 0 1 r
.63039 .64221 m
.63024 .64096 L
s
.63265 .64197 m
.63039 .64221 L
s
.528 0 1 r
.56782 .40234 m
.57002 .40183 L
s
.56815 .39981 m
.56782 .40234 L
s
.56782 .40234 m
.56837 .40077 L
s
.57415 .39471 m
.56782 .40234 L
s
.56815 .39981 m
.56837 .40077 L
s
1 0 0 r
.63105 .61753 m
.6415 .62438 L
s
1 0 .072 r
.56918 .66897 m
.57446 .68129 L
s
1 0 .528 r
.56694 .69205 m
.56935 .6925 L
s
0 .279 1 r
.69335 .37639 m
.69199 .37723 L
s
0 .19 1 r
.56951 .27509 m
.57475 .28102 L
s
.683 0 1 r
.63024 .64096 m
.63165 .63956 L
s
.63165 .63956 m
.63265 .64197 L
s
1 0 .524 r
.63383 .38022 m
.63516 .37855 L
s
.63516 .37855 m
.63466 .37674 L
s
.63516 .37855 m
.63216 .37788 L
s
.992 0 1 r
.57164 .43734 m
.57106 .43635 L
s
.57106 .43635 m
.56928 .43529 L
s
.57106 .43635 m
.56911 .4381 L
s
1 0 .524 r
.63216 .37788 m
.63383 .38022 L
s
.63466 .37674 m
.63216 .37788 L
s
.63216 .37788 m
.63333 .37841 L
s
.64261 .3809 m
.63216 .37788 L
s
1 0 .528 r
.57021 .3176 m
.57312 .32955 L
s
.57349 .32726 m
.57108 .32771 L
s
.574 .3266 m
.57349 .32726 L
s
.57312 .32955 m
.57349 .32726 L
s
.528 0 1 r
.56837 .40077 m
.57002 .40183 L
s
.683 0 1 r
.63024 .64096 m
.63265 .64197 L
s
1 0 .072 r
.57445 .67871 m
.57195 .67965 L
s
.57486 .678 m
.57445 .67871 L
s
.57446 .68129 m
.57445 .67871 L
s
1 0 .528 r
.57108 .32771 m
.57159 .32705 L
s
.57312 .32955 m
.57108 .32771 L
s
.729 0 1 r
.76028 .52182 m
.76054 .52294 L
s
.75858 .52073 m
.76028 .52182 L
s
.76093 .5203 m
.76028 .52182 L
s
.992 0 1 r
.56911 .4381 m
.57164 .43734 L
s
.56928 .43529 m
.56911 .4381 L
s
.56911 .4381 m
.56985 .43628 L
s
.57588 .42917 m
.56911 .4381 L
s
.56928 .43529 m
.56985 .43628 L
s
1 0 .524 r
.63333 .37841 m
.63383 .38022 L
s
1 0 .072 r
.57195 .67965 m
.57236 .67894 L
s
.57446 .68129 m
.57195 .67965 L
s
0 .19 1 r
.57436 .27992 m
.57294 .28075 L
s
.57446 .27891 m
.57436 .27992 L
s
.57475 .28102 m
.57436 .27992 L
s
.655 0 1 r
.57243 .63972 m
.57894 .6475 L
s
.729 0 1 r
.75884 .52185 m
.75858 .52073 L
s
.75858 .52073 m
.76093 .5203 L
s
1 0 .524 r
.63466 .37674 m
.63333 .37841 L
s
0 .279 1 r
.69684 .61803 m
.70217 .61215 L
s
0 .19 1 r
.57294 .28075 m
.57304 .27974 L
s
.57475 .28102 m
.57294 .28075 L
s
.992 0 1 r
.56985 .43628 m
.57164 .43734 L
s
1 0 .528 r
.574 .3266 m
.57312 .32955 L
s
.57159 .32705 m
.57312 .32955 L
s
.57159 .32705 m
.574 .3266 L
s
.528 0 1 r
.57415 .60529 m
.5805 .61295 L
s
.729 0 1 r
.76054 .52294 m
.75884 .52185 L
s
.76093 .5203 m
.76054 .52294 L
s
0 .19 1 r
.57304 .27974 m
.57446 .27891 L
s
.57446 .27891 m
.57475 .28102 L
s
1 0 .072 r
.57486 .678 m
.57446 .68129 L
s
.57236 .67894 m
.57446 .68129 L
s
.729 0 1 r
.75884 .52185 m
.76093 .5203 L
s
0 .19 1 r
.57304 .27974 m
.57475 .28102 L
s
1 0 0 r
.64041 .62293 m
.6386 .62472 L
s
.64021 .6213 m
.64041 .62293 L
s
.6415 .62438 m
.64041 .62293 L
s
1 0 .072 r
.57236 .67894 m
.57486 .678 L
s
0 .279 1 r
.7017 .61328 m
.70186 .61422 L
s
.70035 .61243 m
.7017 .61328 L
s
.70217 .61215 m
.7017 .61328 L
s
.655 0 1 r
.57842 .64586 m
.57671 .64699 L
s
.57856 .64489 m
.57842 .64586 L
s
.57894 .6475 m
.57842 .64586 L
s
.992 0 1 r
.57588 .57083 m
.58266 .57979 L
s
.73 0 1 r
.70121 .43274 m
.70294 .43167 L
s
.70294 .43167 m
.70316 .43053 L
s
.70294 .43167 m
.70085 .4301 L
s
0 .279 1 r
.70051 .61337 m
.70035 .61243 L
s
.70035 .61243 m
.70217 .61215 L
s
1 0 0 r
.6386 .62472 m
.6384 .62309 L
s
.6415 .62438 m
.6386 .62472 L
s
.655 0 1 r
.57671 .64699 m
.57685 .64602 L
s
.57894 .6475 m
.57671 .64699 L
s
.73 0 1 r
.70085 .4301 m
.70121 .43274 L
s
.70316 .43053 m
.70085 .4301 L
s
.70085 .4301 m
.70143 .4316 L
s
.70753 .43777 m
.70085 .4301 L
s
.528 0 1 r
.57994 .61136 m
.57829 .61242 L
s
.58017 .6104 m
.57994 .61136 L
s
.5805 .61295 m
.57994 .61136 L
s
.73 0 1 r
.70143 .4316 m
.70121 .43274 L
s
.992 0 1 r
.5819 .57795 m
.58012 .57902 L
s
.58248 .57697 m
.5819 .57795 L
s
.58266 .57979 m
.5819 .57795 L
s
0 .279 1 r
.70186 .61422 m
.70051 .61337 L
s
.70217 .61215 m
.70186 .61422 L
s
.528 0 1 r
.57829 .61242 m
.57852 .61147 L
s
.5805 .61295 m
.57829 .61242 L
s
0 .279 1 r
.70051 .61337 m
.70217 .61215 L
s
1 0 0 r
.6384 .62309 m
.64021 .6213 L
s
.64021 .6213 m
.6415 .62438 L
s
.655 0 1 r
.57685 .64602 m
.57856 .64489 L
s
.57856 .64489 m
.57894 .6475 L
s
.992 0 1 r
.58012 .57902 m
.5807 .57805 L
s
.58266 .57979 m
.58012 .57902 L
s
.655 0 1 r
.57685 .64602 m
.57894 .6475 L
s
.73 0 1 r
.70316 .43053 m
.70143 .4316 L
s
1 0 0 r
.6384 .62309 m
.6415 .62438 L
s
.528 0 1 r
.57852 .61147 m
.58017 .6104 L
s
.58017 .6104 m
.5805 .61295 L
s
.57852 .61147 m
.5805 .61295 L
s
.269 0 1 r
.64364 .35926 m
.64468 .35796 L
s
.64468 .35796 m
.64429 .35653 L
s
.64468 .35796 m
.64233 .35743 L
s
.859 0 1 r
.58324 .34669 m
.58289 .34608 L
s
.58289 .34608 m
.58084 .3453 L
s
.58289 .34608 m
.58116 .34801 L
s
.269 0 1 r
.64233 .35743 m
.64364 .35926 L
s
.64429 .35653 m
.64233 .35743 L
s
.64233 .35743 m
.64325 .35783 L
s
.65052 .35976 m
.64233 .35743 L
s
.992 0 1 r
.5807 .57805 m
.58248 .57697 L
s
.58248 .57697 m
.58266 .57979 L
s
.5807 .57805 m
.58266 .57979 L
s
1 0 .524 r
.64261 .6191 m
.65311 .61606 L
s
.859 0 1 r
.58084 .3453 m
.5812 .34591 L
s
.58084 .3453 m
.58116 .34801 L
s
.655 0 1 r
.58371 .38533 m
.58356 .38434 L
s
.58356 .38434 m
.58184 .38323 L
s
.58356 .38434 m
.58147 .38584 L
s
0 .264 1 r
.76851 .44599 m
.76986 .44513 L
s
.76986 .44513 m
.77006 .44423 L
s
.76986 .44513 m
.7682 .4439 L
s
.859 0 1 r
.58116 .34801 m
.58324 .34669 L
s
.58116 .34801 m
.5812 .34591 L
s
.58559 .33793 m
.58116 .34801 L
s
.269 0 1 r
.64325 .35783 m
.64364 .35926 L
s
0 .264 1 r
.7682 .4439 m
.76851 .44599 L
s
.77006 .44423 m
.7682 .4439 L
s
.7682 .4439 m
.76872 .44508 L
s
.77364 .44993 m
.7682 .4439 L
s
.655 0 1 r
.58147 .38584 m
.58371 .38533 L
s
.58184 .38323 m
.58147 .38584 L
s
.58147 .38584 m
.58199 .38422 L
s
.58798 .37804 m
.58147 .38584 L
s
0 .264 1 r
.76872 .44508 m
.76851 .44599 L
s
.655 0 1 r
.58184 .38323 m
.58199 .38422 L
s
.269 0 1 r
.64429 .35653 m
.64325 .35783 L
s
1 0 .615 r
.58494 .42126 m
.58454 .42015 L
s
.58454 .42015 m
.58257 .41893 L
s
.58454 .42015 m
.58227 .42197 L
s
1 0 .93 r
.77054 .4848 m
.77267 .48413 L
s
.77267 .48413 m
.77326 .48345 L
s
.77267 .48413 m
.77106 .48199 L
s
.73 0 1 r
.70753 .56223 m
.71424 .55453 L
s
.859 0 1 r
.5812 .34591 m
.58324 .34669 L
s
0 .264 1 r
.77006 .44423 m
.76872 .44508 L
s
1 0 .615 r
.58227 .42197 m
.58494 .42126 L
s
.58257 .41893 m
.58227 .42197 L
s
.58227 .42197 m
.58297 .42005 L
s
.58971 .41261 m
.58227 .42197 L
s
.655 0 1 r
.58199 .38422 m
.58371 .38533 L
s
1 0 .93 r
.77112 .48412 m
.77054 .4848 L
s
.77106 .48199 m
.77054 .4848 L
s
1 0 .615 r
.58257 .41893 m
.58297 .42005 L
s
.4 0 1 r
.58725 .70059 m
.5868 .70004 L
s
.5868 .70004 m
.58486 .69968 L
s
.5868 .70004 m
.58559 .70206 L
s
1 0 .93 r
.77326 .48345 m
.77106 .48199 L
s
.77106 .48199 m
.77112 .48412 L
s
.77526 .49267 m
.77106 .48199 L
s
.4 0 1 r
.58486 .69968 m
.5853 .70023 L
s
.58486 .69968 m
.58559 .70206 L
s
1 0 0 r
.64733 .33396 m
.64733 .33396 L
s
.64733 .33395 m
.64733 .33396 L
s
.64733 .33396 m
.64733 .33395 L
s
.64734 .33396 m
.64733 .33396 L
s
.64735 .33395 m
.64733 .33396 L
s
.64733 .33396 m
.64734 .33396 L
s
.64734 .33396 m
.64733 .33395 L
s
.64733 .33395 m
.64733 .33395 L
s
.64733 .33395 m
.64733 .33396 L
s
.64735 .66605 m
.64738 .66606 L
s
.64738 .66605 m
.64737 .66606 L
s
.64737 .66605 m
.64738 .66605 L
s
.64738 .66606 m
.64738 .66605 L
s
.64737 .66606 m
.64736 .66605 L
s
.64738 .66606 m
.64737 .66606 L
s
.64736 .66605 m
.64737 .66605 L
s
.64737 .66605 m
.64738 .66606 L
s
.64736 .66605 m
.64738 .66606 L
s
.859 0 1 r
.58559 .66207 m
.59002 .67218 L
s
.4 0 1 r
.58559 .70206 m
.58725 .70059 L
s
.58559 .70206 m
.5853 .70023 L
s
.58793 .69241 m
.58559 .70206 L
s
1 0 .615 r
.58297 .42005 m
.58494 .42126 L
s
.73 0 1 r
.71365 .55604 m
.71387 .55717 L
s
.71191 .55497 m
.71365 .55604 L
s
.71424 .55453 m
.71365 .55604 L
s
1 0 .524 r
.65192 .6166 m
.65142 .61842 L
s
.65059 .61492 m
.65192 .6166 L
s
.65311 .61606 m
.65192 .6166 L
s
1 0 .93 r
.77326 .48345 m
.77112 .48412 L
s
0 .264 1 r
.77364 .55007 m
.7791 .54403 L
s
.859 0 1 r
.58998 .67007 m
.58793 .67085 L
s
.59034 .66947 m
.58998 .67007 L
s
.59002 .67218 m
.58998 .67007 L
s
.4 0 1 r
.5853 .70023 m
.58725 .70059 L
s
.73 0 1 r
.71214 .5561 m
.71191 .55497 L
s
.71191 .55497 m
.71424 .55453 L
s
.4 0 1 r
.59055 .31541 m
.5886 .31577 L
s
.591 .31488 m
.59055 .31541 L
s
.59027 .31726 m
.59055 .31541 L
s
.58793 .30759 m
.59027 .31726 L
s
.859 0 1 r
.58793 .67085 m
.58829 .67025 L
s
.59002 .67218 m
.58793 .67085 L
s
.655 0 1 r
.58798 .62196 m
.5945 .62979 L
s
.269 0 1 r
.65052 .64024 m
.65875 .6379 L
s
1 0 .524 r
.65009 .61674 m
.65059 .61492 L
s
.65059 .61492 m
.65311 .61606 L
s
1 0 .93 r
.77526 .50733 m
.77947 .49663 L
s
.4 0 1 r
.5886 .31577 m
.58905 .31523 L
s
.59027 .31726 m
.5886 .31577 L
s
1 0 .524 r
.65142 .61842 m
.65009 .61674 L
s
.65311 .61606 m
.65142 .61842 L
s
.73 0 1 r
.71387 .55717 m
.71214 .5561 L
s
.71424 .55453 m
.71387 .55717 L
s
0 .264 1 r
.77857 .54522 m
.77879 .54612 L
s
.77722 .54436 m
.77857 .54522 L
s
.7791 .54403 m
.77857 .54522 L
s
1 0 .93 r
.7794 .49877 m
.78 .49945 L
s
.77726 .4981 m
.7794 .49877 L
s
.77947 .49663 m
.7794 .49877 L
s
.73 0 1 r
.71214 .5561 m
.71424 .55453 L
s
1 0 .615 r
.58971 .58739 m
.59718 .59677 L
s
.859 0 1 r
.59034 .66947 m
.59002 .67218 L
s
.58829 .67025 m
.59002 .67218 L
s
.4 0 1 r
.591 .31488 m
.59027 .31726 L
s
.58905 .31523 m
.59027 .31726 L
s
0 .264 1 r
.77744 .54526 m
.77722 .54436 L
s
.77722 .54436 m
.7791 .54403 L
s
1 0 .93 r
.77786 .49877 m
.77726 .4981 L
s
.77726 .4981 m
.77947 .49663 L
s
.859 0 1 r
.58829 .67025 m
.59034 .66947 L
s
.765 0 1 r
.65422 .3983 m
.65596 .39721 L
s
.65596 .39721 m
.65614 .39602 L
s
.65596 .39721 m
.65382 .39564 L
s
1 0 .524 r
.65009 .61674 m
.65311 .61606 L
s
.4 0 1 r
.58905 .31523 m
.591 .31488 L
s
.655 0 1 r
.59397 .62815 m
.59226 .62927 L
s
.59413 .62717 m
.59397 .62815 L
s
.5945 .62979 m
.59397 .62815 L
s
.765 0 1 r
.65382 .39564 m
.65422 .3983 L
s
.65614 .39602 m
.65382 .39564 L
s
.65382 .39564 m
.65439 .3971 L
s
.6606 .40323 m
.65382 .39564 L
s
0 .264 1 r
.77879 .54612 m
.77744 .54526 L
s
.7791 .54403 m
.77879 .54612 L
s
.765 0 1 r
.65439 .3971 m
.65422 .3983 L
s
0 .264 1 r
.77744 .54526 m
.7791 .54403 L
s
.655 0 1 r
.59226 .62927 m
.59241 .62829 L
s
.5945 .62979 m
.59226 .62927 L
s
1 0 .615 r
.59646 .59483 m
.5945 .59606 L
s
.59687 .59373 m
.59646 .59483 L
s
.59718 .59677 m
.59646 .59483 L
s
1 0 .93 r
.77947 .49663 m
.78 .49945 L
s
.77786 .49877 m
.77947 .49663 L
s
.78 .49945 m
.77786 .49877 L
s
.269 0 1 r
.65781 .6383 m
.65743 .63974 L
s
.65678 .637 m
.65781 .6383 L
s
.65875 .6379 m
.65781 .6383 L
s
1 0 .615 r
.5945 .59606 m
.5949 .59495 L
s
.59718 .59677 m
.5945 .59606 L
s
.765 0 1 r
.65614 .39602 m
.65439 .3971 L
s
.655 0 1 r
.59241 .62829 m
.59413 .62717 L
s
.59413 .62717 m
.5945 .62979 L
s
.59241 .62829 m
.5945 .62979 L
s
.269 0 1 r
.6564 .63843 m
.65678 .637 L
s
.65678 .637 m
.65875 .6379 L
s
.65743 .63974 m
.6564 .63843 L
s
.65875 .6379 m
.65743 .63974 L
s
1 0 .399 r
.59851 .40478 m
.59828 .40357 L
s
.59828 .40357 m
.59621 .40225 L
s
.59828 .40357 m
.5958 .4054 L
s
1 0 .615 r
.5949 .59495 m
.59687 .59373 L
s
.59687 .59373 m
.59718 .59677 L
s
.5949 .59495 m
.59718 .59677 L
s
0 .295 1 r
.7219 .41148 m
.72325 .41064 L
s
.72325 .41064 m
.72343 .40973 L
s
.72325 .41064 m
.7216 .40941 L
s
1 0 .399 r
.5958 .4054 m
.59851 .40478 L
s
.59621 .40225 m
.5958 .4054 L
s
.5958 .4054 m
.59645 .40345 L
s
.60365 .39594 m
.5958 .4054 L
s
.269 0 1 r
.6564 .63843 m
.65875 .6379 L
s
1 0 .399 r
.59621 .40225 m
.59645 .40345 L
s
0 .295 1 r
.7216 .40941 m
.7219 .41148 L
s
.72343 .40973 m
.7216 .40941 L
s
.7216 .40941 m
.72208 .41057 L
s
.72692 .4154 m
.7216 .40941 L
s
.72208 .41057 m
.7219 .41148 L
s
.859 0 1 r
.60055 .36768 m
.60075 .36635 L
s
.60075 .36635 m
.59927 .36488 L
s
.60075 .36635 m
.59821 .36739 L
s
.765 0 1 r
.6606 .59677 m
.66739 .58916 L
s
.859 0 1 r
.59821 .36739 m
.60055 .36768 L
s
.59927 .36488 m
.59821 .36739 L
s
.59821 .36739 m
.59907 .36621 L
s
.60671 .36184 m
.59821 .36739 L
s
0 .295 1 r
.72343 .40973 m
.72208 .41057 L
s
1 0 .399 r
.59645 .40345 m
.59851 .40478 L
s
.859 0 1 r
.59927 .36488 m
.59907 .36621 L
s
.59907 .36621 m
.60055 .36768 L
s
.765 0 1 r
.66682 .59063 m
.667 .59182 L
s
.66507 .58954 m
.66682 .59063 L
s
.66739 .58916 m
.66682 .59063 L
s
0 .295 1 r
.72692 .5846 m
.73225 .5786 L
s
1 0 .072 r
.60573 .38813 m
.60599 .38649 L
s
.60599 .38649 m
.60419 .3847 L
s
.60599 .38649 m
.60289 .38774 L
s
.765 0 1 r
.66525 .59073 m
.66507 .58954 L
s
.66507 .58954 m
.66739 .58916 L
s
1 0 .072 r
.60289 .38774 m
.60573 .38813 L
s
.60419 .3847 m
.60289 .38774 L
s
.60289 .38774 m
.60393 .38634 L
s
.61329 .3811 m
.60289 .38774 L
s
0 .015 1 r
.79133 .47724 m
.79301 .4767 L
s
.79301 .4767 m
.79349 .47614 L
s
.79301 .4767 m
.79173 .47501 L
s
1 .033 0 r
.60307 .66429 m
.60308 .66428 L
s
.60308 .66428 m
.60309 .66427 L
s
.60308 .66428 m
.60306 .66426 L
s
.60306 .66426 m
.60307 .66429 L
s
.60309 .66427 m
.60306 .66426 L
s
.60306 .66426 m
.60308 .66428 L
s
.60316 .66436 m
.60306 .66426 L
s
.60308 .66428 m
.60307 .66429 L
s
.60309 .66427 m
.60308 .66428 L
s
.60324 .33557 m
.60325 .33558 L
s
.60322 .33556 m
.60324 .33557 L
s
.60325 .33555 m
.60324 .33557 L
s
.60316 .33564 m
.60325 .33555 L
s
.60323 .33557 m
.60322 .33556 L
s
.60322 .33556 m
.60325 .33555 L
s
.60325 .33558 m
.60323 .33557 L
s
.60325 .33555 m
.60325 .33558 L
s
.60323 .33557 m
.60325 .33555 L
s
1 0 .399 r
.60365 .60406 m
.61153 .61357 L
s
0 .015 1 r
.79181 .47668 m
.79133 .47724 L
s
.79173 .47501 m
.79133 .47724 L
s
.79349 .47614 m
.79173 .47501 L
s
.79173 .47501 m
.79181 .47668 L
s
.79513 .48342 m
.79173 .47501 L
s
1 0 .072 r
.60419 .3847 m
.60393 .38634 L
s
.765 0 1 r
.667 .59182 m
.66525 .59073 L
s
.66739 .58916 m
.667 .59182 L
s
0 .295 1 r
.73177 .57977 m
.73196 .58068 L
s
.73041 .57892 m
.73177 .57977 L
s
.73225 .5786 m
.73177 .57977 L
s
.765 0 1 r
.66525 .59073 m
.66739 .58916 L
s
.702 0 1 r
.73135 .46669 m
.73307 .4656 L
s
.73307 .4656 m
.7333 .46448 L
s
.73307 .4656 m
.73096 .46405 L
s
0 .295 1 r
.7306 .57983 m
.73041 .57892 L
s
.73041 .57892 m
.73225 .5786 L
s
1 0 .072 r
.60393 .38634 m
.60573 .38813 L
s
0 .015 1 r
.79349 .47614 m
.79181 .47668 L
s
.702 0 1 r
.73096 .46405 m
.73135 .46669 L
s
.7333 .46448 m
.73096 .46405 L
s
.73096 .46405 m
.73158 .46557 L
s
.73777 .47172 m
.73096 .46405 L
s
.73158 .46557 m
.73135 .46669 L
s
.859 0 1 r
.60671 .63816 m
.61525 .64372 L
s
0 .295 1 r
.73196 .58068 m
.7306 .57983 L
s
.73225 .5786 m
.73196 .58068 L
s
.7306 .57983 m
.73225 .5786 L
s
1 0 .399 r
.61086 .61159 m
.60879 .61293 L
s
.61111 .6104 m
.61086 .61159 L
s
.61153 .61357 m
.61086 .61159 L
s
0 .015 1 r
.79513 .51658 m
.79853 .50815 L
s
1 .033 0 r
.60793 .65881 m
.60795 .6588 L
s
.60795 .6588 m
.60796 .65879 L
s
.60795 .6588 m
.60793 .65878 L
s
.60793 .65878 m
.60793 .65881 L
s
.60796 .65879 m
.60793 .65878 L
s
.60793 .65878 m
.60794 .6588 L
s
.60802 .65887 m
.60793 .65878 L
s
.60794 .6588 m
.60793 .65881 L
s
.60796 .65879 m
.60794 .6588 L
s
.60811 .34106 m
.60812 .34107 L
s
.60809 .34104 m
.60811 .34106 L
s
.60812 .34104 m
.60811 .34106 L
s
.60802 .34113 m
.60812 .34104 L
s
.6081 .34106 m
.60809 .34104 L
s
.60809 .34104 m
.60812 .34104 L
s
.60812 .34107 m
.6081 .34106 L
s
.60812 .34104 m
.60812 .34107 L
s
.6081 .34106 m
.60812 .34104 L
s
.702 0 1 r
.7333 .46448 m
.73158 .46557 L
s
0 .015 1 r
.79845 .50983 m
.79893 .51038 L
s
.79677 .50929 m
.79845 .50983 L
s
.79853 .50815 m
.79845 .50983 L
s
1 0 .399 r
.60879 .61293 m
.60904 .61174 L
s
.61153 .61357 m
.60879 .61293 L
s
0 .015 1 r
.79725 .50984 m
.79677 .50929 L
s
.79677 .50929 m
.79853 .50815 L
s
1 .011 0 r
.61015 .31013 m
.61015 .31015 L
s
.61015 .31012 m
.61015 .31013 L
s
.61015 .31013 m
.61014 .31013 L
s
.61016 .31013 m
.61015 .31013 L
s
.61015 .31015 m
.61015 .31013 L
s
.61015 .31015 m
.61016 .31013 L
s
.61014 .31013 m
.61015 .31015 L
s
.61016 .31013 m
.61015 .31012 L
s
.61015 .31012 m
.61014 .31013 L
s
.61015 .68985 m
.61016 .68982 L
s
.61016 .68982 m
.61017 .68983 L
s
.61014 .68983 m
.61016 .68982 L
s
.61016 .68982 m
.61016 .68982 L
s
.61017 .68983 m
.61016 .68984 L
s
.61016 .68982 m
.61017 .68983 L
s
.61016 .68984 m
.61014 .68983 L
s
.61014 .68983 m
.61016 .68982 L
s
.61016 .68982 m
.61016 .68984 L
s
0 .015 1 r
.79853 .50815 m
.79893 .51038 L
s
.79725 .50984 m
.79853 .50815 L
s
1 0 .399 r
.60904 .61174 m
.61111 .6104 L
s
.61111 .6104 m
.61153 .61357 L
s
0 .015 1 r
.79893 .51038 m
.79725 .50984 L
s
1 0 .399 r
.60904 .61174 m
.61153 .61357 L
s
0 .279 1 r
.67479 .37675 m
.67616 .3759 L
s
.67616 .3759 m
.67631 .37495 L
s
.67616 .3759 m
.67448 .37466 L
s
.859 0 1 r
.61437 .64253 m
.61289 .64401 L
s
.61418 .64121 m
.61437 .64253 L
s
.61525 .64372 m
.61437 .64253 L
s
0 .279 1 r
.67448 .37466 m
.67479 .37675 L
s
.67631 .37495 m
.67448 .37466 L
s
.67448 .37466 m
.67493 .3758 L
s
.67983 .38059 m
.67448 .37466 L
s
.67493 .3758 m
.67479 .37675 L
s
.702 0 1 r
.73777 .52828 m
.74461 .52058 L
s
.859 0 1 r
.61289 .64401 m
.6127 .64269 L
s
.61525 .64372 m
.61289 .64401 L
s
1 0 .072 r
.61329 .6189 m
.62375 .62557 L
s
0 .279 1 r
.67631 .37495 m
.67493 .3758 L
s
1 0 .528 r
.61609 .37875 m
.61745 .37707 L
s
.61745 .37707 m
.61694 .37523 L
s
.61745 .37707 m
.61442 .37637 L
s
.859 0 1 r
.6127 .64269 m
.61418 .64121 L
s
.61418 .64121 m
.61525 .64372 L
s
1 0 .528 r
.61442 .37637 m
.61609 .37875 L
s
.61694 .37523 m
.61442 .37637 L
s
.61442 .37637 m
.61558 .37692 L
s
.62492 .37951 m
.61442 .37637 L
s
.859 0 1 r
.6127 .64269 m
.61525 .64372 L
s
.702 0 1 r
.74398 .52211 m
.74422 .52323 L
s
.74226 .52102 m
.74398 .52211 L
s
.74461 .52058 m
.74398 .52211 L
s
1 0 .528 r
.61558 .37692 m
.61609 .37875 L
s
.702 0 1 r
.7425 .52214 m
.74226 .52102 L
s
.74226 .52102 m
.74461 .52058 L
s
1 0 .528 r
.61694 .37523 m
.61558 .37692 L
s
0 .279 1 r
.67983 .61941 m
.68519 .61346 L
s
.702 0 1 r
.74422 .52323 m
.7425 .52214 L
s
.74461 .52058 m
.74422 .52323 L
s
.7425 .52214 m
.74461 .52058 L
s
1 0 .072 r
.62267 .62415 m
.62088 .62595 L
s
.62243 .62251 m
.62267 .62415 L
s
.62375 .62557 m
.62267 .62415 L
s
0 .279 1 r
.68473 .6146 m
.68488 .61555 L
s
.68336 .61375 m
.68473 .6146 L
s
.68519 .61346 m
.68473 .6146 L
s
.73 0 1 r
.68423 .43195 m
.68599 .43087 L
s
.68599 .43087 m
.6862 .42972 L
s
.68599 .43087 m
.68387 .42929 L
s
0 .279 1 r
.68351 .6147 m
.68336 .61375 L
s
.68336 .61375 m
.68519 .61346 L
s
1 0 .072 r
.62088 .62595 m
.62063 .62431 L
s
.62375 .62557 m
.62088 .62595 L
s
.73 0 1 r
.68387 .42929 m
.68423 .43195 L
s
.6862 .42972 m
.68387 .42929 L
s
.68387 .42929 m
.68444 .4308 L
s
.6906 .43705 m
.68387 .42929 L
s
.68444 .4308 m
.68423 .43195 L
s
0 .279 1 r
.68488 .61555 m
.68351 .6147 L
s
.68519 .61346 m
.68488 .61555 L
s
.68351 .6147 m
.68519 .61346 L
s
1 0 .072 r
.62063 .62431 m
.62243 .62251 L
s
.62243 .62251 m
.62375 .62557 L
s
.73 0 1 r
.6862 .42972 m
.68444 .4308 L
s
1 0 .072 r
.62063 .62431 m
.62375 .62557 L
s
.4 0 1 r
.62576 .35758 m
.62685 .35623 L
s
.62685 .35623 m
.62644 .35474 L
s
.62685 .35623 m
.6244 .35567 L
s
.6244 .35567 m
.62576 .35758 L
s
.62644 .35474 m
.6244 .35567 L
s
.6244 .35567 m
.62534 .35609 L
s
.63289 .35812 m
.6244 .35567 L
s
1 0 .528 r
.62492 .62049 m
.63548 .61733 L
s
0 .326 1 r
.75238 .44542 m
.75372 .44457 L
s
.75372 .44457 m
.75392 .44367 L
s
.75372 .44457 m
.75207 .44335 L
s
.4 0 1 r
.62534 .35609 m
.62576 .35758 L
s
0 .326 1 r
.75207 .44335 m
.75238 .44542 L
s
.75392 .44367 m
.75207 .44335 L
s
.75207 .44335 m
.75257 .44452 L
s
.75746 .44934 m
.75207 .44335 L
s
.4 0 1 r
.62644 .35474 m
.62534 .35609 L
s
0 .326 1 r
.75257 .44452 m
.75238 .44542 L
s
1 0 .945 r
.7544 .48461 m
.75656 .48395 L
s
.75656 .48395 m
.75714 .48326 L
s
.75656 .48395 m
.75494 .48178 L
s
.73 0 1 r
.6906 .56295 m
.69734 .55517 L
s
0 .326 1 r
.75392 .44367 m
.75257 .44452 L
s
1 .285 0 r
.81729 .48485 m
.81741 .48478 L
s
.81741 .48478 m
.81743 .48471 L
s
.81741 .48478 m
.81727 .48468 L
s
.81727 .48468 m
.81729 .48485 L
s
.81743 .48471 m
.81727 .48468 L
s
.81727 .48468 m
.81731 .48478 L
s
.81772 .48518 m
.81727 .48468 L
s
.81731 .48478 m
.81729 .48485 L
s
1 0 .945 r
.75498 .48393 m
.7544 .48461 L
s
.75494 .48178 m
.7544 .48461 L
s
1 .285 0 r
.81743 .48471 m
.81731 .48478 L
s
.81772 .51482 m
.81818 .51431 L
s
1 0 .945 r
.75714 .48326 m
.75494 .48178 L
s
.75494 .48178 m
.75498 .48393 L
s
.75909 .49258 m
.75494 .48178 L
s
1 .285 0 r
.81814 .51441 m
.81815 .51448 L
s
.81802 .51434 m
.81814 .51441 L
s
.81818 .51431 m
.81814 .51441 L
s
.81804 .51441 m
.81802 .51434 L
s
.81802 .51434 m
.81818 .51431 L
s
.81815 .51448 m
.81804 .51441 L
s
.81818 .51431 m
.81815 .51448 L
s
.81804 .51441 m
.81818 .51431 L
s
1 .011 0 r
.62974 .33204 m
.62974 .33205 L
s
.62975 .33203 m
.62974 .33204 L
s
.62976 .33205 m
.62974 .33204 L
s
.62976 .33205 m
.62974 .33205 L
s
.62975 .33203 m
.62976 .33205 L
s
.62975 .33204 m
.62976 .33205 L
s
.6297 .33201 m
.62976 .33205 L
s
.62975 .33204 m
.62975 .33203 L
s
.62974 .33205 m
.62975 .33204 L
s
.6297 .66799 m
.62964 .66804 L
s
.62966 .66804 m
.62965 .66803 L
s
.62965 .66803 m
.62965 .66802 L
s
.62965 .66803 m
.62964 .66804 L
s
.62966 .66803 m
.62966 .66804 L
s
.62964 .66804 m
.62966 .66804 L
s
.62965 .66802 m
.62966 .66803 L
s
.62965 .66802 m
.62964 .66804 L
s
.62964 .66804 m
.62966 .66803 L
s
.73 0 1 r
.69676 .5567 m
.69698 .55784 L
s
.69501 .55561 m
.69676 .5567 L
s
.69734 .55517 m
.69676 .5567 L
s
1 0 .528 r
.6343 .6179 m
.6338 .61973 L
s
.63294 .6162 m
.6343 .6179 L
s
.63548 .61733 m
.6343 .6179 L
s
1 0 .945 r
.75714 .48326 m
.75498 .48393 L
s
0 .326 1 r
.75746 .55066 m
.76286 .54465 L
s
.73 0 1 r
.69522 .55676 m
.69501 .55561 L
s
.69501 .55561 m
.69734 .55517 L
s
.4 0 1 r
.63289 .64188 m
.64142 .63943 L
s
1 0 .528 r
.63244 .61804 m
.63294 .6162 L
s
.63294 .6162 m
.63548 .61733 L
s
1 0 .945 r
.75909 .50742 m
.76326 .49659 L
s
1 0 .528 r
.6338 .61973 m
.63244 .61804 L
s
.63548 .61733 m
.6338 .61973 L
s
.73 0 1 r
.69698 .55784 m
.69522 .55676 L
s
.69734 .55517 m
.69698 .55784 L
s
0 .326 1 r
.76236 .54583 m
.76256 .54673 L
s
.76101 .54498 m
.76236 .54583 L
s
.76286 .54465 m
.76236 .54583 L
s
1 0 .945 r
.76321 .49876 m
.76381 .49942 L
s
.76105 .49809 m
.76321 .49876 L
s
.76326 .49659 m
.76321 .49876 L
s
.73 0 1 r
.69522 .55676 m
.69734 .55517 L
s
0 .326 1 r
.76121 .54587 m
.76101 .54498 L
s
.76101 .54498 m
.76286 .54465 L
s
1 0 .945 r
.76164 .49876 m
.76105 .49809 L
s
.76105 .49809 m
.76326 .49659 L
s
.797 0 1 r
.63654 .39711 m
.63832 .396 L
s
.63832 .396 m
.63848 .39478 L
s
.63832 .396 m
.63613 .39441 L
s
1 0 .528 r
.63244 .61804 m
.63548 .61733 L
s
.797 0 1 r
.63613 .39441 m
.63654 .39711 L
s
.63848 .39478 m
.63613 .39441 L
s
.63613 .39441 m
.6367 .39589 L
s
.64304 .40209 m
.63613 .39441 L
s
0 .326 1 r
.76256 .54673 m
.76121 .54587 L
s
.76286 .54465 m
.76256 .54673 L
s
.797 0 1 r
.6367 .39589 m
.63654 .39711 L
s
0 .326 1 r
.76121 .54587 m
.76286 .54465 L
s
1 0 .945 r
.76326 .49659 m
.76381 .49942 L
s
.76164 .49876 m
.76326 .49659 L
s
.76381 .49942 m
.76164 .49876 L
s
.4 0 1 r
.64047 .63985 m
.64006 .64135 L
s
.63937 .63849 m
.64047 .63985 L
s
.64142 .63943 m
.64047 .63985 L
s
.797 0 1 r
.63848 .39478 m
.6367 .39589 L
s
.4 0 1 r
.63897 .63999 m
.63937 .63849 L
s
.63937 .63849 m
.64142 .63943 L
s
.64006 .64135 m
.63897 .63999 L
s
.64142 .63943 m
.64006 .64135 L
s
0 .295 1 r
.70506 .41044 m
.70644 .40959 L
s
.70644 .40959 m
.70661 .40866 L
s
.70644 .40959 m
.70477 .40834 L
s
.4 0 1 r
.63897 .63999 m
.64142 .63943 L
s
0 .295 1 r
.70477 .40834 m
.70506 .41044 L
s
.70661 .40866 m
.70477 .40834 L
s
.70477 .40834 m
.70524 .40952 L
s
.71013 .4144 m
.70477 .40834 L
s
.70524 .40952 m
.70506 .41044 L
s
.797 0 1 r
.64304 .59791 m
.64998 .59019 L
s
0 .295 1 r
.70661 .40866 m
.70524 .40952 L
s
.797 0 1 r
.64939 .59169 m
.64957 .59291 L
s
.64761 .59057 m
.64939 .59169 L
s
.64998 .59019 m
.64939 .59169 L
s
0 .295 1 r
.71013 .5856 m
.7155 .57952 L
s
.797 0 1 r
.64778 .59179 m
.64761 .59057 L
s
.64761 .59057 m
.64998 .59019 L
s
0 .066 1 r
.77538 .47701 m
.77707 .47649 L
s
.77707 .47649 m
.77754 .47594 L
s
.77707 .47649 m
.7758 .47479 L
s
.77585 .47647 m
.77538 .47701 L
s
.7758 .47479 m
.77538 .47701 L
s
.77754 .47594 m
.7758 .47479 L
s
.7758 .47479 m
.77585 .47647 L
s
.77911 .48323 m
.7758 .47479 L
s
0 .295 1 r
.71502 .58071 m
.7152 .58163 L
s
.71365 .57985 m
.71502 .58071 L
s
.7155 .57952 m
.71502 .58071 L
s
.797 0 1 r
.64957 .59291 m
.64778 .59179 L
s
.64998 .59019 m
.64957 .59291 L
s
.64778 .59179 m
.64998 .59019 L
s
.702 0 1 r
.71459 .4663 m
.71633 .4652 L
s
.71633 .4652 m
.71656 .46406 L
s
.71633 .4652 m
.7142 .46363 L
s
0 .295 1 r
.71383 .58077 m
.71365 .57985 L
s
.71365 .57985 m
.7155 .57952 L
s
.702 0 1 r
.7142 .46363 m
.71459 .4663 L
s
.71656 .46406 m
.7142 .46363 L
s
.7142 .46363 m
.71481 .46516 L
s
.72106 .47139 m
.7142 .46363 L
s
0 .066 1 r
.77754 .47594 m
.77585 .47647 L
s
.702 0 1 r
.71481 .46516 m
.71459 .4663 L
s
0 .295 1 r
.7152 .58163 m
.71383 .58077 L
s
.7155 .57952 m
.7152 .58163 L
s
.71383 .58077 m
.7155 .57952 L
s
0 .066 1 r
.77911 .51677 m
.78243 .50832 L
s
.702 0 1 r
.71656 .46406 m
.71481 .46516 L
s
0 .066 1 r
.78238 .51001 m
.78285 .51054 L
s
.78069 .50948 m
.78238 .51001 L
s
.78243 .50832 m
.78238 .51001 L
s
.78116 .51001 m
.78069 .50948 L
s
.78069 .50948 m
.78243 .50832 L
s
.78243 .50832 m
.78285 .51054 L
s
.78116 .51001 m
.78243 .50832 L
s
.78285 .51054 m
.78116 .51001 L
s
0 .19 1 r
.65722 .37522 m
.65864 .37434 L
s
.65864 .37434 m
.65877 .37335 L
s
.65864 .37434 m
.65689 .37306 L
s
.65689 .37306 m
.65722 .37522 L
s
.65877 .37335 m
.65689 .37306 L
s
.65689 .37306 m
.65735 .37423 L
s
.66241 .37918 m
.65689 .37306 L
s
.65735 .37423 m
.65722 .37522 L
s
.702 0 1 r
.72106 .52861 m
.72794 .52083 L
s
0 .19 1 r
.65877 .37335 m
.65735 .37423 L
s
.702 0 1 r
.72732 .52238 m
.72755 .52351 L
s
.72558 .52127 m
.72732 .52238 L
s
.72794 .52083 m
.72732 .52238 L
s
.72581 .5224 m
.72558 .52127 L
s
.72558 .52127 m
.72794 .52083 L
s
0 .19 1 r
.66241 .62082 m
.66795 .61468 L
s
.702 0 1 r
.72755 .52351 m
.72581 .5224 L
s
.72794 .52083 m
.72755 .52351 L
s
.72581 .5224 m
.72794 .52083 L
s
0 .19 1 r
.66748 .61586 m
.66762 .61684 L
s
.66606 .61497 m
.66748 .61586 L
s
.66795 .61468 m
.66748 .61586 L
s
.771 0 1 r
.6668 .4311 m
.6686 .43 L
s
.6686 .43 m
.66879 .42882 L
s
.6686 .43 m
.66644 .42838 L
s
0 .19 1 r
.66619 .61596 m
.66606 .61497 L
s
.66606 .61497 m
.66795 .61468 L
s
.771 0 1 r
.66644 .42838 m
.6668 .4311 L
s
.66879 .42882 m
.66644 .42838 L
s
.66644 .42838 m
.66699 .42992 L
s
.67326 .4363 m
.66644 .42838 L
s
.66699 .42992 m
.6668 .4311 L
s
0 .19 1 r
.66762 .61684 m
.66619 .61596 L
s
.66795 .61468 m
.66762 .61684 L
s
.66619 .61596 m
.66795 .61468 L
s
.771 0 1 r
.66879 .42882 m
.66699 .42992 L
s
0 .326 1 r
.73578 .44477 m
.73714 .44391 L
s
.73714 .44391 m
.73733 .443 L
s
.73714 .44391 m
.73547 .44267 L
s
.73547 .44267 m
.73578 .44477 L
s
.73733 .443 m
.73547 .44267 L
s
.73547 .44267 m
.73596 .44386 L
s
.7409 .44874 m
.73547 .44267 L
s
.73596 .44386 m
.73578 .44477 L
s
1 0 .945 r
.73781 .48443 m
.74 .48376 L
s
.74 .48376 m
.74058 .48307 L
s
.74 .48376 m
.73836 .48156 L
s
.771 0 1 r
.67326 .5637 m
.6801 .55575 L
s
0 .326 1 r
.73733 .443 m
.73596 .44386 L
s
1 0 .945 r
.73838 .48374 m
.73781 .48443 L
s
.73836 .48156 m
.73781 .48443 L
s
1 .195 0 r
.80158 .48477 m
.80166 .48472 L
s
.80166 .48472 m
.80167 .48466 L
s
.80166 .48472 m
.80156 .48464 L
s
.80156 .48464 m
.80158 .48477 L
s
.80167 .48466 m
.80156 .48464 L
s
.80156 .48464 m
.80159 .48471 L
s
.80189 .48501 m
.80156 .48464 L
s
.80159 .48471 m
.80158 .48477 L
s
.80167 .48466 m
.80159 .48471 L
s
.80189 .51499 m
.80221 .51463 L
s
.80218 .5147 m
.80219 .51475 L
s
.8021 .51465 m
.80218 .5147 L
s
.80221 .51463 m
.80218 .5147 L
s
1 0 .945 r
.74058 .48307 m
.73836 .48156 L
s
.73836 .48156 m
.73838 .48374 L
s
.74254 .4925 m
.73836 .48156 L
s
1 .195 0 r
.80211 .5147 m
.8021 .51465 L
s
.8021 .51465 m
.80221 .51463 L
s
.80219 .51475 m
.80211 .5147 L
s
.80221 .51463 m
.80219 .51475 L
s
.80211 .5147 m
.80221 .51463 L
s
.771 0 1 r
.67953 .55731 m
.67973 .55848 L
s
.67773 .5562 m
.67953 .55731 L
s
.6801 .55575 m
.67953 .55731 L
s
1 0 .945 r
.74058 .48307 m
.73838 .48374 L
s
0 .326 1 r
.7409 .55126 m
.74634 .54518 L
s
.771 0 1 r
.67793 .55737 m
.67773 .5562 L
s
.67773 .5562 m
.6801 .55575 L
s
1 0 .945 r
.74254 .5075 m
.74674 .49655 L
s
.771 0 1 r
.67973 .55848 m
.67793 .55737 L
s
.6801 .55575 m
.67973 .55848 L
s
0 .326 1 r
.74584 .54638 m
.74603 .54728 L
s
.74447 .54551 m
.74584 .54638 L
s
.74634 .54518 m
.74584 .54638 L
s
1 0 .945 r
.74671 .49874 m
.74729 .49942 L
s
.74451 .49807 m
.74671 .49874 L
s
.74674 .49655 m
.74671 .49874 L
s
.771 0 1 r
.67793 .55737 m
.6801 .55575 L
s
0 .326 1 r
.74466 .54642 m
.74447 .54551 L
s
.74447 .54551 m
.74634 .54518 L
s
1 0 .945 r
.74509 .49874 m
.74451 .49807 L
s
.74451 .49807 m
.74674 .49655 L
s
0 .326 1 r
.74603 .54728 m
.74466 .54642 L
s
.74634 .54518 m
.74603 .54728 L
s
.74466 .54642 m
.74634 .54518 L
s
1 0 .945 r
.74674 .49655 m
.74729 .49942 L
s
.74509 .49874 m
.74674 .49655 L
s
.74729 .49942 m
.74509 .49874 L
s
0 .222 1 r
.68773 .4093 m
.68916 .40842 L
s
.68916 .40842 m
.68932 .40747 L
s
.68916 .40842 m
.68743 .40713 L
s
.68743 .40713 m
.68773 .4093 L
s
.68932 .40747 m
.68743 .40713 L
s
.68743 .40713 m
.6879 .40834 L
s
.69293 .41338 m
.68743 .40713 L
s
.6879 .40834 m
.68773 .4093 L
s
.68932 .40747 m
.6879 .40834 L
s
.69293 .58662 m
.69845 .58035 L
s
0 .066 1 r
.75896 .47674 m
.76067 .47621 L
s
.76067 .47621 m
.76113 .47565 L
s
.76067 .47621 m
.75938 .47449 L
s
.75942 .47619 m
.75896 .47674 L
s
.75938 .47449 m
.75896 .47674 L
s
.76113 .47565 m
.75938 .47449 L
s
.75938 .47449 m
.75942 .47619 L
s
.76272 .48303 m
.75938 .47449 L
s
0 .222 1 r
.69797 .58157 m
.69815 .58252 L
s
.69655 .58069 m
.69797 .58157 L
s
.69845 .58035 m
.69797 .58157 L
s
.729 0 1 r
.6974 .46587 m
.69918 .46475 L
s
.69918 .46475 m
.69939 .46359 L
s
.69918 .46475 m
.69701 .46315 L
s
0 .222 1 r
.69672 .58164 m
.69655 .58069 L
s
.69655 .58069 m
.69845 .58035 L
s
.729 0 1 r
.69701 .46315 m
.6974 .46587 L
s
.69939 .46359 m
.69701 .46315 L
s
.69701 .46315 m
.69761 .46471 L
s
.70395 .47105 m
.69701 .46315 L
s
0 .066 1 r
.76113 .47565 m
.75942 .47619 L
s
.729 0 1 r
.69761 .46471 m
.6974 .46587 L
s
0 .222 1 r
.69815 .58252 m
.69672 .58164 L
s
.69845 .58035 m
.69815 .58252 L
s
.69672 .58164 m
.69845 .58035 L
s
0 .066 1 r
.76272 .51697 m
.76606 .50842 L
s
.729 0 1 r
.69939 .46359 m
.69761 .46471 L
s
0 .066 1 r
.76601 .51013 m
.76648 .51067 L
s
.7643 .50959 m
.76601 .51013 L
s
.76606 .50842 m
.76601 .51013 L
s
.76477 .51013 m
.7643 .50959 L
s
.7643 .50959 m
.76606 .50842 L
s
.76606 .50842 m
.76648 .51067 L
s
.76477 .51013 m
.76606 .50842 L
s
.76648 .51067 m
.76477 .51013 L
s
.729 0 1 r
.70395 .52895 m
.71092 .52103 L
s
.7103 .52261 m
.71052 .52376 L
s
.70852 .52148 m
.7103 .52261 L
s
.71092 .52103 m
.7103 .52261 L
s
.70874 .52263 m
.70852 .52148 L
s
.70852 .52148 m
.71092 .52103 L
s
.71052 .52376 m
.70874 .52263 L
s
.71092 .52103 m
.71052 .52376 L
s
.70874 .52263 m
.71092 .52103 L
s
0 .264 1 r
.71869 .44405 m
.7201 .44316 L
s
.7201 .44316 m
.72028 .44222 L
s
.7201 .44316 m
.71838 .44189 L
s
.71838 .44189 m
.71869 .44405 L
s
.72028 .44222 m
.71838 .44189 L
s
.71838 .44189 m
.71887 .44311 L
s
.72394 .44812 m
.71838 .44189 L
s
.71887 .44311 m
.71869 .44405 L
s
1 0 .93 r
.72076 .48426 m
.72298 .48356 L
s
.72298 .48356 m
.72355 .48285 L
s
.72298 .48356 m
.72129 .48134 L
s
0 .264 1 r
.72028 .44222 m
.71887 .44311 L
s
1 0 .93 r
.72132 .48354 m
.72076 .48426 L
s
.72129 .48134 m
.72076 .48426 L
s
1 .195 0 r
.78536 .48458 m
.78544 .48453 L
s
.78544 .48453 m
.78545 .48448 L
s
.78544 .48453 m
.78534 .48446 L
s
.78534 .48446 m
.78536 .48458 L
s
.78545 .48448 m
.78534 .48446 L
s
.78534 .48446 m
.78537 .48453 L
s
.78567 .48483 m
.78534 .48446 L
s
.78537 .48453 m
.78536 .48458 L
s
.78545 .48448 m
.78537 .48453 L
s
.78567 .51517 m
.786 .5148 L
s
1 0 .93 r
.72355 .48285 m
.72129 .48134 L
s
.72129 .48134 m
.72132 .48354 L
s
.7256 .49241 m
.72129 .48134 L
s
1 .195 0 r
.78597 .51488 m
.78598 .51493 L
s
.78588 .51482 m
.78597 .51488 L
s
.786 .5148 m
.78597 .51488 L
s
.7859 .51488 m
.78588 .51482 L
s
.78588 .51482 m
.786 .5148 L
s
.78598 .51493 m
.7859 .51488 L
s
.786 .5148 m
.78598 .51493 L
s
.7859 .51488 m
.786 .5148 L
s
1 0 .93 r
.72355 .48285 m
.72132 .48354 L
s
0 .264 1 r
.72394 .55188 m
.72951 .54562 L
s
1 0 .93 r
.7256 .50759 m
.72991 .49651 L
s
0 .264 1 r
.72901 .54685 m
.72919 .54779 L
s
.7276 .54596 m
.72901 .54685 L
s
.72951 .54562 m
.72901 .54685 L
s
1 0 .93 r
.72987 .49873 m
.73045 .49943 L
s
.72765 .49803 m
.72987 .49873 L
s
.72991 .49651 m
.72987 .49873 L
s
0 .264 1 r
.72778 .54689 m
.7276 .54596 L
s
.7276 .54596 m
.72951 .54562 L
s
1 0 .93 r
.72822 .49873 m
.72765 .49803 L
s
.72765 .49803 m
.72991 .49651 L
s
0 .264 1 r
.72919 .54779 m
.72778 .54689 L
s
.72951 .54562 m
.72919 .54779 L
s
.72778 .54689 m
.72951 .54562 L
s
1 0 .93 r
.72991 .49651 m
.73045 .49943 L
s
.72822 .49873 m
.72991 .49651 L
s
.73045 .49943 m
.72822 .49873 L
s
0 .015 1 r
.74204 .47641 m
.74379 .47586 L
s
.74379 .47586 m
.74425 .47528 L
s
.74379 .47586 m
.74245 .4741 L
s
.7425 .47584 m
.74204 .47641 L
s
.74245 .4741 m
.74204 .47641 L
s
.74425 .47528 m
.74245 .4741 L
s
.74245 .4741 m
.7425 .47584 L
s
.74593 .48282 m
.74245 .4741 L
s
.74425 .47528 m
.7425 .47584 L
s
.74593 .51718 m
.74941 .50844 L
s
.74936 .51019 m
.74982 .51075 L
s
.7476 .50963 m
.74936 .51019 L
s
.74941 .50844 m
.74936 .51019 L
s
.74806 .51019 m
.7476 .50963 L
s
.7476 .50963 m
.74941 .50844 L
s
.74941 .50844 m
.74982 .51075 L
s
.74806 .51019 m
.74941 .50844 L
s
.74982 .51075 m
.74806 .51019 L
s
1 .285 0 r
.76861 .4843 m
.76873 .48422 L
s
.76873 .48422 m
.76875 .48415 L
s
.76873 .48422 m
.76859 .48412 L
s
.76859 .48412 m
.76861 .4843 L
s
.76875 .48415 m
.76859 .48412 L
s
.76859 .48412 m
.76863 .48422 L
s
.76906 .48464 m
.76859 .48412 L
s
.76863 .48422 m
.76861 .4843 L
s
.76875 .48415 m
.76863 .48422 L
s
.76906 .51536 m
.76953 .51483 L
s
.76948 .51494 m
.7695 .51501 L
s
.76937 .51486 m
.76948 .51494 L
s
.76953 .51483 m
.76948 .51494 L
s
.76938 .51494 m
.76937 .51486 L
s
.76937 .51486 m
.76953 .51483 L
s
.7695 .51501 m
.76938 .51494 L
s
.76953 .51483 m
.7695 .51501 L
s
.76938 .51494 m
.76953 .51483 L
s
0 g
.001 w
[ .01 .01 ] 0 setdash
.19888 .17456 m
.78139 .11915 L
s
.78139 .11915 m
.78139 .88085 L
s
.78139 .88085 m
.19888 .82544 L
s
.19888 .82544 m
.19888 .17456 L
s
.83789 .13482 m
.78139 .11915 L
s
.78139 .11915 m
.78139 .88085 L
s
.78139 .88085 m
.83789 .86518 L
s
.83789 .86518 m
.83789 .13482 L
s
.003 w
[ ] 0 setdash
.83789 .86518 m
.78139 .88085 L
s
.25 Mabswid
.82613 .86844 m
.82613 .86219 L
s
gsave
.82613 .88094 -73.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.81023 .87285 m
.81023 .8666 L
s
gsave
.81023 .88535 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.79395 .87737 m
.79395 .87112 L
s
gsave
.79395 .88987 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.82219 .86953 m
.82219 .86578 L
s
.81823 .87063 m
.81823 .86688 L
s
.81424 .87174 m
.81424 .86799 L
s
.8062 .87397 m
.8062 .87022 L
s
.80214 .87509 m
.80214 .87134 L
s
.79805 .87623 m
.79805 .87248 L
s
.83004 .86735 m
.83004 .8636 L
s
.83393 .86627 m
.83393 .86252 L
s
.8378 .8652 m
.8378 .86145 L
s
.78982 .87851 m
.78982 .87476 L
s
.78566 .87966 m
.78566 .87591 L
s
.78148 .88082 m
.78148 .87707 L
s
gsave
.81023 .94785 -68.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{413, 413},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0001WB000`400?l00000o`00003oo`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00_@3oool300000=d0oooo002m0?ooo`030>k^kP000000k^k^0=d0oooo002n0?ooo`030000
003oool0oooo0=`0oooo002m0?ooo`030>k^kP000000k^k^0=d0oooo002m0?ooo`<0A4A4g@3oool0
0;`0oooo00D0QhN704A4A03oool0<S8b0:VYZ@3L0?ooo`00^`3oool01`3<c<`000000>k^kP3oool0
c<c<0000003<c<`0f`3oool00;/0oooo0P0000000`0b<S80oooo0000000200000=/0oooo003o0?oo
oih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oo
obh0oooo100000000`2j^[X0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH0?oo
o`3oool0G@3oool00?l0oooo;P3oool04@3<c<`0k^k^0?ooo`3<c<`0EEEE0?ooo`000000V9RH0?oo
o`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000005l0oooo003o0?ooobl0oooo00<0c<c<0>k^
kP3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`1M0?ooo`00o`3oool`0?ooo`050:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo05d0oooo003o0?oooc00oooo00D0gMgM06IVIP3oool0oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0G@3oool00?l0oooo;P3oool0
101gMgL0oooo0?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo05d0oooo003b0?ooo`<0000000<0oooo09RHV00000000P0000000`2HV9P0oooo
09RHV0030000000309RHV03oool0oooo02X0oooo00@0000009RHV02HV9P000000P3oool02`000000
V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000005l0oooo003c0?ooo`0>0000003o
ool0oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV000000/0?ooo`0409RH
V0000000000009RHV080oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool0G@3oool00?<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo09X0oooo003c0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`2J0?ooo`00l`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0VP3oool00;h0oooo00D0V9RH0000
00000000000009RHV00`0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`2J0?ooo`00_P3oool01@000000V9RH0?ooo`2HV9P000000300oooo00h0
00000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH000009`0oooo
002n0?ooo`050000003oool0oooo0?ooo`000000;`3oool01@0Q8B4000000?ooo`3oool0V9RH00<0
000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0d0?ooo`H00000H03oool00;h0oooo
00D000000?ooo`3oool0oooo0000001Y0?ooo`/000000`3oool00`000000oooo000000020?ooo`<0
0000F`3oool00;h0oooo00D000000?ooo`3oool0oooo0000001O0?ooo`d000001`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00001I0?ooo`00R@3oool3000000030?oo
o`2HV9P000000080000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0T0?ooo`050000
003oool0oooo0?ooo`000000E@3oool:000000030?ooo`000000000000D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0`00001C0?ooo`00
RP3oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0
00009P3oool01@000000V9RH0?ooo`2HV9P0000004X0oooo2`0000030?ooo`<00000303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo0P00001A0?ooo`00RP3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0903oool01@2H
V9P00000000000000000V9RH0400oooo3@0000000`3oool000000?ooo`0:0?ooo`030000003oool0
oooo02l0oooo0`00001;0?ooo`00P03oool7000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo05h0oooo3P00000;0?ooo`030000003oool0
oooo03`0oooo0`00001:0?ooo`00RP3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0E03oool<000000030?ooo`000000000000P0oooo00<00000
0?ooo`3oool0@@3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo04P0oooo001F0?oo
o`@0000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo
0240oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo04X0oooo3@0000080?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01@000003
0?ooo`8000002@3oool00`000000oooo0?ooo`180?ooo`00EP3oool04@3<c<`0k^k^0?ooo`3<c<`0
EEEE0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000002<0oooo00h0
00000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH00000440oooo
3@0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool3000000<0oooo
1P00000E0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030<c<c03^k^h0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0803oool01@0Q8B40
00000?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0e0?oo
o`X000002@3oool00`000000oooo0?ooo`120?ooo`D000000`3oool2000000/0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`180?ooo`00C`3oool700000080oooo00D0ZJVY0>k^kP3o
ool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0F`3oool=0000
00H0oooo00<000000?ooo`3oool0@03oool300000080oooo1@00000H0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0B03oool005P0oooo00D0gMgM06IVIP3oool0oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0D@3oool:000000030?ooo`0000000000
00D0oooo00<000000?ooo`3oool0@@3oool5000000<0oooo0P00000R0?ooo`030000003oool0oooo
0140oooo0`00001:0?ooo`00EP3oool0101gMgL0oooo0?ooo`0000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo04H0oooo2`0000070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0>@3oool5000004D0oooo00<000000?ooo`3oool0B03o
ool005H0oooo00@0000009RHV02HV9P000000P3oool02`000000V9RH0?ooo`2HV9P000000?ooo`00
0000V9RH0?ooo`2HV9P0000003h0oooo3@0000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0=P3oool3000000<0oooo1@00001=0?ooo`030000003oool0oooo00`0oooo10000000
0`2j^[X0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0:@3oool0
05H0oooo00@0V9RH000000000000V9RH0P3oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P0
0`0000000`2HV9P0oooo0?ooo`0b0?ooo``00000103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool5000000<0oooo0P00001H0?ooo`030000
003oool0oooo00`0oooo0140c<c<0>k^kP3oool0c<c<05EEE@3oool0000009RHV03oool0V9RH0000
003oool0000009RHV03oool0V9RH0000000[0?ooo`00T03oool;000000H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0e0?ooo`<000000`3oool5000004h0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0=0?ooo`030<c<c03^k^h0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0:@3oool008H0oooo3@0000030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool5000000<0oooo0P00001I0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool700000080oooo00D0ZJVY0>k^
kP3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0:@3oool0
07/0oooo3@0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool30000
00<0oooo1@00001V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool01@3M
gMd0IVIV0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Y
0?ooo`00L@3oool:000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0_0?oo
o`030?m8003oool0oooo0080oooo0`0000000`3oool0odP00?m8000200000740oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`0407MgM`3oool0oooo00000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0:@3oool006L0oooo3@00
00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0[0?ooo`@0000000<0odP00?ooo`3oool00P00000;0?ooo`80oc40K03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00`0oooo00@0000009RHV02HV9P000000P3oool02`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000002/0oooo001L0?ooo`d000001@3oool0
0`000000oooo0?ooo`0k0?ooo`<000000`3oool5000000h0oooo0P3o<@2;0?ooo`030000003oool0
oooo00`0oooo00@0V9RH000000000000V9RH0P3oool01`2HV9P00000000000000000V9RH0?ooo`2H
V9P00`0000000`2HV9P0oooo0?ooo`0Y0?ooo`00E`3oool5000000T0oooo00<000000?ooo`3oool0
>P3oool5000000<0oooo0P00000Q0?ooo`030?la003oool0oooo00H0oooo00<0oc400?ooo`3oool0
N@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`02000000<0oooo0`00
000b0?ooo`<000000`3oool5000003D0oooo00<0odP00?ooo`3oool01P3oool00`3oB000oooo0?oo
o`1b0?ooo`030000003oool0oooo04P0oooo001G0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool2000002L0oooo1@0000020?ooo`800000@03oool00`3oB000oooo0?ooo`1U0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool03@3oool5
000001L0oooo1@00002d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool0
05L0oooo00<000000?ooo`3oool0503oool3000000@0oooo0`0000030?ooo`D00000_03oool00`00
0000oooo0?ooo`0B0?ooo`800000BP3oool00740oooo1000001:0?ooo`8000?oN`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo04T0oooo
0`000ol70?ooo`8000?oLP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo
001b0?ooo`030000003oool0oooo04P0oooo00<000?o0?ooo`3oool01P3oool2000@o`80oooo00<0
00?o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0500oooo00<0013o0?ooo`004?l00P3oool010000ol0oooo0?ooo`3o
ool4000@oh00oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`1H0?ooo`80013o0P3oool2000@o`80oooo00@000?o000@o`004?l0013oN@3o
ool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`1b0?ooo`03000@o`3oool0
oooo00D0oooo0P000ol20?ooo`80013o0`3oool30003oe`0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`1i0?ooo`030003o`3oool0oooo
00T0oooo0P000omK0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0
oooo00<000000?ooo`3oool0Q@3oool00`000ol0oooo0?ooo`1J0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0CP3oool20?l0kWL0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?oo
o`1<0?ooo`<0o`3^1P3oool00`3o0?40oooo0?ooo`1_0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0?`3oool20013o`X0oooo00<0o`3^
0?ooo`3oool00P3oool30?l0kP80oooo0P3o0?460?ooo`030013o`3oool0oooo07d0oooo00<00000
0?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0o0?oo
o`030013o`3oool0oooo00D0oooo00<005?o0?ooo`3oool0203oool20?l0kP80o`3a00<0oooo0?l0
l@3o0?400`3oool20?l0l@8004?o1@3oool00`00Dol0oooo0?ooo`1e0?ooo`030000003oool0oooo
04P0oooo001G0?ooo`030000003oool0oooo05T0oooo00<004?o0?ooo`3oool01@3oool2001Co`H0
oooo00H005?o0?ooo`3oool0oooo0?l0kP3o0?450?ooo`<0o`3a00@0oooo0?l0l@3o0?4004?o0`3o
ool20?l0kP030?ooo`00Dol005?o00@0oooo00<005?o0?ooo`3oool0KP3oool00`000000oooo0?oo
o`180?ooo`00E`3oool00`000000oooo0?ooo`1P0?ooo`03001Co`3oool0oooo00H0oooo00<005?o
0?ooo`3oool0103oool20013o`<0oooo0P3o0?440?ooo`80o`3a00@0o`3^0?ooo`3o0>h0oooo0P00
Dol50?ooo`8005?o103oool00`00@ol0oooo0?ooo`1A0?ooo`030000003oool0oooo0180oooo0P00
001:0?ooo`00E`3oool00`000000oooo0?ooo`1X0?ooo`03001Co`3oool0oooo00D0oooo0P00@ol:
0?ooo`80o`3a0P3oool40?l0kP@0oooo0P00Dol50?ooo`030013o`3oool0oooo0500oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05D0oooo00<004?o0?ooo`3oool0403oool20?l0kPX0oooo0P00@omA0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3o
ool0E03oool00`00@ol0oooo0?ooo`1`0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0B03oool00780oooo00<000000?ooo`3oool0AP3oool20;X0ogl0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`170?ooo`030;X0o`3o
ool0oooo00@0oooo0P2c0?n=0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0AP3oool00`2j0?l0oooo0?ooo`050?ooo`030;<0o`3oool0
oooo00@0oooo00<0/`3o0;X0o`2j0?l0Q@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`00
0000oooo0?ooo`1P0?ooo`030;X0o`3oool0oooo00D0oooo00<0/`3o0?ooo`3oool01@3oool20;<0
o`030?ooo`2j0?l0^P3o0080oooo0P2j0?l00`2c0?l0oooo0?ooo`1l0?ooo`030000003oool0oooo
04P0oooo001G0?ooo`030000003oool0oooo06L0oooo00<0/`3o0?ooo`3oool01@3oool0102c0?l0
oooo0?ooo`3oool20;X0o`80oooo0P2j0?l00`3oool0/`3o0;<0o`040?ooo`030;<0o`3oool0oooo
05l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000
oooo0?ooo`1^0?ooo`030;<0o`3oool0oooo00D0oooo00@0^P3o0?ooo`3oool0oooo0P2c0?l40?oo
o`050;<0o`3oool0oooo0?ooo`00>?l00P3oool00`2j0?l0oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0e0?ooo`03000ho`3oool0oooo0280oooo00<0^P3o0?ooo`3oool02@3oool20;<0
o`80oooo00<003So0?ooo`2j0?l00`3oool00`00Bol0oooo0?ooo`1D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0=@3oool00`00>?l0
oooo0?ooo`050?ooo`03001;o`3oool0oooo02L0oooo00<0/`3o0?ooo`3oool00P00>?l00`3oool0
^P3o0;X0o`020?ooo`03001;o`3oool0oooo00<0oooo00<004_o0?ooo`3oool0C@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo03@0oooo
00<003So0?ooo`3oool01@3oool2001;o`H0oooo00<004_o0?ooo`3oool09P3oool20;X0o`80oooo
0P00Bol50?ooo`03001;o`3oool0oooo00<0oooo00<003So0?ooo`3oool0G03oool00`000000oooo
0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`0c0?ooo`03000ho`3oool0oooo00H0oooo00<0
04_o0?ooo`3oool01@3oool00`00Bol0oooo0?ooo`040?ooo`03000ho`3oool0oooo02X0oooo0P00
Bol40?ooo`03000ho`3oool0oooo05`0oooo00<000000?ooo`3oool0B03oool005L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0k0?ooo`03001;o`3oool0oooo00D0oooo00<004_o
0?ooo`3oool01@3oool00`00>?l0oooo0?ooo`0a0?ooo`03000ho`3oool0oooo05X0oooo0P00001:
0?ooo`00E`3oool00`000000oooo0?ooo`1M0?ooo`03001;o`3oool0oooo00D0oooo00<003So0?oo
o`3oool0<`3oool00`00>?l0oooo0?ooo`140?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0B03oool005L0oooo00<000000?ooo`3oool0I@3oool00`00>?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0
F03oool00`350?l0oooo0?ooo`270?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
B03oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?ooo`030<D0o`3o
ool0oooo00D0oooo00<0^P3o0?ooo`3oool06P3oool00`350?l0oooo0?ooo`1S0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0>`3oool0
0`350?l0oooo0?ooo`050?ooo`80^P3o1P3oool00`2j0?l0oooo0?ooo`0D0?ooo`030<D0o`3oool0
oooo00@0oooo00<0^P3o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04P0oooo001b0?ooo`030000003oool0oooo03X0oooo00<0a@3o0?ooo`3oool01P3oool00`2j
0?l0oooo0?ooo`050?ooo`030;X0o`3oool0oooo00@0oooo00<0a@3o0?ooo`3oool03P3oool20<D0
o`@0oooo00<0^P3o0?ooo`3oool0103oool00`2j0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo
04P0oooo001b0?ooo`030000003oool0oooo0480oooo00<0^P3o0?ooo`3oool01@3oool00`2j0?l0
oooo0?ooo`050?ooo`030<D0o`3oool0oooo00h0oooo0P350?l50?ooo`80^P3o103oool00`2j0?l0
oooo0?ooo`040?ooo`030<D0o`3oool0oooo06<0oooo00<000000?ooo`3oool0B03oool005L0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`190?ooo`030;X0o`3oool0oooo00D0oooo
00<0a@3o0?ooo`3oool05P3oool20;X0o`D0oooo0P2j0?l01@3oool0033o0?ooo`3oool0a@3o06D0
oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0J`3oool00`350?l0oooo
0?ooo`0N0?ooo`80^P3o0P3oool2000`o`050?ooo`350?l0a@3o0?ooo`00Aol0B`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo04D0oooo
0P00<?m90?ooo`80033o00<0oooo0<D0o`350?l00P3oool20017o`@0oooo00<004Oo0?ooo`3oool0
@P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003o
ool0oooo04D0oooo00<0033o0?ooo`3oool01@3oool20017odP0oooo0P00Aol50?ooo`8004Oo103o
ool00`00<?l0oooo0?ooo`0k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03o
ool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Y0?ooo`03000`o`3oool0
oooo00H0oooo00<004Oo0?ooo`3oool0103oool20017o`H0oooo00<0033o0?ooo`3oool0?`3oool2
0017o`D0oooo0P00<?lk0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool0
0780oooo00<000000?ooo`3oool0<@3oool00`00Aol0oooo0?ooo`050?ooo`030017o`3oool0oooo
00D0oooo00<0033o0?ooo`3oool0AP3oool2000`oc/0oooo00<000000?ooo`3oool04P3oool20000
04X0oooo001b0?ooo`030000003oool0oooo03P0oooo00<004Oo0?ooo`3oool01@3oool00`00<?l0
oooo0?ooo`2J0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo03l0oooo
00<0033o0?ooo`3oool0V`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0B03oool005L0oooo00<00000
0?ooo`3oool0C03oool20<`0ocX0oooo00<0c03o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo04d0oooo00<0c03o0?oo
o`3oool0103oool20<<0oc80oooo00<0c03o0?ooo`3oool0103oool00`330?l0oooo0?ooo`040?oo
o`030<<0o`3oool0oooo04T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?oo
o`00E`3oool00`000000oooo0?ooo`1<0?ooo`030<`0o`3oool0oooo00D0oooo0P330?l50?ooo`80
``3o1P3oool00`3<0?l0oooo0?ooo`0S0?ooo`80c03o1@3oool20<<0o`@0oooo00<0``3o0?ooo`3o
ool0103oool00`3<0?l0oooo0?ooo`120?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0B03oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0`0?ooo`030<`0
o`3oool0oooo00D0oooo00<0``3o0?ooo`3oool01P3oool00`330?l0oooo0?ooo`030?ooo`80c03o
9P3oool00`3<0?l0oooo0?ooo`030?ooo`80``3o103oool00`1V0?l0``3o0<<0o`040?ooo`030<`0
o`3oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3o
ool00`000000oooo0?ooo`0T0?ooo`0306H0o`3oool0oooo0100oooo00<0``3o0?ooo`3oool01P3o
ool00`330?l0oooo0?ooo`040?ooo`030<`0o`3oool0oooo0340oooo00<0IP3o0<<0o`330?l0103o
ool00`140?l0c03o0?l200120?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03o
ool00780oooo00<000000?ooo`3oool08`3oool206H0o`H0oooo00<0A03o0?ooo`3oool04@3oool0
0`330?l0oooo0?ooo`040?ooo`030<`0o`3oool0oooo0380oooo00<0IP3o0?ooo`3oool0103oool0
0`140?l0c03o0<`0o`040?ooo`0304@0o`3oool0o`000540oooo00<000000?ooo`3oool0B03oool0
0780oooo00<000000?ooo`3oool0903oool00`1V0?l0oooo0?ooo`030?ooo`030?l0Q`140?l0oooo
00D0oooo0P140?m80?ooo`0306H0o`3oool0oooo00<0oooo00<0A03o0?ooo`3oool0103oool00`14
0?l0oooo0?ooo`040?ooo`0306H0o`3oool0o`0004X0oooo00<000000?ooo`3oool0B03oool005L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0S0?ooo`0306H0o`3oool0oooo00<0
oooo0P3o08L00`140?l0oooo0?ooo`030?ooo`030?l0QP140?l0A03o00D0oooo0P1V0?li0?ooo`03
0?l0Q`3oool0oooo00@0oooo0P1V0?l50?ooo`80A03o1@3oool00`140?l0oooo0?ooo`040?ooo`03
06H0o`3oool0oooo00D0oooo0P3o0P130?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000
003oool0oooo03h0oooo00<0IP3o0?ooo`3oool0103oool00`3o08L0oooo0?ooo`040?ooo`80o`26
1P3oool00`3o08H0IP3o0?ooo`0h0?ooo`030?l0Q`3oool0oooo00@0oooo00<0o`260?ooo`3oool0
1@3oool00`140?l0oooo0?ooo`030?ooo`80A03o1@3oool00`1V0?l0oooo0?ooo`0d0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0=P3o
ool00`3o0P00oooo0?ooo`0;0?ooo`030?l0Q`140?l0oooo00D0oooo00<0o`2604@0o`3oool0103o
ool20?l0QPD0oooo0P3o08Lc0?ooo`030?l0Q`3oool0oooo00@0oooo00<0o`260?ooo`3oool0103o
ool00`3o08H0oooo0?ooo`050?ooo`0304@0o`3oool0oooo00<0oooo0P1V0?le0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0?P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0Q`3oool0oooo00@0oooo00<0o`260?ooo`3oool01P3oool0
0`3o08H0oooo0?ooo`040?ooo`030?l0Q`3oool0oooo0380oooo00<0o`270?ooo`3oool00`3oool0
0`3o08H0oooo0?ooo`040?ooo`030?l0QP3oool0oooo00@0oooo00<0o`270?ooo`3oool01@3oool0
0`1V0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo0`00000@0?ooo`<0000000<0oooo
09RHV00000000P0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo02T0oooo001b0?oo
o`030000003oool0oooo02T0oooo00<0o`270?l0003oool0103oool00`3o08H0oooo0?ooo`050?oo
o`030?l0QP3oool0oooo00D0oooo00<0o`270?ooo`3oool0<@3oool30?l0Q`D0oooo00<0o`260?oo
o`3oool00`3oool00`3o08H0oooo0?ooo`040?ooo`030?l0Q`3oool0oooo03/0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`0>0000003oool0oooo0000002HV9P0oooo09RH
V0000000oooo0000002HV9P0oooo09RHV000000[0?ooo`00LP3oool00`000000oooo0?ooo`0W0?oo
o`80o`0B1P3oool0103o0000o`260?ooo`3o0P050?ooo`030?l0QP3oool0oooo00@0oooo00<0o`27
0?ooo`3oool0<`3oool00`3o08L0oooo0?ooo`040?ooo`80o`261@3oool20?l0QP@0oooo00<0o`27
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo02T0oooo001b
0?ooo`030000003oool0oooo02L0oooo00<0o`0B0?ooo`3oool01@3oool20?l000D0oooo0P3o0007
0?ooo`030?l0Q`3oool0oooo0380oooo00<0o`0B0?ooo`3oool0103oool00`3o0000o`260?ooo`04
0?ooo`<0o`26103oool20?l0Q`80o`80D03oool00`000000oooo0?ooo`050?ooo`L000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0:@3o
ool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030?l04P3oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool20?l000H0oooo0P3o018d0?ooo`030?l04P3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o2000o`000?l0QP050?ooo`80o`27203oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0:@3o
ool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030=/0o`3oool0
oooo00<0oooo00<0o`0B0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0o`0B0?ooo`3oool0<P3oool00`3o0180oooo0?ooo`040?ooo`030=/0o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o1`00o`0B0?ooo`0>0?ooo`030?l0003oool0
oooo00@0oooo00<0o`800?ooo`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Y0?ooo`00E`3oool0
0`000000oooo0?ooo`0m0?ooo`80f`3o1@3oool00`3o0180[P3o0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0180oooo0?ooo`0`0?ooo`<0o`0B1P3oool0
0`3K0?l0oooo0?ooo`040?ooo`030:h0o`3oool0oooo00D0oooo00<0o`0B0?ooo`3oool00`3oool0
0`3o1`00oooo0?ooo`040?ooo`030?l8003oool0oooo02h0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0?0?ooo`0>0000003oool0oooo0000002HV9P0oooo09RHV0000000oooo0000
002HV9P0oooo09RHV000000[0?ooo`00E`3oool00`000000oooo0?ooo`0n0?ooo`030=/0o`3oool0
oooo00@0oooo00<0[P3o0?l0IP3o06H0103oool00`3o0000o`180?l0B0040?ooo`030?l0003oool0
oooo00@0oooo00<0o`0B0?ooo`3oool0;@3oool00`3o06H0oooo0?ooo`020?l04PD0oooo00<0f`3o
0?l0003oool01@3oool00`2^0?l0oooo0?l800040?ooo`030:h0o`3oool0o`L000@0oooo00<0f`3o
0?ooo`3oool0103oool00`3o2000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool03P3oool01@0Q8B4000000?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`00
00000`2HV9P0oooo0?ooo`0Y0?ooo`00E`3oool00`000000oooo0?ooo`0_0?ooo`80o`80203oool0
0`3o2000oooo0?ooo`020?ooo`030=/0o`3oool0oooo00@0oooo00<0[P3o0?l0IP3o06H0103oool0
0`2^0?l0o`180?l0B0040?ooo`80f`3o0P3o04P30?ooo`030?l04P3oool0oooo02d0oooo00<0o`1V
0?ooo`3oool0103oool01@3o04P0oooo0=/0o`3K0?l0o`0000@0oooo00<0o`000:h0o`3o0000103o
ool20?l04P030:h0o`3oool0oooo00@0oooo00<0f`3o0?ooo`3o1`001P3oool00`3o2000oooo0?oo
o`0/0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<00000
0?ooo`3oool0703oool00`3o0000oooo0?ooo`050?ooo`030=/0o`3o1`00oooo00@0oooo00<0[P3o
0?ooo`3o06H0103oool00`2^0?l0o`180?ooo`040?ooo`030=/0o`3o04P0o`1800D0oooo0P3o06H[
0?ooo`030?l0IP3oool0oooo00D0oooo00@0o`180?ooo`3K0?l0f`3o0`3oool0103o04P0oooo0:h0
o`2^0?l30?ooo`040?l0IP3oool0[P3o0:h0o`H0oooo00<0f`3o0?ooo`3oool01P3oool20?l802h0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`0[0?ooo`040:h0o`3oool0o`L00?l0IP@0oooo00<0[P3o0?l0B03oool00`3oool0103K0?l0
oooo0?ooo`3o04P40?ooo`80o`1V:@3oool20?l0IPD0oooo00<0o`180?ooo`3o04P01P3oool0103o
04P0oooo0?ooo`2^0?l40?ooo`040?l0IP3oool0[P3o0:h0o`D0oooo0P3K0?lh0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0703oool0
0`3o2000oooo0?ooo`050?ooo`030?l7003oool0oooo00d0oooo00<0o`P00?l0B03oool00`3oool0
103K0?l0oooo0?ooo`3o04P50?ooo`030?l0IP3oool0oooo02H0oooo0P3o06H50?ooo`80o`181@3o
ool20?l0B0L0oooo00<0o`1V0?ooo`3oool01`3oool20=/0odh0oooo00<000000?ooo`3oool0B03o
ool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0[0?ooo`030?l7003oool0
oooo00@0oooo00<0o`P00?ooo`3oool03`3oool00`3o06H0oooo0?ooo`0/0?ooo`030?l0B03oool0
oooo00@0oooo0P3o04P50?ooo`80o`1V1P3oool306H0oe40oooo00<000000?ooo`3oool0B03oool0
05L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0`0?ooo`80o`2M1@3oool20?l0
M4P0oooo0P3o06H70?ooo`0406H0o`3oool0IP3o06H0o`80oooo0`140?l50?ooo`0304@0o`3oool0
oooo0480oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0@@3oool20:L0
o`P0oooo0P3o09d50?ooo`80o`1d1P3oool00`3o07@0oooo0?ooo`0W0?ooo`80o`2M1P3oool01@3o
07@0oooo0?ooo`3oool0Y`3o01/0oooo00@0A03o0?ooo`140?l0A03o0P3oool304@0o`@0oooo0`1V
0?lV0?ooo`030000003oool0oooo0180oooo0P00001:0?ooo`00E`3oool00`000000oooo0?ooo`11
0?ooo`80Y`3o1P3oool01@1c0?l0oooo0?ooo`3oool0o`2M00H0oooo00<0o`1d0?ooo`3oool00`3o
ool00`3o07@0oooo0?ooo`040?ooo`80o`2M803oool00`3o09d0oooo0?ooo`060?ooo`040?l0M03o
ool0oooo0:L0o`<0oooo00D0o`1d0?ooo`3oool0oooo07<0o`040?ooo`80f`3o00<0L`3o0?ooo`3o
ool00P3oool20:h0oa00oooo00D0A03o0?ooo`3oool0oooo06H0o`020?ooo`0306H0o`3oool0oooo
02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<0f`3o0?ooo`3oool02P3oool00`2W0?l0
oooo0?ooo`040?ooo`0307<0o`3oool0oooo0080oooo00@0o`2M0?ooo`1c0?l0L`3o0`3oool0103o
07@0oooo0:L0o`2W0?l20?ooo`030?l0M03oool0oooo00<0oooo0P3o09dO0?ooo`030?l0W@3oool0
oooo00H0oooo00@0o`1d0?ooo`3oool0Y`3o0`3oool00`3o07@0oooo0?ooo`020?ooo`0307<0o`3o
ool0oooo0080f`3o0P3oool01@1c0?l0oooo0?ooo`3oool0[P3o0080oooo00<0Y`3o0?ooo`3oool0
0P3oool20:h0ocH0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3o
ool00`000000oooo0?ooo`0I0?ooo`<0f`3o1@3oool20:h0o`D0oooo00<0Y`3o0?ooo`3oool0103o
ool00`1c0?l0oooo0?ooo`040?ooo`0307<0o`3oool0oooo00<0oooo0P2W0?l30?ooo`030?l0M03o
ool0oooo00@0oooo00<0o`2M0?ooo`3oool06`3oool20?l0W@H0oooo0P3o07@20?ooo`80Y`3o00<0
oooo0?l0M03o07@00`3oool207<0o`80oooo00<0o`2M0=/0o`3K0?l00P1c0?l30?ooo`80[P3o00<0
oooo0:L0o`3oool00`3oool00`2^0?l0oooo0?ooo`050?ooo`80f`3o;`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo0140oooo0`1V0?l6
0?ooo`030=/0o`140?l0f`3o00@0oooo0`2^0?l50?ooo`80[P3o1@3oool00`1c0?l0f`3o0?ooo`04
0?ooo`0307<0o`3oool0oooo00<0oooo00<0Y`3o0?ooo`3oool02@3oool00`3o09d0oooo0?ooo`0R
0?ooo`80o`1d1@3oool20?l0M0<0oooo00@0L`3o0?ooo`3o09d0o`2M0`3oool00`1c0?l0oooo0?oo
o`030?ooo`030:h0o`2W0?l0oooo00<0oooo0P2^0?l50?ooo`80f`3o<@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo0140oooo00<0IP3o
0?ooo`3oool0103oool204@0o`H0oooo00D0A03o0?ooo`140?l0A03o0:h0o`040?ooo`030:h0o`1V
0?l0[P3o00@0oooo0`3K0?l20?ooo`80o@3o1@3oool00`3o0<h0oooo0:L0o`0m0?ooo`80o`2M2@3o
ool20:L0o`/0oooo0P3K0?l2000`odD0oooo00<000000?ooo`3oool0B03oool005L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`0304@0o`3oool0oooo00@0oooo0P140?l5
0?ooo`80IP3o0P3oool208L0o`H0oooo00@0f`3o0?ooo`3m0?l0o@3o1@3oool20?l0cPD0oooo0P3o
0<hO0?ooo`030?d0o`3oool0oooo01h0oooo0P3o08L?0?ooo`80033o1@3oool20017o`D0oooo0P00
Aolg0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo03/0oooo0P2W0?l6
0?ooo`0306H0o`3oool0oooo0080Q`3o1@3oool204`0o`<0oooo00<0o@3o0?ooo`3oool00P1<0?l0
0`3oool0o`3>0?l0cP050?ooo`030?l0cP3oool0oooo00@0oooo00<0o@3o0?ooo`3oool05@3oool0
0`3m0?l0oooo0?ooo`050?ooo`030?l0cP3oool0oooo0080oooo00@0Q`3o0?ooo`3oool0o`3>0`3o
ool01@1<0?l0oooo0?ooo`3oool0Y`3o00X0oooo103o08L20?ooo`@0o`26103oool0103o08H0oooo
0?ooo`00<?l50?ooo`8004Oo1@3oool00`00Aol0oooo0?ooo`030?ooo`80033o<@3oool00`000000
oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0l0?ooo`030:L0o`3oool0oooo00@0oooo
0P1c0?l20?ooo`0508L0o`3oool0oooo0?ooo`1c0?l00P3oool204`0o`<0oooo00@0o@3o0?ooo`1<
0?l0C03o0`3oool0103o0<h0oooo08L0o`270?l20?ooo`030?l0cP3oool0oooo00<0oooo0P3m0?lD
0?ooo`80o@3o1`3oool00`3o0<h0oooo0?ooo`020?ooo`0408L0o`3oool0oooo0?l0cP<0oooo00L0
C03o0?ooo`3oool0o@3o0?ooo`2W0?l0oooo0080C03o0`3oool0101c0?l0oooo0?l04P3o01830?oo
o`0507<0o`3o08L0oooo0?ooo`3o08H00P3oool20?l0QP040?ooo`3o08H0o`260?l0QP80oooo00<0
033o0?ooo`3o08L00P3o08L20?ooo`030017o`3oool0oooo00<0oooo00<004Oo0?ooo`3oool00P3o
ool2000`oa/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool0
0`000000oooo0?ooo`0a0?ooo`80o`0B2P3oool00`2W0?l0oooo0?ooo`030?ooo`80L`3o0`3oool0
10270?l0oooo0?ooo`1c0?l40?ooo`0404`0o`3oool0Y`3o0:L0o`80oooo00<0C03o0?ooo`3oool0
0`3oool208L0o`<0oooo00<0o`3>0?ooo`3oool0103oool00`3m0?l0oooo0?ooo`0A0?ooo`80o@3o
1P3oool0103o0<h0oooo0?ooo`3oool208L0o`030?ooo`3o0<h0o`3>0080oooo0P1<0?l30?ooo`80
Y`3o00<0oooo04`0o`3oool0103oool00`1c0?l0o`0B08L0o`040?ooo`0407<0o`3oool0o`000?l0
00<0oooo00@0Y`3o0?ooo`3o0000o`000P3oool20?l0QP<0oooo00@0o`270?ooo`3o08L0o`271`3o
ool00`00Aol0oooo0?ooo`030?ooo`03000`o`3oool0oooo01P0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01H0oooo0`3o01850?ooo`80o`000`3oool00`2W0?l0oooo0?ooo`020?l00080oooo00<0L`3o
0?ooo`3oool0103oool00`1c0?l0oooo0?ooo`030?ooo`80Y`3o0`3oool00`1<0?l0oooo0?ooo`04
0?ooo`0308L0o`3oool0oooo0280oooo0P3o0<h30?ooo`0308L0o`3oool0oooo0080o`3>0P3oool2
04`0o`050?ooo`3m0?l0o@3o0:L0o`3oool00P1<0?l30?ooo`0407<0o`3o0180o`0B08L0o`<0oooo
00@0L`3o0?l0003oool0o`00103oool00`2W0?l0oooo0?l000070?ooo`80o`0B;03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo01D0oooo
0P3o08L00`3o0180oooo0?l04P050?ooo`<0o`00103oool20?l000D0oooo0P3o01830?ooo`0307<0
o`3oool0oooo00@0oooo00<0Y`3o0?ooo`3oool0>`3oool20?d0o`L0oooo00@0L`3o0?l04P3o0180
Q`3o0`3oool00`1c0?l0o`000?l000030?ooo`80Y`3o0P3o00050?ooo`<0o`0B;P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo00X0oooo
00<0033o0?ooo`3oool0103oool01000Aol0oooo0?l0Q`3o08L50?ooo`030?l04P3o08H0o`260080
o`260`3oool0103o0000oooo0?l0QP3o08H20?ooo`030?l0003oool0oooo0080oooo00<0o`0B0?oo
o`3o01800P0h0?l80?ooo`80J03o1@3oool20:D0o`H0oooo00<0Y@3o0?ooo`3oool0?03oool20?l0
00<0oooo00@0Y`3o0?ooo`3o0000o`00103oool30?l04Rl0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`090?ooo`03000`o`3oool0oooo
00D0oooo00<004Oo0?ooo`3o08L01@3oool00`00Aol0o`260?l0QP040?ooo`05000`o`3oool0o`26
0?l0QP3oool00P270?l20?ooo`030?l0003o08L0o`270080o`270P3oool203P0o`D0oooo0P001?l2
0?ooo`80J03o0P3oool00`001?l0oooo0?ooo`020:D0o`D0oooo00<0Y@3o0?ooo`3oool0103oool0
0`1X0?l0oooo0?ooo`0;0?ooo`80J03o1P3oool01@2U0?l0oooo0?ooo`3oool0>03o02`0oooo00<0
o`0B0?ooo`3oool0@`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00P0oooo0P00<?l60?ooo`030017o`3oool0oooo00@0oooo0P00Aol2
0?ooo`80o`1V0`3oool01000<?l0oooo0?l0B03o04P20?ooo`0508L0o`3oool0oooo0?l0Q`3o04P0
0P3oool204`0o`80oooo00<0>03o0?ooo`3oool00P1<0?l20?ooo`080004o`3oool0oooo0?ooo`27
0?l0J03o0?ooo`001?l40?ooo`030:D0o`3oool0>03o00<0oooo00<0Y@3o0?ooo`3oool00`3oool2
06P0o`X0oooo0P1X0?l70?ooo`030:D0o`3oool0oooo0080oooo00@0>03o0?ooo`3oool0Y@3o0`3o
ool020001?l0oooo0?ooo`1X0?l0oooo08L0o`3oool000Co103oool01@1<0?l0oooo0?ooo`3oool0
o`1V00`0oooo0P3<0?l50?ooo`80``3o1@3oool00`330?l0oooo0?ooo`0m0?ooo`800000BP3oool0
05L0oooo00<000000?ooo`3oool0:`3oool00`00Aol0oooo0?ooo`040?ooo`8004Oo0P3oool01@3o
06H0oooo0?ooo`3oool0033o0080oooo0P3o04P30?ooo`0308L0o`3oool0oooo0080o`1800<0oooo
04`0o`1<0?l00P3oool01@3o06H0>03o0?ooo`3oool0C03o00<0oooo00@000Co0?ooo`3oool0Q`3o
0`3oool00`001?l0oooo0?ooo`030?ooo`80>03o0`3oool00`2U0?l0oooo0?ooo`040?ooo`0306P0
o`3oool0oooo00L0oooo0P1X0?l60?ooo`040:D0o`3oool0oooo0?ooo`80>03o00<0oooo0:D0o`2U
0?l00P3oool20004o`050?ooo`1X0?l0J03o0?ooo`270?l00P3oool01@001?l0oooo0?ooo`3oool0
C03o0080oooo00@0>03o0?ooo`3o06H0oooo0P1<0?l30?ooo`030?l0B03oool0Q`3o00<0oooo0P3<
0?l50?ooo`80``3o1@3oool20<<0o`@0oooo0P3<0?lS0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0=`3oool0103o06H0oooo0?ooo`00
<?l40?ooo`050?l0B03oool0oooo0?ooo`270?l00P3oool01P3o04P0oooo0?ooo`3oool0C03o0?oo
o`80o`1V0`3oool00`1<0?l0oooo0?ooo`040?ooo`0508L0o`3oool0oooo0?ooo`001?l01P3oool0
0`0h0?l0oooo0?ooo`0H0?ooo`80Y@3o0`3oool203P0o`030?ooo`2U0?l0Y@3o0080oooo0P001?l0
1@3oool0J03o08L0o`270?l0oooo008000Co0`3oool0201<0?l0oooo03P0o`0h0?l0oooo0?l0IP3o
ool0C03o103oool0103o04P0oooo0?ooo`270?l40?ooo`030?l0B03<0?l0oooo00@0oooo00<0o`1V
0<<0o`3oool00`3oool20<<0o`@0oooo0P3<0?lS0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0>03oool00`3o06H0oooo0?ooo`050?oo
o`030?l0B03oool0oooo00<0oooo00<0o`180?ooo`3oool01@3oool01@3o06H0oooo0?ooo`3oool0
C03o00H0oooo00<0Q`3o0?ooo`3oool0<P3oool010270?l0oooo0?ooo`001?l30?ooo`80C03o00D0
oooo03P0o`3o06H0o`1V0?ooo`0204`0o`80oooo0P3o04P00`3oool0Q`3o08L0o`040?ooo`040?l0
B03oool0oooo0<`0o`<0oooo00@0o`1V0?ooo`3oool0``3o1@3oool00`330?l0oooo0?ooo`030?oo
o`030<`0o`3oool0oooo0200oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?oo
o`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<0o`180?ooo`3o
ool01@3oool00`3o06H0oooo0?ooo`0@0?ooo`03000Ao`3oool0oooo03@0oooo0P3o06H50?ooo`80
o`1800<0oooo08L0o`270?l00P3oool20?l0B0D0oooo0P3o06H@0?ooo`030<`0o`3oool0oooo01l0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`0P0?ooo`030?l0W@3oool0oooo00P0oooo00<0>03o0?ooo`3oool01`3oool20012o`H0oooo
00@008;o0?ooo`00;ol002oo1P3oool2000Ao`D0oooo0P004Ol80?ooo`8002oo<P3oool20?l0B0D0
oooo0P3o06H=0?ooo`8003So1@3oool2001;o`D0oooo00<004_o0?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo0100oooo
00<0c03o0?ooo`3oool01@3oool00`330?l0oooo0?ooo`050?ooo`80o`2M1@3oool20?l0M080oooo
00D0>03o0?ooo`3oool0oooo0?l0M0020?ooo`8000Co0P3oool00`00@_l0oooo0?ooo`020004o`80
oooo00<008;o0?ooo`3oool00P00;ol20?ooo`8008;o0`3oool00`004Ol0oooo0012o`020?ooo`03
000Ao`3oool0017o00@0oooo0`00;ol70?ooo`<0017o0`3oool01000@_l0oooo0?ooo`004Ol30?oo
o`050022o`3oool0oooo0?ooo`0h0?l00P3oool00`00P_l0oooo0?ooo`0]0?ooo`03000ho`3oool0
oooo00<0oooo0P00Bol50?ooo`03001;o`3oool0oooo00<0oooo0P00>?lU0?ooo`030000003oool0
oooo04P0oooo001b0?ooo`030000003oool0oooo0100oooo00<0c03o0?ooo`3oool01@3oool00`33
0?l0oooo0?ooo`040?ooo`030<<0o`3o09d0o`2M00D0oooo0P3o07@30?ooo`0403P0o`3oool0oooo
0?l0M080oooo0P001?l20?ooo`050?l0W@00@_l0oooo0?ooo`001?l00`3oool01000P_l0oooo0?oo
o`0h0?l40?ooo`030022o`3oool0oooo0080oooo0P00@_l90?ooo`<002oo1@3oool2000Ao`<0oooo
0P00@_l00`3oool0017o000Ao`020?ooo`8008;o0P3oool2000_o`0303P0o`3oool008;o00@0oooo
00P000Co0?ooo`3oool004;o0?ooo`3o09d0oooo0004o`@0oooo00<0o`1d0?ooo`0h0?l0103oool0
0`3o07@0oooo0?ooo`0G0?ooo`03000ho`3oool0oooo00@0oooo00<004_o0?ooo`3oool00`3oool0
0`00Bol0oooo0?ooo`020?ooo`8003So9@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo0P3<0?l60?ooo`80``3o1@3oool20<<0
o`80oooo00<0o`2M0?ooo`3oool00P3oool0103<0?l0oooo0?ooo`3o07@20?ooo`0503P0o`3oool0
oooo0?ooo`3o07@00`3oool00`001?l0oooo0?l0W@040?ooo`030004o`3oool0oooo00@0oooo00<0
>03o0?ooo`3oool0203oool00`00@_l0oooo0?ooo`0C0?ooo`040012o`3oool0oooo000Ao`<0oooo
0P00P_l01@3oool002oo03P0o`0h0?l0oooo008008;o0P3oool20004o`050?ooo`00@_l004;o0?oo
o`3o09d00P3oool00`001?l0oooo0?ooo`020?ooo`030?l0M03oool0>03o00@0oooo00<0o`1d0?oo
o`3oool00`3oool00`3o09d0oooo0?ooo`0O0?ooo`03001;o`3oool0oooo00<0oooo00<003So0?oo
o`3oool08P3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0Y0?ooo`80
c03o1P3oool00`330?l0oooo0?ooo`040?ooo`80``3o0`3oool0103o09d0oooo0?ooo`3<0?l40?oo
o`030?l0M03oool0oooo00@0oooo00<0o`1d0?ooo`3oool00`3oool00`3o09d0oooo0?ooo`090?oo
o`0303P0o`3oool0oooo02P0oooo0P0h0?l50?ooo`8000Co00D0oooo0012o`3o09d0o`2M0?ooo`02
0004o`@0oooo00<0o`1d03P0o`0h0?l0103oool00`3o07@0oooo0?ooo`040?ooo`030?l0W@3oool0
oooo03@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`00
0000oooo0?ooo`0o0?ooo`80c03o4P3oool00`3o09d0oooo0?ooo`0:0?ooo`800=So103oool2003o
hPD0oooo0P00on80103oool00=So003Ho`00f?lQ0?ooo`80o`2M00<0oooo0004o`3oool00P3oool2
0?l0M0030?ooo`0h0?l0>03o0080oooo0P3o07@50?ooo`80o`2M=`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01/0oooo00<003So0?oo
o`3oool01@3oool00`00Bol0oooo0?ooo`040?ooo`03001;o`3oool0oooo01<0oooo00<0o@3o0?oo
o`3oool0203oool00`00@_l0oooo0?ooo`0B0?ooo`03003Ho`3oool00=So00<0oooo00<00?oR0?oo
o`00on80103oool01@00on80oooo003Ho`00f?l0oooo00<00=So00@0oooo003ohP00on800?oR1@3o
ool2003ohP@0oooo0P00f?lE0?ooo`80o`1d1@3oool20?l0M0D0oooo0P3o09dg0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0603oool0
0`00000003So000ho`060?ooo`8004_o1`3oool00`00Bol0oooo0?ooo`050?ooo`03000ho`3oool0
oooo00/0oooo0P3m0?l50?ooo`80o`3>0P3oool01@00@_l0oooo0?ooo`3oool0o`3>0080oooo0P00
P_l00`3oool00?oQ003oh@030?ooo`040022o`3oool0oooo003o_@80oooo0P00@_l20?ooo`800?nm
3`3oool00`00f?l00?oR0?ooo`020?ooo`05003oh@3oool0oooo0?ooo`00on800`3oool00`00okd0
oooo003Ho`1M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo
00<00000000ho`00>?l01P3oool2001;o`H0oooo00<004_o0?ooo`3oool0103oool2000ho`l0oooo
00<0o@3o0?ooo`3oool00`3oool20?l0cP<0oooo00@004;o0?ooo`3oool0o`3>0P3oool20022o`80
oooo00D0o@3o003oh@3oool0oooo0022o`030?ooo`04003o_@3oool004;o0012o`80oooo00<00?nm
0?ooo`00okd01@3oool2003oh@X0oooo0P00on460?ooo`800?nm103oool01000@_l0oooo003o_@00
okd30?ooo`050022o`3oool0oooo003oh@3m0?l00P3oool00`00P_l0oooo0?ooo`0N0?ooo`80a@3o
1@3oool20;X0ob@0oooo00<000000?ooo`3oool04P3oool2000004X0oooo001b0?ooo`030000003o
ool0oooo01D0oooo0P00>?l?0?ooo`030?d0o`3oool0oooo00D0oooo00@0o`3>0?ooo`3oool004;o
0`3oool01@3o0<h0oooo0?ooo`3oool008;o0080oooo00D0o@3o0?ooo`3oool0oooo0022o`050?oo
o`030012o`3oool0oooo00X0oooo00<00?oQ0?ooo`3oool01`3oool00`00on40oooo0?ooo`050?oo
o`800?nm0P3oool20012o`030?ooo`00okd00?nm00<0oooo00<008;o0?ooo`3oool00P00on40103m
0?l0oooo0?ooo`00P_l30?ooo`040?l0cP3oool0oooo0012o`<0oooo00<0o`3>0?ooo`3oool0103o
ool00`3m0?l0oooo0?ooo`0<0?ooo`80a@3o1@3oool20;X0o`@0oooo0P2j0?l50?ooo`80a@3o;@3o
ool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`0W0?ooo`030?d0o`3oool0
oooo00D0oooo00<0o`3>0?ooo`3oool0103oool00`3o0<h0oooo0?ooo`030?ooo`030?d0o`3oool0
oooo00P0oooo00<004;o0?ooo`3oool07`3oool20012o`D0oooo0P00P_l20?ooo`03003oh@3m0?l0
oooo008008;o103oool00`3o0<h004;o0012o`040?ooo`030?l0cP3oool0oooo00@0oooo00<0o@3o
0?ooo`3oool03P3oool00`350?l0oooo0?ooo`030?ooo`030;X0o`3oool0oooo00<0oooo00<0^P3o
0?ooo`3oool00`3oool20<D0obd0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0m0?ooo`030?d0o`3oool0oooo03@0oooo0P3m0?l00`3o
ool008;o0?ooo`020?ooo`80o`3>00<0oooo0012o`00@_l00P3oool20?l0cPD0oooo0P3m0?lB0?oo
o`030<D0o`3oool0oooo00<0oooo00<0^P3o0?ooo`3oool00`3oool00`2j0?l0oooo0?ooo`040?oo
o`030<D0o`3oool0oooo02X0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3o
ool0S`3oool00`3m0?l0oooo0?ooo`040?ooo`80o`3>1@3oool20?l0cPD0oooo0P3m0?lO0?ooo`03
0;X0o`3oool0oooo00@0oooo00<0a@3o0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo0240oooo00<0a@3o0?ooo`3oool0
8@3oool206P0o`H0oooo00@0Y@3o0?ooo`3oool00?oQ0`3oool01@2U0?l0oooo0?ooo`3oool00?nm
0080oooo00D0J03o0?ooo`00ogT00?mi003o_@030?ooo`03023o003oool0oooo00@0oooo0P0Po`03
0?ooo`800?mi<`3oool00`3m0?l0oooo0?ooo`0R0?ooo`8004?o5`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo0240oooo00<0a@3o0?oo
o`3oool01@3oool00`2j0?l0oooo0?ooo`050?ooo`030;X0o`3oool0oooo00@0oooo00<0a@3o0?oo
o`3oool02P3oool00`1X0?l0oooo0?ooo`050?ooo`040:D0o`3oool0oooo003oh@<0oooo00D0Y@3o
0?ooo`3oool0oooo003o_@020?ooo`80J03o0P3oool01000ogT0oooo0?ooo`3oool2023o0080oooo
00<00?oQ0?ooo`3oool00P0Po`030?ooo`800?mi103oool3003oN@<0oooo0P0Po`030?ooo`04003o
h@3oool0oooo023o00@0oooo00<00?nm0?ooo`3oool0?P3oool20013o`D0oooo0P00Dol50?ooo`03
001Co`3oool0oooo00<0oooo0P00@ol30?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0B03oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`80a@3o
203oool00`2j0?l0oooo0?ooo`040?ooo`030;X0o`3oool0oooo00D0oooo00<0a@3o0?ooo`3oool0
2`3oool00`1X0?l0oooo0?ooo`050?ooo`040:D0o`3oool0oooo003oh@<0oooo00D0Y@3o0?ooo`3o
ool0oooo003o_@020?ooo`0506P0o`3oool0oooo0?ooo`00okd01P3oool00`00on40oooo0?ooo`07
0?ooo`05003oN@3oool0oooo0?ooo`00ogT01@3oool01@0Po`00oooo0?ooo`3oool00?oQ0080oooo
00<08?l00?ooo`3oool00P3oool00`00okd0oooo0?ooo`020?ooo`0406P0o`3oool0oooo003o_@<0
oooo00@0Y@3o0?ooo`3oool00?oQ0`3oool00`2U0?l0oooo0?ooo`040?ooo`0306P0o`3oool0oooo
02L0oooo00<004?o0?ooo`3oool00`3oool00`00Dol0oooo0?ooo`030?ooo`8005?o103oool20013
o`<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000
oooo0?ooo`040?ooo`80a@3o1P3oool20;X0o`H0oooo00<0^P3o0?ooo`3oool0103oool20<D0o`l0
oooo00<0J03o0?ooo`3oool0103oool00`2U0?l0oooo0?ooo`050?ooo`030:D0o`3oool0oooo00@0
oooo00<0J03o0?ooo`3oool0203oool00`00on40oooo0?ooo`0C0?ooo`800?oQ1P3oool2003o_@@0
oooo00<0J03o0?ooo`00okd0103oool0102U0?l0oooo0?ooo`00on430?ooo`030:D0o`3oool0oooo
00@0oooo00<0J03o0?ooo`3oool0:03oool00`00@ol0oooo0?ooo`030?ooo`03001Co`3oool0oooo
00@0oooo00<005?o0?ooo`3oool00`3oool01000@ol0oooo0?ooo`00000E0?ooo`030000003oool0
oooo04P0oooo001b0?ooo`030000003oool0oooo00`0oooo00<0^P3o0?ooo`3oool0103oool20;X0
o`H0oooo0P350?mB0?ooo`80J03o1@3oool20:D0o`80oooo00<00?oQ0?ooo`3oool00P2U0?l60?oo
o`0306P0o`3oool0oooo05D0oooo00<000000?ooo`3oool0B03oool006/0oooo00<004?o0?ooo`3o
ool0103oool00`00000005?o0?ooo`060?ooo`03001Co`3oool0oooo06H0oooo0P1X0?l50?ooo`80
Y@3o1@3oool20:D0o`D0oooo0P1X0?mG0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000
003oool0oooo0140oooo00<004?o0?ooo`3oool0103oool00`00000005?o0?ooo`060?ooo`03001C
o`3oool0oooo00@0oooo00<004?o0?ooo`3oool0803oool00`00;ol0oooo0?ooo`040?ooo`80017o
1@3oool2000Aoid0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0403o
ool00`00@ol0oooo0?ooo`050?ooo`03001Co`3oool0oooo00@0oooo0P00Dol60?ooo`8004?o8P3o
ool2000_o`D0oooo00<0017o0?ooo`3oool00P3oool2003oN@80017o1P3oool2000_o`H0oooo00<0
0?mi0?ooo`3oool0MP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G
0?ooo`030000003oool0oooo01l0oooo00<005?o0?ooo`3oool01@3oool00`00@ol0oooo0?ooo`0Q
0?ooo`03000_o`3oool0oooo00D0oooo00D0017o0?ooo`3oool0oooo003oN@020?ooo`04000Ao`3o
ool0oooo023o00@0oooo00@002oo0?ooo`0Po`008?l00`3oool2003oNA80oooo00<00?mi0?ooo`3o
ool01P3oool00`00;ol0oooo0?ooo`050?ooo`03000Ao`3oool0oooo00@0oooo00<0017o0?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000
003oool0oooo04/0oooo00<002oo0?ooo`3oool01@3oool00`004Ol0oooo0?ooo`020?ooo`04003o
N@3oool0oooo000Ao`80oooo00<08?l00?ooo`3oool00P3oool00`00;ol0oooo023o00040?ooo`03
003oN@3oool0oooo0100oooo00<00?mi0?ooo`3oool00P3oool01@0Po`00oooo0?ooo`3oool002oo
00<0oooo00H08?l00?ooo`3oool0oooo000Ao`00ogT50?ooo`03000Ao`3oool0oooo00@0oooo00<0
02oo0?ooo`3oool08P3oool20;X0o`D0oooo0P2c0?l40?ooo`80/`3o1@3oool20;X0o`/0oooo00<0
00000?ooo`3oool04P3oool2000004X0oooo001b0?ooo`030000003oool0oooo0640oooo0P00ogT4
0?ooo`04023o003oool0oooo000_o`<0oooo00<08?l00?ooo`3oool00P004Ol2003oN@@0oooo00<0
017o0?ooo`3oool01@3oool00`00;ol0oooo0?ooo`0R0?ooo`80^P3o1@3oool00`2c0?l0oooo0?oo
o`030?ooo`80/`3o1@3oool20;X0o`/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`180?ooo`00LP3oool00`000000oooo0?ooo`0f0?ooo`03003Ho`3oool0oooo00<0oooo00<00?oR
0?ooo`3oool00`3oool00`00on80oooo0?ooo`030?ooo`03003Ho`3oool0oooo01h0oooo0P00;ol6
0?ooo`80017o00<00?mi0?ooo`3oool00P3oool2000Ao`H0oooo0P00;olV0?ooo`030;X0o`3oool0
oooo00<0oooo00<0/`3o0?ooo`3oool0103oool00`2c0?l0oooo0?ooo`030?ooo`030;X0o`3oool0
oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`00
0000oooo0?ooo`0f0?ooo`03003Ho`3oool0oooo0080oooo0P00on850?ooo`800?oR103oool2003H
ocH0oooo0P00;olW0?ooo`030;X0o`3oool0oooo00<0oooo00<0/`3o0?ooo`3oool0103oool00`2c
0?l0oooo0?ooo`030?ooo`030;X0o`3oool0oooo01h0oooo00<000000?ooo`3oool0B03oool005L0
oooo00<000000?ooo`3oool0603oool00`2j0?l0oooo0?ooo`040?ooo`030;<0o`3oool0oooo00D0
oooo00<0/`3o0?ooo`3oool0103oool00`2j0?l0oooo0?ooo`0P0?ooo`03003Ho`3oool0oooo00<0
oooo00<00?oR0?ooo`3oool0103oool00`00on80oooo0?ooo`030?ooo`03003Ho`3oool0oooo01`0
oooo00<00=So0?ooo`3oool00`3oool00`00on80oooo0?ooo`040?ooo`03003ohP3oool0oooo00<0
oooo00<00=So0?ooo`3oool0>P3oool20003o`@0oooo0P004?l50?ooo`03000@o`3oool0oooo00<0
oooo00<000?o0?ooo`3oool03`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo
0?ooo`0G0?ooo`030;X0o`000000oooo00D0oooo00<0/`3o0?ooo`3oool01@3oool00`2c0?l0oooo
0?ooo`040?ooo`030;X0o`3oool0oooo02d0oooo00<00?oR0?ooo`3oool0103oool00`00f?l0oooo
0?ooo`0K0?ooo`03003Ho`3oool0oooo00<0oooo00<00?oR0?ooo`3oool0103oool00`00on80oooo
0?ooo`030?ooo`03003Ho`3oool0oooo03X0oooo00<000?o0?ooo`3oool00`3oool2000@o`D0oooo
0P004?l40?ooo`8000?o403oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?oo
o`0E0?ooo`80^P3o1P3oool20;<0o`H0oooo0P2c0?l50?ooo`80^P3oE03oool2003Ho`@0oooo0P00
on860?ooo`03003ohP3oool0oooo00<0oooo0P00f?ll0?ooo`030003o`3oool0oooo00<0oooo00<0
013o0?ooo`3oool0103oool00`004?l000000?ooo`030?ooo`030003o`3oool0oooo00h0oooo00<0
00000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool05@3oool20;X0o`H0oooo0P2c0?l6
0?ooo`80/`3o1@3oool20;X0oe@0oooo00<00=So0?ooo`3oool02`3oool00`00on80oooo0?ooo`03
0?ooo`03003Ho`3oool0oooo0340oooo0P3o0>h50?ooo`80o`3a00<0oooo0003o`3oool00P3oool2
0?l0l@050?ooo`004?l0oooo0?ooo`3o0>h00P3oool00`004?l000000?ooo`030?ooo`030003o`3o
ool0oooo00h0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool02`3oool0
0`000ol0oooo0?ooo`050?ooo`03000@o`3oool0oooo00@0oooo00<0013o0?ooo`3oool01@3oool0
0`000ol0oooo0?ooo`2U0?ooo`80o`3^1@3oool20?l0l@D0oooo00<0o`3a0?ooo`3oool00P3oool0
0`3oB000o`3^0?l0kP020?ooo`030000003oool0oc4000<0oooo00<000?o0?ooo`3o<@001@3oool2
0?m800H0oooo00<000000?ooo`3oool0B03oool005h0oooo00<0odP00?ooo`3oool0103oool00`00
0ol0oc400?ooo`050?ooo`03000@o`3o<@00oooo0080oooo00@000000?ooo`004?l0odP01P3oool0
0`000ol0oooo0?ooo`2V0?ooo`030?l0kP3oool0oooo00@0oooo00<0o`3a0?ooo`3oool00`3oool0
0`3o0?40oooo0?ooo`040?ooo`040?l0kP3oool0oooo000001D0oooo00<000000?ooo`3oool0B03o
ool006@0oooo00<000?o0?ooo`3oool01@3oool00`004?l0oooo0?ooo`030?ooo`03000000004?l0
oooo00H0oooo00<000?o0?ooo`3oool0Y`3oool00`3o0>h0oooo0?ooo`040?ooo`030?l0l@3oool0
oooo00@0oooo00<0o`3a0?ooo`3oool00`3oool0103o0>h0oooo0?ooo`00000E0?ooo`030000003o
ool0oooo04P0oooo001T0?ooo`030003o`3oool0oooo00@0oooo00<0o`3^000@o`3oool0103oool0
0`000000o`3a000@o`050?ooo`030?l0l@000ol0oooo00D0oooo00<0o`3^0?ooo`3oool0X@3oool0
0`3o0>h0oooo0?ooo`040?ooo`030?l0l@3oool0oooo00<0oooo00<0o`3a0?ooo`3oool0103oool0
0`3o0>h0oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo
0140oooo00<0o`3^0?ooo`3oool0103oool00`000000o`3a0?ooo`050?ooo`030?l0l@3oool0oooo
00D0oooo00<0o`3^0?ooo`3oool0c@3oool00`000000oooo0?ooo`040?ooo`0509RHV00000000000
0000002HV9P0503oool6000002D0oooo001G0?ooo`030000003oool0oooo0140oooo00<0o`3^0?oo
o`3oool0103oool00`3o0?40oooo0?ooo`050?ooo`030?l0l@3oool0oooo00D0oooo00<0o`3^0?oo
o`3oool0XP3oool20?l0kPD0oooo00<0o`3a0?ooo`3oool00`3oool20?l0l@@0oooo0P3o0>hF0?oo
o`030000003oool0oooo00@0oooo00D0000009RHV03oool0V9RH0000000D0?ooo`060:VYZ@0b<S80
oooo0?ooo`3^k^h0<S8b9@3oool005L0oooo00<000000?ooo`3oool03`3oool20?l0kPH0oooo0P3o
0?460?ooo`80o`3a1@3oool20?l0kZD0oooo0P3o0>h50?ooo`80o`3a103oool20?l0l@D0oooo00<0
o`3^0000003oool04P3oool3000000H0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`0306IV
IP1gMgL0oooo02L0oooo001G0?ooo`030000003oool0oooo0100oooo00<0o`3^0?ooo`3oool0103o
ool20?l0l@H0oooo0P3o0?460?ooo`030?l0kP3oool0oooo0:<0oooo00<0o`3^0?ooo`3oool0103o
ool00`3o0?40oooo0?ooo`030?ooo`030?l0l@3oool0oooo00@0oooo00<0o`3^0000003oool0503o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000005@3oool00`3^k^h08B4Q
0<c<c00W0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0;80oooo00<0
o`3^0?ooo`3oool00`3oool00`3o0?40oooo0?ooo`040?ooo`030?l0l@3oool0oooo00<0oooo00<0
o`3^0?ooo`0000005@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
5P3oool00`3<c<`08B4Q0>k^kP0V0?ooo`00J`3oool00`3o0>h0oooo0?ooo`040?ooo`030000003o
0?40oooo00D0oooo00<0o`3a0?ooo`3oool01@3oool00`3o0>h0oooo0?ooo`2Q0?ooo`030?l0kP3o
ool0oooo00@0oooo00@0o`3a0?ooo`3oool000?o0P3oool0103o0?40oooo0?ooo`004?l30?ooo`04
0?l0kP3oool00000000@o`D0oooo00<000?o0?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000005`3oool00`1gMgL0IVIV0?ooo`0U0?ooo`00J`3oool00`3o
0>h0oooo0?ooo`040?ooo`030000003o0?40oooo00D0oooo00<0o`3a0?ooo`3oool01@3oool00`3o
0>h0oooo0?ooo`2Z0?ooo`8000?o103oool2000@o`D0oooo00<00000000@o`3oool00`3oool20003
o`h0oooo00<000000?ooo`3oool0103oool01@000000V9RH0?ooo`2HV9P0000001@0oooo00H0<S8b
0>k^kP3oool0oooo038b<P2YZJTU0?ooo`00GP3oool00`3oB000oooo0?ooo`050?ooo`030?la003o
ool0oooo0080oooo0P3o0>h00`3oool0oc400?ooo`020?ooo`030000003oool0o`3a0080odP0103o
ool20?l0l@H0oooo00<0o`3^0?ooo`3oool0Z@3oool00`000ol0oooo0?ooo`040?ooo`03000@o`3o
ool0oooo00<0oooo00<0013o0?ooo`3oool0103oool00`000ol0oooo0?ooo`050?ooo`030?m8003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool01@2HV9P00000000000000000V9RH01@0oooo
1P00000U0?ooo`00E`3oool00`000000oooo0?ooo`0;0?ooo`030003o`3oool0oooo00@0oooo00<0
o`3^000@o`3oool00`3oool00`000000o`3a0?l0l@060?ooo`80o`3a1P3oool00`3o0>h0oooo0?oo
o`2Y0?ooo`030003o`3oool0oooo00<0oooo00@0013o0?ooo`3oB000odP00`3oool00`004?l0oooo
0?la00030?ooo`040003o`3oool0oc400?la00@0oooo0P3oB0060?ooo`030000003oool0oooo04P0
oooo001G0?ooo`030000003oool0oooo00/0oooo00<000?o0?ooo`3oool0103oool00`3o0>h0013o
0?ooo`050?ooo`03000@o`3oool0oooo00D0oooo00<000?o0?ooo`3oool0;03oool00`00f?l0oooo
0?ooo`040?ooo`03003ohP3oool0oooo00D0oooo00<00?oR0?ooo`3oool00P3oool2003Hofd0oooo
00<000?o0?ooo`3oool0103oool00`004?l0oooo0?ooo`030?ooo`03000@o`3oool0oooo00@0oooo
00<000?o0?ooo`3oool03@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?oo
o`0;0?ooo`8000?o1P3oool2000@o`H0oooo00<0013o0?ooo`3oool0103oool20003ob`0oooo0P00
f?l50?ooo`800?oR1P3oool2003ohP@0oooo0P00f?mN0?ooo`80^P3o1@3oool20;<0o`D0oooo0P2c
0?l40?ooo`80^P3o1`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G
0?ooo`030000003oool0oooo00/0oooo0P000ol70?ooo`03000@o`3oool0oooo00@0oooo00<0013o
0?ooo`3oool01@3oool00`000ol0oooo0?ooo`0[0?ooo`03003Ho`3oool0oooo00<0oooo00<00?oR
0?ooo`3oool01@3oool00`00on80oooo0?ooo`030?ooo`03003Ho`3oool0oooo05h0oooo00<0^P3o
0?ooo`3oool00`3oool20;<0o`D0oooo0P2c0?l40?ooo`80^P3o1`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00<0^P3o0?oo
o`3oool0103oool00`2c0?l0oooo0?ooo`050?ooo`030;<0o`3oool0oooo00@0oooo00<0^P3o0?oo
o`3oool0803oool00`00f?l0oooo0?ooo`030?ooo`03003ohP3oool0oooo00@0oooo00<00?oR0?oo
o`3oool08P3oool00`00f?l0oooo0?ooo`030?ooo`03003ohP3oool0oooo00@0oooo00<00?oR0?oo
o`3oool00`3oool00`00f?l0oooo0?ooo`0/0?ooo`030;X0o`3oool0oooo00<0oooo00<0/`3o0?oo
o`3oool0103oool00`2c0?l0oooo0?ooo`030?ooo`030;X0o`3oool0oooo00L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`2j0?l0oooo0?ooo`050?ooo`03
0;<0o`3oool0oooo00@0oooo00<0/`3o0?ooo`3oool01@3oool00`2j0?l0oooo0?ooo`0J0?ooo`03
000_o`3oool0oooo00D0oooo00<0017o0?ooo`3oool01@3oool00`004Ol0oooo0?ooo`040?ooo`80
02oo7P3oool00`00f?l0oooo0?ooo`040?ooo`03003ohP3oool0oooo00<0oooo00<00?oR0?ooo`3o
ool00`3oool00`00f?l0oooo0?ooo`0[0?ooo`030;X0o`3oool0oooo00<0oooo00<0/`3o0?ooo`3o
ool0103oool00`2c0?l0oooo0?ooo`030?ooo`030;X0o`3oool0oooo00P0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000^P3o0;X0o`060?ooo`030;<0
o`3oool0oooo00@0oooo0P2c0?l60?ooo`80^P3o6@3oool2000_o`L0oooo00<0017o0?ooo`3oool0
0P3oool01000ogT0oooo000Ao`004Ol70?ooo`03000_o`3oool0oooo00@0oooo00<00?mi0?ooo`3o
ool05P3oool2003Ho`@0oooo0P00on850?ooo`03003ohP3oool0oooo0080oooo0P00f?m:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000;X0o`2j0?l0
1P3oool20;<0o`D0oooo0P2c0?l70?ooo`030;X0o`3oool0oooo01L0oooo00<002oo0?ooo`3oool0
1@3oool00`004Ol0oooo0?ooo`030?ooo`03003oN@3oool0017o0080oooo0P0Po`030?ooo`04000_
o`3oool0oooo023o00@0oooo00<00?mi0?ooo`3oool05`3oool00`00f?l0oooo0?ooo`1`0?ooo`03
0000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
<03oool00`00;ol0oooo0?ooo`050?ooo`03000Ao`3oool0oooo0080oooo00@00?mi0?ooo`3oool0
017o0P3oool00`0Po`00oooo0?ooo`020?ooo`03000_o`3oool08?l000@0oooo00<00?mi0?ooo`3o
ool07@3oool00`0Po`00oooo0?ooo`020?ooo`03003oN@3oool0oooo00X0oooo00<002oo0?ooo`3o
ool0F03oool2000004X0oooo001G0?ooo`030000003oool0oooo07d0oooo00<00?mi0?ooo`3oool0
0P3oool2023o0080oooo00D002oo0?ooo`3oool0oooo023o00030?ooo`03000Ao`00ogT0oooo00@0
oooo00<0017o0?ooo`3oool0103oool00`00;ol0oooo0?ooo`130?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0O@3oool2003oN@@0oooo
00@08?l00?ooo`3oool002oo0`3oool01@0Po`00oooo0?ooo`3oool0017o00800?mi103oool00`00
4Ol0oooo0?ooo`040?ooo`03000_o`3oool0oooo04<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0X0?ooo`030013o`3oool0oooo01d0
oooo00<0J03o0?ooo`3oool0103oool20:D0o`H0oooo0P2U0?l50?ooo`80J03o7P3oool00`00ogT0
oooo0?ooo`060?ooo`03000_o`3oool0oooo00D0oooo00<0017o0?ooo`3oool00`3oool2000Ao`D0
oooo0P00;om20?ooo`8004?o00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00
E`3oool00`000000oooo0?ooo`0A0?ooo`030013o`3oool0oooo00@0oooo00<00000001Co`3oool0
1P3oool00`00Dol0oooo0?ooo`040?ooo`030013o`3oool0oooo01`0oooo0P1X0?l60?ooo`80Y@3o
1P3oool20:D0o`H0oooo00<0J03o0?ooo`3oool01`3oool00`00on40oooo0?ooo`0K0?ooo`03000_
o`3oool0oooo00D0oooo00<0017o0?ooo`3oool0103oool00`004Ol0oooo0?ooo`0d0?ooo`8004?o
1@3oool00`00Dol0oooo0?ooo`030?ooo`8005?o1@3oool00`00@ol000000?ooo`0D0?ooo`030000
003oool0oooo04P0oooo001/0?ooo`8004?o103oool010000000oooo001Co`00Dol60?ooo`03001C
o`3oool0oooo00@0oooo0P00@olL0?ooo`0306P0o`3oool0oooo00D0oooo00@0Y@3o0?ooo`3oool0
0?oQ103oool0102U0?l0oooo003o_@00okd30?ooo`0406P0o`3oool0oooo003o_@L0oooo00<00?oQ
0?ooo`3oool0H@3oool20013o`@0oooo0P00Dol50?ooo`03001Co`3oool0oooo00<0oooo00<004?o
0?ooo`0000005@3oool00`000000oooo0?ooo`180?ooo`00K@3oool00`00@ol0oooo0?ooo`020?oo
o`040000003oool005?o001Co`H0oooo0P00Dol60?ooo`030013o`3oool0oooo01X0oooo00<0J03o
0?ooo`3oool0103oool01@2U0?l0oooo0?ooo`3oool00?oQ00<0oooo00<0Y@3o0?ooo`3oool00P00
okd20?ooo`0506P0o`3oool0oooo0?ooo`00okd01P3oool00`00on40oooo0?ooo`070?ooo`03003o
N@3oool0oooo05L0oooo00<004?o0?ooo`3oool00`3oool00`00Dol0oooo0?ooo`040?ooo`03001C
o`3oool0oooo00<0oooo00<004?o0?ooo`3oool05P3oool00`000000oooo0?ooo`180?ooo`00LP3o
ool00`000000oooo0?ooo`0f0?ooo`03003oh@3oool0oooo00D0oooo00<00?nm0?ooo`3oool0103o
ool00`00ogT0oooo0?ooo`020?ooo`03023o003oool0oooo00@0oooo00<08?l00?ooo`3oool00`3o
ool00`00ogT0oooo0?ooo`0G0?ooo`0306P0o`3oool0oooo00@0oooo00@0Y@3o0?ooo`3oool00?oQ
0`3oool00`2U0?l0oooo0?ooo`040?ooo`0306P0o`3oool0oooo02@0oooo00<0^P3o0?ooo`3oool0
0P3oool20<D0obT0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030;X0o`3oool0oooo00D0oooo00<0^P3o0?ooo`3oool0103o
ool00`350?l0oooo0?ooo`0P0?ooo`040?d0o`3oool0oooo0?ooo`800?mi0`3oool00`0Po`00oooo
0?ooo`040?ooo`03023o003oool0oooo00<0oooo00<00?mi0?ooo`3oool0203oool01@0Po`00oooo
0?ooo`3oool00?oQ0080oooo00<08?l00?ooo`3oool00P3oool01@00okd00?mi0?ooo`3oool0J03o
0080oooo00D00?nm0?ooo`3oool0oooo0:D0o`020?ooo`800?oQ0P3oool00`2U0?l0oooo0?ooo`04
0?ooo`0306P0o`3oool0oooo01D0oooo0P350?l50?ooo`80^P3o1@3oool20;X0o`@0oooo0P350?lY
0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo0240oooo00<0a@3o0?oo
o`3oool01@3oool00`2j0?l0oooo0?ooo`050?ooo`030;X0o`3oool0oooo00@0oooo00<0a@3o0?oo
o`3oool0203oool20?d0o`H0oooo0P3o0<h50?ooo`80o`3>1P3oool20?d0oa/0oooo0P00ogT40?oo
o`03023o003oool0oooo00800?oQ0P3oool0100Po`00oooo0?ooo`3oool2003o_@05003oN@3oool0
oooo06P0o`3oool00P00okd30?ooo`80Y@3o0P00on430?ooo`80Y@3o1@3oool00`1X0?l0oooo0?oo
o`0D0?ooo`80a@3o1@3oool20;X0o`D0oooo0P2j0?l40?ooo`030<D0o`3oool0oooo0180oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0Q
0?ooo`030<D0o`3oool0oooo00H0oooo0P2j0?l60?ooo`80^P3o1@3oool20<D0o`P0oooo0P3m0?l7
0?ooo`030?l0cP3oool0oooo00@0oooo00<0o`3>0?ooo`3oool0103oool00`3m0?l0oooo0?ooo`07
0?ooo`030012o`3oool0oooo0140oooo00<00?mi0?ooo`3oool01P3oool00`00on40oooo0?ooo`05
0?ooo`04003o_@3oool0oooo0?ooo`80J03o00<0oooo003o_@3oool00P3oool20:D0o`D0oooo0P2U
0?l50?ooo`0306P0o`3oool0oooo01@0oooo00<0a@3o0?ooo`3oool00`3oool00`2j0?l0oooo0?oo
o`040?ooo`030;X0o`3oool0oooo00<0oooo00<0a@3o0?ooo`3oool04`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo0280oooo0P350?l6
0?ooo`80^P3o1P3oool20;X0o`D0oooo0P350?l80?ooo`030?d0o`3oool0oooo00D0oooo00@0o`3>
0?ooo`00@_l004;o0`3oool0103o0<h0oooo0?ooo`00P_l30?ooo`030?d0o`3oool0oooo008008;o
1@3oool20012obT0oooo00<0J03o0?ooo`3oool09`3oool00`350?l0oooo0?ooo`030?ooo`030;X0
o`3oool0oooo00@0oooo00<0^P3o0?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203o
ool00`350?l0oooo0?ooo`0L0?ooo`030?d0o`3oool0oooo00D0oooo00<0o`3>0?ooo`3oool00P00
@_l20?ooo`050?l0cP3oool0oooo0?ooo`00P_l00P3oool01@3m0?l0oooo0?ooo`3oool008;o00D0
oooo00<004;o0?ooo`3oool00P3oool00`00okd0oooo0?ooo`050?ooo`03003oh@3oool0oooo0700
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`0a0?ooo`030012o`3oool0oooo00D0oooo00D008;o0?ooo`3oool0oooo003oh@020?ooo`04
0022o`3oool0oooo0?ooo`800?nm1P3oool00`00okd0oooo0?ooo`040?ooo`03003oh@3oool0oooo
02h0oooo00<0o`3>0?ooo`3oool0103oool00`3m0?l0oooo0?ooo`0i0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0=03oool00`3o07@0
oooo0?ooo`030?ooo`80o`2M00<00?oQ0?ooo`3oool0103oool00`00okd0oooo0?ooo`050?ooo`03
003o_@3oool0oooo01d0oooo00@004;o0?ooo`3oool00?nm0`3oool01@00P_l0oooo0?ooo`00on40
o@3o0080oooo00D008;o0?ooo`3oool0oooo0?l0cP020?ooo`050012o`3oool0oooo0?ooo`3o0<h0
1P3oool00`3m0?l0oooo0?ooo`1>0?ooo`800000BP3oool00780oooo00<000000?ooo`3oool0903o
ool00`3o09d0oooo0?ooo`040?ooo`80o`1d1P3oool20?l0M0D0oooo0P3o09dB0?ooo`03003ohP3o
ool0oooo00@0oooo0P00on850?ooo`800=So00<0oooo003oh@00on401P3oool2003o_@80oooo00<0
04;o0?ooo`3oool00P00okd30?ooo`050022o`3oool0oooo003oh@3m0?l00P3oool20022o`80oooo
00<0o`3>0?ooo`3oool00P00@_l20?ooo`030?l0cP3oool0oooo00@0oooo0P3m0?m?0?ooo`030000
003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool003So
1`3oool00`00Bol0oooo0?ooo`040?ooo`03001;o`3oool0oooo00D0oooo00<003So0?ooo`3oool0
2@3oool20?l0W@L0oooo00<0o`1d0?ooo`3oool0103oool00`3o07@0oooo0?ooo`030?ooo`050?l0
W@3oool0oooo0?ooo`001?l01P3oool203P0o`030?ooo`00f?l00=So00@0oooo0P00on850?ooo`03
003ohP3oool0oooo00<0oooo0P00f?l40?ooo`800?oQ0P3oool2003ohP80oooo0P00okd2003Ho`80
04;o00<0oooo003o_@3oool00P3oool20022o`<0oooo0P3m0?l20022o`<0oooo0P3o0<h20012o`<0
oooo0P3o0<h40?ooo`80o@3oC`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo
0?ooo`0K0?ooo`03000ho`3oool0oooo00D0oooo00<004_o0?ooo`3oool01@3oool2001;o`H0oooo
00<003So0?ooo`3oool0203oool00`3o09d0oooo0?ooo`050?ooo`040?l0M03oool0oooo03P0o`<0
oooo00<0o`1d0?ooo`3oool00P001?l00`3oool0o`2M0?ooo`030?ooo`030004o`3oool0oooo00@0
oooo0P0h0?l80?ooo`8004;o1`3oool4003Ho`80oooo0`00on850?ooo`800?oR103oool00`00f?l0
04;o0012o`0:0?ooo`80o@3o1@3oool20?l0cPD0oooo0P3o0<hT0?ooo`8004_o1@3oool2001;o`D0
oooo00<003So0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0
oooo001G0?ooo`030000003oool0oooo01`0oooo0P00>?l60?ooo`03001;o`3oool0oooo00@0oooo
0P00Bol60?ooo`8003So203oool00`3o09d0oooo0?ooo`050?ooo`030?l0M03oool0oooo0080>03o
0P3oool01@3o07@0oooo0?ooo`3oool000Co0080oooo0P00@_l20?ooo`050004o`3oool0oooo0?oo
o`00P_l00P3oool0100h0?l0oooo0?ooo`3oool20022o`D0oooo0P00@_l90?ooo`03003Ho`3oool0
oooo00<0oooo00<00?oR0?ooo`3oool0A03oool2000ho`D0oooo00<004_o0?ooo`3oool00`3oool2
001;o`@0oooo00<003So0?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04P0oooo001G0?ooo`030000003oool0oooo01`0oooo0P00>?lY0?ooo`0303P0o`3oool0oooo
00D0oooo00@000Co0?ooo`3oool0oooo0P00@_l00`3oool000Co0?ooo`020?ooo`8008;o1P3oool0
1`00P_l0oooo0?ooo`3oool0017o0?ooo`00@_l0103oool2000Ao`H0oooo0P00;old0?ooo`030?l0
W@3oool0oooo0180oooo00<003So0?ooo`3oool0103oool00`00Bol0oooo0?ooo`030?ooo`03001;
o`3oool0oooo00<0oooo00<003So0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09`3o
ool00`3<0?l0o`180?ooo`040?ooo`80o`181@3oool20?l0IP030012o`3oool0oooo00@0oooo00@0
08;o0?ooo`3oool0oooo0P00;ol20?ooo`040022o`3oool0oooo0?ooo`80017o1@3oool00`004Ol0
oooo000Ao`040?ooo`8002oo5@3oool00`00;ol0oooo0?ooo`080?ooo`050012o`3oool0o`2M0?oo
o`001?l0103oool00`3o07@0oooo03P0o`040?ooo`030?l0M03oool0oooo00<0oooo00<0o`2M0?oo
o`3oool04@3oool00`00>?l0oooo0?ooo`020<`0o`80oooo00<004_o0?ooo`3oool06@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo0100
oooo00<0c03o0?ooo`3oool01@3oool00`330?l0oooo0?ooo`040?ooo`80o`1V1P3oool20?l0B0D0
oooo0P3o04P60?ooo`030?l0IP3oool0oooo00L0oooo00@0Q`3o000_o`3oool002oo1@3oool00`00
4Ol0oooo0?ooo`040?ooo`03000Ao`3oool0oooo0180oooo00@004;o0?ooo`3oool0017o0`3oool0
2000P_l0oooo0?ooo`3oool0>03o000_o`3oool008;o0`3oool020001?l0oooo0?ooo`3oool004;o
0?l0W@3oool000Co103oool00`3o07@0oooo03P0o`050?ooo`030?l0M03oool0oooo00<0oooo00<0
o`2M0?ooo`3<0?l01@3oool20<<0o`D0oooo0P330?l50?ooo`030<`0o`3oool0oooo01d0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`0@
0?ooo`030<`0o`3oool0oooo00D0oooo00<0``3o0?ooo`3oool0103oool20?l0IP030<<0o`3oool0
oooo00<0oooo00<0o`180<`0o`3<0?l00`3oool00`3o04P0oooo0?ooo`0204`0o`<0oooo00<0o`1V
0?ooo`3oool00P1<0?l50?ooo`80Q`3o603oool4000_o`@0oooo0`004Ol00`3oool004;o0?ooo`02
0?ooo`80017o0P3oool20022o`80oooo00<0>03o0?ooo`3oool00P00P_l20?ooo`8000Co00D0oooo
0012o`00@_l0o`2M0?ooo`020004o`<0oooo00@0o`1d0?ooo`0h0?l0>03o103oool00`3o07@0oooo
0?ooo`030?ooo`030?l0W@3<0?l0oooo00@0oooo0P330?l50?ooo`80``3o103oool00`3<0?l0oooo
0?ooo`0d0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo0140oooo0P3<
0?l60?ooo`80``3o0`3oool00`3o06H0oooo0?ooo`020<<0o`<0oooo00<0o`180?ooo`3<0?l00P27
0?l00`3oool0o`180?ooo`020?ooo`80C03o0P3oool01@3o06H0oooo0?ooo`3oool0C03o00H0oooo
00<0Q`3o0?ooo`3oool00P001?l60?ooo`0303P0o`3oool0oooo00h0oooo0P00;ol60?ooo`80017o
00<0oooo0012o`00@_l00P3oool00`004Ol0oooo0?ooo`020022o`<0oooo00@0>03o0?ooo`00P_l0
08;o0`3oool00`001?l0oooo0?ooo`020?ooo`80o`2M00<000Co0?ooo`3oool00P3oool20?l0M003
03P0o`3oool0oooo0080oooo0P3o07@40?ooo`80c03o1@3oool00`330?l0oooo0?ooo`030?ooo`03
0<<0o`3oool0oooo00<0oooo00<0c03o0?ooo`3oool0=@3oool00`000000oooo0?ooo`180?ooo`00
E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<0c03o0?ooo`3oool0
103oool20<<0o`80oooo00<0o`1V0?ooo`3oool01@3oool01@3o04P0oooo0?ooo`3oool0Q`3o00H0
oooo00<0C03o0?ooo`3oool00P0h0?l20?ooo`0504`0o`3oool0oooo0?ooo`001?l00P3oool01027
0?l0oooo0?ooo`3oool20004o`D0oooo0P0h0?l20?ooo`80Y@3o1@3oool206P0oa00oooo0P00@_l:
0?ooo`80>03o2P3oool20?l0W@H0oooo00<0o`1d0?ooo`3oool02@3oool00`3<0?l0oooo0?ooo`03
0?ooo`030<<0o`3oool0oooo00<0oooo00<0``3o0?ooo`3oool0?03oool00`000000oooo0?ooo`18
0?ooo`00E`3oool00`000000oooo0?ooo`130?ooo`0308L0o`3oool0oooo00@0oooo00@0C03o0?oo
o`3oool0oooo0P0h0?l50?ooo`040004o`3oool0oooo0?ooo`80J03o00<0oooo0004o`3oool00`3o
ool00`2U0?l0oooo03P0o`030?ooo`<0Y@3o103oool00`1X0?l0oooo06P0o`0k0?ooo`030<`0o`3o
ool0oooo03<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool0
0`000000oooo0?ooo`170?ooo`80o`00103oool00`0h0?l0o`0B0?l04P040?ooo`030004o`3oool0
oooo0080oooo0P1X0?l50?ooo`80Y@3o103oool00`2U0?l0oooo0?ooo`040?ooo`0306P0o`3oool0
oooo02l0oooo00L0C03o0?ooo`3oool0oooo0?l0B03oool0Q`3o00@0oooo00<0o`180?ooo`3oool0
103oool00`3o06H0oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
B03oool005L0oooo00<000000?ooo`3oool0>03oool20?l04PD0oooo0P3o00050?ooo`80o`00103o
ool30?l04PH0oooo0P2W0?l00`3oool0J03o0?ooo`050?ooo`030:D0o`3oool0oooo02H0oooo00D0
Y@3o0?ooo`3oool0oooo0004o`020?ooo`0406P0o`3oool0Q`3o0?ooo`8000Co0`3oool01@1<0?l0
oooo03P0o`3oool0o`1V0080oooo00D0C03o0?ooo`3oool0oooo0?l0B0020?ooo`0508L0o`3oool0
oooo0?ooo`3o04P01`3oool00`3o06H0oooo0?ooo`0]0?ooo`030000003oool0oooo0180oooo0P00
001:0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<004Oo
0?ooo`3o01800P3o01820?ooo`06000`o`3oool0oooo0?l0003oool0Y`3o103oool00`3o0000oooo
07<0o`020?l0Q`040?ooo`3o0180oooo0?ooo`80L`3o1@3oool20:L0o`T0oooo00<0Q`3o0?ooo`3o
ool05`3oool00`1X0?l0oooo0?ooo`040?ooo`80Y@3o0P3oool01@0h0?l0oooo0?ooo`3oool0Y@3o
00<0oooo00D000Co0?ooo`3oool0J03o08L0o`030?ooo`040004o`3oool0oooo04`0o`80oooo00<0
>03o0?l0IP3oool00P3oool204`0o`80oooo00<0o`180?ooo`3oool00P270?l20?ooo`030?l0B03o
ool0o`1800D0oooo0P3o06H]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03o
ool00780oooo00<000000?ooo`3oool02P3oool00`00<?l0oooo0?ooo`040?ooo`030017o`3oool0
oooo00H0oooo00@0o`0B0?ooo`3oool0oooo0P3o08H0103oool0033o0?l0003oool20:L0o`<0o`26
00@0o`000?ooo`3oool0L`3o0P3oool20?l0Q`80oooo0P1c0?l00`3oool0C03o04`0o`020?ooo`03
0:L0o`3oool0oooo0080C03o1P3oool00`270?l0oooo0?ooo`070?ooo`80o@3o3`3oool00`1X0?l0
oooo0?ooo`050?ooo`80Y@3o00<0oooo03P0o`3oool00P3oool20:D0o`80oooo00@000Co0?ooo`3o
ool0J03o0P270?l00`3oool000Co0004o`020?ooo`80C03o00D0oooo03P0o`3o06H0oooo0?l0IP02
04`0o`<0oooo0P3o04P208L0o`<0oooo0P3o04P50?ooo`80o`1V;@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo00/0oooo00<0033o0?oo
o`3oool0103oool20017o`80oooo103o08L20017o`@0oooo0P3o08H00`00<?l0oooo0:L0o`030?oo
o`80o`2600@0oooo07<0o`3oool0oooo0P270?l00`3o08L0oooo07<0o`030?ooo`80C03o00<0oooo
0:L0o`3oool00P3oool204`0o`80oooo0P3o0<h00`3oool0Q`3o0?ooo`020?ooo`80o`3>1@3oool2
0?d0oa00oooo0P1X0?l50?ooo`80Y@3o0P3oool203P0o`030?ooo`2U0?l0Y@3o0080oooo0P001?l2
0?ooo`80Q`3o1@3oool204`0o`<0oooo0P3o06H50?ooo`80o`181P3oool00`3o04P0oooo0?ooo`0<
0?ooo`030?l0Q`3oool0oooo00<0oooo0P00Aol50?ooo`80033o;@3oool00`000000oooo0?ooo`18
0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo0P00<?l60?oo
o`030017o`3oool0oooo0080oooo0`3o08L50?ooo`80o`2600<0oooo0:L0o`3oool00`3oool00`3o
08H0oooo07<0o`030?ooo`80Q`3o1P3oool00`1<0?l0oooo0?ooo`020?d0o`030?ooo`1<0?l0oooo
00<0oooo0P3o0<h01`270?l0oooo0?ooo`3oool0o`3>0?ooo`3o0<h0103oool00`3m0?l0oooo0?oo
o`0@0?ooo`80J03o2P3oool00`0h0?l0oooo0?ooo`0D0?ooo`030?l0IP3oool0oooo00d0oooo00<0
o`260?ooo`3oool00P3oool00`3o08H0033o000`o`040?ooo`030?l0Q`00Aol0o`2700@0oooo0P00
Aol40?ooo`03000`o`3oool0oooo02d0oooo00<000000?ooo`3oool0B03oool005L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030?l0Q`3oool0oooo0140oooo00<0Q`3o
0?ooo`3oool01@3oool0101<0?l0oooo0?ooo`3oool20?d0o`D0oooo00<0o`3>0?ooo`3oool00`3o
ool00`3o0<h0oooo0?ooo`040?ooo`030?d0o`3oool0oooo03`0oooo0`3o08L0103oool0Y`3o0?oo
o`3oool30?l0QP080?ooo`3o08H0o`260?ooo`00<?l0o`260?l04P3oool20?l0Q`030017o`3o08L0
oooo00<0oooo00<004Oo0?ooo`3oool00`3oool00`00<?l0oooo0?ooo`0^0?ooo`030000003oool0
oooo04P0oooo001G0?ooo`030000003oool0oooo0500oooo0P3K0?l00`3oool0o@3o0?ooo`050?oo
o`030?l0cP3oool0oooo03L0oooo00<0o@3o0?ooo`3oool00P3oool01`1<0?l0oooo0?ooo`3oool0
L`3o0?ooo`270?l00P3o01820?ooo`0807<0o`3o08L0o`270?ooo`3o08L0o`000?ooo`2W0?l20?l0
QP040?ooo`3o08H0o`000?l00080oooo00<0033o0?ooo`3oool00P3o01800`3oool004Oo0?ooo`0V
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?oo
o`3oool0@@3oool20:h0o`D0oooo0P2^0?l50?ooo`80f`3o0`3oool00`1c0?l0oooo0?ooo`040?oo
o`80Y`3o:@3oool00`3o0<h0oooo0?ooo`020?ooo`0408L0o`3oool0oooo0?l0cP<0oooo00D0C03o
0?ooo`3oool0o@3o0:L0o`020?ooo`0304`0o`3oool0oooo0080oooo00@0L`3o0?ooo`270?l0oooo
0`3o01850?ooo`80o`000P2W0?l30?ooo`80o`0000@0033o0?ooo`3oool0oooo0`3o018X0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0
>@3oool20=/0o`D0oooo0P2^0?l30?ooo`050:L0o`3oool0[P3o0?ooo`2^0?l00P3oool207<0o`03
0=/0o`3oool0oooo00<0oooo00<0L`3o0?ooo`3oool00`3oool20:L0o`80oooo0P3o07@60?ooo`80
o`2M5`3oool00`3m0?l0oooo0?ooo`050?ooo`050?l0cP3oool0oooo0?ooo`270?l00P3oool01@3o
0<h0oooo0?ooo`3oool0C03o00<0oooo00@0o@3o0:L0o`3oool0oooo0P1<0?l30?ooo`0407<0o`3o
ool0Q`3o08L0o`80o`0B0P1c0?l30?ooo`80o`000P2W0?l30?ooo`030?l0003oool0oooo02h0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?oo
o`0M0?ooo`030=/0o`3oool0f`3o00<0oooo00<0A03o0:h0o`3oool0103oool00`2W0?l0[P3o06H0
o`040?ooo`80L`3o00<0oooo0?l0W@3o09d00P3oool0101c0?l0oooo0?ooo`3oool20?l0M0030:L0
o`3oool0oooo0080oooo0P3o07@60?ooo`030?l0W@3oool0oooo01L0oooo00<0o@3o0?ooo`3oool0
1@3oool20?l0cP80oooo0P270?l00`3oool0o`3>0?l0cP020?ooo`80C03o00<0oooo0?d0o`3m0?l0
0P2W0?l204`0o`<0oooo0P1c0?l00`3oool0Q`3o0?l04P020?ooo`0307<0o`3oool0oooo03T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?oo
o`0C0?ooo`<0IP3o1@3oool00`140?l0f`3o04@0o`060?ooo`80A03o0`3oool00`2W0?l0oooo0?oo
o`0206H0o`<0oooo00<0L`3o0?ooo`3oool00P3o09d00`3oool0L`3o0?ooo`030?ooo`80o`1d103o
ool00`3o07@0oooo0?ooo`050?ooo`030?l0W@3oool0oooo01T0oooo0P3m0?l60?ooo`030?l0cP3o
ool0oooo0080Q`3o00<0oooo0?l0cP3o0<h00`3oool0101<0?l0oooo0?ooo`3oool20:L0odP0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?oo
o`0E0?ooo`80IP3o1P3oool204@0o`H0oooo00@0A03o0?ooo`3oool0Y`3o1`3oool01@1c0?l0oooo
0?ooo`3oool0o`2M00H0oooo00<0o`1d0?ooo`3oool00`3oool00`3o07@0oooo0?ooo`050?ooo`03
0?l0W@3oool0oooo01X0oooo0P3m0?me0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`1V0?l0oooo0?ooo`0J0?ooo`030?l0
W@3oool0oooo00@0oooo00<0o`1d0?ooo`3oool0@P3oool00`3o09d0oooo0?ooo`080?ooo`030:L0
o`3oool0oooo00<0oooo0P2^0?l50?ooo`80f`3o103oool00`140?l0oooo0?ooo`030?ooo`80IP3o
>03oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo04H0oooo0P3o06H`0?ooo`050?l0M03oool0oooo0?ooo`1c0?l00P3oool00`3o09d0oooo
0?ooo`020=/0o`D0oooo0P2^0?l40?ooo`0306H0o`3oool0oooo0080[P3o0P3oool204@0o`040?oo
o`3K0?l0f`3o0?ooo`<0A03o0P3oool206H0o`030?ooo`1V0?l0oooo03L0oooo00<000000?ooo`3o
ool0B03oool005L0oooo00<000000?ooo`3oool0C`3oool00`2^0?l0oooo0?ooo`020?l0B080oooo
00<0f`3o0?ooo`3oool00P3o04P60?ooo`030?l0IP3oool0oooo0240oooo00<0o`2M0?ooo`3oool0
103oool01@3o07@0oooo0?ooo`3oool0Y`3o0080oooo00D0o`1d0?ooo`3oool0oooo07<0o`030?oo
o`050?l0W@3oool0oooo07<0o`3K0?l01P3oool20:h0o`80oooo0P1V0?l20?ooo`040:h0o`140?l0
A03o04@0o`80oooo00<0f`3o04@0o`140?l0:`3oool00`000000oooo0?ooo`0B0?ooo`800000BP3o
ool005L0oooo00<000000?ooo`3oool0@03oool00`3K0?l0oooo0?ooo`040?ooo`80[P3o00D0oooo
0?l0IP3o06H0oooo0?l800020:h0o`80oooo0P3o04P20?ooo`050=/0o`3oool0oooo0?ooo`3o04P0
1@3oool00`3o06H0oooo0?ooo`0R0?ooo`030?l0W@3oool0oooo00D0oooo00D0o`1d0?ooo`3oool0
oooo0:L0o`020?ooo`040?l0M03oool0o`1d0?ooo`80L`3o00<0oooo0?l0W@3o09d00P3oool00`1c
0?l0f`3o0?ooo`040?ooo`060:L0o`2^0?l0IP3o06H0o`3oool0IP3o=P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo03l0oooo0P3K0?l5
0?ooo`040?l7002^0?l0[P3o0?ooo`80o`1V0`3oool0102^0?l0oooo0?ooo`3o04P20?ooo`060?l0
003oool0oooo0?ooo`3o04P0oooo0P3o01820?ooo`030?l0IP3oool0oooo02@0oooo00<0o`2M0?oo
o`3o09d01@3oool20?l0M080oooo00<0Y`3o0?ooo`3oool00P3o07@20?ooo`0407<0o`3oool0o`2M
0?l0W@<0oooo0P3K0?m00?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool0
0780oooo00<000000?ooo`3oool0703oool00`3o2000oooo0?ooo`040?ooo`030?l7003oool0f`3o
00H0oooo00@0[P3o0?ooo`3oool0o`1V0`3oool0103o0000o`P00?ooo`3o04P20?ooo`80o`000P3o
ool01@3o04P0oooo0?ooo`3oool0o`0B02X0oooo0P3o09d50?ooo`80o`1d0P3oool20:L0o`80oooo
00<0o`1d0?ooo`3oool0B@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo
001b0?ooo`030000003oool0oooo02@0oooo00<0f`3o0?l7003oool00`3oool20?l04P030?ooo`3o
1`00o`1V00<0oooo0P3o00000`3oool0o`180?ooo`020?ooo`80o`001@3oool00`3o0180oooo0?oo
o`0Z0?ooo`030?l0W@3oool0oooo05L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`180?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030?l0003o2000o`P000D0oooo00<0f`3o
0?ooo`3oool00`3oool20?l04PH0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030?l04P3oool0oooo03X0oooo00<0o`180?ooo`3oool0103oool00`3o06H0oooo0?ooo`0@
0?ooo`80o`P0A03oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01@0oooo0P3o0P0D0?ooo`030?l04P3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l04P3oool0oooo03@0oooo00<0o`180?oo
o`3oool0103oool00`3o04P0oooo0?ooo`050?ooo`030?l0IP3oool0oooo00T0oooo00<0o`L00?oo
o`3oool0B@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`150?ooo`03
0?l04P3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o08H0o`000?ooo`040?ooo`80
o`27;`3oool00`3o06H0oooo0?ooo`040?ooo`030?l0B03oool0oooo00D0oooo00<0o`180?ooo`3o
ool00P3oool00`3o2000oooo0?ooo`020?l0IP030:h0o`3oool0o`L000@0oooo00<0f`3o0?ooo`3o
ool0103oool00`3o2000oooo0?ooo`140?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000
003oool0oooo04@0oooo00<0o`0B0?ooo`3oool00`3oool00`3o08H0oooo0?ooo`050?ooo`80o`26
1@3oool00`3o08L0oooo0?ooo`0^0?ooo`030?l0IP3oool0oooo00D0oooo00<0o`180?ooo`3oool0
1@3oool20?l0B0030:h0o`3oool0oooo0080oooo0P3o06H00`2^0?l0oooo0?ooo`040?ooo`030?l7
003oool0oooo03D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3o
ool00`000000oooo0?ooo`130?ooo`80o`271@3oool20?l0QPH0oooo00<0o`260?ooo`3oool0103o
ool00`3o08L0oooo0?ooo`0_0?ooo`030?l0IP3oool0o`1V00D0oooo0P3o04P00`3K0?l0oooo0?oo
o`020?ooo`80o`1800<0o`P00?ooo`3oool0103oool00`3o1`00[P3o0?ooo`050?ooo`80f`3o1`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l2003oool0oooo02@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02P0oooo00<0o`270?ooo`3oool0103oool00`3o08H0oooo0?ooo`060?ooo`030?l0QP3oool0
oooo00@0oooo00<0o`270?ooo`3oool0;`3oool20?l0IPD0oooo0P3o04P00`3K0?l0oooo0?ooo`04
0?ooo`030?l8002^0?l0oooo00D0oooo0P2^0?l50?ooo`80f`3o00<0oooo0?l0003oool0103oool0
0`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool3
000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0a
0?ooo`00LP3oool00`000000oooo0?ooo`0X0?ooo`030?l0Q`3oool0oooo00D0oooo00<0o`2604@0
o`3oool01@3oool00`3o08H0IP3o0?ooo`040?ooo`030?l0Q`3oool0oooo0300oooo00<0o`1V0?oo
o`3o01801P3oool00`3K0?l0oooo0?ooo`040?ooo`80[P3o1@3oool20:h0o`030?ooo`3o0P00oooo
03T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`0>0000003oool0oooo
0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV000000c0?ooo`00LP3oool00`00
0000oooo0?ooo`0Y0?ooo`030?l0Q`140?l0oooo00@0oooo00<0o`2604@0o`140?l01@3oool00`3o
08H0oooo0?ooo`0i0?ooo`030?l04P3oool0oooo00@0oooo0P3K0?l60?ooo`030:h0o`3oool0oooo
00@0oooo00<0o`0B0?ooo`3oool0>P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0340oooo001b0?ooo`030000003oool0oooo0280oooo00<0IP3o0?l0003oool0103oool00`3o
08L0A03o0?ooo`050?ooo`0304@0o`3oool0oooo00D0oooo00<0IP3o0?ooo`3oool0>@3oool00`3o
0180oooo0?ooo`040?ooo`030=/0o`3oool0oooo00@0oooo0P3o00050?ooo`80o`0BD@3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0a0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01/0oooo00<0o`800?ooo`3oool0103oool00`1V0?l0oooo0?ooo`050?ooo`0304@0o`3oool0oooo
00D0oooo00<0A03o0?ooo`3oool0103oool00`1V0?l0oooo0?ooo`0i0?ooo`030?l04P3oool0oooo
00@0oooo0P3o00050?ooo`80o`00103oool00`3o08L0oooo0?l04P1?0?ooo`<000002@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0<@3oool0
05L0oooo00<000000?ooo`3oool0?P3oool00`1V0?l0oooo0?ooo`040?ooo`0304@0o`3oool0oooo
00D0oooo00<0A03o0?ooo`3oool0@03oool20?l04PD0oooo0P3o00040?ooo`030?l0QP3oool0o`00
00@0oooo00<0o`270?ooo`3oool0>`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0340oooo001G0?ooo`030000003oool0oooo03h0oooo00<0IP3o0?ooo`3oool07P3oool00`3<
0?l0oooo0?ooo`0^0?ooo`80o`0B103oool00`3o08H0oooo0?l000040?ooo`030?l0QP3oool0oooo
00@0oooo00<0o`270?ooo`3oool0>`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
000003<0oooo001G0?ooo`030000003oool0oooo0500oooo00<0``3o0?ooo`3oool0103oool20<<0
o`H0oooo00<0c03o0?ooo`3oool0;@3oool00`3o08L0oooo0?ooo`040?ooo`030?l0QP3oool0oooo
00@0oooo00<0o`260?ooo`3oool00`3oool00`3o08L0oooo0?ooo`0=0?ooo`80o`80;@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00D08B4Q0000003oool0oooo09RHV003
0000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0<@3oool005L0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0]0?ooo`80c03o1P3oool20<<0o`D0oooo0P330?l70?oo
o`030<`0o`3oool0oooo02`0oooo00<0o`270?ooo`3oool0103oool00`3o08H0oooo0?ooo`030?oo
o`030?l0QP3oool0oooo00<0oooo0`3o08L60?ooo`0306H0o`3oool0o`0003@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`0^0?ooo`03
0<`0o`3oool0oooo00D0oooo00<0``3o0?ooo`3oool01@3oool00`330?l0oooo0?ooo`050?ooo`03
0<`0o`3oool0oooo02/0oooo00<0o`270?ooo`3oool00`3oool00`3o08H0oooo0?ooo`040?ooo`80
o`2600<0oooo0?l2003oool00P3oool0103o08L0A03o0?ooo`3o00040?ooo`0306H0o`3oool0oooo
03@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000
oooo0?ooo`0_0?ooo`030<`0o`3oool0oooo00D0oooo00<0``3o0?ooo`3oool01@3oool00`330?l0
oooo0?ooo`0a0?ooo`80o`271@3oool20?l0QPD0oooo00<0o`2604@0o`3oool01@3oool00`140?l0
oooo0?ooo`040?ooo`0306H0o`3oool0oooo04X0oooo00<000000?ooo`3oool0B03oool00780oooo
00<000000?ooo`3oool0<03oool00`3<0?l0oooo0?ooo`100?ooo`80o`271@3oool00`3o08H0IP3o
0?ooo`050?ooo`0304@0o`3oool0oooo00@0oooo00<0A03o0?ooo`3oool00`3oool00`1V0?l0oooo
0?ooo`1;0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0N`3oool00`1V0?l0oooo0?ooo`030?ooo`0304@0o`3<0?l0oooo00@0oooo0P14
0?l50?ooo`0306H0o`3oool0oooo04/0oooo00<000000?ooo`3oool0B03oool005L0oooo00<00000
0?ooo`3oool0U@3oool00`1V0?l0``3o0?ooo`040?ooo`80A03o1@3oool00`140?l0oooo0?ooo`0l
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?oo
o`3oool0F@3oool00`00<?l0oooo0?ooo`0/0?ooo`030<`0o`3oool0oooo00<0oooo0P330?l50?oo
o`80IP3o0`3oool20<`0odH0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?oo
o`00E`3oool00`000000oooo0?ooo`1A0?ooo`8004Oo1P3oool00`00<?l0oooo0?ooo`0[0?ooo`03
0<`0o`3oool0oooo0080oooo0P330?l50?ooo`80``3o1@3oool20<`0odH0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo02l0oooo0P00Aol50?ooo`8004Oo1`3oool00`00<?l0oooo0?ooo`0X0?ooo`80c03o
1@3oool20<<0o`D0oooo00<0``3o0?ooo`3oool0C03oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo02L0oooo0P00<?l60?ooo`8004Oo1`3o
ool00`00Aol0oooo0?ooo`0_0?ooo`80c03oF`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo04P0oooo001b0?ooo`030000003oool0oooo02P0oooo00<0033o0?ooo`3oool01P3oool0
0`00Aol0oooo0?ooo`2X0?ooo`800000BP3oool00780oooo00<000000?ooo`3oool0:@3oool00`00
<?l0oooo0?ooo`0R0?ooo`80a@3oS@3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo04L0oooo00<0^P3o0?ooo`3oool0103oool00`350?l0
oooo0?ooo`0h0?ooo`03000`o`3oool0oooo0540oooo00<000000?ooo`3oool0B03oool005L0oooo
00<000000?ooo`3oool0FP3oool20;X0o`H0oooo00<0^P3o0?ooo`3oool01@3oool00`350?l0oooo
0?ooo`0`0?ooo`030017o`3oool0oooo00@0oooo00<0033o0?ooo`3oool0>`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo05<0oooo0P35
0?l50?ooo`80^P3o1`3oool00`2j0?l0oooo0?ooo`050?ooo`030<D0o`3oool0oooo02P0oooo00<0
04Oo0?ooo`3oool0103oool00`00Aol0oooo0?ooo`020?ooo`80033o?P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo05<0oooo00<0a@3o
0?ooo`3oool01P3oool00`2j0?l0oooo0?ooo`050?ooo`030;X0o`3oool0oooo02P0oooo00<0033o
0?ooo`3oool0103oool00`00Aol0oooo0?ooo`020?ooo`8004Oo1@3oool00`00<?l0oooo0?ooo`0m
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0i0?ooo`030<D0o`3oool0oooo00H0oooo00<0^P3o0?oo
o`3oool0;`3oool01@00<?l0oooo0?ooo`350?l0oooo008004Oo1@3oool20017odD0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo0?ooo`0j0?oo
o`030<D0o`3oool0oooo03<0oooo00@0^P3o0?ooo`00<?l0033o0P3oool00`350?l0oooo0?ooo`02
0017od`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`00
0000oooo0?ooo`1Y0?ooo`030;X0o`3oool0oooo00<0oooo00D0^P3o0?ooo`3oool0033o0?ooo`02
0<D0ofL0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0B03oool00`00
>?l0oooo0?ooo`0F0?ooo`030<D0o`3oool0oooo00@0oooo00<0^P3o0?ooo`3oool00P3oool20;X0
o`D0oooo0P350?mW0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0@@3oool00`00Bol0oooo0?ooo`040?ooo`8003So5`3oool00`350?l0
oooo0?ooo`020?ooo`80^P3o1@3oool20;X0ofh0oooo00<000000?ooo`3oool0B03oool005L0oooo
00<000000?ooo`3oool0E03oool2001;o`H0oooo00<004_o0?ooo`3oool01P3oool00`00>?l0oooo
0?ooo`0B0?ooo`80a@3o1@3oool20;X0oel0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`1=0?ooo`03000ho`3oool0oooo00@0oooo0P00
Bol70?ooo`03001;o`3oool0oooo01X0oooo0P350?mV0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0C@3oool00`00>?l0oooo0?ooo`06
0?ooo`03001;o`3oool0oooo08T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`18
0?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03<0oooo00<003So0?oo
o`3oool08P3oool20;X0ofd0oooo00<000000?ooo`3oool04P3oool2000004X0oooo001b0?ooo`03
0000003oool0oooo0540oooo0P2c0?l50?ooo`030;X0o`3oool0oooo02<0oooo00<003So0?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000
003oool0oooo04X0oooo0P2c0?l50?ooo`80/`3o1P3oool00`2j0?l0oooo0?ooo`0K0?ooo`03001;
o`3oool0oooo0080oooo0P00>?mO0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0@P3oool20;X0o`H0oooo0P2c0?l60?ooo`030;<0o`3o
ool0oooo00D0oooo00<0^P3o0?ooo`3oool04`3oool00`00Bol0oooo0?ooo`020?ooo`8004_o1@3o
ool00`00>?l0oooo0?ooo`1N0?ooo`030000003oool0oooo04P0oooo001G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0@P3oool20;X0o`L0oooo00<0/`3o0?ooo`3oool01@3oool0
0`2c0?l0oooo0?ooo`0C0?ooo`05000ho`3oool0oooo0;X0o`3oool00P00Bol50?ooo`03001;o`3o
ool0oooo06D0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0G`3oool0
0`2j0?l0oooo0?ooo`050?ooo`030;<0o`3oool0oooo01H0oooo00@0/`3o0?ooo`00>?l003So0P3o
ool0102j0?l0oooo0?ooo`00BomH0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
B03oool005L0oooo00<000000?ooo`3oool0H03oool00`2j0?l0oooo0?ooo`0F0?ooo`030;<0o`3o
ool0oooo00<0oooo00@0/`3o0?ooo`3oool003So0P3oool00`2j0?l0oooo0?ooo`1J0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0N03o
ool00`2c0?l0oooo0?ooo`030?ooo`030;<0o`3oool0oooo00<0oooo0P2j0?mL0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0DP3oool2
0013o`80oooo00<0^P3o0?ooo`3oool00P3oool20;<0o`D0oooo0P2c0?mS0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0B`3oool00`00
Dol0oooo0?ooo`040?ooo`8004?o0P2j0?l50?ooo`80/`3oJP3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo04@0oooo00<005?o0?ooo`3o
ool0103oool00`00Dol0oooo0?ooo`060?ooo`80^P3o203oool20?l0kWd0oooo00<000000?ooo`3o
ool0B03oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`140?ooo`03001C
o`3oool0oooo00D0oooo00<005?o0?ooo`3oool01`3oool20?l0l@H0oooo00<0o`3^0?ooo`3o0>h0
O03oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo03`0oooo0P00@ol70?ooo`03001Co`3oool0oooo00D0oooo00@005?o0?ooo`3oool0o`3a
1P3oool30?l0l@L0oooo00<0o`3^0?ooo`3oool00P3o0>ig0?ooo`030000003oool0oooo04P0oooo
001G0?ooo`030000003oool0oooo05P0oooo00<004?o0?ooo`3oool01@3oool00`00Dol0oooo0?oo
o`070?ooo`80o`3a2@3oool00`3o0?40oooo0?ooo`060?ooo`030?l0kP3oool0oooo00d0oooo00<0
04?o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0B0?ooo`800000BP3oool005L0oooo00<00000
0?ooo`3oool0F@3oool00`00@ol0oooo0?ooo`070?ooo`80o`3^1`3oool20?l0l@P0oooo00@0o`3a
0?ooo`3o0?40o`3a0`3oool20?l0kPP0oooo00<005?o0?ooo`3oool00P3oool20013oe@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`1S
0?ooo`030?l0kP3oool0o`3^00P0oooo0P3o0?400`3oool0o`3a0?l0l@030?ooo`80o`3a203oool0
0`00Dol0oooo0?ooo`020?ooo`8005?o1@3oool00`00@ol0oooo0?ooo`1C0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<000000?ooo`3oool0B`3oool0103o
0>h0oooo0?ooo`3oool20?l0kP<0oooo0P3o0?470?ooo`030013o`3oool0oooo00@0oooo00<005?o
0?ooo`3oool00`3oool2001Coe/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`18
0?ooo`00LP3oool00`000000oooo0?ooo`1=0?ooo`80o`3^1P3oool00`3o0?40oooo0?ooo`050?oo
o`030013o`3oool0oooo00<0oooo00<005?o0?ooo`3oool0H@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo04`0oooo0P3o0>h=0?ooo`03
0003o`00@ol0oooo07l0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1L0?ooo`030013o`000ol0oooo07h0oooo00<000000?ooo`3oool0
B03oool005L0oooo00<000000?ooo`3oool0K`3oool3000@o`L0oooo00<000?o0?ooo`3oool0O03o
ool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`1X0?ooo`80013o203oool0
0`004?l0oooo0?ooo`0<0?ooo`<000?oGP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04P0oooo001G0?ooo`030000003oool0oooo0640oooo00<000?o0?ooo`3oool01@3oool2000@
oa00oooo0P004?l40?ooo`030003o`3oool0oooo05h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`180?ooo`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04H0
oooo0P000ol80?ooo`03000@o`3oool0oooo00H0oooo0P004?l40?ooo`03000@o`3oool0oooo06D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`180?ooo`030003o`3oool0oooo00d0oooo00<0013o0?ooo`3oool0103oool00`004?l0oooo
0?ooo`1U0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B03oool00780oooo00<0
00000?ooo`3oool0D03oool010000ol0oooo0003o`000ol30?ooo`80013oKP3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001`0?ooo`D00000D03oool20003oh/0oooo00<0
00000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3oool0503oool2000000D0oooo0P000003
0?ooo`<00000e03oool2000004X0oooo001G0?ooo`030000003oool0oooo00d0oooo1@00000A0?oo
o`8000000`3oool500000</0oooo00<000000?ooo`3oool0B03oool005L0oooo00<000000?ooo`3o
ool01`3oool3000002H0oooo1@0000030?ooo`<00000?P3oool20?m806L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`180?ooo`00E`3oool00`000000oooo00000002000000<0oooo
0P00000d0?ooo`8000000P3oool5000002h0oooo0P3o<@0>0?ooo`80odP0GP3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo04P0oooo001G0?ooo`<00000A`3oool5000000<0oooo0`00
000Q0?ooo`030?la003oool0oooo00H0oooo00<0oc400?ooo`3oool0H`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04P0oooo001M0?ooo`D000000`3oool3000004@0oooo0P000003
0?ooo`D000003`3oool00`3o<@00oooo0?ooo`0>0?ooo`030?la003oool0oooo06<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`180?ooo`00J03oool2000000<0oooo1@0000170?oo
o`D0000000<0odP00?ooo`3oool03@3oool20?la0880oooo00<000000?ooo`3oool0B03oool007@0
oooo1@0000180?ooo`D0000000<0oooo0?m8000000000P0000270?ooo`030000003oool0oooo04P0
oooo001l0?ooo`D000000`3oool3000004@0oooo0P0000030?ooo`D00000O@3oool00`000000oooo
0?ooo`040?ooo`@0000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RH
V03oool0oooo0340oooo00270?ooo`8000000`3oool5000004L0oooo1@0000030?ooo`<00000F@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0140c<c<0>k^kP3oool0c<c<
05EEE@3oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH0000000c0?ooo`00
U03oool5000004X0oooo0P0000030?ooo`D00000C`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00D0oooo00<0c<c<0>k^kP3oool00P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`0a0?ooo`00W03oool500000080oooo0`00001:0?ooo`D0
00000P3oool300000480oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`05
0:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
0340oooo002V0?ooo`8000000`3oool5000004X0oooo0P0000030?ooo`<00000>P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00D0gMgM06IVIP3oool0oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0<@3oool00;<0oooo1@0000030?ooo`<0
0000A03oool2000000<0oooo1@00000`0?ooo`030000003oool0oooo0180oooo0P0000060?ooo`04
07MgM`3oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0<@3oool00;h0oooo0P0000030?ooo`<00000B@3oool5000000<0oooo0`00000f
0?ooo`030000003oool0000000H0oooo00@0000009RHV02HV9P000000P3oool02`000000V9RH0?oo
o`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000003<0oooo00360?ooo`8000000`3oool40000
04/0oooo0P0000030?ooo`@00000;`3oool00`000000oooo0?ooo`040?ooo`0409RHV00000000000
09RHV080oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0
<@3oool00=80oooo1@0000030?ooo`<00000B@3oool5000000<0oooo0`00000Q0?ooo`030000003o
ool0oooo04P0oooo003M0?ooo`8000000`3oool3000004`0oooo0P0000030?ooo`D0000000<0oooo
0000003oool0503oool00`000000oooo0?ooo`180?ooo`00i@3oool2000000<0oooo1@00001=0?oo
o`030000003oool0000000@000000`3oool3000000D0oooo00D000000?ooo`3oool0oooo0000001:
0?ooo`00lP3oool5000000<0oooo0`00000o0?ooo`030000003oool0oooo00X0oooo0P0000030?oo
o`D00000BP3oool00?d0oooo00@000000?ooo`3oool0oooo0`00000h0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000003000004X0oooo003o0?oo
o`D0oooo0P0000030?ooo`D00000;P3oool00`000000oooo0?ooo`080?ooo`040000003oool00000
0?ooo`D00000C@3oool00?l0oooo4P3oool5000000<0oooo0`00000U0?ooo`050000003oool00000
0000003oool00P0000000`3oool000000000000200000500oooo003o0?oooad0oooo0P0000030?oo
o`<000006`3oool010000000oooo0000003oool6000005@0oooo003o0?ooobD0oooo0P0000020?oo
o`D000003`3oool01@000000oooo000000000000oooo00D00000E`3oool00?l0oooo<@3oool50000
00<0oooo0`0000000`3oool000000?ooo`03000005`0oooo003o0?oooc`0oooo0`00001O0?ooo`00
o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooom=0?ooo`@0
000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`140?ooo`00o`3ooom=0?ooo`0;0<c<
c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000AP3oool00?l0ooooA@3oool0
1@2HV9P00000000000000000V9RH00@0oooo00<0c<c<0>k^kP3oool00P3oool01@000000oooo0?oo
o`3oool0000004H0oooo003o0?oooc`0oooo100000000`2j^[X0oooo09RHV00:00000080oooo00D0
ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo04@0oooo003o0?oooc`0oooo00T0
c<c<0>k^kP3oool0c<c<05EEE@3oool0000009RHV03oool00P0000020?ooo`030000003oool0oooo
00<0oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003oool0oooo04@0oooo003o0?oo
ocd0oooo00<0c<c<0>k^kP3oool00P3oool00`000000oooo0?ooo`0200000080oooo00D000000?oo
o`3oool0oooo07MgM`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0A03o
ool00?l0oooo?P3oool01@2YZJT0k^k^0?ooo`3oool000000080oooo0P0000020?ooo`050000003o
ool0oooo0?ooo`0000000P2HV9P020000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000AP3oool0
0?l0oooo?P3oool01@3MgMd0IVIV0?ooo`3oool000000080oooo0P0000020?ooo`050000003oool0
oooo0?ooo`2HV9P00P000000102HV9P0oooo0?ooo`2HV9P30000000309RHV03oool0oooo04@0oooo
003o0?oooc`0oooo00@0MgMg0?ooo`3oool000000P3oool00`000000oooo0?ooo`02000000030?oo
o`2HV9P0000005@0oooo003o0?oooc`0oooo00@0000009RHV02HV9P000000P3oool010000000V9RH
0?ooo`2HV9P30000000309RHV03oool0oooo0580oooo003o0?oooc`0oooo00@0V9RH000000000000
V9RH0P3oool01@2HV9P00000000000000000V9RH05L0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oood<0oooo0`0000000`3oool0
MgMg00000002000005<0oooo003o0?oood@0oooo00H0V9RH07MgM`3oool0oooo024Q8@2YZJUD0?oo
o`00o`3ooom50?ooo`0405EEE@2HV9P0MgMg06IVIUD0oooo003o0?ooodD0oooo00<0k^k^024Q8@0b
<S80EP3oool00?l0ooooA@3oool00`3^k^h0410@038b<P1F0?ooo`00o`3ooom50?ooo`0406IVIP1g
MgL0ZJVY06IVIUD0oooo003o0?oood@0oooo00@0ZJVY024Q8@3oool0oooo0P2HV9P00`3^k^h0oooo
0?ooo`1A0?ooo`00o`3ooom30?ooo`<0000000<0MgMg0?ooo`0b<S800P0000000`2j^[X0oooo0?oo
o`1@0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3o
oonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3o
oonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00T03o
ool01P2HV9P0410@0000000@4100MgMg0>k^k_l0oooo203oool00900oooo00H000000;Zj^P3oool0
k^k^08N7Q`0b<S;o0?ooo`P0oooo002@0?ooo`0607MgM`3^k^h0oooo0?ooo`3MgMd00000o`3oool8
0?ooo`00P03oool3000000040?ooo`2j^[X0A4A40?ooo`<0000000L0oooo09RHV0000000V9RH024Q
8@1EEED0MgMg00<0000000<0410@08N7Q`0000000P0000001`3oool000000000002HV9P00000010@
403<c<`00P3oool00`2YZJT0<S8b000000070000000809RHV0000000V9RH024Q8@1EEED0oooo0:VY
Z@0b<S830000000609RHV000000000000000002HV9P0oooo0`0000000`3oool00000000000050?oo
o`H0000000<0oooo000000000000103oool60000000909RHV000000000000000002HV9P00000010@
403<c<`0oooo00<0000000@0oooo000000000000oooo0P0000001@2HV9P00000010@403<c<`0oooo
00<0000000H0oooo000000000000oooo0:VYZ@0b<S860?ooo`030000003oool0000000L0oooo0`00
00030?ooo`<000000`3oool3000008<0oooo00200?ooo`0B0=gMg@000000c<c<0?ooo`0b<S800000
0=gMg@3^k^h000000>k^kP3oool0000009RHV03MgMd000000>k^kP0b<S80gMgM1@3oool02@000000
oooo0?ooo`000000oooo0000002HV9P0^[Zj010@40020?ooo`070000003oool0oooo0000003oool0
c<c<024Q8@020?ooo`08038b<P000000V9RH0=gMg@000000k^k^0?ooo`0000020?ooo`070000003o
ool0000009RHV03oool0V9RH000000020?ooo`040000003oool0oooo000000L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`040?ooo`0=0000003oool0oooo0?ooo`2YZJT0A4A4
0?ooo`000000oooo0000002HV9P0^[Zj010@40020?ooo`040000003oool0oooo00000080oooo00H0
00000?ooo`000000V9RH0;Zj^P0@41020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01@3oool0100b<S80^[Zj038b<P2j^[X70?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`220?ooo`00P@3oool010000000oooo0;Zj^P0b<S82
07MgM`0>0?ooo`000000oooo0?ooo`000000V9RH0?ooo`000000oooo0=gMg@0Q8B400000010@402Y
ZJT20?ooo`060000003oool0oooo0000003oool000001@3oool010000000oooo0?ooo`0000020?oo
o`0809RHV01EEED0oooo0?ooo`000000V9RH0?ooo`0000020?ooo`060000003oool0oooo0000003o
ool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`04038b<P2j^[X0<S8b0;Zj
^PL0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0880oooo00210?ooo`080000003oool0<S8b0:VYZ@3^k^h0410@0?ooo`0000020?ooo`0:09RHV000
000000000000003oool08B4Q08N7Q`3oool0gMgM00000080oooo00D000000?ooo`3oool000000?oo
o`0400000080oooo00@000000?ooo`3oool000000`3oool0101EEED0V9RH0?ooo`2HV9P300000080
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0000000300000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0000000300000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`D000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0PP3oool00840oooo00<000000;Zj^P0@41000P3oool00`1E
EED0ZJVY000000040?ooo`0809RHV0000000oooo0000003<c<`0oooo08N7Q`0000020?ooo`060000
003<c<`0V9RH0000003oool000000P2HV9P010000000oooo0?ooo`0000020?ooo`070000003oool0
IVIV0?ooo`3^k^h08B4Q0<c<c0020?ooo`0509RHV0000000oooo0?ooo`0000000P3oool01`000000
oooo0000002HV9P0oooo09RHV00000000P3oool010000000c<c<09RHV00000070?ooo`070000003o
ool0oooo0000003<c<`0V9RH000000060?ooo`@000000`3oool00`000000oooo0000000209RHV004
0000003oool0oooo00000080c<c<00H000000;Zj^P3<c<`000000?ooo`00000209RHV0070000003o
ool0oooo0000003<c<`0V9RH000000020?ooo`030000003oool0oooo00D0oooo101gMgL70?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`220?ooo`00
P@3oool00`000000<S8b09RHV0020?ooo`030=gMg@14A4@000000080oooo00/0A4A4000000000000
V9RH0?ooo`3<c<`0410@00000014A4@0k^k^0?ooo`020000000509RHV0000000V9RH0?ooo`2HV9P0
0P0000000`2HV9P0oooo00000004000000030?ooo`000000000000<0000000D0A4A4000000000000
V9RH0?ooo`05000000030?ooo`2HV9P000000080000000L0V9RH0?ooo`000000000009RHV0000000
V9RH00H0oooo0P0000001P3oool000000000002HV9P0000009RHV0H0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo09RHV0020000000<09RHV03oool000000000002HV9P0000008N7Q`2H
V9P0000009RHV03oool0V9RH0P000000202HV9P0oooo000000000000V9RH0000002HV9P0oooo0`00
00060?ooo`D000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0PP3oool00800oooo00<0k^k^0000000@4100103oool00`0b<S8000000>k^kP0G
0?ooo`0308N7Q`000000oooo00d0oooo00<0QhN70000003oool08P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0603oool00`27QhL000000?ooo`060?ooo`040;Zj^P0b
<S80^[Zj038b<PL0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0880oooo00200?ooo`80000000<0V9RH0?ooo`3oool00P3oool00`2YZJT000000000
000H0?ooo`04038b<P3oool0oooo038b<P`0oooo00@0<S8b0?ooo`3oool0<S8b4`3oool00`0b<S80
oooo0?ooo`090?ooo`H0000000<0oooo0000000000006`3oool00`0b<S80oooo0?ooo`060?ooo`03
0000003oool0000000H0oooo00<08B4Q0000003oool00`3oool00`0Q8B4000000?ooo`030?ooo`03
024Q8@000000oooo08<0oooo003o0?oooih0oooo003o0?oooih0oooo0000\
\>"],
  ImageRangeCache->{{{0, 412}, {412, 0}} -> {-0.024063, -5.06255*^-6, \
0.002544, 0.002544}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ settings\ of\ the\ plot\ *) \n\(obj = g;\)\), "\n", 
    \(ny = 6; ymin = 1; ymax = 35;\), "\n", 
    \(nz = 40; zmin = 20; zmax = 150;\), "\n", 
    \(nm = 11; mmin = 0.0; mmax = 2;\), "\n", 
    \(\(x = 5;\)\n\n (*\ Prepare\ the\ Plot\ *) \), "\n", 
    \(\(t0 = AbsoluteTime[];\)\), "\n", 
    \(\(t1 = 
        Table[radFldLst[obj, "\<M\>", {x, ymin, z}, {x, ymax, z}, ny], {z, 
            zmin, zmax, \((zmax - zmin)\)/\((nz - 1)\)}];\)\), "\n", 
    \(\(Print[AbsoluteTime[] - t0, "\< sec\>"];\)\), "\n", 
    \(\(f[x_, y_, z_] := Sqrt[x^2 + y^2 + z^2];\)\), "\n", 
    \(\(tt = Apply[f, t1, {2}]\ ;\)\), "\n", 
    \(\(ct = 
        Table[w, {w, mmin, 
            mmax, \((mmax - mmin)\)/\((nm - 1)\)}]\ ;\)\n\n (*\ 
      Plot\ *) \), "\n", 
    \(\(ListContourPlot[tt\n, Axes -> True\n, PlotLabel -> "\< X = 5 mm\>"\n, 
        Contours -> ct\n, ColorFunction -> \ Hue\n, 
        AspectRatio -> Abs[\((zmax - zmin)\)/\((ymax - ymin)\)]\n, 
        MeshRange \[Rule] {{ymin, ymax}, {zmin, zmax}}\n];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\(0``5.7196\[InvisibleSpace]" sec"\),
      SequenceForm[ 0``5.7196, " sec"],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.82353 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.00904977 0.0282805 -0.492081 0.0282805 [
[.13235 -0.0125 -5 -14 ]
[.13235 -0.0125 5 0 ]
[.27376 -0.0125 -8 -14 ]
[.27376 -0.0125 8 0 ]
[.41516 -0.0125 -8 -14 ]
[.41516 -0.0125 8 0 ]
[.55656 -0.0125 -8 -14 ]
[.55656 -0.0125 8 0 ]
[.69796 -0.0125 -8 -14 ]
[.69796 -0.0125 8 0 ]
[.83937 -0.0125 -8 -14 ]
[.83937 -0.0125 8 0 ]
[.98077 -0.0125 -8 -14 ]
[.98077 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07353 -16 -7 ]
[-0.0125 .07353 0 7 ]
[-0.0125 .63914 -16 -7 ]
[-0.0125 .63914 0 7 ]
[-0.0125 1.20475 -16 -7 ]
[-0.0125 1.20475 0 7 ]
[-0.0125 1.77036 -16 -7 ]
[-0.0125 1.77036 0 7 ]
[-0.0125 2.33597 -22 -7 ]
[-0.0125 2.33597 0 7 ]
[-0.0125 2.90158 -22 -7 ]
[-0.0125 2.90158 0 7 ]
[-0.0125 3.46719 -22 -7 ]
[-0.0125 3.46719 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 3.82353 .125 0 ]
[ 1 0 .125 0 ]
[.5 3.83603 -28.4688 0 ]
[.5 3.83603 28.4688 14 ]
[ 0 0 0 0 ]
[ 1 3.82353 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13235 0 m
.13235 .00625 L
s
gsave
.13235 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.27376 0 m
.27376 .00625 L
s
gsave
.27376 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.41516 0 m
.41516 .00625 L
s
gsave
.41516 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55656 0 m
.55656 .00625 L
s
gsave
.55656 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.69796 0 m
.69796 .00625 L
s
gsave
.69796 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.83937 0 m
.83937 .00625 L
s
gsave
.83937 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
1.000 setlinewidth
grestore
.125 Mabswid
.16063 0 m
.16063 .00375 L
s
.18891 0 m
.18891 .00375 L
s
.21719 0 m
.21719 .00375 L
s
.24548 0 m
.24548 .00375 L
s
.30204 0 m
.30204 .00375 L
s
.33032 0 m
.33032 .00375 L
s
.3586 0 m
.3586 .00375 L
s
.38688 0 m
.38688 .00375 L
s
.44344 0 m
.44344 .00375 L
s
.47172 0 m
.47172 .00375 L
s
.5 0 m
.5 .00375 L
s
.52828 0 m
.52828 .00375 L
s
.58484 0 m
.58484 .00375 L
s
.61312 0 m
.61312 .00375 L
s
.6414 0 m
.6414 .00375 L
s
.66968 0 m
.66968 .00375 L
s
.72624 0 m
.72624 .00375 L
s
.75452 0 m
.75452 .00375 L
s
.78281 0 m
.78281 .00375 L
s
.81109 0 m
.81109 .00375 L
s
.86765 0 m
.86765 .00375 L
s
.89593 0 m
.89593 .00375 L
s
.92421 0 m
.92421 .00375 L
s
.95249 0 m
.95249 .00375 L
s
.10407 0 m
.10407 .00375 L
s
.07579 0 m
.07579 .00375 L
s
.04751 0 m
.04751 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07353 m
.00625 .07353 L
s
gsave
-0.0125 .07353 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .63914 m
.00625 .63914 L
s
gsave
-0.0125 .63914 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 1.20475 m
.00625 1.20475 L
s
gsave
-0.0125 1.20475 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 1.77036 m
.00625 1.77036 L
s
gsave
-0.0125 1.77036 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 2.33597 m
.00625 2.33597 L
s
gsave
-0.0125 2.33597 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 2.90158 m
.00625 2.90158 L
s
gsave
-0.0125 2.90158 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
1.000 setlinewidth
grestore
0 3.46719 m
.00625 3.46719 L
s
gsave
-0.0125 3.46719 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .21493 m
.00375 .21493 L
s
0 .35633 m
.00375 .35633 L
s
0 .49774 m
.00375 .49774 L
s
0 .78054 m
.00375 .78054 L
s
0 .92195 m
.00375 .92195 L
s
0 1.06335 m
.00375 1.06335 L
s
0 1.34615 m
.00375 1.34615 L
s
0 1.48756 m
.00375 1.48756 L
s
0 1.62896 m
.00375 1.62896 L
s
0 1.91176 m
.00375 1.91176 L
s
0 2.05317 m
.00375 2.05317 L
s
0 2.19457 m
.00375 2.19457 L
s
0 2.47738 m
.00375 2.47738 L
s
0 2.61878 m
.00375 2.61878 L
s
0 2.76018 m
.00375 2.76018 L
s
0 3.04299 m
.00375 3.04299 L
s
0 3.18439 m
.00375 3.18439 L
s
0 3.32579 m
.00375 3.32579 L
s
0 3.6086 m
.00375 3.6086 L
s
0 3.75 m
.00375 3.75 L
s
.25 Mabswid
0 0 m
0 3.82353 L
s
.13235 3.81728 m
.13235 3.82353 L
s
.27376 3.81728 m
.27376 3.82353 L
s
.41516 3.81728 m
.41516 3.82353 L
s
.55656 3.81728 m
.55656 3.82353 L
s
.69796 3.81728 m
.69796 3.82353 L
s
.83937 3.81728 m
.83937 3.82353 L
s
.98077 3.81728 m
.98077 3.82353 L
s
.125 Mabswid
.16063 3.81978 m
.16063 3.82353 L
s
.18891 3.81978 m
.18891 3.82353 L
s
.21719 3.81978 m
.21719 3.82353 L
s
.24548 3.81978 m
.24548 3.82353 L
s
.30204 3.81978 m
.30204 3.82353 L
s
.33032 3.81978 m
.33032 3.82353 L
s
.3586 3.81978 m
.3586 3.82353 L
s
.38688 3.81978 m
.38688 3.82353 L
s
.44344 3.81978 m
.44344 3.82353 L
s
.47172 3.81978 m
.47172 3.82353 L
s
.5 3.81978 m
.5 3.82353 L
s
.52828 3.81978 m
.52828 3.82353 L
s
.58484 3.81978 m
.58484 3.82353 L
s
.61312 3.81978 m
.61312 3.82353 L
s
.6414 3.81978 m
.6414 3.82353 L
s
.66968 3.81978 m
.66968 3.82353 L
s
.72624 3.81978 m
.72624 3.82353 L
s
.75452 3.81978 m
.75452 3.82353 L
s
.78281 3.81978 m
.78281 3.82353 L
s
.81109 3.81978 m
.81109 3.82353 L
s
.86765 3.81978 m
.86765 3.82353 L
s
.89593 3.81978 m
.89593 3.82353 L
s
.92421 3.81978 m
.92421 3.82353 L
s
.95249 3.81978 m
.95249 3.82353 L
s
.10407 3.81978 m
.10407 3.82353 L
s
.07579 3.81978 m
.07579 3.82353 L
s
.04751 3.81978 m
.04751 3.82353 L
s
.01923 3.81978 m
.01923 3.82353 L
s
.25 Mabswid
0 3.82353 m
1 3.82353 L
s
.99375 .07353 m
1 .07353 L
s
.99375 .63914 m
1 .63914 L
s
.99375 1.20475 m
1 1.20475 L
s
.99375 1.77036 m
1 1.77036 L
s
.99375 2.33597 m
1 2.33597 L
s
.99375 2.90158 m
1 2.90158 L
s
.99375 3.46719 m
1 3.46719 L
s
.125 Mabswid
.99625 .21493 m
1 .21493 L
s
.99625 .35633 m
1 .35633 L
s
.99625 .49774 m
1 .49774 L
s
.99625 .78054 m
1 .78054 L
s
.99625 .92195 m
1 .92195 L
s
.99625 1.06335 m
1 1.06335 L
s
.99625 1.34615 m
1 1.34615 L
s
.99625 1.48756 m
1 1.48756 L
s
.99625 1.62896 m
1 1.62896 L
s
.99625 1.91176 m
1 1.91176 L
s
.99625 2.05317 m
1 2.05317 L
s
.99625 2.19457 m
1 2.19457 L
s
.99625 2.47738 m
1 2.47738 L
s
.99625 2.61878 m
1 2.61878 L
s
.99625 2.76018 m
1 2.76018 L
s
.99625 3.04299 m
1 3.04299 L
s
.99625 3.18439 m
1 3.18439 L
s
.99625 3.32579 m
1 3.32579 L
s
.99625 3.6086 m
1 3.6086 L
s
.99625 3.75 m
1 3.75 L
s
.25 Mabswid
1 0 m
1 3.82353 L
s
0 0 m
1 0 L
s
0 0 m
0 3.82353 L
s
gsave
.5 3.83603 -89.4688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
77.625 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
88.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
97.312 14.000 moveto
(mm) show
115.938 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 3.82353 L
0 3.82353 L
closepath
clip
newpath
1 .742 0 r
.01923 3.75 m
.98077 3.75 L
.98077 .07353 L
.01923 .07353 L
F
0 g
.5 Mabswid
0 1 .067 r
.01923 .5117 m
.21154 .5117 L
.2792 .54487 L
.40385 .60597 L
.47151 .63914 L
.59615 .68018 L
.7083 .73341 L
.78846 .77634 L
.92518 .82768 L
.94195 .92195 L
.94195 1.01621 L
.94195 1.11048 L
.94195 1.20475 L
.94876 1.29902 L
.94876 1.39329 L
.94876 1.48756 L
.94876 1.58183 L
.95247 1.67609 L
.95247 1.77036 L
.95247 1.86463 L
.95247 1.9589 L
.95443 2.05317 L
.95443 2.14744 L
.95443 2.2417 L
.95443 2.33597 L
.9553 2.43024 L
.9553 2.52451 L
.9553 2.61878 L
.9553 2.71305 L
.98077 2.73907 L
.98077 3.75 L
.01923 3.75 L
F
0 g
.01923 .5117 m
.21154 .5117 L
.2792 .54487 L
.40385 .60597 L
.47151 .63914 L
.59615 .68018 L
.7083 .73341 L
.78846 .77634 L
.92518 .82768 L
.94195 .92195 L
.94195 1.01621 L
.94195 1.11048 L
.94195 1.20475 L
.94876 1.29902 L
.94876 1.39329 L
.94876 1.48756 L
.94876 1.58183 L
.95247 1.67609 L
.95247 1.77036 L
.95247 1.86463 L
.95247 1.9589 L
.95443 2.05317 L
.95443 2.14744 L
.95443 2.2417 L
.95443 2.33597 L
.9553 2.43024 L
.9553 2.52451 L
.9553 2.61878 L
.9553 2.71305 L
.98077 2.73907 L
s
0 .608 1 r
.01923 .89204 m
.21154 .89204 L
.40385 .89204 L
.51741 .82768 L
.48737 .73341 L
.59615 .7188 L
.62893 .73341 L
.78846 .8144 L
.83916 .82768 L
.89164 .92195 L
.89164 1.01621 L
.89164 1.11048 L
.89164 1.20475 L
.90942 1.29902 L
.90942 1.39329 L
.90942 1.48756 L
.90942 1.58183 L
.91864 1.67609 L
.91864 1.77036 L
.91864 1.86463 L
.91864 1.9589 L
.92339 2.05317 L
.92339 2.14744 L
.92339 2.2417 L
.92339 2.33597 L
.92547 2.43024 L
.92547 2.52451 L
.92547 2.61878 L
.92547 2.71305 L
.98077 2.76212 L
.98077 3.75 L
.01923 3.75 L
F
0 g
.01923 .89204 m
.21154 .89204 L
.40385 .89204 L
.51741 .82768 L
.48737 .73341 L
.59615 .7188 L
.62893 .73341 L
.78846 .8144 L
.83916 .82768 L
.89164 .92195 L
.89164 1.01621 L
.89164 1.11048 L
.89164 1.20475 L
.90942 1.29902 L
.90942 1.39329 L
.90942 1.48756 L
.90942 1.58183 L
.91864 1.67609 L
.91864 1.77036 L
.91864 1.86463 L
.91864 1.9589 L
.92339 2.05317 L
.92339 2.14744 L
.92339 2.2417 L
.92339 2.33597 L
.92547 2.43024 L
.92547 2.52451 L
.92547 2.61878 L
.92547 2.71305 L
.98077 2.76212 L
s
.716 0 1 r
.01923 1.62703 m
.21154 1.62703 L
.40385 1.62703 L
.44612 1.58183 L
.44612 1.48756 L
.44612 1.39329 L
.44612 1.29902 L
.56019 1.20475 L
.56019 1.11048 L
.56019 1.01621 L
.56019 .92195 L
.59615 .9021 L
.78846 .88921 L
.81081 .92195 L
.81081 1.01621 L
.81081 1.11048 L
.81081 1.20475 L
.85556 1.29902 L
.85556 1.39329 L
.85556 1.48756 L
.85556 1.58183 L
.87514 1.67609 L
.87514 1.77036 L
.87514 1.86463 L
.87514 1.9589 L
.88458 2.05317 L
.88458 2.14744 L
.88458 2.2417 L
.88458 2.33597 L
.8886 2.43024 L
.8886 2.52451 L
.8886 2.61878 L
.8886 2.71305 L
.98077 2.78539 L
.98077 3.75 L
.01923 3.75 L
F
0 g
.01923 1.62703 m
.21154 1.62703 L
.40385 1.62703 L
.44612 1.58183 L
.44612 1.48756 L
.44612 1.39329 L
.44612 1.29902 L
.56019 1.20475 L
.56019 1.11048 L
.56019 1.01621 L
.56019 .92195 L
.59615 .9021 L
.78846 .88921 L
.81081 .92195 L
.81081 1.01621 L
.81081 1.11048 L
.81081 1.20475 L
.85556 1.29902 L
.85556 1.39329 L
.85556 1.48756 L
.85556 1.58183 L
.87514 1.67609 L
.87514 1.77036 L
.87514 1.86463 L
.87514 1.9589 L
.88458 2.05317 L
.88458 2.14744 L
.88458 2.2417 L
.88458 2.33597 L
.8886 2.43024 L
.8886 2.52451 L
.8886 2.61878 L
.8886 2.71305 L
.98077 2.78539 L
s
0 .608 1 r
.01923 2.82843 m
.13529 2.90158 L
.13683 2.99585 L
.13683 3.09012 L
.13412 3.18439 L
.13412 3.27866 L
.1602 3.37293 L
.21154 3.38591 L
.37667 3.46719 L
.40385 3.48053 L
.56895 3.56146 L
.59615 3.5748 L
.76026 3.65573 L
.78846 3.68077 L
.98059 3.65573 L
.92038 3.56146 L
.97968 3.46719 L
.97968 3.37293 L
.97968 3.27866 L
.98077 3.27804 L
.98077 3.75 L
.01923 3.75 L
F
0 g
.01923 2.82843 m
.13529 2.90158 L
.13683 2.99585 L
.13683 3.09012 L
.13412 3.18439 L
.13412 3.27866 L
.1602 3.37293 L
.21154 3.38591 L
.37667 3.46719 L
.40385 3.48053 L
.56895 3.56146 L
.59615 3.5748 L
.76026 3.65573 L
.78846 3.68077 L
.98059 3.65573 L
.92038 3.56146 L
.97968 3.46719 L
.97968 3.37293 L
.97968 3.27866 L
.98077 3.27804 L
s
0 1 .067 r
.01923 2.85246 m
.08369 2.90158 L
.08479 2.99585 L
.08479 3.09012 L
.08317 3.18439 L
.08317 3.27866 L
.095 3.37293 L
.21154 3.41253 L
.32201 3.46719 L
.40385 3.50735 L
.51424 3.56146 L
.59615 3.60161 L
.70509 3.65573 L
.78846 3.71262 L
.94144 3.75 L
.01923 3.75 L
F
0 g
.01923 2.85246 m
.08369 2.90158 L
.08479 2.99585 L
.08479 3.09012 L
.08317 3.18439 L
.08317 3.27866 L
.095 3.37293 L
.21154 3.41253 L
.32201 3.46719 L
.40385 3.50735 L
.51424 3.56146 L
.59615 3.60161 L
.70509 3.65573 L
.78846 3.71262 L
.94144 3.75 L
s
1 .742 0 r
.01923 2.8761 m
.04725 2.90158 L
.04778 2.99585 L
.04778 3.09012 L
.04707 3.18439 L
.04707 3.27866 L
.05177 3.37293 L
.21154 3.4384 L
.26952 3.46719 L
.40385 3.53308 L
.46175 3.56146 L
.59615 3.62735 L
.653 3.65573 L
.78846 3.73375 L
.88797 3.75 L
.01923 3.75 L
F
0 g
.01923 2.8761 m
.04725 2.90158 L
.04778 2.99585 L
.04778 3.09012 L
.04707 3.18439 L
.04707 3.27866 L
.05177 3.37293 L
.21154 3.4384 L
.26952 3.46719 L
.40385 3.53308 L
.46175 3.56146 L
.59615 3.62735 L
.653 3.65573 L
.78846 3.73375 L
.88797 3.75 L
s
1 0 0 r
.59615 1.63821 m
.78846 1.63821 L
.80725 1.67609 L
.80725 1.77036 L
.80725 1.86463 L
.80725 1.9589 L
.82905 2.05317 L
.82905 2.14744 L
.82905 2.2417 L
.82905 2.33597 L
.83744 2.43024 L
.83744 2.52451 L
.83744 2.61878 L
.83744 2.71305 L
.90066 2.80732 L
.90066 2.90158 L
.93854 2.99585 L
.93854 3.09012 L
.9644 3.18439 L
.78846 3.22392 L
.70111 3.18439 L
.59615 3.12965 L
.4771 3.09012 L
.4771 2.99585 L
.44721 2.90158 L
.44721 2.80732 L
.48499 2.71305 L
.48499 2.61878 L
.48499 2.52451 L
.48499 2.43024 L
.508 2.33597 L
.508 2.2417 L
.508 2.14744 L
.508 2.05317 L
.55885 1.9589 L
.55885 1.86463 L
.55885 1.77036 L
.55885 1.67609 L
F
0 g
.59615 1.63821 m
.78846 1.63821 L
.80725 1.67609 L
.80725 1.77036 L
.80725 1.86463 L
.80725 1.9589 L
.82905 2.05317 L
.82905 2.14744 L
.82905 2.2417 L
.82905 2.33597 L
.83744 2.43024 L
.83744 2.52451 L
.83744 2.61878 L
.83744 2.71305 L
.90066 2.80732 L
.90066 2.90158 L
.93854 2.99585 L
.93854 3.09012 L
.9644 3.18439 L
.78846 3.22392 L
.70111 3.18439 L
.59615 3.12965 L
.4771 3.09012 L
.4771 2.99585 L
.44721 2.90158 L
.44721 2.80732 L
.48499 2.71305 L
.48499 2.61878 L
.48499 2.52451 L
.48499 2.43024 L
.508 2.33597 L
.508 2.2417 L
.508 2.14744 L
.508 2.05317 L
.55885 1.9589 L
.55885 1.86463 L
.55885 1.77036 L
.55885 1.67609 L
.59615 1.63821 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{173.375, 662.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002]0002UR000`400?l00000o`00003o[@3oool0
0:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3o
ool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00
[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?oo
o`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]
0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo
002]0?ooo`00[@3oool002L0oooo00D0410@000000000000000009RHV00?0?ooo`<0000000<0oooo
09RHV00000000P0000000`2HV9P0oooo0?ooo`090?ooo`<0000000<0oooo010@400000000P000000
0`2HV9P0oooo0?ooo`070?ooo`@0000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`07
0?ooo`@0000000<0^[Zj0?ooo`0@41000`0000000`2HV9P0oooo0?ooo`080?ooo`04010@40000000
410@07MgM`80oooo00D0V9RH000000000000000009RHV0090?ooo`04010@40000000410@07MgM`80
oooo00D0410@000000000000000009RHV0040?ooo`00:P3oool00`2HV9P000000?ooo`0?0?ooo`08
0000003oool0oooo0000002HV9P0oooo09RHV000000<0?ooo`030000003oool0oooo00<0oooo00<0
V9RH0000003oool0203oool02`3<c<`0k^k^0?ooo`3<c<`0EEEE0?ooo`000000V9RH0?ooo`2HV9P0
000000T0oooo00D0c<c<0>k^kP3oool0c<c<05EEE@040?ooo`0309RHV0000000oooo00`0oooo00P0
MgMg06IVIP3oool0000009RHV03oool0V9RH000000`0oooo00<0MgMg06IVIP3oool00`3oool00`2H
V9P000000?ooo`030?ooo`00:`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00P0oooo00<0c<c<0>k^kP3oool00P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0c<c<
0>k^kP3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000[0?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool01@2YZJT0k^k^0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool02@3oool00`2YZJT0k^k^0?ooo`050?ooo`030000003o
ool0oooo00X0oooo00D0gMgM08N7Q`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<0gMgM08N7Q`0000001@3oool00`000000oooo0?ooo`020?ooo`00:P3oool00`2HV9P000000?oo
o`0?0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`0309RHV0000000oooo00X0oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`03
0000003oool0oooo00T0oooo00<0gMgM06IVIP3oool0103oool00`2HV9P000000?ooo`0:0?ooo`06
05EEE@0@4100000009RHV03oool000000`3oool00`000000oooo0?ooo`080?ooo`0405EEE@0@4100
000009RHV0@0oooo00<0V9RH0000003oool00`3oool002L0oooo100000000`2HV9P0oooo0?ooo`0>
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040000000309RHV03oool0oooo00L0oooo00@0MgMg0?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00@0MgMg0?ooo`3oool000000P3oool40000000309RHV03oool0oooo
00/0oooo00@0^[Zj09RHV03oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030;Zj^P2HV9P0
oooo00@0000000<0V9RH0?ooo`3oool00P3oool002L0oooo00<0MgMg05EEE@3oool04P3oool02000
0000oooo0?ooo`000000V9RH0?ooo`2HV9P00000303oool01@000000oooo0?ooo`1gMgL0EEEE00`0
oooo00@0000009RHV02HV9P000000P3oool01@000000V9RH0?ooo`2HV9P0000000T0oooo00@00000
09RHV02HV9P000000P3oool00`1gMgL0EEEE0?ooo`0<0?ooo`0;04A4A02j^[X0oooo0;Zj^P000000
oooo0000002HV9P0oooo09RHV00000002@3oool02014A4@0^[Zj0?ooo`2j^[X000000?ooo`1gMgL0
EEEE1`3oool002P0oooo00@0410@000000000000<S8b3`3oool01@0Q8B4000000?ooo`3oool0V9RH
00<0000000<0V9RH0?ooo`3oool02@3oool00`0Q8B4000000?ooo`020?ooo`04010@400000000000
038b<PT0oooo00@0V9RH000000000000V9RH0P3oool01@2HV9P00000000000000000V9RH00T0oooo
00@0V9RH000000000000V9RH0`3oool0100@410000000000000b<S8:0?ooo`070>k^kP14A4@00000
0000002HV9P0oooo09RHV0030000000309RHV03oool0oooo00L0oooo00D0k^k^04A4A00000000000
09RHV0020?ooo`04010@400000000000038b<P@0oooo002]0?ooo`00[@3oool00:d0oooo000G0?oo
oi4000001@3oool001L0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?ooo`00203oool4000000030;Zj^P3o
ool0V9RH00<0000000<0V9RH0?ooo`3oool00P3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo00<0oooo00080?ooo`0;0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RH
V0000000103oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00<0oooo00090?ooo`03
0<c<c03^k^h0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`800000S@3oool20000
00D0oooo000:0?ooo`050:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`002P3oool01@3MgMd0
IVIV0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2:0?nm
00<0oooo00<000000?ooo`3oool00`3oool000P0oooo00@0MgMg0?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0
oooo00<0oooo00080?ooo`040000002HV9P0V9RH00000080oooo00D0000009RHV03oool0V9RH0000
00040?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`00203oool0
102HV9P000000000002HV9P20?ooo`0509RHV000000000000000002HV9P0103oool00`000000oooo
0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o
_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<00000
0?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo
08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0
oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool2000000030?oo
o`3o_@00okd008P0okd00P3oool2000000D0oooo000G0?ooo`030000003oool0oooo08X0okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0
oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?oo
o`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo0P00
00000`3oool0okd00?nm00280?nm0080oooo0P0000050?ooo`005`3oool00`000000oooo0?ooo`2:
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?oo
o`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G
0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0RP3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo08X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0RP3o_@030?oo
o`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08X0okd00`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo0P0000000`3oool0okd00?nm00280?nm0080oooo0P0000050?ooo`005`3oool0
0`000000oooo0?ooo`2:0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?oo
o`3oool07P00001/0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool07P00oa42000006X0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`0P003o4@800000J03o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo02800?lA00<000000?nm003o_@00I@3o_@030?ooo`030000003oool0oooo00<0oooo000G
0?ooo`030000003oool0oooo02<00?lA0P00001U0?nm00<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool09@00oa42000006<0okd00`3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`0W003o4@800000H@3o_@030?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo02T00?lA0`00001N0?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0;000oa42000005`0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`0^003o4@800000FP3o_@030?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo03000?lA0P00001H0?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0<P00oa43000005D0okd00`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0e003o4@800000D`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03L00?lA0P00001A0?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0>@00oa42000004l0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0k003o4@800000C@3o_@030?oo
o`030000003oool0oooo00<0oooo000;0?ooo`040000003oool0oooo09RHV0<0000000<0V9RH0?oo
o`3oool00P3oool00`000000oooo0?ooo`0m003o4@800000B`3o_@030?ooo`030000003oool0oooo
00<0oooo000;0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV00000040?ooo`030000003o
ool0oooo03l00?lA0P0000190?nm00<0oooo00<000000?ooo`3oool00`3oool000P0oooo1`000003
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool00?lA003o4@0o003o4@<00000AP3o_@02
0?ooo`8000001@3oool000P0oooo00@0A4A409RHV03oool000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0A000oa43000004<0okd00`3oool00`000000oooo0?oo
o`030?ooo`00203oool0103^k^h0410@0=gMg@0000020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`17003o4@<00000@03o_@030?ooo`030000003oool0oooo00<0oooo
00090?ooo`030:VYZ@0b<S8000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo04X00?lA0`00000m0?nm00<0oooo00<000000?ooo`3oool00`3oool000X0oooo00T0
IVIV0000003oool0oooo0000002HV9P0oooo09RHV0000000103oool00`000000oooo0?ooo`1=003o
4@<00000>P3o_@030?ooo`030000003oool0oooo00<0oooo000:0?ooo`050>k^kP0@4100oooo0?oo
o`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`030000003oool0oooo05000?lA0`00000g0?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0D`00oa42000003D0
okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1E003o4@800000
<`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo05L00?lA0P00
000a0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0F@00oa42
000002l0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1K003o
4@800000;@3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo05d0
0?lA0P00000[0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
C`00oa46000000X00?lA0P00000Y0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0A`00oa48000000H009_o0P00000:003o4@8000009`3o_@030?ooo`030000003o
ool0oooo00<0oooo000G0?ooo`030000003oool0oooo04<00?lA1000000@002Ko`8000002P00oa42
000002D0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`13003o
4@0300000000Vol009_o01<009_o0P00000:003o4@8000008`3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo04<00?lA00<00000002Ko`00Vol05@00Vol2000000X0
0?lA0P00000Q0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
A000oa400`00000009_o002Ko`0F002Ko`8000002P00oa400`000000okd00?nm000N0?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0A000oa400`00000009_o002K
o`0H002Ko`8000002@00oa42000001h0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool0
0`000000oooo0?ooo`14003o4@0300000000Vol009_o01X009_o0`000008003o4@800000703o_@03
0?ooo`030000003oool0oooo00<0oooo000G0?ooo`80000000<0oooo003o4@00oa40@`00oa400`00
000009_o002Ko`0L002Ko`8000002000oa42000001X0okd00P3oool2000000D0oooo000G0?ooo`03
0000003oool0oooo04D00?lA00<00000002Ko`00Vol07P00Vol2000000P00?lA0`00000G0?nm00<0
oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0A@00oa400`00000009_o
002Ko`0P002Ko`8000002@00oa43000001@0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`16003o4@0300000000Vol009_o024009_o0P00000:003o4@<000004@3o
_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H00?lA00<00000
002Ko`00Vol08`00Vol2000000/00?lA0`00000>0?nm00<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool0AP00oa400`00000009_o002Ko`0U002Ko`<000002`00oa430000
00/0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`17003o4@03
00000000Vol009_o02L009_o1000000:003o4@<00000203o_@030?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo04H00?lA0P00000]002Ko`8000002`00oa400`000000okd0
0?nm00050?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0A000
oa420000030009_o00<00000003o4@00oa402@00oa400`000000okd00?nm00050?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`00oa400`00000009_o002Ko`0a
002Ko`0300000000oa400?lA00P00?lA00<000000?nm003o_@001@3o_@030?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo04400?lA0P00000d002Ko`0300000000oa400?lA
00P00?lA00<000000?nm003o_@001@3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo03l00?lA0P00000g002Ko`0300000000oa400?lA00P00?lA00<000000?nm003o
_@00103o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03d00?lA
0P00000i002Ko`0300000000oa400?lA00P00?lA00<000000?nm003o_@00103o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03/00?lA0P00000l002Ko`0300000000
oa400?lA00L00?lA00<000000?nm003o_@00103o_@030?ooo`030000003oool0oooo00<0oooo000G
0?ooo`030000003oool0oooo03X00?lA00<00000002Ko`00Vol0?000Vol00`0000000?lA003o4@07
003o4@030000003o_@00okd000@0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`0h003o4@800000@000Vol00`0000000?lA003o4@06003o4@030000003o_@00okd0
00@0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0h000002l0
09_o2000000;002Ko`0300000000oa400?lA00H00?lA00<000000?nm003o_@00103o_@030?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo05X009_o3@0000070;L0o`030000
0000Vol009_o00X009_o00<00000003o4@00oa401@00oa400`000000okd00?nm00040?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0DP00Vol8000001D0]`3o00<0
0000002Ko`00Vol02@00Vol00`0000000?lA003o4@06003o4@030000003o_@00okd000<0okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1@002Ko`8000007P2g0?l0
0`00000009_o002Ko`09002Ko`0300000000oa400?lA00D00?lA00<000000?nm003o_@000`3o_@03
0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04l009_o00<000000;L0
o`2g0?l07`2g0?l00`00000009_o002Ko`08002Ko`0300000000oa400?lA00D00?lA00<000000?nm
003o_@000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`80000000<0oooo002Ko`00
Vol0C000Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00
oa401000oa400`000000okd00?nm00030?nm0080oooo0P0000050?ooo`005`3oool00`000000oooo
0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA
003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000
Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000
002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o
0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd0
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`03
0000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@03
0000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA
003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000
Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000
002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o
0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd0
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`03
0000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@03
0000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA
003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000
Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000
002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o
0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd0
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`03
0000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@03
0000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA
003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol02000
Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000
002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o
0240]`3o00<00000002Ko`00Vol02000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd0
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool2000000030?ooo`00Vol009_o04`0
09_o00<000000;L0o`2g0?l08@2g0?l00`00000009_o002Ko`08002Ko`0300000000oa400?lA00@0
0?lA00<000000?nm003o_@000`3o_@020?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0
CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa40
1000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<0
0000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol0
09_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0
o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000
]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000
okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa40
1000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<0
0000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol0
09_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0
o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000
]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000
okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa40
1000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<0
0000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol0
09_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0
o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0CP00Vol00`000000
]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000
okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<00000003o4@00oa40
1000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol009_o00P009_o00<0
0000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<000000?ooo`3oool00`3o
ool000P0oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0
0P3oool00`000000oooo0?ooo`1>002Ko`030000002g0?l0]`3o0240]`3o00<00000002Ko`00Vol0
2000Vol00`0000000?lA003o4@04003o4@030000003o_@00okd000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`00203oool02`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0
000000@0oooo00<000000?ooo`3oool0CP00Vol00`000000]`3o0;L0o`0Q0;L0o`0300000000Vol0
09_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0oooo00<00000
0?ooo`3oool00`3oool000P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`00Vol009_o04/009_o0P00000S0;L0o`0300000000
Vol009_o00P009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm0080oooo0P00
00050?ooo`00203oool01`000000c<c<0?ooo`2HV9P000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo04`009_o00<000000;L0o`2g0?l08`2g0?l00`00000009_o
002Ko`08002Ko`0300000000oa400?lA00@00?lA00<000000?nm003o_@000`3o_@030?ooo`030000
003oool0oooo00<0oooo00080?ooo`07010@401EEED000000000002HV9P0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0B`00Vol00`000000]`3o0;L0o`0U0;L0o`03
00000000Vol009_o00L009_o00<00000003o4@00oa401000oa400`000000okd00?nm00030?nm00<0
oooo00<000000?ooo`3oool00`3oool000P0oooo00<0MgMg04A4A03oool00`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0BP00Vol00`000000]`3o0;L0o`0V0;L0o`03
00000000Vol009_o00P009_o00<00000003o4@00oa400`00oa400`000000okd00?nm00030?nm00<0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<0EEEE07MgM`3oool00P3oool01@000000V9RH
0?ooo`2HV9P0000000@0oooo00<000000?ooo`3oool0B@00Vol00`000000]`3o0;L0o`0X0;L0o`03
00000000Vol009_o00L009_o00<00000003o4@00oa400`00oa400`000000okd00?nm00030?nm00<0
oooo00<000000?ooo`3oool00`3oool000X0oooo00D0V9RH04A4A027QhL0oooo09RHV00300000003
09RHV03oool0oooo0080oooo00<000000?ooo`3oool0A`00Vol2000002/0]`3o00<00000002Ko`00
Vol01`00Vol00`0000000?lA003o4@03003o4@030000003o_@00okd000<0okd00`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`16002Ko`030000002g0?l0]`3o02/0]`3o
00<00000002Ko`00Vol01`00Vol00`0000000?lA003o4@03003o4@030000003o_@00okd000<0okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`15002Ko`030000002g
0?l0]`3o02d0]`3o00<00000002Ko`00Vol01P00Vol00`0000000?lA003o4@03003o4@030000003o
_@00okd000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`14
002Ko`030000002g0?l0]`3o02h0]`3o00<00000002Ko`00Vol01`00Vol00`0000000?lA003o4@03
003o4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`12002Ko`800000<P2g0?l00`00000009_o002Ko`06002Ko`0300000000oa400?lA
00<00?lA00<000000?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo044009_o00<000000;L0o`2g0?l0<P2g0?l00`00000009_o002Ko`06002Ko`03
00000000oa400?lA00<00?lA00<000000?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo040009_o00<000000;L0o`2g0?l0=02g0?l00`00000009_o
002Ko`05002Ko`0300000000oa400?lA00<00?lA00<000000?nm003o_@000P3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03l009_o00<000000;L0o`2g0?l0=@2g
0?l00`00000009_o002Ko`05002Ko`0300000000oa400?lA00<00?lA00<000000?nm003o_@000P3o
_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03h009_o00<00000
0;L0o`2g0?l0=P2g0?l00`00000009_o002Ko`06002Ko`0300000000oa400?lA00800?lA00<00000
0?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo
03d009_o00<000000;L0o`2g0?l0>02g0?l00`00000009_o002Ko`05002Ko`0300000000oa400?lA
00800?lA00<000000?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo03d009_o00<000000;L0o`2g0?l0>02g0?l00`00000009_o002Ko`05002Ko`03
00000000oa400?lA00800?lA00<000000?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo03d009_o00<000000;L0o`2g0?l0>02g0?l00`00000009_o
002Ko`05002Ko`0300000000oa400?lA00800?lA00<000000?nm003o_@000P3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03d009_o00<000000;L0o`2g0?l0>02g
0?l00`00000009_o002Ko`05002Ko`0300000000oa400?lA00800?lA00<000000?nm003o_@000P3o
_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo03d009_o00<00000
0;L0o`2g0?l0>02g0?l00`00000009_o002Ko`05002Ko`0300000000oa400?lA00800?lA00<00000
0?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo
03d009_o00<000000;L0o`2g0?l0>02g0?l00`00000009_o002Ko`05002Ko`0300000000oa400?lA
00800?lA00<000000?nm003o_@000P3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`80
000000<0oooo002Ko`00Vol0>`00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D0
09_o00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm0080oooo0P0000050?ooo`00
5`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol0
1@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<0
0000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0
]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00
okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002K
o`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o
4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`000000
0?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol0
1@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<0
0000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0
]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00
okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002K
o`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o
4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`000000
0?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol0
1@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<0
0000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0
]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00
okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002K
o`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o
4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`000000
0?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol0
1@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<0
0000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00okd00080okd00`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002Ko`030000002g0?l0
]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o4@030000003o_@00
okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m002K
o`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`0000000?lA003o4@02003o
4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`0m002Ko`030000002g0?l0]`3o03P0]`3o00<00000002Ko`00Vol01@00Vol00`000000
0?lA003o4@02003o4@030000003o_@00okd00080okd00`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool2000000030?ooo`00Vol009_o03/009_o00<000000;L0o`2g0?l0>02g0?l00`00000009_o
002Ko`05002Ko`0300000000oa400?lA00800?lA00<000000?nm003o_@000P3o_@020?ooo`800000
1@3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000
Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h
0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm0002
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`00
0000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`00
0000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00
oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o
00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000
Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h
0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm0002
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`00
0000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`00
0000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00
oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o
00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000
Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`000000]`3o0;L0o`0h
0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`000000okd00?nm0002
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0?@00Vol00`00
0000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00oa400P00oa400`00
0000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0?@00Vol00`000000]`3o0;L0o`0h0;L0o`0300000000Vol009_o00D009_o00<00000003o4@00
oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0?000Vol00`000000]`3o0;L0o`0i0;L0o`0300000000Vol009_o00D009_o
00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0>`00Vol00`000000]`3o0;L0o`0k0;L0o`0300000000
Vol009_o00@009_o00<00000003o4@00oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<0
00000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0>P00Vol00`000000]`3o0;L0o`0l
0;L0o`0300000000Vol009_o00@009_o00<00000003o4@00oa400P00oa400`000000okd00?nm0002
0?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0>@00Vol00`00
0000]`3o0;L0o`0m0;L0o`0300000000Vol009_o00@009_o00<00000003o4@00oa400P00oa400`00
0000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0>000Vol00`000000]`3o0;L0o`0n0;L0o`0300000000Vol009_o00@009_o00<00000003o4@00
oa400P00oa400`000000okd00?nm00020?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo
0P0000000`3oool000000000000f00000440]`3o00<00000002Ko`00Vol01000Vol00`0000000?lA
003o4@02003o4@030000003o_@00okd00080okd00P3oool2000000D0oooo000G0?ooo`030000003o
ool0oooo05<0]`3o7000000;0;L0o`0300000000Vol009_o00@009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo0580]`3o00<000000?l0003o00006@3o00000`000000]`3o0;L0o`090;L0o`0300000000
Vol009_o00@009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0540]`3o00<000000?l0003o00006`3o
00000`000000]`3o0;L0o`080;L0o`0300000000Vol009_o00@009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo0500]`3o00<000000?l0003o0000703o00000`000000]`3o0;L0o`080;L0o`0300000000
Vol009_o00@009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04l0]`3o00<000000?l0003o00007P3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00@009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04h0]`3o00<000000?l0003o00007`3o00000`000000]`3o0;L0o`080;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000
Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd00?nm003o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o
00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00
oa4010000000okd00?nm003o_@030?ooo`030000003oool0oooo00<0oooo00080?ooo`0709RHV000
000000000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo0080oooo00<000000?ooo`3o
ool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00
Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?oo
o`3oool00`3oool000P0oooo00/0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
000000040?ooo`030000003oool0oooo04d0]`3o00<000000?l0003o00008@3o00000`000000]`3o
0;L0o`070;L0o`0300000000Vol009_o00<009_o00<00000003o4@00oa400P00oa4010000000okd0
0?nm003o_@030?ooo`030000003oool0oooo00<0oooo00080?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo0P0000000`3oool0]`3o0;L0o`1;0;L0
o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002K
o`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd00P3oool2000000D0oooo00080?oo
o`0709RHV01gMgL0^[Zj0:VYZ@1EEED0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool000P0oooo00@0gMgM024Q8@14A4@0<S8b0P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l00003
0000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@04
0000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool000P0oooo00L08B4Q0:VYZ@3o
ool0gMgM038b<P3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=
0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03
002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?oo
o`030?ooo`00203oool02`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
00@0oooo00<000000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o
00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd0
0?nm00<0oooo00<000000?ooo`3oool00`3oool000P0oooo00L0V9RH000000000000000009RHV03o
ool0V9RH00<0000000<0V9RH0?ooo`3oool00P3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1=0;L0o`030000003o
0000o`000240o`0000<000000;L0o`2g0?l01`2g0?l00`00000009_o002Ko`03002Ko`0300000000
oa400?lA00800?lA00@000000?nm003o_@00okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`1=0;L0o`030000003o0000o`000240o`0000<000000;L0o`2g0?l01`2g
0?l00`00000009_o002Ko`03002Ko`0300000000oa400?lA00800?lA00@000000?nm003o_@00okd0
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool2000000030?ooo`2g0?l0]`3o04/0]`3o00<0
00000?l0003o00008@3o00000`000000]`3o0;L0o`070;L0o`0300000000Vol009_o00<009_o00<0
0000003o4@00oa400P00oa4010000000okd00?nm003o_@020?ooo`8000001@3oool001L0oooo00<0
00000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0C@2g0?l00`000000o`000?l0
000Q0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0C@2g0?l00`000000o`000?l0
000Q0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0C@2g0?l00`000000o`000?l0
000Q0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0C@2g0?l00`000000o`000?l0000Q0?l000030000002g0?l0]`3o00L0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0C02g0?l00`000000o`000?l0
000R0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0C02g0?l00`000000o`000?l0000S0?l000030000002g0?l0]`3o00H0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0B`2g0?l00`000000o`000?l0
000T0?l000030000002g0?l0]`3o00H0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0B`2g0?l00`000000o`000?l0000T0?l000030000002g0?l0]`3o00H0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0BP2g0?l00`000000o`000?l0
000U0?l000030000002g0?l0]`3o00H0]`3o00<00000002Ko`00Vol00`00Vol00`0000000?lA003o
4@02003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0BP2g0?l00`000000o`000?l0000U0?l000030000002g0?l0]`3o00H0]`3o00<0
0000002Ko`00Vol00`00Vol00`0000000?lA003o4@02003o4@040000003o_@00okd00?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0B@2g0?l00`000000o`000?l0
000W0?l000030000002g0?l0]`3o00H0]`3o00<00000002Ko`00Vol00`00Vol01@0000000?lA003o
4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?oo
o`190;L0o`030000003o0000o`0002L0o`0000<000000;L0o`2g0?l01P2g0?l00`00000009_o002K
o`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo
000G0?ooo`030000003oool0oooo04P0]`3o00<000000?l0003o0000:03o00000`000000]`3o0;L0
o`060;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0B02g0?l00`000000o`000?l0
000X0?l000030000002g0?l0]`3o00H0]`3o00<00000002Ko`00Vol00`00Vol01@0000000?lA003o
4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?oo
o`170;L0o`030000003o0000o`0002T0o`0000<000000;L0o`2g0?l01P2g0?l00`00000009_o002K
o`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo
000G0?ooo`030000003oool0oooo04L0]`3o00<000000?l0003o0000:P3o00000`000000]`3o0;L0
o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo
00<000000?ooo`3oool00`3oool001L0oooo0P0000000`3oool0]`3o0;L0o`140;L0o`030000003o
0000o`0002/0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000
oa400?lA003o4@0000000`3o_@020?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000:`3o
00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA
000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0AP2g
0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00
Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool2000000030?ooo`2g0?l0]`3o04@0]`3o00<000000?l0003o0000:`3o00000`000000]`3o0;L0
o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa400?lA000000030?nm0080oooo
0P0000050?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<0
0000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<0
0000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<0
0000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<0
0000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o00D0]`3o00<0
0000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<0
00000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@000000
0`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04H0]`3o00<0
00000?l0003o0000:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D0
0000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool000@0oooo0`00
00000`3oool0V9RH000000020000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool00P3o
ool00`000000oooo0?ooo`160;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g
0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000
003oool0oooo00<0oooo00050?ooo`0>0000003oool0oooo0000002HV9P0oooo09RHV0000000oooo
0000002HV9P0oooo09RHV00000040?ooo`030000003oool0oooo04H0]`3o00<000000?l0003o0000
:`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<009_o00D00000003o4@00oa40
0?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo0P0000000`3oool0
]`3o0;L0o`140;L0o`030000003o0000o`0002/0o`0000<000000;L0o`2g0?l01@2g0?l00`000000
09_o002Ko`03002Ko`0500000000oa400?lA003o4@0000000`3o_@020?ooo`8000001@3oool000D0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0AP2g0?l00`000000o`000?l0000[0?l000030000002g0?l0]`3o
00D0]`3o00<00000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool0
0`000000oooo0?ooo`030?ooo`001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`160;L0o`030000003o0000
o`0002/0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa40
0?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo00050?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04D0]`3o00<000000?l0003o0000;03o00000`000000]`3o0;L0o`050;L0o`0300000000
Vol009_o00<009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RHV03o
ool0V9RH000000@0oooo00<000000?ooo`3oool0A@2g0?l00`000000o`000?l0000/0?l000030000
002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0
okd00`3oool00`000000oooo0?ooo`030?ooo`00103oool01@0Q8B4000000?ooo`3oool0V9RH00<0
000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`020?ooo`030000003oool0oooo04D0
]`3o00<000000?l0003o0000;03o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o00<0
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0A@2g0?l00`000000o`000?l0000/0?l000030000002g0?l0]`3o00D0
]`3o00<00000002Ko`00Vol00`00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`150;L0o`030000003o0000o`0002`0
o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`03002Ko`0500000000oa400?lA003o
4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04@0
]`3o00<000000?l0003o0000;P3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0A02g0?l00`000000o`000?l0000^0?l000030000002g0?l0]`3o00D0
]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`140;L0o`030000003o0000o`0002h0
o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`0500000000oa400?lA003o
4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04@0
]`3o00<000000?l0003o0000;P3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0A02g0?l00`000000o`000?l0000^0?l000030000002g0?l0]`3o00D0
]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`030000003o0000o`0002l0
o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`0500000000oa400?lA003o
4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04<0
]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l000030000002g0?l0]`3o00D0
]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`030000003o0000o`0002l0
o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`0500000000oa400?lA003o
4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04<0
]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l000030000002g0?l0]`3o00D0
]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa40000000<0okd00`3oool00`00
0000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`030000003o0000o`0002l0
o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`0500000000oa400?lA003o
4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo04<0
]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo0P0000000`3oool0]`3o0;L0o`110;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g
0?l01@2g0?l00`00000009_o002Ko`02002Ko`0500000000oa400?lA003o4@0000000`3o_@020?oo
o`8000001@3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130;L0o`03
0000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`00000009_o002Ko`02002Ko`05
00000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`03
00000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l00003
0000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@00oa400000
00<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool2000000030?ooo`2g0?l0]`3o0440
]`3o00<000000?l0003o0000;`3o00000`000000]`3o0;L0o`050;L0o`0300000000Vol009_o0080
09_o00D00000003o4@00oa400?lA000000030?nm0080oooo0P0000050?ooo`005`3oool00`000000
oooo0?ooo`130;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`000000
09_o002Ko`02002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000
]`3o0;L0o`050;L0o`0300000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000
o`000?l0000_0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@000000
0?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`130;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`000000
09_o002Ko`02002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000
]`3o0;L0o`050;L0o`0300000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000
o`000?l0000_0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@000000
0?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`130;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`000000
09_o002Ko`02002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000
]`3o0;L0o`050;L0o`0300000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000
o`000?l0000_0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@000000
0?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`130;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l00`000000
09_o002Ko`02002Ko`0500000000oa400?lA003o4@0000000`3o_@030?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo04<0]`3o00<000000?l0003o0000;`3o00000`000000
]`3o0;L0o`050;L0o`0300000000Vol009_o008009_o00D00000003o4@00oa400?lA000000030?nm
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@`2g0?l00`000000
o`000?l0000_0?l000030000002g0?l0]`3o00D0]`3o00<00000002Ko`00Vol00P00Vol01@000000
0?lA003o4@00oa40000000<0okd00`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`130;L0o`030000003o0000o`0002l0o`0000<000000;L0o`2g0?l01@2g0?l2000000<0
09_o0P000002003o4@040000003o_@00okd00?nm00<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool0@`2g0?l00`000000o`000?l0000_0?l000030000002g0?l0]`3o00L0
]`3o00<00000002Ko`00Vol00P00Vol0100000000?lA003o4@0000020?nm00<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0@P2g0?l00`000000o`000?l0000a0?l00003
0000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00P00Vol01@0000000?lA003o4@000000okd0
00<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0@P2g0?l00`000000
o`000?l0000b0?l000030000002g0?l0]`3o00L0]`3o00<00000002Ko`00Vol00P00Vol010000000
0?lA003o4@0000030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo0440
]`3o00<000000?l0003o0000<`3o00000`000000]`3o0;L0o`080;L0o`0300000000Vol009_o0080
09_o00@00000003o4@00oa4000000P3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`110;L0o`030000003o0000o`0003@0o`0000<000000;L0o`2g0?l0202g0?l2000000<0
09_o00<00000003o4@3oool00P3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`110;L0o`030000003o0000o`0003D0o`0000<000000;L0o`2g0?l02@2g0?l01@00000009_o
002Ko`00Vol0000000<0oooo00<000000?ooo`3oool00`3oool001L0oooo0P0000000`3oool0]`3o
0;L0o`0n0;L0o`030000003o0000o`0003H0o`0000<000000;L0o`2g0?l02P2g0?l01P00000009_o
002Ko`00Vol000000?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0@02g0?l00`000000
o`000?l0000g0?l000030000002g0?l0]`3o00X0]`3o00<00000002Ko`00Vol00`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0o0;L0o`030000003o0000o`0003P0o`00
00<000000;L0o`2g0?l02`2g0?l00`00000009_o0?ooo`020?ooo`030000003oool0oooo00<0oooo
000G0?ooo`030000003oool0oooo03l0]`3o00<000000?l0003o0000>@3o00000`000000]`3o0;L0
o`0;0;L0o`050000003oool0oooo0?ooo`0000001@3oool001L0oooo00<000000?ooo`3oool0?P2g
0?l00`000000o`000?l0000k0?l000030000002g0?l0]`3o00/0]`3o00@000000?ooo`3oool00000
1@3oool001L0oooo00<000000?ooo`3oool0?P2g0?l00`000000o`000?l0000k0?l000030000002g
0?l0]`3o00/0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0n
0;L0o`030000003o0000o`0003`0o`0000<000000;L0o`2g0?l02P2g0?l30?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo03d0]`3o00<000000?l0003o0000?P3o00000`00
0000]`3o0;L0o`090;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3o
ool0?@2g0?l00`000000o`000?l0000n0?l000030000002g0?l0]`3o00T0]`3o0`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m0;L0o`030000003o0000o`0003h0o`00
00<000000;L0o`2g0?l02@2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo00800000>`2g0?l00`000000o`000?l0000n0?l000030000002g0?l0]`3o00T0]`3o0`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`02002Ko`800000>@2g0?l0
0`000000o`000?l0000n0?l000030000002g0?l0]`3o00T0]`3o0`3oool00`000000oooo0?ooo`03
0?ooo`005`3oool00`000000oooo0?ooo`04002Ko`030000002g0?l0]`3o03H0]`3o00<000000?l0
003o0000?P3o00000`000000]`3o0;L0o`090;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0
oooo00<000000?ooo`3oool00P000003002Ko`800000=P2g0?l00`000000o`000?l0000n0?l00003
0000002g0?l0]`3o00T0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`02003o4@0300000000Vol009_o008009_o0P00000d0;L0o`030000003o0000o`0003h0o`00
00<000000;L0o`2g0?l02@2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo00<00?lA00<00000002Ko`00Vol00`00Vol00`000000]`3o0;L0o`0a0;L0o`030000003o
0000o`0003h0o`0000<000000;L0o`2g0?l02@2g0?l30?ooo`030000003oool0oooo00<0oooo000G
0?ooo`030000003oool0oooo00@00?lA0P000004002Ko`800000<@2g0?l00`000000o`000?l0000n
0?l000030000002g0?l0]`3o00T0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`02000000@00?lA00<00000002Ko`00Vol00`00Vol2000002l0]`3o00<000000?l0
003o0000?P3o00000`000000]`3o0;L0o`090;L0o`<0oooo00<000000?ooo`3oool00`3oool000@0
oooo0`0000000`3oool0000000000002000000030;Zj^P3oool0V9RH00<0000000<0V9RH0?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?nm000300000000oa400?lA00800?lA00<00000002Ko`00
Vol01000Vol00`000000]`3o0;L0o`0/0;L0o`030000003o0000o`0003h0o`0000<000000;L0o`2g
0?l02@2g0?l30?ooo`030000003oool0oooo00<0oooo00050?ooo`0>0000003oool0oooo0<c<c03^
k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV00000040?ooo`030000003oool0oooo00<0
okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`04002Ko`800000;02g0?l00`000000
o`000?l0000n0?l000030000002g0?l0]`3o00T0]`3o0`3oool00`000000oooo0?ooo`030?ooo`00
1@3oool01P000000oooo0?ooo`3oool0c<c<0>k^kP<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`80000000<0oooo0?nm003o_@000P3o_@000`0000000?lA003o4@02003o4@0300000000Vol0
09_o00D009_o00<000000;L0o`2g0?l0:@2g0?l00`000000o`000?l0000n0?l000030000002g0?l0
]`3o00T0]`3o0P3oool2000000D0oooo00050?ooo`030000003oool0oooo0080oooo00D0ZJVY0>k^
kP3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o_@00
0`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0:@2g0?l0
0`000000o`000?l0000n0?l000030000002g0?l0]`3o00T0]`3o0`3oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`050=gMg@1VIVH0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00oa40
0`00000009_o002Ko`05002Ko`030000002g0?l0]`3o02X0]`3o00<000000?l0003o0000?P3o0000
0`000000]`3o0;L0o`080;L0o`<0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?oo
o`3oool0MgMg0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<0
00000;L0o`2g0?l0:P2g0?l00`000000o`000?l0000n0?l000030000002g0?l0]`3o00P0]`3o0`3o
ool00`000000oooo0?ooo`030?ooo`001@3oool010000000oooo0?ooo`00000209RHV0080000003o
ool0oooo0000002HV9P0oooo09RHV00000040?ooo`030000003oool0oooo00@0okd000<00000003o
4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o02X0]`3o00<000000?l0
003o0000?`3o00000`000000]`3o0;L0o`070;L0o`<0oooo00<000000?ooo`3oool00`3oool000@0
oooo00D08B4Q0000003oool0oooo09RHV0020000000409RHV03oool0oooo09RHV0<0000000<0V9RH
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000
002Ko`00Vol01@00Vol00`000000]`3o0;L0o`0[0;L0o`030000003o0000o`0003h0o`0000<00000
0;L0o`2g0?l01`2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo
00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o
02/0]`3o00<000000?l0003o0000?P3o00000`000000]`3o0;L0o`070;L0o`<0oooo00<000000?oo
o`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@03
00000000Vol009_o00D009_o00<000000;L0o`2g0?l0:`2g0?l00`000000o`000?l0000o0?l00003
0000002g0?l0]`3o00H0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o
0;L0o`0/0;L0o`030000003o0000o`0003h0o`0000<000000;L0o`2g0?l01P2g0?l30?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00
oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o02`0]`3o00<000000?l0003o0000?`3o
00000`000000]`3o0;L0o`050;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<00000
0?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<00000
0;L0o`2g0?l0;02g0?l00`000000o`000?l0000o0?l000030000002g0?l0]`3o00D0]`3o0`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA
00800?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`0]0;L0o`030000003o0000o`00
03l0o`0000<000000;L0o`2g0?l0102g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`03
0000003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`03
0000002g0?l0]`3o02d0]`3o00<000000?l0003o0000?`3o00000`000000]`3o0;L0o`040;L0o`<0
oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA
003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0;@2g0?l00`000000o`00
0?l0000o0?l000030000002g0?l0]`3o00@0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00
Vol00`000000]`3o0;L0o`0^0;L0o`030000003o0000o`0003l0o`0000<000000;L0o`2g0?l00`2g
0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000
003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o02h0]`3o00<00000
0?l0003o0000?`3o00000`000000]`3o0;L0o`030;L0o`<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o
00D009_o00<000000;L0o`2g0?l0;P2g0?l00`000000o`000?l0000o0?l000030000002g0?l0]`3o
00<0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm0003
00000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`0^0;L0o`03
0000003o0000o`0003l0o`0000<000000;L0o`2g0?l00`2g0?l30?ooo`030000003oool0oooo00<0
oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o
002Ko`05002Ko`030000002g0?l0]`3o02h0]`3o00<000000?l0003o0000?`3o00000`000000]`3o
0;L0o`030;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o
_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0;P2g
0?l00`000000o`000?l0000o0?l000030000002g0?l0]`3o00<0]`3o0`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000
002Ko`00Vol01@00Vol00`000000]`3o0;L0o`0^0;L0o`030000003o0000o`0003l0o`0000<00000
0;L0o`2g0?l00`2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`80000000<0oooo0?nm
003o_@000P3o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0
o`2g0?l0;P2g0?l00`000000o`000?l0000o0?l000030000002g0?l0]`3o00<0]`3o0P3oool20000
00D0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`000000
09_o002Ko`05002Ko`030000002g0?l0]`3o02h0]`3o00<000000?l0003o0000?`3o00000`000000
]`3o0;L0o`030;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0
;P2g0?l00`000000o`000?l0000o0?l000030000002g0?l0]`3o00<0]`3o0`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<0
0000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`0^0;L0o`030000003o0000o`0003l0o`0000<0
00000;L0o`2g0?l00`2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0
oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0
]`3o02h0]`3o00<000000?l0003o0000?`3o00000`000000]`3o0;L0o`030;L0o`<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o
4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0;P2g0?l00`000000o`000?l0000o0?l0
00030000002g0?l0]`3o00<0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000
oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol00`000000
]`3o0;L0o`0^0;L0o`800000@03o00000`000000]`3o0;L0o`030;L0o`<0oooo00<000000?ooo`3o
ool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@030000
0000Vol009_o00D009_o00<000000;L0o`2g0?l0<02g0?l3000003d0o`0000<000000;L0o`2g0?l0
0`2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<0
0000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o03<0]`3o0`00
000j0?l000030000002g0?l0]`3o00<0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool0
0`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol0
0`000000]`3o0;L0o`0f0;L0o`<00000>03o00000`000000]`3o0;L0o`020;L0o`<0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o
4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0>@2g0?l3000003D0o`0000<000000;L0
o`2g0?l00P2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0
okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o03`0
]`3o0`00000b0?l000030000002g0?l0]`3o0080]`3o0`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol0
1@00Vol00`000000]`3o0;L0o`0o0;L0o`800000<@3o000010000000]`3o0;L0o`2g0?l30?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa40
0P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o0440]`3o0P00000_0?l000040000
002g0?l0]`3o0;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0
103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0
@`2g0?l2000002d0o`0000@000000;L0o`2g0?l0]`3o0`3oool00`000000oooo0?ooo`030?ooo`00
5`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol0
1@00Vol00`000000]`3o0;L0o`150;L0o`800000:`3o000010000000]`3o0;L0o`2g0?l30?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa40
0P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o04L0]`3o00<000000?l0003o0000
:@3o00000`000000]`3o0;L0o`030?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003o
ool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g
0?l0]`3o04P0]`3o0P00000Y0?l000030000002g0?l0]`3o00<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol0
09_o00D009_o00<000000;L0o`2g0?l0BP2g0?l2000002L0o`0000<000000;L0o`2g0?l00`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA
00800?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`1<0;L0o`8000009P3o00000`00
0000]`3o0?ooo`020?ooo`030000003oool0oooo00<0oooo000G0?ooo`80000000<0oooo0?nm003o
_@000P3o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g
0?l0CP2g0?l200000280o`000`0000000`2g0?l0oooo0?ooo`02000000D0oooo000G0?ooo`030000
003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000
002g0?l0]`3o0500]`3o0P00000K0?l000D00000102g0?l30?ooo`030000003oool0oooo00<0oooo
000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002K
o`05002Ko`030000002g0?l0]`3o0580]`3o0P00000E0?l000@000002@2g0?l30?ooo`030000003o
ool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400P00oa40
0`00000009_o002Ko`05002Ko`030000002g0?l0]`3o05@0]`3o0P00000?0?l000@000003@2g0?l3
0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o
4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o05H0]`3o0P0000080?l0
00D000004@2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0
okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o05P0
]`3o0P0000020?l000@000005P2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000
003oool0oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000
002g0?l0]`3o05X0]`3o0P00000J0;L0o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<0
00000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00D009_o00<0
00000;L0o`2g0?l0MP2g0?l30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0
oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0
]`3o07H0]`3o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm
000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`1f0;L0
o`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0103o_@000`000000
0?lA003o4@02003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0MP2g0?l30?ooo`03
0000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa40
0P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0]`3o07H0]`3o0`3oool00`000000oooo
0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<0
0000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`1f0;L0o`<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@02003o4@0300000000Vol0
09_o00D009_o00<000000;L0o`2g0?l0MP2g0?l010000000oooo0?ooo`0000050?ooo`005`3oool0
0`000000oooo0?ooo`040?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01@00Vol0
0`000000]`3o0;L0o`1f0;L0o`040000003oool0oooo000000D0oooo000G0?ooo`030000003oool0
oooo00@0okd000<00000003o4@00oa400P00oa400`00000009_o002Ko`05002Ko`030000002g0?l0
]`3o07H0]`3o00@000000?ooo`3oool000001@3oool001L0oooo00<000000?ooo`3oool0103o_@00
0`0000000?lA003o4@02003o4@0300000000Vol009_o00H009_o00<000000;L0o`2g0?l0M@2g0?l0
10000000oooo0?ooo`0000050?ooo`005`3oool00`000000oooo0?ooo`040?nm000300000000oa40
0?lA00<00?lA00<00000002Ko`00Vol01@00Vol00`000000]`3o0;L0o`1e0;L0o`040000003oool0
oooo000000D0oooo000G0?ooo`030000003oool0oooo00@0okd000<00000003o4@00oa400`00oa40
0`00000009_o002Ko`05002Ko`030000002g0?l0]`3o07D0]`3o00@000000?ooo`3oool000001@3o
ool001L0oooo00<000000?ooo`3oool0103o_@000`0000000?lA003o4@03003o4@0300000000Vol0
09_o00D009_o00<000000;L0o`2g0?l0M@2g0?l010000000oooo0?ooo`0000050?ooo`005`3oool2
000000030?ooo`3o_@00okd00080okd000<00000003o4@00oa400`00oa400`00000009_o002Ko`05
002Ko`030000002g0?l0]`3o07D0]`3o00@000000?ooo`00000000001@3oool001L0oooo00<00000
0?ooo`3oool01@3o_@000`0000000?lA003o4@02003o4@0300000000Vol009_o00H009_o00<00000
0;L0o`2g0?l0M02g0?l010000000oooo0?ooo`0000050?ooo`005`3oool00`000000oooo0?ooo`05
0?nm000300000000oa400?lA00800?lA00<00000002Ko`00Vol01P00Vol00`000000]`3o0;L0o`1d
0;L0o`040000003oool0oooo000000D0oooo000G0?ooo`030000003oool0oooo00D0okd000<00000
003o4@00oa400P00oa400`00000009_o002Ko`06002Ko`030000002g0?l0]`3o07@0]`3o00@00000
0?ooo`3oool000001@3oool001L0oooo00<000000?ooo`3oool01@3o_@000`0000000?lA003o4@03
003o4@0300000000Vol009_o00D009_o00<000000;L0o`2g0?l0M02g0?l010000000oooo0?ooo`00
00050?ooo`005`3oool00`000000oooo0?ooo`050?nm000300000000oa400?lA00<00?lA00<00000
002Ko`00Vol01@00Vol00`000000]`3o0;L0o`1d0;L0o`040000003oool0oooo000000D0oooo000G
0?ooo`030000003oool0oooo00D0okd000<00000003o4@00oa400`00oa400`00000009_o002Ko`06
002Ko`030000002g0?l0]`3o07<0]`3o00@000000?ooo`3oool000001@3oool001L0oooo00<00000
0?ooo`3oool01@3o_@02000000@00?lA0P000007002Ko`<00000L`2g0?l010000000oooo0?ooo`00
00050?ooo`005`3oool00`000000oooo0?ooo`070?nm00<000000`00oa43000000L009_o1000001_
0;L0o`040000003oool0oooo000000D0oooo000G0?ooo`030000003oool0oooo00X0okd00P000004
003o4@<000002000Vol3000006`0]`3o00@000000?ooo`3oool000001@3oool001L0oooo00<00000
0?ooo`3oool0303o_@03000000@00?lA0`000008002Ko`800000JP2g0?l010000000oooo0?ooo`00
00050?ooo`005`3oool00`000000oooo0?ooo`0?0?nm00<000001000oa43000000L009_o0P00001X
0;L0o`040000003oool0oooo000000D0oooo000G0?ooo`030000003oool0oooo0180okd00P000005
003o4@<000001P00Vol2000006H0]`3o00@000000?ooo`3oool000001@3oool001L0oooo00<00000
0?ooo`3oool0503o_@03000000D00?lA0P000006002Ko`800000I02g0?l010000000oooo0?ooo`00
00050?ooo`005`3oool00`000000oooo0?ooo`0G0?nm008000001@00oa42000000H009_o0P00001R
0;L0o`040000003oool0oooo000000D0oooo000G0?ooo`030000003oool0oooo01T0okd00`000004
003o4@8000001P00Vol00`000000]`3o0;L0o`1O0;L0o`040000003oool0oooo000000D0oooo000G
0?ooo`030000003oool0oooo01`0okd00P000004003o4@8000001@00Vol2000005l0]`3o00@00000
0?ooo`3oool000001@3oool001L0oooo00<000000?ooo`3oool07P3o_@000`0000000?lA003o4@03
003o4@0300000000Vol009_o00@009_o0P00001M0;L0o`040000003oool0oooo000000D0oooo000G
0?ooo`030000003oool0oooo01l0okd00P000004003o4@8000001P00Vol2000005/0]`3o00@00000
0?ooo`3oool000001@3oool000@0oooo0`0000040?ooo`040000003oool0oooo09RHV0<0000000<0
V9RH0?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?nm008000001000oa42000000H009_o0P00
001I0;L0o`040000003oool0oooo000000D0oooo00050?ooo`030000003oool0oooo00<0oooo00P0
00000?ooo`3oool0000009RHV03oool0V9RH000000@0oooo00<000000?ooo`3oool08`3o_@000`00
00000?lA003o4@03003o4@8000001P00Vol2000005L0]`3o00@000000?ooo`3oool000001@3oool0
00D0oooo00<000000?ooo`3oool01`0000030?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool0okd00?nm000R0?nm008000001@00oa42000000H009_o0`00001D0;L0o`040000003oool00000
000000D0oooo00050?ooo`070000003oool0oooo04A4A02HV9P0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0V0?nm008000001@00oa43000000H009_o
0`00001A0;L0o`040000003oool0oooo000000D0oooo00050?ooo`070000003oool0oooo0>k^kP0@
4100gMgM000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0X
0?nm008000001P00oa42000000L009_o0P00001>0;L0o`050000003oool0oooo0?ooo`0000001@3o
ool000D0oooo00L000000?ooo`3oool0oooo0:VYZ@0b<S8000000080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo02X0okd00P000006003o4@8000001`00Vol2000004/0
]`3o00<00000002Ko`3oool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`020?ooo`0906IVIP000000oooo0?ooo`000000V9RH0?ooo`2HV9P0000000@0oooo00<00000
0?ooo`3oool0;03o_@03000000D00?lA0`000006002Ko`800000B@2g0?l00`00000009_o0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00040?ooo`03024Q8@000000oooo00<0oooo00D0k^k^010@
403oool0oooo09RHV0030000000309RHV03oool0oooo0080oooo00<000000?ooo`3oool0;`3o_@02
000000H00?lA0P000006002Ko`800000AP2g0?l00`00000009_o002Ko`030?ooo`030000003oool0
oooo00<0oooo000G0?ooo`030000003oool0oooo0340okd00P000006003o4@8000001P00Vol20000
04<0]`3o00@00000002Ko`00Vol009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`0c0?nm008000001P00oa42000000H009_o0P0000100;L0o`0300000000Vol009_o
008009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0e0?nm0080
00001P00oa42000000H009_o0P00000n0;L0o`0300000000Vol009_o008009_o0`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0g0?nm008000001P00oa42000000H009_o
0P00000k0;L0o`0300000000Vol009_o00<009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool00`000000oooo0?ooo`0i0?nm008000001P00oa42000000H009_o0P00000h0;L0o`0300000000
Vol009_o00@009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0k
0?nm008000001P00oa42000000H009_o0P00000f0;L0o`0300000000Vol009_o00@009_o0`3oool0
0`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`0m0?nm008000001P00oa420000
00H009_o0P00000c0;L0o`0300000000Vol009_o00D009_o0`3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`0o0?nm008000001P00oa42000000H009_o0P00000`0;L0o`03
00000000Vol009_o00H009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`110?nm008000001P00oa42000000H009_o0P00000^0;L0o`0300000000Vol009_o00H009_o
0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`130?nm00<000001@00
oa42000000H009_o0P00000]0;L0o`0300000000Vol009_o00D009_o0`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`160?nm008000001@00oa42000000H009_o0P00000/
0;L0o`0300000000Vol009_o00@009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`180?nm008000001@00oa42000000H009_o0P00000Z0;L0o`0300000000Vol009_o
00@009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1:0?nm0080
00001@00oa42000000H009_o0P00000Y0;L0o`0300000000Vol009_o00<009_o0`3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1<0?nm008000001@00oa42000000H009_o
0P00000X0;L0o`0300000000Vol009_o008009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3o
ool2000000030?ooo`3o_@00okd004`0okd00`000004003o4@8000001P00Vol2000002H0]`3o00<0
0000002Ko`00Vol00P00Vol20?ooo`8000001@3oool001L0oooo00<000000?ooo`3oool0D@3o_@02
000000@00?lA0P000006002Ko`030000002g0?l0]`3o02@0]`3o00@00000002Ko`00Vol009_o0`3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1C0?nm008000001000oa42
000000D009_o0P00000T0;L0o`0400000000Vol009_o002Ko`<0oooo00<000000?ooo`3oool00`3o
ool001L0oooo00<000000?ooo`3oool0E@3o_@000`0000000?lA003o4@03003o4@0300000000Vol0
09_o00@009_o0P00000S0;L0o`0300000000Vol009_o00<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool0EP3o_@02000000@00?lA0P000006002Ko`8000008P2g0?l00`00
000009_o0?ooo`020?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo05P0
okd00P000004003o4@8000001P00Vol200000200]`3o00<00000002Ko`3oool00P3oool00`000000
oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1J0?nm000300000000oa400?lA00<00?lA
0P000006002Ko`8000007`2g0?l01@000000oooo0?ooo`3oool0000000D0oooo000G0?ooo`030000
003oool0oooo05/0okd00P000005003o4@8000001P00Vol2000001T0]`3o1P0000020?ooo`030000
003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo05d0okd00P000005003o4@0300000000
Vol009_o00D009_o00<000000;L0o`2g0?l03@2g0?l9000000D009_o0`3oool00`000000oooo0?oo
o`030?ooo`005`3oool00`000000oooo0?ooo`1O0?nm000300000000oa400?lA00<00?lA0P000006
002Ko`030000002g0?l0]`3o00<0]`3o2@00000>002Ko`<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo00<000000?ooo`3oool0H03o_@02000000D00?lA00<00000002Ko`00Vol01000Vol50000
01L009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`1R0?nm0080
00001000oa420000020009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo
0?ooo`1T0?nm008000001000oa400`00000009_o002Ko`0M002Ko`<0oooo00<000000?ooo`3oool0
0`3oool001L0oooo00<000000?ooo`3oool0IP3o_@000`0000000?lA003o4@02003o4@8000007@00
Vol30?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo06L0okd00P000004
003o4@0300000000Vol009_o01X009_o0`3oool00`000000oooo0?ooo`030?ooo`005`3oool00`00
0000oooo0?ooo`1Y0?nm008000000`00oa43000001T009_o0`3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`1[0?nm000300000000oa400?lA00<00?lA1@00000D002Ko`<0
oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0K03o_@02000000P00?lA
1000000@002Ko`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0KP3o
_@05000000L00?lA1000000<002Ko`<0oooo00<000000?ooo`3oool00`3oool001L0oooo00<00000
0?ooo`3oool0L`3o_@07000000@00?lA1@000007002Ko`<0oooo00<000000?ooo`3oool00`3oool0
01L0oooo0P0000000`3oool0okd00?nm001h0?nm00@000001@00oa42000000D009_o0P3oool20000
00D0oooo000G0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool00`3oool001L0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?oo
o`005`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00<0oooo000G0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool00`3oool001L0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`030?ooo`005`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00<0oooo000G0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`005`3o
oonA000000D0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool004L0oooo0`000000
0`3oool0MgMg00000002000000l0oooo00D0410@000000000000000009RHV0040?ooo`<0000000@0
oooo000000000000oooo1@000000103oool000000000003oool2000003@0oooo00180?ooo`0609RH
V01gMgL0oooo0?ooo`0Q8B40ZJVY1P3oool7000000H0oooo00<0V9RH0000003oool0103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
=@3oool004T0oooo00@0EEEE09RHV01gMgL0IVIV5@3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000e
0?ooo`00B@3oool00`3^k^h08B4Q038b<P0F0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003D0oooo
00190?ooo`030>k^kP0@4100<S8b00P0oooo1`0000060?ooo`0309RHV0000000oooo00@0oooo00L0
00000<c<c03<c<`000000;Zj^P3<c<`000000080oooo00L000000<c<c03<c<`000000;Zj^P3<c<`0
000003D0oooo00190?ooo`0406IVIP1gMgL0ZJVY06IVIQ40oooo100000000`2HV9P0oooo0?ooo`02
0?ooo`80000000L0V9RH00000027QhL0V9RH0000002HV9P0oooo0080000000H0V9RH00000027QhL0
V9RH0000002HV9Pe0?ooo`00B03oool0102YZJT08B4Q0?ooo`3oool209RHV0030>k^kP3oool0oooo
00d0oooo00<0MgMg05EEE@3oool0C03oool004L0oooo0`0000000`1gMgL0oooo038b<P0200000003
0;Zj^P3oool0oooo00d0oooo00@0410@000000000000<S8bBP3oool00:d0oooo002]0?ooo`00[@3o
ool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00
[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?oo
o`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]
0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo
002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 172.375}, {661.875, 0}} -> {-5.54935, 3.36128, \
0.24669, 0.24669}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuickDraw3D Graphics", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Here are instructions to plot using QuickDraw3D the whole quadrupole or \
the periodic part of the iron structure. One can save the geometry with \
colors in a 3dmf format using the menu \"File->Save As\"  in Radia.exe before \
returning to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ". A 3dmf file can be read by a number of CAD and RayTracing Packages. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\( (*\ 
      If\ QuickDraw3D\ is\ installed\ *) \)\(\[IndentingNewLine]\)\( (*\ 
      The\ whole\ geometry\ *) \)\(\n\)\(radObjDrwQD3D[t];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      If\ QuickDraw3D\ is\ installed\ *) \)\(\[IndentingNewLine]\)\( (*\ 
      The\ Periodic\ part\ of\ the\ Iron\ \ *) \)\(\n\)\(radObjDrwQD3D[
        g];\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics"
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The plot of the whole quadrupole requires significant memory for the \
Kernel. Depending on your memory  you may or may not be capable of plotting \
it. However, one may just want to plot the periodic part of the iron \
structure to see  its  segmentation. To plot the whole quadrupole replace \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  "radObjDrw[g]\" by \"radObjDrw[t]\" and be preapred to wait for some time. \
This time can be minimized if you only plot loosely segmented structures. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"draw", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}], ";", "\n", 
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", 
      "\n", \(Show[Graphics3D[draw]\n, ViewPoint -> {5, \(-2\), 1}\n, 
        PlotRange -> All\n, AmbientLight\  -> \ GrayLevel[0.1]]\), 
      ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.77604 .868 -11.9602 0 ]
[.77604 .868 12.2898 14 ]
[.80885 .86189 -4.92393 0 ]
[.80885 .86189 5.07607 14 ]
[.84289 .85555 -7.86483 0 ]
[.84289 .85555 8.13517 14 ]
[.8098 .92438 -7.69364 0 ]
[.8098 .92438 7.93136 14 ]
[.2558 .09462 -14.9359 -14 ]
[.2558 .09462 15.3141 0 ]
[.40479 .11129 -15.0513 -14 ]
[.40479 .11129 15.1987 0 ]
[.54925 .12746 -5.01259 -14 ]
[.54925 .12746 4.98741 0 ]
[.68939 .14315 -11.1064 -14 ]
[.68939 .14315 10.8936 0 ]
[.8254 .15837 -11.1827 -14 ]
[.8254 .15837 10.8173 0 ]
[.5491 .06496 -7.83217 -14 ]
[.5491 .06496 7.79283 0 ]
[.13019 .20369 -30.25 -7.70388 ]
[.13019 .20369 0 6.29612 ]
[.12751 .34993 -30.25 -7.59909 ]
[.12751 .34993 0 6.40091 ]
[.1248 .49835 -10 -7.49279 ]
[.1248 .49835 0 6.50721 ]
[.12205 .64902 -22 -7.38495 ]
[.12205 .64902 0 6.61505 ]
[.11926 .80197 -22 -7.27553 ]
[.11926 .80197 0 6.72447 ]
[.06246 .49396 -14.3125 -7.49279 ]
[.06246 .49396 0 6.50721 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.75292 .85977 m
.86804 .83832 L
s
.25 Mabswid
.77587 .8555 m
.77578 .84925 L
s
gsave
.77604 .868 -72.9602 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.80866 .84939 m
.80856 .84314 L
s
gsave
.80885 .86189 -65.9239 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.84268 .84305 m
.84257 .8368 L
s
gsave
.84289 .85555 -68.8648 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.78233 .85429 m
.78228 .85054 L
s
.78884 .85308 m
.78879 .84933 L
s
.7954 .85186 m
.79534 .84811 L
s
.802 .85063 m
.80195 .84688 L
s
.81536 .84814 m
.8153 .84439 L
s
.82211 .84688 m
.82205 .84313 L
s
.82892 .84561 m
.82886 .84186 L
s
.83577 .84434 m
.83571 .84059 L
s
.76945 .85669 m
.7694 .85294 L
s
.76308 .85788 m
.76303 .85413 L
s
.75676 .85906 m
.75671 .85531 L
s
.84964 .84175 m
.84957 .838 L
s
.85665 .84045 m
.85658 .8367 L
s
.86371 .83913 m
.86364 .83538 L
s
gsave
.8098 .92438 -68.6936 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.22109 .10325 m
.85599 .17427 L
s
.25 Mabswid
.25564 .10712 m
.25556 .11336 L
s
gsave
.2558 .09462 -75.9359 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.40473 .12379 m
.4047 .13004 L
s
gsave
.40479 .11129 -76.0513 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.54929 .13996 m
.5493 .14621 L
s
gsave
.54925 .12746 -66.0126 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.68951 .15565 m
.68957 .1619 L
s
gsave
.68939 .14315 -72.1064 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.8256 .17087 m
.82571 .17712 L
s
gsave
.8254 .15837 -72.1827 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.28583 .11049 m
.28579 .11424 L
s
.31583 .11385 m
.3158 .1176 L
s
.34565 .11718 m
.34562 .12093 L
s
.37528 .1205 m
.37526 .12425 L
s
.434 .12707 m
.43398 .13082 L
s
.46308 .13032 m
.46308 .13407 L
s
.49199 .13355 m
.49199 .1373 L
s
.52073 .13677 m
.52073 .14052 L
s
.57767 .14314 m
.57769 .14689 L
s
.60589 .14629 m
.60591 .15004 L
s
.63393 .14943 m
.63396 .15318 L
s
.66181 .15255 m
.66184 .1563 L
s
.71706 .15873 m
.7171 .16248 L
s
.74444 .16179 m
.74448 .16554 L
s
.77165 .16484 m
.7717 .16859 L
s
.79871 .16786 m
.79876 .17161 L
s
.22526 .10372 m
.22521 .10747 L
s
.85234 .17386 m
.85241 .17761 L
s
gsave
.5491 .06496 -68.8322 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.14322 .17203 m
.13112 .83753 L
s
.25 Mabswid
.14263 .20494 m
.14884 .20557 L
s
gsave
.13019 .20369 -91.25 -11.7039 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.13997 .35099 m
.1462 .35152 L
s
gsave
.12751 .34993 -91.25 -11.5991 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.13727 .49923 m
.14351 .49967 L
s
gsave
.1248 .49835 -71 -11.4928 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.13453 .6497 m
.14077 .65005 L
s
gsave
.12205 .64902 -83 -11.3849 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.13175 .80247 m
.138 .80271 L
s
gsave
.11926 .80197 -83 -11.2755 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.1421 .23398 m
.14583 .23434 L
s
.14157 .2631 m
.1453 .26346 L
s
.14104 .29231 m
.14477 .29265 L
s
.1405 .32161 m
.14424 .32194 L
s
.13943 .38046 m
.14317 .38077 L
s
.13889 .41002 m
.14263 .41032 L
s
.13836 .43967 m
.14209 .43995 L
s
.13781 .4694 m
.14155 .46968 L
s
.13673 .52914 m
.14047 .52939 L
s
.13618 .55915 m
.13992 .55939 L
s
.13563 .58924 m
.13938 .58947 L
s
.13508 .61943 m
.13883 .61964 L
s
.13398 .68007 m
.13773 .68027 L
s
.13343 .71053 m
.13717 .71071 L
s
.13287 .74108 m
.13662 .74125 L
s
.13231 .77173 m
.13606 .77189 L
s
.14315 .17599 m
.14688 .17638 L
s
.13119 .8333 m
.13494 .83343 L
s
gsave
.06246 .49396 -75.3125 -11.4928 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.14322 .17203 m
.13112 .83753 L
s
.13112 .83753 m
.75292 .85977 L
s
.75292 .85977 m
.74513 .23459 L
s
.74513 .23459 m
.14322 .17203 L
s
.22109 .10325 m
.85599 .17427 L
s
.85599 .17427 m
.86804 .83832 L
s
.86804 .83832 m
.21096 .81296 L
s
.21096 .81296 m
.22109 .10325 L
s
.14322 .17203 m
.13112 .83753 L
s
.13112 .83753 m
.21096 .81296 L
s
.21096 .81296 m
.22109 .10325 L
s
.22109 .10325 m
.14322 .17203 L
s
.74513 .23459 m
.85599 .17427 L
s
.85599 .17427 m
.86804 .83832 L
s
.86804 .83832 m
.75292 .85977 L
s
.75292 .85977 m
.74513 .23459 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.55328 .37495 m .53768 .38308 L .59069 .44354 L p .577 0 0 r
F P
0 g
s
.59069 .44354 m .60678 .43604 L .55328 .37495 L p .577 0 0 r
F P
0 g
s
.5578 .47614 m .59069 .44354 L .53768 .38308 L p .855 0 0 r
F P
0 g
s
.5578 .47614 m .61374 .46467 L .59069 .44354 L .831 0 0 r
F
.60678 .43604 m .59069 .44354 L .61374 .46467 L .577 0 0 r
F
.60678 .43604 m .59069 .44354 L .5578 .47614 L p .164 0 0 r
F P
0 g
s
.57364 .46894 m .59069 .44354 L .60678 .43604 L .164 0 0 r
F
.57364 .46894 m .5578 .47614 L .59069 .44354 L F
.58094 .49742 m .63724 .47732 L .61374 .46467 L .765 0 0 r
F
.61454 .44315 m .61374 .46467 L .63724 .47732 L .577 0 0 r
F
.5578 .47614 m .58094 .49742 L .61374 .46467 L .831 0 0 r
F
.60678 .43604 m .61374 .46467 L .61454 .44315 L .577 0 0 r
F
0 g
.59513 .44761 m
.61374 .46467 L
s
.53768 .38308 m .50441 .41546 L .5578 .47614 L p .855 0 0 r
F P
0 g
s
.50441 .41546 m .53768 .38308 L .55328 .37495 L p .1 0 0 r
F P
0 g
s
.51976 .40761 m .53768 .38308 L .50441 .41546 L .1 0 0 r
F
.51976 .40761 m .55328 .37495 L .53768 .38308 L F
.48733 .391 m .53768 .38308 L .5208 .35865 L .88 0 0 r
F
.48733 .391 m .50441 .41546 L .53768 .38308 L F
.54762 .36674 m .53768 .38308 L .55328 .37495 L .577 0 0 r
F
.54762 .36674 m .5208 .35865 L .53768 .38308 L F
.76399 .53068 m .77673 .52595 L .74267 .48686 L p 0 .319 .936 r
F P
0 g
s
.74267 .48686 m .73014 .49188 L .76399 .53068 L p 0 .319 .936 r
F P
0 g
s
.74444 .52928 m .76399 .53068 L .73014 .49188 L closepath p 0 .349 .781 r
F P
0 g
s
.76399 .53068 m .77673 .52595 L .75707 .52453 L p 0 .458 1 r
F P
0 g
s
.75707 .52453 m .74444 .52928 L .76399 .53068 L p 0 .458 1 r
F P
0 g
s
.77673 .52595 m .76399 .53068 L .73098 .56481 L p 0 .05 .248 r
F P
0 g
s
.73098 .56481 m .76399 .53068 L .74444 .52928 L closepath p 0 .349 .781 r
F P
0 g
s
.77673 .52595 m .76399 .53068 L .74444 .52928 L p 0 .458 1 r
F P
0 g
s
.73014 .49188 m .71356 .50883 L .72073 .52758 L p 0 .349 .781 r
F P
0 g
s
.72073 .52758 m .74444 .52928 L .73014 .49188 L p 0 .349 .781 r
F P
0 g
s
.73014 .49188 m .74267 .48686 L .726 .50392 L p 0 .05 .212 r
F P
0 g
s
.726 .50392 m .71356 .50883 L .73014 .49188 L p 0 .05 .212 r
F P
0 g
s
.73014 .49188 m .65069 .4008 L .61686 .43443 L p 0 .349 .781 r
F P
0 g
s
.61686 .43443 m .69689 .52586 L .73014 .49188 L p 0 .349 .781 r
F P
0 g
s
.69689 .52586 m .72073 .52758 L .71356 .50883 L closepath p 0 .349 .781 r
F P
0 g
s
.73014 .49188 m .69689 .52586 L .72178 .5162 L p 0 .05 .212 r
F P
0 g
s
.74267 .48686 m .77673 .52595 L .78966 .52115 L p 0 .319 .936 r
F P
0 g
s
.78966 .52115 m .75538 .48177 L .74267 .48686 L p 0 .319 .936 r
F P
0 g
s
.72178 .5162 m .75538 .48177 L .73014 .49188 L p 0 .05 .212 r
F P
0 g
s
.73014 .49188 m .75538 .48177 L .67487 .38932 L p 0 .319 .936 r
F P
0 g
s
.67487 .38932 m .65069 .4008 L .73014 .49188 L p 0 .319 .936 r
F P
0 g
s
.5578 .47614 m .57364 .46894 L .60678 .43604 L p .164 0 0 r
F P
0 g
s
.5578 .47614 m .53519 .43541 L .56287 .45668 L .569 0 0 r
F
.51976 .40761 m .53062 .41998 L p .53519 .43541 L F P
0 g
s
.53062 .41998 m .56287 .45668 L p .53519 .43541 L .569 0 0 r
F P
0 g
s
.50441 .41546 m .51976 .40761 L p .52115 .41012 L .569 0 0 r
F P
0 g
s
.51492 .42227 m .50441 .41546 L .52115 .41012 L .569 0 0 r
F
.54188 .45805 m .50441 .41546 L p .53519 .43541 L F P
0 g
s
.55328 .37495 m .51976 .40761 L .50441 .41546 L p .1 0 0 r
F P
0 g
s
.50714 .4109 m .51976 .40761 L .50441 .41546 L .569 0 0 r
F
.51404 .39939 m .51812 .40526 L .50714 .4109 L F
.51812 .40526 m .51976 .40761 L .50714 .4109 L F
.51404 .39939 m .55328 .37495 L .51976 .40761 L .881 0 0 r
F
.51404 .39939 m .54762 .36674 L .55328 .37495 L F
.51404 .39939 m .50441 .41546 L .50201 .41202 L .569 0 0 r
F
.50912 .39784 m .50201 .41202 L .48733 .391 L F
.51404 .39939 m .50201 .41202 L .50912 .39784 L F
.54558 .35959 m .5208 .35865 L .54762 .36674 L .577 0 0 r
F
.54558 .35959 m .51452 .33724 L .5208 .35865 L F
.54771 .35542 m .51452 .33724 L .54558 .35959 L F
.51396 .38816 m .54558 .35959 L .54771 .35542 L .937 0 0 r
F
.48081 .36967 m .48733 .391 L .5208 .35865 L .939 0 0 r
F
.50949 .39052 m .48733 .391 L .48081 .36967 L .569 0 0 r
F
.51191 .39227 m .50667 .392 L .50949 .39052 L F
.50667 .392 m .48733 .391 L .50949 .39052 L F
.51294 .39022 m .54558 .35959 L .51396 .38816 L .937 0 0 r
F
.54344 .3708 m .54796 .36722 L .54762 .36674 L .881 0 0 r
F
.48008 .43239 m .54796 .36722 L .54344 .3708 L F
.48008 .43239 m .55328 .37495 L .54796 .36722 L F
.55927 .36863 m .59352 .33526 L .5129 .24283 L p 0 .349 .781 r
F P
0 g
s
.5129 .24283 m .59352 .33526 L .61694 .32279 L p 0 .319 .936 r
F P
0 g
s
.5129 .24283 m .47805 .27583 L .55927 .36863 L p 0 .349 .781 r
F P
0 g
s
.61694 .32279 m .53524 .22894 L .5129 .24283 L p 0 .319 .936 r
F P
0 g
s
.49552 .25929 m .50651 .25249 L .52399 .23594 L p 0 .05 .1 r
F P
0 g
s
.52399 .23594 m .5129 .24283 L .49552 .25929 L p 0 .05 .1 r
F P
0 g
s
.55925 .37024 m .54762 .36674 L .55328 .37495 L .577 0 0 r
F
.51191 .39227 m .54762 .36674 L .51404 .39939 L .941 0 0 r
F
.51191 .39227 m .54558 .35959 L .54762 .36674 L F
.51191 .39227 m .51404 .39939 L .50912 .39784 L .569 0 0 r
F
.51191 .39227 m .50912 .39784 L .48733 .391 L F
.47985 .42127 m .47787 .4253 L .51191 .39227 L .937 0 0 r
F
.51294 .39022 m .51191 .39227 L .54558 .35959 L F
.51396 .38816 m .51191 .39227 L .48081 .36967 L .569 0 0 r
F
.47985 .42127 m .51191 .39227 L .51294 .39022 L .937 0 0 r
F
.47787 .4253 m .54762 .36674 L .54558 .35959 L .941 0 0 r
F
.47787 .4253 m .48008 .43239 L .54762 .36674 L F
.55896 .36922 m .54762 .36674 L .55925 .37024 L .577 0 0 r
F
.55896 .36922 m .54558 .35959 L .54762 .36674 L F
.51396 .38816 m .54558 .35959 L .51191 .39227 L .937 0 0 r
F
.51396 .38816 m .54771 .35542 L .54558 .35959 L F
.55927 .36863 m .54558 .35959 L .55896 .36922 L .577 0 0 r
F
.55927 .36863 m .54771 .35542 L .54558 .35959 L F
.59352 .33526 m .57645 .3519 L .58134 .37056 L p 0 .349 .781 r
F P
0 g
s
.58134 .37056 m .57645 .3519 L .55927 .36863 L closepath p 0 .349 .781 r
F P
0 g
s
.59352 .33526 m .55927 .36863 L .58232 .35657 L p 0 .05 .1 r
F P
0 g
s
.57071 .36264 m .55927 .36863 L .57645 .3519 L p 0 .05 .1 r
F P
0 g
s
.57645 .3519 m .58798 .34581 L .57071 .36264 L p 0 .05 .1 r
F P
0 g
s
.62215 .36808 m .63397 .36214 L .60515 .32907 L p 0 .319 .936 r
F P
0 g
s
.60515 .32907 m .59352 .33526 L .62215 .36808 L p 0 .319 .936 r
F P
0 g
s
.62215 .36808 m .59352 .33526 L .6033 .37248 L p 0 .349 .781 r
F P
0 g
s
.58134 .37056 m .6033 .37248 L .59352 .33526 L p 0 .349 .781 r
F P
0 g
s
.61694 .32279 m .60515 .32907 L .63397 .36214 L p 0 .319 .936 r
F P
0 g
s
.58232 .35657 m .61694 .32279 L .59352 .33526 L p 0 .05 .1 r
F P
0 g
s
.59352 .33526 m .60515 .32907 L .58798 .34581 L p 0 .05 .1 r
F P
0 g
s
.58798 .34581 m .57645 .3519 L .59352 .33526 L p 0 .05 .1 r
F P
0 g
s
.58798 .34581 m .60515 .32907 L .61694 .32279 L p 0 .05 .1 r
F P
0 g
s
.61694 .32279 m .59968 .33963 L .58798 .34581 L p 0 .05 .1 r
F P
0 g
s
.58232 .35657 m .57071 .36264 L .58798 .34581 L p 0 .05 .1 r
F P
0 g
s
.58798 .34581 m .59968 .33963 L .58232 .35657 L p 0 .05 .1 r
F P
0 g
s
.61694 .32279 m .58232 .35657 L p .57559 .33832 L 0 .349 .781 r
F P
0 g
s
.57559 .33832 m .55989 .29576 L .60532 .30943 L 0 .349 .781 r
F
.53524 .22894 m .57812 .2782 L p .55989 .29576 L F P
0 g
s
.57812 .2782 m .60532 .30943 L p .55989 .29576 L 0 .349 .781 r
F P
0 g
s
.54771 .35542 m .57061 .34316 L p .55692 .3275 L .577 0 0 r
F P
0 g
s
.52068 .32454 m .54771 .35542 L p .55692 .3275 L .577 0 0 r
F P
0 g
s
.58232 .35657 m .61694 .32279 L .60532 .30943 L p 0 .349 .781 r
F P
0 g
s
.57559 .33832 m .57812 .2782 L .55989 .29576 L 0 .349 .781 r
F
.5 .26235 m .53524 .22894 L p .57559 .33832 L F P
0 g
s
.58232 .35657 m .57061 .34316 L p .57559 .33832 L 0 .349 .781 r
F P
0 g
s
.58232 .35657 m .60532 .30943 L .57559 .33832 L 0 .349 .781 r
F
.60532 .30943 m .61694 .32279 L p .57559 .33832 L F P
0 g
s
.61694 .32279 m .59968 .33963 L .60466 .35856 L p 0 .349 .781 r
F P
0 g
s
.63397 .36214 m .64595 .3561 L .61694 .32279 L p 0 .319 .936 r
F P
0 g
s
.62891 .31641 m .61694 .32279 L .64595 .3561 L p 0 .319 .936 r
F P
0 g
s
.64595 .3561 m .63397 .36214 L .6627 .3951 L p 0 .319 .936 r
F P
0 g
s
.63397 .36214 m .64595 .3561 L .64025 .36173 L p 0 .05 .1 r
F P
0 g
s
.65069 .4008 m .6627 .3951 L .63397 .36214 L p 0 .319 .936 r
F P
0 g
s
.63397 .36214 m .62215 .36808 L .65069 .4008 L p 0 .319 .936 r
F P
0 g
s
.64025 .36173 m .62829 .36773 L .63397 .36214 L p 0 .05 .1 r
F P
0 g
s
.64595 .3561 m .63397 .36214 L .62829 .36773 L p 0 .05 .1 r
F P
0 g
s
.62829 .36773 m .64025 .36173 L .64595 .3561 L p 0 .05 .1 r
F P
0 g
s
.64025 .36173 m .64595 .3561 L .61694 .32279 L p 0 .349 .781 r
F P
0 g
s
.62688 .36054 m .61694 .32279 L .64595 .3561 L p 0 .349 .781 r
F P
0 g
s
.61694 .32279 m .62688 .36054 L .64025 .36173 L p 0 .349 .781 r
F P
0 g
s
.60466 .35856 m .62688 .36054 L .61694 .32279 L p 0 .349 .781 r
F P
0 g
s
.59968 .33963 m .61694 .32279 L .62688 .36054 L p 0 .349 .781 r
F P
0 g
s
.64595 .3561 m .65812 .34998 L .62891 .31641 L p 0 .319 .936 r
F P
0 g
s
.62688 .36054 m .60466 .35856 L .59968 .33963 L p 0 .349 .781 r
F P
0 g
s
.59968 .33963 m .58232 .35657 L .60466 .35856 L closepath p 0 .349 .781 r
F P
0 g
s
.60466 .35856 m .58232 .35657 L .59968 .33963 L closepath p 0 .349 .781 r
F P
0 g
s
.64106 .30994 m .62891 .31641 L .65812 .34998 L p 0 .319 .936 r
F P
0 g
s
.64106 .30994 m .61694 .32279 L .58232 .35657 L p 0 .05 .1 r
F P
0 g
s
.59968 .33963 m .61694 .32279 L .62891 .31641 L p 0 .05 .1 r
F P
0 g
s
.62891 .31641 m .61156 .33336 L .59968 .33963 L p 0 .05 .1 r
F P
0 g
s
.58232 .35657 m .60606 .34416 L .64106 .30994 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .62361 .327 L .62867 .34621 L closepath p 0 .35 .78 r
F P
0 g
s
.60693 .34415 m .60665 .34385 L .60606 .34416 L .577 0 0 r
F
.59968 .33963 m .61156 .33336 L .5941 .35041 L p 0 .05 .1 r
F P
0 g
s
.61156 .33336 m .62361 .327 L .60606 .34416 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .5941 .35041 L .61156 .33336 L p 0 .05 .1 r
F P
0 g
s
.60532 .30943 m .57812 .2782 L p .57559 .33832 L 0 .349 .781 r
F P
0 g
s
.55824 .21464 m .53524 .22894 L .61694 .32279 L p 0 .319 .936 r
F P
0 g
s
.57812 .2782 m .53524 .22894 L p .55989 .29576 L 0 .349 .781 r
F P
0 g
s
.53524 .22894 m .5 .26235 L .57061 .34316 L p 0 .349 .781 r
F P
0 g
s
.57061 .34316 m .58232 .35657 L p .57559 .33832 L 0 .349 .781 r
F P
0 g
s
.57559 .33832 m .53524 .22894 L .57061 .34316 L 0 .349 .781 r
F
.54771 .35542 m .55927 .36863 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.59418 .33054 m .57061 .34316 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.57061 .34316 m .54771 .35542 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.55927 .36863 m .58232 .35657 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.58232 .35657 m .55927 .36863 L .54771 .35542 L p 0 .318 .939 r
F P
0 g
s
.58232 .35657 m .54771 .35542 L .56729 .34494 L 0 .318 .939 r
F
.57061 .34316 m .58232 .35657 L p .56729 .34494 L F P
0 g
s
.5941 .35041 m .58232 .35657 L .59968 .33963 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .59418 .33054 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.58232 .35657 m .60606 .34416 L p .57647 .34987 L .577 0 0 r
F P
0 g
s
.60606 .34416 m .58232 .35657 L p .57393 .34138 L 0 .318 .939 r
F P
0 g
s
.57061 .34316 m .5 .26235 L p .57559 .33832 L 0 .349 .781 r
F P
0 g
s
.55692 .3275 m .56641 .29869 L .54321 .31181 L .577 0 0 r
F
.59418 .33054 m .56641 .29869 L p .55692 .3275 L F P
0 g
s
.57061 .34316 m .59418 .33054 L p .55692 .3275 L .577 0 0 r
F P
0 g
s
.57393 .34138 m .55417 .30561 L .59418 .33054 L 0 .318 .939 r
F
.56641 .29869 m .59418 .33054 L p .55417 .30561 L F P
0 g
s
.54321 .31181 m .52068 .32454 L p .55692 .3275 L .577 0 0 r
F P
0 g
s
.47805 .27583 m .5 .26235 L .54321 .31181 L p 0 .318 .939 r
F P
0 g
s
.53437 .3168 m .47805 .27583 L .54321 .31181 L 0 .318 .939 r
F
.56729 .34494 m .5324 .31792 L .57061 .34316 L F
.5324 .31792 m .47805 .27583 L .53437 .3168 L F
.5324 .31792 m .53437 .3168 L .57061 .34316 L F
.54321 .31181 m .57061 .34316 L p .53437 .3168 L F P
0 g
s
.54771 .35542 m .52068 .32454 L p .56729 .34494 L 0 .318 .939 r
F P
0 g
s
.56729 .34494 m .52068 .32454 L .5324 .31792 L 0 .318 .939 r
F
.48674 .35716 m .51452 .33724 L .52068 .32454 L .946 0 0 r
F
.54771 .35542 m .52068 .32454 L .51452 .33724 L .577 0 0 r
F
.48081 .36967 m .5208 .35865 L .51452 .33724 L .939 0 0 r
F
.51396 .38816 m .54771 .35542 L .52068 .32454 L p .856 0 0 r
F P
0 g
s
.51396 .38816 m .52068 .32454 L .54771 .35542 L .856 0 0 r
F
.48674 .35716 m .48081 .36967 L .51452 .33724 L .946 0 0 r
F
.52068 .32454 m .48674 .35716 L .51396 .38816 L p .856 0 0 r
F P
0 g
s
.51396 .38816 m .48674 .35716 L .52068 .32454 L .856 0 0 r
F
.48674 .35716 m .54321 .31181 L .5261 .32828 L .1 0 0 r
F
.52068 .32454 m .47805 .27583 L p .5324 .31792 L 0 .318 .939 r
F P
0 g
s
.41839 .32854 m .42935 .3861 L .45243 .36721 L .778 0 0 r
F
.41839 .32854 m .39538 .34759 L .42935 .3861 L F
.39538 .34759 m .4059 .40737 L .42935 .3861 L .831 0 0 r
F
.39538 .34759 m .37185 .36885 L .4059 .40737 L F
.43493 .31666 m .45243 .36721 L .46917 .35561 L .684 0 0 r
F
.43493 .31666 m .41839 .32854 L .45243 .36721 L F
.45006 .30233 m .43493 .31666 L p .46408 .29073 L 0 .05 .1 r
F P
0 g
s
.43605 .38585 m .42935 .3861 L .42829 .3922 L .1 0 0 r
F
.43605 .38585 m .45243 .36721 L .42935 .3861 L F
.40168 .34687 m .46251 .43098 L .4703 .42469 L .778 0 0 r
F
.46408 .29073 m .43493 .31666 L .43965 .31327 L 0 .05 .1 r
F
.44975 .30601 m .46408 .29073 L .43965 .31327 L F
.47805 .27583 m .45006 .30233 L p .46408 .29073 L F P
0 g
s
.43493 .31666 m .46917 .35561 L p .47376 .32349 L .567 0 0 r
F P
0 g
s
.45639 .30369 m .43493 .31666 L p .47376 .32349 L .567 0 0 r
F P
0 g
s
.44162 .38201 m .45243 .36721 L .43733 .3844 L .1 0 0 r
F
.44162 .38201 m .43733 .3844 L .43605 .38585 L F
.44162 .38201 m .46917 .35561 L .45243 .36721 L F
.44162 .38201 m .46917 .35561 L p .4482 .33176 L .856 0 0 r
F P
0 g
s
.43587 .3258 m .44052 .32302 L .43493 .31666 L p .856 0 0 r
F P
0 g
s
.40718 .34294 m .43493 .31666 L .46917 .35561 L .856 0 0 r
F
.43493 .31666 m .40718 .34294 L .44162 .38201 L p F P
0 g
s
.5 .26235 m .49369 .26622 L p .42745 .33083 L 0 .05 .1 r
F P
0 g
s
.40718 .34294 m .46917 .35561 L .44162 .38201 L .856 0 0 r
F
.40718 .34294 m .44162 .38201 L p .44579 .35016 L .559 0 0 r
F P
0 g
s
.4501 .31729 m .42832 .3303 L p .44579 .35016 L .559 0 0 r
F P
0 g
s
.42832 .3303 m .40718 .34294 L p .44579 .35016 L .559 0 0 r
F P
0 g
s
.42832 .3303 m .5 .26235 L p .42745 .33083 L 0 .05 .1 r
F P
0 g
s
.43493 .31666 m .41228 .33811 L p .43787 .31488 L 0 .05 .1 r
F P
0 g
s
.43965 .31327 m .43493 .31666 L .43787 .31488 L 0 .05 .1 r
F
.43965 .31327 m .41228 .33811 L .41661 .33453 L F
.42687 .39316 m .42935 .3861 L .4059 .40737 L .1 0 0 r
F
.42829 .3922 m .42837 .39172 L .42687 .39316 L F
.42837 .39172 m .42935 .3861 L .42687 .39316 L F
.3992 .49188 m .45464 .43815 L .42039 .39936 L p .856 0 0 r
F P
0 g
s
.38602 .36044 m .4059 .40737 L .37185 .36885 L .556 0 0 r
F
.42829 .3922 m .4059 .40737 L .42039 .39936 L .1 0 0 r
F
.38602 .36044 m .42039 .39936 L .4059 .40737 L .556 0 0 r
F
.38602 .36044 m .37185 .36885 L .4059 .40737 L p F P
0 g
s
.4059 .40737 m .42039 .39936 L .38602 .36044 L p .556 0 0 r
F P
0 g
s
.35049 .46038 m .4059 .40737 L .37185 .36885 L p .855 0 0 r
F P
0 g
s
.42039 .39936 m .4059 .40737 L .35049 .46038 L p .1 0 0 r
F P
0 g
s
.36454 .45285 m .42039 .39936 L p .39598 .42068 L .1 0 0 r
F P
0 g
s
.35844 .4591 m .39068 .50186 L .39317 .49819 L .968 0 0 r
F
.35049 .46038 m .36195 .45424 L p .36951 .44378 L .1 0 0 r
F P
0 g
s
.37185 .36885 m .31605 .42162 L .35049 .46038 L p .855 0 0 r
F P
0 g
s
.36195 .45424 m .36454 .45285 L p .36951 .44378 L .1 0 0 r
F P
0 g
s
.32977 .41368 m .36454 .45285 L .35049 .46038 L p .54 0 0 r
F P
0 g
s
.35049 .46038 m .31605 .42162 L .32977 .41368 L p .54 0 0 r
F P
0 g
s
.36454 .45285 m .35049 .46038 L .33224 .47903 L .1 0 0 r
F
.32977 .41368 m .35049 .46038 L .36454 .45285 L .54 0 0 r
F
.32977 .41368 m .31605 .42162 L .35049 .46038 L F
.35441 .46273 m .33224 .47903 L .32428 .48991 L .1 0 0 r
F
.35844 .4591 m .35362 .46277 L .35441 .46273 L F
.35362 .46277 m .33224 .47903 L .35441 .46273 L F
.35715 .46088 m .39068 .50186 L .35844 .4591 L .968 0 0 r
F
.40459 .48969 m .39317 .49819 L .39068 .50186 L .1 0 0 r
F
.40424 .49021 m .39068 .50186 L .39243 .50191 L F
.36454 .45285 m .33224 .47903 L .35844 .4591 L F
.35844 .4591 m .32428 .48991 L .35586 .46268 L F
.32359 .41986 m .3209 .42334 L .35586 .46268 L .968 0 0 r
F
.35715 .46088 m .35586 .46268 L .39068 .50186 L F
.32359 .41986 m .35586 .46268 L .35715 .46088 L F
.35586 .46268 m .32897 .48995 L .3523 .46759 L .1 0 0 r
F
.40459 .48969 m .39068 .50186 L .40424 .49021 L F
.35586 .46268 m .39243 .50191 L .39068 .50186 L F
.35668 .46264 m .39243 .50191 L .35586 .46268 L F
.32359 .41986 m .35844 .4591 L .35586 .46268 L .968 0 0 r
F
.32359 .41986 m .35586 .46268 L .3209 .42334 L F
.35668 .46264 m .35751 .46261 L .39243 .50191 L .1 0 0 r
F
.3615 .45597 m .39317 .49819 L .36454 .45285 L .884 0 0 r
F
.32977 .41368 m .32359 .41986 L .39317 .49819 L F
.36951 .44378 m .36454 .45285 L .39598 .42068 L .1 0 0 r
F
.36454 .45285 m .39317 .49819 L .3992 .49188 L .884 0 0 r
F
.32977 .41368 m .3615 .45597 L .36454 .45285 L F
.3992 .49188 m .42039 .39936 L .39259 .42599 L .856 0 0 r
F
.46109 .43485 m .45464 .43815 L .44186 .45054 L p .1 0 0 r
F P
0 g
s
.44186 .45054 m .3992 .49188 L p .44677 .44804 L .1 0 0 r
F P
0 g
s
.44677 .44804 m .46109 .43485 L .44186 .45054 L .1 0 0 r
F
.42039 .39936 m .38602 .36044 L p .39259 .42599 L .856 0 0 r
F P
0 g
s
.39394 .35327 m .45464 .43815 L .46251 .43098 L .831 0 0 r
F
.46222 .43382 m .46251 .43098 L .45464 .43815 L .1 0 0 r
F
.39394 .35327 m .38602 .36044 L .45464 .43815 L .831 0 0 r
F
.39394 .35327 m .42829 .3922 L .42039 .39936 L F
.39394 .35327 m .42039 .39936 L .38602 .36044 L F
.428 .40344 m .4395 .41842 L .42645 .40428 L .556 0 0 r
F
.4395 .41842 m .43509 .41601 L .38602 .36044 L F
.4395 .41842 m .45464 .43815 L .43509 .41601 L F
.46222 .43382 m .45464 .43815 L .46109 .43485 L .1 0 0 r
F
.4395 .41842 m .46109 .43485 L .45464 .43815 L .556 0 0 r
F
.44473 .41631 m .45324 .42595 L .44011 .41876 L F
.45324 .42595 m .46109 .43485 L .4395 .41842 L F
.428 .40344 m .44473 .41631 L .4395 .41842 L F
.39218 .35677 m .43162 .40146 L .428 .40344 L F
.43162 .40146 m .44473 .41631 L .428 .40344 L F
.40168 .34687 m .39394 .35327 L .46251 .43098 L .778 0 0 r
F
.40718 .34294 m .40168 .34687 L .4703 .42469 L .682 0 0 r
F
.4306 .32296 m .41661 .33453 L .40859 .34193 L 0 .05 .1 r
F
.40718 .34294 m .4703 .42469 L .47593 .42095 L .682 0 0 r
F
.41228 .33811 m .40718 .34294 L p .41661 .33453 L 0 .05 .1 r
F P
0 g
s
.40168 .34687 m .42829 .3922 L .39394 .35327 L .778 0 0 r
F
.40168 .34687 m .43605 .38585 L .42829 .3922 L F
.40718 .34294 m .43605 .38585 L .40168 .34687 L .682 0 0 r
F
.40718 .34294 m .44162 .38201 L .43605 .38585 L F
.46333 .43292 m .4703 .42469 L .46251 .43098 L .1 0 0 r
F
.46414 .43238 m .4703 .42469 L .46333 .43292 L F
.46414 .43238 m .47593 .42095 L .4703 .42469 L F
.46414 .43238 m .47593 .42095 L .40718 .34294 L p .856 0 0 r
F P
0 g
s
.39521 .35427 m .40718 .34294 L .47593 .42095 L .856 0 0 r
F
.49369 .26622 m .47805 .27583 L p .46408 .29073 L 0 .05 .1 r
F P
0 g
s
.44162 .38201 m .40718 .34294 L .42832 .3303 L p .559 0 0 r
F P
0 g
s
.41621 .34178 m .49369 .26622 L .46408 .29073 L 0 .05 .1 r
F
.49552 .25929 m .5129 .24283 L .47811 .22426 L p 0 .349 .781 r
F P
0 g
s
.50651 .25249 m .49552 .25929 L .47805 .27583 L p 0 .05 .1 r
F P
0 g
s
.47805 .27583 m .48895 .26914 L .50651 .25249 L p 0 .05 .1 r
F P
0 g
s
.50651 .25249 m .48895 .26914 L .5 .26235 L p 0 .05 .1 r
F P
0 g
s
.5 .26235 m .47805 .27583 L .5129 .24283 L p 0 .05 .1 r
F P
0 g
s
.47811 .22426 m .47808 .25001 L .49552 .25929 L p 0 .349 .781 r
F P
0 g
s
.49552 .25929 m .47808 .25001 L .47805 .27583 L closepath p 0 .349 .781 r
F P
0 g
s
.47808 .25001 m .48896 .24314 L .48895 .26914 L p 0 .181 .719 r
F P
0 g
s
.47811 .22426 m .47813 .20298 L .44303 .23581 L closepath p 0 .349 .781 r
F P
0 g
s
.5129 .24283 m .47813 .20298 L .47811 .22426 L closepath p 0 .349 .781 r
F P
0 g
s
.48897 .21721 m .47811 .22426 L .47808 .25001 L p 0 .181 .719 r
F P
0 g
s
.47808 .25001 m .47811 .22426 L .44303 .23581 L p 0 .349 .781 r
F P
0 g
s
.48896 .24314 m .47808 .25001 L .47811 .22426 L p 0 .181 .719 r
F P
0 g
s
.47808 .25001 m .48896 .24314 L .48897 .21721 L p 0 .181 .719 r
F P
0 g
s
.48896 .24314 m .47808 .25001 L .47805 .27583 L p 0 .181 .719 r
F P
0 g
s
.44303 .23581 m .46056 .25584 L .47808 .25001 L p 0 .349 .781 r
F P
0 g
s
.47805 .27583 m .47808 .25001 L .46056 .25584 L closepath p 0 .349 .781 r
F P
0 g
s
.48895 .26914 m .47805 .27583 L .47808 .25001 L p 0 .181 .719 r
F P
0 g
s
.47805 .27583 m .48895 .26914 L .48896 .24314 L p 0 .181 .719 r
F P
0 g
s
.48895 .26914 m .47805 .27583 L .46056 .25584 L p 0 .318 .939 r
F P
0 g
s
.40168 .34687 m .39538 .34759 L .41839 .32854 L .1 0 0 r
F
.40168 .34687 m .39394 .35327 L .39538 .34759 L F
.40718 .34294 m .41839 .32854 L .43493 .31666 L F
.40718 .34294 m .40168 .34687 L .41839 .32854 L F
.39443 .35483 m .39394 .35327 L .40168 .34687 L F
.39521 .35427 m .40168 .34687 L .40718 .34294 L F
.39521 .35427 m .39443 .35483 L .39462 .35462 L F
.39521 .35427 m .39462 .35462 L .40168 .34687 L F
.47805 .27583 m .44303 .23581 L p .39521 .35427 L 0 .349 .781 r
F P
0 g
s
.40718 .34294 m .39521 .35427 L .46414 .43238 L p .856 0 0 r
F P
0 g
s
.40718 .34294 m .39521 .35427 L p .40807 .3424 L 0 .05 .1 r
F P
0 g
s
.40859 .34193 m .40718 .34294 L .40807 .3424 L 0 .05 .1 r
F
.41661 .33453 m .40718 .34294 L .40859 .34193 L F
.41158 .33979 m .40859 .34193 L .39521 .35427 L F
.4306 .32296 m .40859 .34193 L .41158 .33979 L F
.39521 .35427 m .41621 .34178 L p .44975 .30601 L F P
0 g
s
.39394 .35327 m .37185 .36885 L .39538 .34759 L .1 0 0 r
F
.44303 .23581 m .35957 .31387 L .39521 .35427 L p 0 .349 .781 r
F P
0 g
s
.44975 .30601 m .43965 .31327 L .41661 .33453 L 0 .05 .1 r
F
.44975 .30601 m .41661 .33453 L .4306 .32296 L F
.40718 .34294 m .43493 .31666 L .45639 .30369 L p .1 0 0 r
F P
0 g
s
.4785 .29034 m .45639 .30369 L p .47376 .32349 L .567 0 0 r
F P
0 g
s
.42832 .3303 m .4501 .31729 L p .44579 .35016 L .559 0 0 r
F P
0 g
s
.44162 .38201 m .42832 .3303 L .44579 .35016 L .559 0 0 r
F
.57393 .34138 m .54521 .31068 L .55417 .30561 L 0 .318 .939 r
F
.57061 .34316 m .5 .26235 L p .57393 .34138 L F P
0 g
s
.5261 .32828 m .56641 .29869 L .50889 .34485 L .1 0 0 r
F
.5 .26235 m .52261 .24846 L p .55417 .30561 L 0 .318 .939 r
F P
0 g
s
.54521 .31068 m .5 .26235 L .55417 .30561 L 0 .318 .939 r
F
.58232 .35657 m .57061 .34316 L p .57393 .34138 L F P
0 g
s
.59418 .33054 m .60606 .34416 L p .57393 .34138 L 0 .318 .939 r
F P
0 g
s
.55968 .36413 m .59418 .33054 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.48008 .43239 m .48587 .44063 L .55328 .37495 L .881 0 0 r
F
.49158 .43458 m .55927 .36863 L .54771 .35542 L p .856 0 0 r
F P
0 g
s
.49158 .43458 m .54771 .35542 L .55927 .36863 L .856 0 0 r
F
.53648 .37632 m .55968 .36413 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.47985 .42127 m .51294 .39022 L .51396 .38816 L .937 0 0 r
F
.54771 .35542 m .47985 .42127 L .49158 .43458 L p .856 0 0 r
F P
0 g
s
.49158 .43458 m .47985 .42127 L .54771 .35542 L .856 0 0 r
F
.53648 .37632 m .59418 .33054 L .54799 .37027 L .1 0 0 r
F
.50198 .40985 m .54799 .37027 L .53414 .38688 L F
.52017 .40048 m .50198 .40985 L p .53414 .38688 L F P
0 g
s
.53648 .37632 m .54799 .37027 L .50198 .40985 L .1 0 0 r
F
.50198 .40985 m .47985 .42127 L p .53648 .37632 L F P
0 g
s
.49158 .43458 m .47985 .42127 L .52479 .3981 L p .56 0 0 r
F P
0 g
s
.47985 .42127 m .51396 .38816 L p .53648 .37632 L .1 0 0 r
F P
0 g
s
.51396 .38816 m .48081 .36967 L .48674 .35716 L .569 0 0 r
F
.46917 .35561 m .51369 .33051 L .4785 .29034 L p .567 0 0 r
F P
0 g
s
.46917 .35561 m .44162 .38201 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.51369 .33051 m .4911 .34325 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.4911 .34325 m .46917 .35561 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.44162 .38201 m .47593 .42095 L p .46323 .36999 L .559 0 0 r
F P
0 g
s
.39521 .35427 m .47593 .42095 L .46414 .43238 L .856 0 0 r
F
.59418 .33054 m .55968 .36413 L p .54799 .37027 L .1 0 0 r
F P
0 g
s
.54771 .35542 m .51396 .38816 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.57061 .34316 m .54771 .35542 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.51396 .38816 m .53648 .37632 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.54771 .35542 m .57061 .34316 L p .53648 .37632 L .1 0 0 r
F P
0 g
s
.59418 .33054 m .57061 .34316 L p .55359 .3597 L .1 0 0 r
F P
0 g
s
.57061 .34316 m .59418 .33054 L p .53648 .37632 L .1 0 0 r
F P
0 g
s
.51396 .38816 m .54771 .35542 L p .53648 .37632 L .1 0 0 r
F P
0 g
s
.5317 .33216 m .55968 .36413 L .51396 .38816 L p .569 0 0 r
F P
0 g
s
.51396 .38816 m .48674 .35716 L .5317 .33216 L p .569 0 0 r
F P
0 g
s
.48757 .35722 m .52077 .39776 L .52294 .3975 L .175 0 0 r
F
.4855 .3576 m .51369 .33051 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.50889 .34485 m .48674 .35716 L p .5261 .32828 L .1 0 0 r
F P
0 g
s
.48674 .35716 m .52068 .32454 L .54321 .31181 L p .1 0 0 r
F P
0 g
s
.4501 .31729 m .51369 .33051 L .4785 .29034 L .858 0 0 r
F
.4501 .31729 m .4855 .3576 L .51369 .33051 L F
.48757 .35722 m .49068 .35262 L .4855 .3576 L .1 0 0 r
F
.4855 .3576 m .4501 .31729 L .4785 .29034 L p .858 0 0 r
F P
0 g
s
.45206 .31679 m .4501 .31729 L .4855 .3576 L .175 0 0 r
F
.4785 .29034 m .51369 .33051 L .4855 .3576 L p .858 0 0 r
F P
0 g
s
.45206 .31679 m .4855 .3576 L .48653 .35741 L .175 0 0 r
F
.45206 .31679 m .48653 .35741 L .48757 .35722 L F
.44162 .38201 m .46323 .36999 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.46323 .36999 m .4855 .3576 L p .47719 .35659 L .1 0 0 r
F P
0 g
s
.52077 .39776 m .4501 .31729 L p .45899 .35295 L .559 0 0 r
F P
0 g
s
.46323 .36999 m .4501 .31729 L .44162 .38201 L .559 0 0 r
F
.4501 .31729 m .4855 .3576 L .44162 .38201 L p F P
0 g
s
.50538 .40572 m .52077 .39776 L p .45899 .35295 L .559 0 0 r
F P
0 g
s
.49158 .43458 m .47787 .4253 L .47985 .42127 L .56 0 0 r
F
.47593 .42095 m .46414 .43238 L p .46827 .42985 L .1 0 0 r
F P
0 g
s
.46827 .42985 m .478 .42391 L .4792 .41926 L .1 0 0 r
F
.4792 .41926 m .47593 .42095 L p .46827 .42985 L F P
0 g
s
.478 .42391 m .49206 .41531 L .48689 .41528 L .1 0 0 r
F
.49206 .41531 m .50631 .4066 L .49802 .40953 L F
.49802 .40953 m .48689 .41528 L p .49206 .41531 L F P
0 g
s
.50931 .40369 m .49802 .40953 L p .50631 .4066 L .1 0 0 r
F P
0 g
s
.47593 .42095 m .50538 .40572 L p .45899 .35295 L .559 0 0 r
F P
0 g
s
.5087 .4095 m .52077 .39776 L p .51641 .40042 L .1 0 0 r
F P
0 g
s
.49129 .43515 m .48008 .43239 L .47787 .4253 L .56 0 0 r
F
.49158 .43458 m .49129 .43515 L .47787 .4253 L F
.46414 .43238 m .47503 .42679 L p .478 .42391 L .1 0 0 r
F P
0 g
s
.49206 .41531 m .49978 .41294 L .50631 .4066 L .1 0 0 r
F
.48797 .41928 m .49809 .41459 L .49206 .41531 L F
.49809 .41459 m .50527 .41126 L .49978 .41294 L F
.49809 .41459 m .49978 .41294 L .49206 .41531 L F
.478 .42391 m .48797 .41928 L .49206 .41531 L F
.47503 .42679 m .48609 .42111 L p .478 .42391 L F P
0 g
s
.55328 .37495 m .60678 .43604 L .57364 .46894 L p .856 0 0 r
F P
0 g
s
.56006 .37142 m .55328 .37495 L .60678 .43604 L p .577 0 0 r
F P
0 g
s
.5578 .47614 m .54188 .45805 L p .53519 .43541 L .569 0 0 r
F P
0 g
s
.56287 .45668 m .57364 .46894 L .57193 .46972 L p .569 0 0 r
F P
0 g
s
.57193 .46972 m .5578 .47614 L p .56287 .45668 L .569 0 0 r
F P
0 g
s
.62242 .44736 m .63724 .47732 L .65506 .47807 L .577 0 0 r
F
.61454 .44315 m .63724 .47732 L .62242 .44736 L F
.62242 .44736 m .65506 .47807 L .62834 .44754 L F
.58931 .48038 m .62834 .44754 L .62242 .44736 L .58 0 0 r
F
.57428 .47972 m .58094 .49742 L .56106 .47914 L .569 0 0 r
F
.57451 .47233 m .58094 .49742 L .57072 .47027 L F
.58094 .49742 m .6044 .51029 L .63724 .47732 L .765 0 0 r
F
.58118 .48681 m .6044 .51029 L .58094 .49742 L .569 0 0 r
F
.58143 .4761 m .58693 .48427 L .58118 .48681 L F
.58693 .48427 m .6044 .51029 L .58118 .48681 L F
.61686 .43443 m .62834 .44754 L p .6465 .43003 L .577 0 0 r
F P
0 g
s
.71356 .50883 m .726 .50392 L .70925 .52107 L p 0 .05 .212 r
F P
0 g
s
.726 .50392 m .74267 .48686 L .75538 .48177 L p 0 .05 .212 r
F P
0 g
s
.62834 .44754 m .65506 .47807 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.75538 .48177 m .73863 .49894 L .726 .50392 L p 0 .05 .212 r
F P
0 g
s
.70925 .52107 m .726 .50392 L .73863 .49894 L p 0 .05 .212 r
F P
0 g
s
.73863 .49894 m .72178 .5162 L .70925 .52107 L p 0 .05 .212 r
F P
0 g
s
.75538 .48177 m .72178 .5162 L .67939 .46768 L p 0 .349 .781 r
F P
0 g
s
.67939 .46768 m .65231 .43668 L p .69262 .45432 L 0 .349 .781 r
F P
0 g
s
.69262 .45432 m .75538 .48177 L .67939 .46768 L 0 .349 .781 r
F
.65231 .43668 m .62834 .44754 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.65721 .43179 m .69558 .45133 L .65231 .43668 L 0 .349 .781 r
F
.69558 .45133 m .75538 .48177 L .69262 .45432 L F
.69558 .45133 m .69262 .45432 L .65231 .43668 L F
.69689 .52586 m .65506 .47807 L p .66771 .47266 L 0 .318 .939 r
F P
0 g
s
.65506 .47807 m .67939 .46768 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.70925 .52107 m .69689 .52586 L .71356 .50883 L p 0 .05 .212 r
F P
0 g
s
.72178 .5162 m .69689 .52586 L p .66771 .47266 L 0 .318 .939 r
F P
0 g
s
.64068 .42337 m .61686 .43443 L p .6465 .43003 L .577 0 0 r
F P
0 g
s
.64884 .43825 m .67939 .46768 L .66771 .47266 L 0 .318 .939 r
F
.65231 .43668 m .67939 .46768 L p .64884 .43825 L F P
0 g
s
.64884 .43825 m .66771 .47266 L .62834 .44754 L 0 .318 .939 r
F
.65506 .47807 m .62834 .44754 L p .66771 .47266 L F P
0 g
s
.64068 .42337 m .67487 .38932 L .68642 .40258 L p 0 .349 .781 r
F P
0 g
s
.62834 .44754 m .65231 .43668 L p .6465 .43003 L .577 0 0 r
F P
0 g
s
.61686 .43443 m .64068 .42337 L p .64884 .43825 L 0 .318 .939 r
F P
0 g
s
.62834 .44754 m .61686 .43443 L p .64884 .43825 L 0 .318 .939 r
F P
0 g
s
.58143 .4761 m .62242 .44736 L .61454 .44315 L .764 0 0 r
F
.57451 .47233 m .58143 .4761 L .58134 .48003 L .569 0 0 r
F
.57643 .47981 m .58134 .48003 L .58094 .49742 L F
.57451 .47233 m .58134 .48003 L .57643 .47981 L F
.6044 .51029 m .65506 .47807 L .63724 .47732 L .587 0 0 r
F
.6044 .51029 m .62208 .51128 L .65506 .47807 L F
.58931 .48038 m .62208 .51128 L .6044 .51029 L .569 0 0 r
F
.58143 .4761 m .58931 .48038 L .6044 .51029 L F
.58931 .48038 m .59517 .48064 L .62208 .51128 L F
.55583 .51375 m .56164 .51409 L .59517 .48064 L .58 0 0 r
F
.59223 .48051 m .59517 .48064 L .62834 .44754 L F
.55583 .51375 m .59517 .48064 L .59223 .48051 L F
.54797 .50939 m .55583 .51375 L .58931 .48038 L .764 0 0 r
F
.58537 .47824 m .58931 .48038 L .62242 .44736 L F
.54797 .50939 m .58931 .48038 L .58537 .47824 L F
.57434 .47167 m .58143 .4761 L .57451 .47233 L .569 0 0 r
F
.57364 .46894 m .57587 .47098 L .57434 .47167 L F
.57587 .47098 m .58143 .4761 L .57434 .47167 L F
.57364 .46894 m .60678 .43604 L .61454 .44315 L .831 0 0 r
F
.57072 .47027 m .57428 .47972 L .5578 .47614 L .569 0 0 r
F
.57428 .47972 m .56106 .47914 L .5578 .47614 L F
.57364 .46894 m .57451 .47233 L .57072 .47027 L F
.54014 .50219 m .61454 .44315 L .60678 .43604 L .831 0 0 r
F
.61378 .43278 m .60678 .43604 L .61454 .44315 L .577 0 0 r
F
.58143 .4761 m .61454 .44315 L .62242 .44736 L .764 0 0 r
F
.57364 .46894 m .61454 .44315 L .58143 .4761 L .831 0 0 r
F
.61489 .4338 m .61454 .44315 L .62242 .44736 L .577 0 0 r
F
.54014 .50219 m .54797 .50939 L .61454 .44315 L .831 0 0 r
F
.61378 .43278 m .61454 .44315 L .61489 .4338 L .577 0 0 r
F
.61602 .4344 m .62242 .44736 L .62834 .44754 L F
.61489 .4338 m .62242 .44736 L .61602 .4344 L F
.55583 .51375 m .59223 .48051 L .58931 .48038 L .58 0 0 r
F
.59223 .48051 m .62834 .44754 L .58931 .48038 L F
.58537 .47824 m .62242 .44736 L .58143 .4761 L .764 0 0 r
F
.58931 .48038 m .62242 .44736 L .62834 .44754 L .58 0 0 r
F
.58143 .4761 m .62242 .44736 L .58931 .48038 L .764 0 0 r
F
.58931 .48038 m .62834 .44754 L .59517 .48064 L .58 0 0 r
F
.61602 .4344 m .62834 .44754 L .61686 .43443 L .577 0 0 r
F
.56164 .51409 m .62834 .44754 L .61686 .43443 L p .856 0 0 r
F P
0 g
s
.57066 .48681 m .58419 .4776 L .58143 .4761 L .764 0 0 r
F
.54797 .50939 m .58419 .4776 L .57066 .48681 L F
.54797 .50939 m .58537 .47824 L .58419 .4776 L F
.55 .50088 m .61686 .43443 L .62834 .44754 L .856 0 0 r
F
.61686 .43443 m .55 .50088 L .56164 .51409 L p F P
0 g
s
.61686 .43443 m .64068 .42337 L p .59526 .4622 L .166 0 0 r
F P
0 g
s
.55 .50088 m .58361 .46747 L p .59526 .4622 L .166 0 0 r
F P
0 g
s
.58361 .46747 m .61686 .43443 L p .59526 .4622 L .166 0 0 r
F P
0 g
s
.55 .50088 m .64068 .42337 L .60707 .45685 L .166 0 0 r
F
.64068 .42337 m .68642 .40258 L .65721 .43179 L 0 .349 .781 r
F
.68642 .40258 m .75538 .48177 L p .65721 .43179 L F P
0 g
s
.65231 .43668 m .64068 .42337 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.67487 .38932 m .64068 .42337 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.75538 .48177 m .68642 .40258 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.68642 .40258 m .67487 .38932 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.62208 .51128 m .65506 .47807 L .62834 .44754 L p .856 0 0 r
F P
0 g
s
.59517 .48064 m .62834 .44754 L .65506 .47807 L .856 0 0 r
F
.62834 .44754 m .59517 .48064 L .62208 .51128 L p F P
0 g
s
.59517 .48064 m .62834 .44754 L .65231 .43668 L p .18 0 0 r
F P
0 g
s
.72178 .5162 m .75538 .48177 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.64068 .42337 m .65231 .43668 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.65231 .43668 m .72178 .5162 L p .65721 .43179 L 0 .349 .781 r
F P
0 g
s
.677 .42551 m .65531 .44012 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.7459 .51796 m .73863 .49894 L .75538 .48177 L p 0 .349 .781 r
F P
0 g
s
.75538 .48177 m .78966 .52115 L .76989 .51971 L closepath p 0 .349 .781 r
F P
0 g
s
.75538 .48177 m .78966 .52115 L .80278 .51629 L p 0 .319 .936 r
F P
0 g
s
.76989 .51971 m .78966 .52115 L .75538 .48177 L closepath p 0 .349 .781 r
F P
0 g
s
.75538 .48177 m .76989 .51971 L .7459 .51796 L p 0 .349 .781 r
F P
0 g
s
.80278 .51629 m .76827 .47661 L .75538 .48177 L p 0 .319 .936 r
F P
0 g
s
.76989 .51971 m .75538 .48177 L .73863 .49894 L p 0 .349 .781 r
F P
0 g
s
.73863 .49894 m .7459 .51796 L .76989 .51971 L p 0 .349 .781 r
F P
0 g
s
.7459 .51796 m .72178 .5162 L .73863 .49894 L closepath p 0 .349 .781 r
F P
0 g
s
.73863 .49894 m .72178 .5162 L .7459 .51796 L closepath p 0 .349 .781 r
F P
0 g
s
.78135 .47137 m .76827 .47661 L .80278 .51629 L p 0 .319 .936 r
F P
0 g
s
.78135 .47137 m .75538 .48177 L .72178 .5162 L p 0 .05 .212 r
F P
0 g
s
.72178 .5162 m .73863 .49894 L .75143 .49388 L p 0 .05 .212 r
F P
0 g
s
.75143 .49388 m .7345 .51126 L .72178 .5162 L p 0 .05 .212 r
F P
0 g
s
.72178 .5162 m .74741 .50624 L .78135 .47137 L p 0 .05 .212 r
F P
0 g
s
.74741 .50624 m .7345 .51126 L .75143 .49388 L p 0 .05 .212 r
F P
0 g
s
.74741 .50624 m .72178 .5162 L .67939 .46768 L p 0 .318 .939 r
F P
0 g
s
.68905 .46355 m .74741 .50624 L .67939 .46768 L 0 .318 .939 r
F
.70444 .45698 m .677 .42551 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.67939 .46768 m .70444 .45698 L p .66586 .45219 L .577 0 0 r
F P
0 g
s
.65579 .43511 m .74741 .50624 L .65231 .43668 L 0 .318 .939 r
F
.67939 .46768 m .72178 .5162 L p .66771 .47266 L F P
0 g
s
.6465 .43003 m .677 .42551 L .65268 .42408 L .577 0 0 r
F
.677 .42551 m .66521 .41199 L p .65268 .42408 L F P
0 g
s
.66521 .41199 m .64068 .42337 L p .6465 .43003 L .577 0 0 r
F P
0 g
s
.66521 .41199 m .677 .42551 L p .65769 .42437 L 0 .318 .939 r
F P
0 g
s
.64068 .42337 m .66521 .41199 L p .65769 .42437 L 0 .318 .939 r
F P
0 g
s
.65231 .43668 m .677 .42551 L p .6465 .43003 L .577 0 0 r
F P
0 g
s
.64068 .42337 m .677 .42551 L .65579 .43511 L 0 .318 .939 r
F
.65231 .43668 m .64068 .42337 L p .65579 .43511 L F P
0 g
s
.64068 .42337 m .65231 .43668 L p .64884 .43825 L 0 .318 .939 r
F P
0 g
s
.64068 .42337 m .66521 .41199 L p .60707 .45685 L .166 0 0 r
F P
0 g
s
.55 .50088 m .62834 .44754 L .56164 .51409 L .856 0 0 r
F
.60707 .45685 m .66521 .41199 L .57309 .49069 L .166 0 0 r
F
.61879 .47021 m .59517 .48064 L p .63559 .4534 L .18 0 0 r
F P
0 g
s
.59517 .48064 m .65231 .43668 L .63559 .4534 L .18 0 0 r
F
.61879 .47021 m .63559 .4534 L .59517 .48064 L F
.62834 .44754 m .59517 .48064 L p .63559 .4534 L F P
0 g
s
.65231 .43668 m .62834 .44754 L p .63559 .4534 L .18 0 0 r
F P
0 g
s
.59517 .48064 m .65506 .47807 L .62208 .51128 L .856 0 0 r
F
.73863 .49894 m .75538 .48177 L .76827 .47661 L p 0 .05 .212 r
F P
0 g
s
.76827 .47661 m .75143 .49388 L .73863 .49894 L p 0 .05 .212 r
F P
0 g
s
.677 .42551 m .70444 .45698 L p .66608 .44309 L 0 .318 .939 r
F P
0 g
s
.66608 .44309 m .70444 .45698 L .69755 .46753 L 0 .318 .939 r
F
.67076 .49107 m .70444 .45698 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.70444 .45698 m .67939 .46768 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.67487 .38932 m .75538 .48177 L .78135 .47137 L p 0 .319 .936 r
F P
0 g
s
.76443 .48876 m .75143 .49388 L .76827 .47661 L p 0 .05 .212 r
F P
0 g
s
.76827 .47661 m .78135 .47137 L .76443 .48876 L p 0 .05 .212 r
F P
0 g
s
.75143 .49388 m .76443 .48876 L .74741 .50624 L p 0 .05 .212 r
F P
0 g
s
.78135 .47137 m .74741 .50624 L .66521 .41199 L p 0 .35 .78 r
F P
0 g
s
.677 .42551 m .70444 .45698 L .71235 .44486 L .577 0 0 r
F
.65579 .43511 m .677 .42551 L .66608 .44309 L 0 .318 .939 r
F
.67939 .46768 m .65231 .43668 L p .68905 .46355 L F P
0 g
s
.64311 .45947 m .70444 .45698 L .677 .42551 L .858 0 0 r
F
.67939 .46768 m .65506 .47807 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.64311 .45947 m .67076 .49107 L .70444 .45698 L .858 0 0 r
F
.677 .42551 m .70444 .45698 L .67076 .49107 L p F P
0 g
s
.67076 .49107 m .71235 .44486 L .70444 .45698 L .86 0 0 r
F
.70444 .45698 m .74741 .50624 L p .69755 .46753 L 0 .318 .939 r
F P
0 g
s
.63559 .4534 m .677 .42551 L .61879 .47021 L .18 0 0 r
F
.677 .42551 m .64311 .45947 L .61879 .47021 L p F P
0 g
s
.65231 .43668 m .677 .42551 L p .63559 .4534 L .18 0 0 r
F P
0 g
s
.61879 .47021 m .677 .42551 L .63559 .4534 L .18 0 0 r
F
.677 .42551 m .65231 .43668 L p .63559 .4534 L F P
0 g
s
.61578 .50411 m .60425 .49097 L p .64311 .45947 L .569 0 0 r
F P
0 g
s
.60425 .49097 m .59517 .48064 L .61592 .47147 L p .569 0 0 r
F P
0 g
s
.61592 .47147 m .64311 .45947 L p .60425 .49097 L .569 0 0 r
F P
0 g
s
.56164 .51409 m .60884 .49382 L .64311 .45947 L p .18 0 0 r
F P
0 g
s
.64311 .45947 m .677 .42551 L p .61879 .47021 L .18 0 0 r
F P
0 g
s
.56164 .51409 m .64311 .45947 L .61879 .47021 L .18 0 0 r
F
.66521 .41199 m .677 .42551 L .60884 .49382 L p .858 0 0 r
F P
0 g
s
.66521 .41199 m .677 .42551 L .67955 .4214 L .577 0 0 r
F
.59517 .48064 m .56164 .51409 L p .61879 .47021 L .18 0 0 r
F P
0 g
s
.59688 .4802 m .5982 .4793 L .59745 .47963 L .858 0 0 r
F
.5982 .4793 m .677 .42551 L .59745 .47963 L F
.59745 .47963 m .677 .42551 L .66521 .41199 L F
.59688 .4802 m .60884 .49382 L .677 .42551 L F
.64311 .45947 m .67955 .4214 L .677 .42551 L .881 0 0 r
F
.64434 .45746 m .67955 .4214 L .64311 .45947 L F
.64311 .45947 m .677 .42551 L .67955 .4214 L F
.67076 .49107 m .64311 .45947 L .677 .42551 L p .858 0 0 r
F P
0 g
s
.64311 .45947 m .67955 .4214 L .64558 .45544 L .881 0 0 r
F
.60884 .49382 m .59688 .4802 L .66521 .41199 L p .858 0 0 r
F P
0 g
s
.60884 .49382 m .61123 .48986 L .64558 .45544 L .881 0 0 r
F
.64434 .45746 m .64558 .45544 L .67955 .4214 L F
.60884 .49382 m .64558 .45544 L .64434 .45746 L F
.78135 .47137 m .69977 .3775 L .67487 .38932 L p 0 .319 .936 r
F P
0 g
s
.66521 .41199 m .69977 .3775 L .78135 .47137 L p 0 .35 .78 r
F P
0 g
s
.66521 .41199 m .67955 .4214 L .66593 .41166 L .577 0 0 r
F
.69977 .3775 m .66521 .41199 L .64068 .42337 L p 0 .05 .118 r
F P
0 g
s
.65286 .41772 m .66521 .41199 L .68254 .39469 L p 0 .05 .118 r
F P
0 g
s
.65069 .4008 m .67487 .38932 L .64068 .42337 L p 0 .05 .118 r
F P
0 g
s
.6627 .3951 m .67487 .38932 L .64595 .3561 L p 0 .319 .936 r
F P
0 g
s
.65783 .4063 m .67487 .38932 L .6627 .3951 L p 0 .05 .118 r
F P
0 g
s
.67487 .38932 m .65783 .4063 L .67009 .40054 L p 0 .05 .118 r
F P
0 g
s
.67009 .40054 m .68723 .38345 L .67487 .38932 L p 0 .05 .118 r
F P
0 g
s
.6627 .3951 m .65069 .4008 L .63382 .41757 L p 0 .05 .118 r
F P
0 g
s
.63382 .41757 m .64574 .41197 L .6627 .3951 L p 0 .05 .118 r
F P
0 g
s
.6627 .3951 m .64574 .41197 L .65783 .4063 L p 0 .05 .118 r
F P
0 g
s
.65783 .4063 m .67487 .38932 L .64035 .37598 L p 0 .349 .781 r
F P
0 g
s
.64068 .42337 m .67487 .38932 L .69977 .3775 L p 0 .05 .118 r
F P
0 g
s
.6165 .37364 m .61659 .38769 L .65069 .4008 L p 0 .349 .781 r
F P
0 g
s
.65069 .4008 m .62215 .36808 L .6165 .37364 L p 0 .349 .781 r
F P
0 g
s
.63382 .41757 m .65069 .4008 L .61659 .38769 L p 0 .349 .781 r
F P
0 g
s
.64052 .39965 m .64035 .37598 L .67487 .38932 L p 0 .349 .781 r
F P
0 g
s
.64068 .42337 m .61686 .43443 L .65069 .4008 L p 0 .05 .118 r
F P
0 g
s
.67487 .38932 m .65783 .4063 L .64052 .39965 L p 0 .349 .781 r
F P
0 g
s
.67009 .40054 m .65783 .4063 L .64068 .42337 L p 0 .05 .118 r
F P
0 g
s
.64068 .42337 m .65286 .41772 L .67009 .40054 L p 0 .05 .118 r
F P
0 g
s
.69977 .3775 m .68723 .38345 L .67009 .40054 L p 0 .05 .118 r
F P
0 g
s
.67009 .40054 m .68254 .39469 L .69977 .3775 L p 0 .05 .118 r
F P
0 g
s
.68254 .39469 m .67009 .40054 L .65286 .41772 L p 0 .05 .118 r
F P
0 g
s
.66501 .38793 m .68254 .39469 L .66521 .41199 L closepath p 0 .35 .78 r
F P
0 g
s
.66521 .41199 m .66593 .41166 L .66557 .4114 L .577 0 0 r
F
.66557 .4114 m .67955 .4214 L .67773 .41413 L F
.61123 .48986 m .67773 .41413 L .67955 .4214 L .95 0 0 r
F
.64558 .45544 m .67773 .41413 L .64367 .44821 L F
.61123 .48986 m .60924 .48266 L .67773 .41413 L F
.64558 .45544 m .64367 .44821 L .64898 .44989 L .569 0 0 r
F
.64558 .45544 m .67955 .4214 L .67773 .41413 L .95 0 0 r
F
.64558 .45544 m .64898 .44989 L .67288 .45745 L .569 0 0 r
F
.64311 .45947 m .64558 .45544 L .64811 .45727 L F
.64311 .45947 m .64811 .45727 L .67843 .47917 L F
.60884 .49382 m .64434 .45746 L .64311 .45947 L .881 0 0 r
F
.62208 .51128 m .61578 .50411 L p .64311 .45947 L .569 0 0 r
F P
0 g
s
.66521 .41199 m .59688 .4802 L .57309 .49069 L p .166 0 0 r
F P
0 g
s
.65231 .42487 m .64003 .43052 L .62714 .44336 L p 0 .05 .118 r
F P
0 g
s
.64003 .43052 m .65231 .42487 L .66521 .41199 L p 0 .05 .118 r
F P
0 g
s
.62714 .44336 m .63936 .4378 L .65231 .42487 L p 0 .05 .118 r
F P
0 g
s
.63936 .4378 m .62714 .44336 L .61421 .45626 L p 0 .05 .118 r
F P
0 g
s
.61421 .45626 m .62635 .45078 L .63936 .4378 L p 0 .05 .118 r
F P
0 g
s
.64574 .41197 m .63382 .41757 L .61686 .43443 L p 0 .05 .118 r
F P
0 g
s
.61686 .43443 m .62869 .42894 L .64574 .41197 L p 0 .05 .118 r
F P
0 g
s
.65783 .4063 m .64574 .41197 L .62869 .42894 L p 0 .05 .118 r
F P
0 g
s
.62869 .42894 m .64068 .42337 L .65783 .4063 L p 0 .05 .118 r
F P
0 g
s
.64052 .39965 m .64068 .42337 L .65783 .4063 L closepath p 0 .349 .781 r
F P
0 g
s
.65783 .4063 m .64068 .42337 L .64052 .39965 L closepath p 0 .349 .781 r
F P
0 g
s
.61659 .38769 m .61672 .41103 L .63382 .41757 L p 0 .349 .781 r
F P
0 g
s
.62613 .40671 m .64068 .42337 L .64052 .39965 L closepath p 0 .349 .781 r
F P
0 g
s
.64052 .39965 m .64068 .42337 L .62613 .40671 L closepath p 0 .349 .781 r
F P
0 g
s
.65286 .41772 m .64068 .42337 L .62613 .40671 L p 0 .318 .939 r
F P
0 g
s
.65286 .41772 m .64068 .42337 L .62792 .43608 L p 0 .05 .118 r
F P
0 g
s
.62613 .40671 m .64068 .42337 L .65286 .41772 L p 0 .318 .939 r
F P
0 g
s
.62613 .40671 m .6382 .40094 L .65286 .41772 L p 0 .318 .939 r
F P
0 g
s
.65286 .41772 m .6382 .40094 L .62613 .40671 L p 0 .318 .939 r
F P
0 g
s
.62792 .43608 m .64003 .43052 L .65286 .41772 L p 0 .05 .118 r
F P
0 g
s
.66521 .41199 m .65286 .41772 L .6382 .40094 L p 0 .318 .939 r
F P
0 g
s
.66521 .41199 m .65286 .41772 L .64003 .43052 L p 0 .05 .118 r
F P
0 g
s
.6382 .40094 m .65286 .41772 L .66521 .41199 L p 0 .318 .939 r
F P
0 g
s
.66521 .41199 m .65231 .42487 L .63752 .40792 L p 0 .35 .78 r
F P
0 g
s
.61686 .43443 m .63382 .41757 L .61672 .41103 L closepath p 0 .349 .781 r
F P
0 g
s
.6025 .41801 m .61686 .43443 L .61672 .41103 L closepath p 0 .349 .781 r
F P
0 g
s
.64068 .42337 m .62869 .42894 L .61423 .4124 L p 0 .318 .939 r
F P
0 g
s
.62792 .43608 m .64068 .42337 L .62869 .42894 L p 0 .05 .118 r
F P
0 g
s
.61423 .4124 m .62613 .40671 L .64068 .42337 L p 0 .318 .939 r
F P
0 g
s
.62869 .42894 m .64068 .42337 L .62613 .40671 L p 0 .318 .939 r
F P
0 g
s
.62613 .40671 m .61423 .4124 L .62869 .42894 L p 0 .318 .939 r
F P
0 g
s
.62869 .42894 m .61686 .43443 L .6025 .41801 L p 0 .318 .939 r
F P
0 g
s
.6025 .41801 m .61423 .4124 L .62869 .42894 L p 0 .318 .939 r
F P
0 g
s
.61686 .43443 m .62869 .42894 L .61423 .4124 L p 0 .318 .939 r
F P
0 g
s
.61423 .4124 m .6025 .41801 L .61686 .43443 L p 0 .318 .939 r
F P
0 g
s
.64068 .42337 m .62613 .40671 L .61333 .4194 L p 0 .349 .781 r
F P
0 g
s
.61599 .44157 m .62869 .42894 L .61686 .43443 L p 0 .05 .118 r
F P
0 g
s
.62869 .42894 m .61599 .44157 L .62792 .43608 L p 0 .05 .118 r
F P
0 g
s
.61333 .4194 m .62792 .43608 L .64068 .42337 L p 0 .349 .781 r
F P
0 g
s
.64068 .42337 m .62792 .43608 L .61333 .4194 L p 0 .349 .781 r
F P
0 g
s
.61333 .4194 m .62613 .40671 L .64068 .42337 L p 0 .349 .781 r
F P
0 g
s
.64003 .43052 m .62792 .43608 L .61511 .44885 L p 0 .05 .118 r
F P
0 g
s
.61511 .44885 m .62714 .44336 L .64003 .43052 L p 0 .05 .118 r
F P
0 g
s
.65231 .42487 m .63936 .4378 L .62452 .42083 L p 0 .35 .78 r
F P
0 g
s
.62452 .42083 m .63752 .40792 L .65231 .42487 L p 0 .35 .78 r
F P
0 g
s
.60678 .43604 m .61378 .43278 L .56006 .37142 L p .577 0 0 r
F P
0 g
s
.61378 .43278 m .60678 .43604 L .54014 .50219 L p .164 0 0 r
F P
0 g
s
.57575 .47055 m .60678 .43604 L .61378 .43278 L .164 0 0 r
F
.56297 .48324 m .5728 .47189 L .57575 .47055 L F
.56134 .48398 m .5728 .47189 L .56297 .48324 L F
.60678 .43604 m .55328 .37495 L p .54329 .47171 L .856 0 0 r
F P
0 g
s
.54014 .50219 m .55614 .48631 L p .54329 .47171 L .856 0 0 r
F P
0 g
s
.55614 .48631 m .60678 .43604 L p .54329 .47171 L .856 0 0 r
F P
0 g
s
.57309 .49069 m .55 .50088 L p .60707 .45685 L .166 0 0 r
F P
0 g
s
.54805 .50022 m .61489 .4338 L .61602 .4344 L .764 0 0 r
F
.54692 .49918 m .61489 .4338 L .54805 .50022 L .831 0 0 r
F
.54917 .50084 m .61602 .4344 L .61686 .43443 L .577 0 0 r
F
.54805 .50022 m .61602 .4344 L .54917 .50084 L .764 0 0 r
F
.54917 .50084 m .61686 .43443 L .55 .50088 L .577 0 0 r
F
.57883 .47223 m .56605 .48493 L .5776 .47977 L p 0 .05 .118 r
F P
0 g
s
.55917 .48495 m .55614 .48631 L .56888 .47367 L .164 0 0 r
F
.5728 .47189 m .56888 .47367 L .60678 .43604 L F
.56134 .48398 m .56888 .47367 L .5728 .47189 L F
.55474 .49701 m .55579 .49513 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.54692 .49918 m .55673 .48778 L .55529 .49036 L .164 0 0 r
F
.54692 .49918 m .54014 .50219 L .55614 .48631 L F
.54692 .49918 m .55614 .48631 L .55803 .48546 L F
.55673 .48778 m .55803 .48546 L .55917 .48495 L F
.54692 .49918 m .55803 .48546 L .55673 .48778 L F
.54692 .49918 m .56134 .48398 L .56297 .48324 L F
.53519 .43541 m .51492 .42227 L .52115 .41012 L .569 0 0 r
F
.55328 .37495 m .48587 .44063 L .54014 .50219 L p .856 0 0 r
F P
0 g
s
.55529 .49036 m .55917 .48495 L .56134 .48398 L .164 0 0 r
F
.55673 .48778 m .55917 .48495 L .55529 .49036 L F
.55917 .48495 m .56888 .47367 L .56134 .48398 L F
.5728 .47189 m .60678 .43604 L .57575 .47055 L F
.57364 .46894 m .51976 .40761 L .55328 .37495 L p .856 0 0 r
F P
0 g
s
.56297 .48324 m .57575 .47055 L p .55993 .48461 L .164 0 0 r
F P
0 g
s
.54014 .50219 m .57575 .47055 L .57182 .47233 L .164 0 0 r
F
.57575 .47055 m .61378 .43278 L p .57182 .47233 L F P
0 g
s
.56006 .37142 m .61378 .43278 L .56297 .48324 L p .856 0 0 r
F P
0 g
s
.54014 .50219 m .54692 .49918 L .56297 .48324 L p .164 0 0 r
F P
0 g
s
.54014 .50219 m .56297 .48324 L .55993 .48461 L .164 0 0 r
F
.56297 .48324 m .54692 .49918 L p .55007 .46858 L .856 0 0 r
F P
0 g
s
.55007 .46858 m .56006 .37142 L .56297 .48324 L .856 0 0 r
F
.54692 .49918 m .61378 .43278 L .61489 .4338 L .831 0 0 r
F
.56605 .48493 m .57318 .47784 L p .56544 .47448 L 0 .349 .781 r
F P
0 g
s
.57318 .47784 m .57883 .47223 L p .56544 .47448 L 0 .349 .781 r
F P
0 g
s
.57883 .47223 m .56435 .45574 L p .56544 .47448 L 0 .349 .781 r
F P
0 g
s
.56435 .45574 m .55153 .46842 L .56605 .48493 L p 0 .349 .781 r
F P
0 g
s
.56298 .46314 m .55153 .46842 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.5776 .47977 m .57565 .47755 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.57565 .47755 m .56298 .46314 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.59156 .45957 m .57883 .47223 L .59045 .46698 L p 0 .05 .118 r
F P
0 g
s
.57883 .47223 m .59045 .46698 L p .58695 .46547 L 0 .317 .941 r
F P
0 g
s
.56435 .45574 m .57883 .47223 L .59156 .45957 L p 0 .349 .781 r
F P
0 g
s
.5769 .47003 m .57883 .47223 L p .58695 .46547 L 0 .317 .941 r
F P
0 g
s
.59045 .46698 m .57883 .47223 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.56435 .45574 m .5769 .47003 L p .58695 .46547 L 0 .317 .941 r
F P
0 g
s
.59156 .45957 m .57712 .44311 L .56435 .45574 L p 0 .349 .781 r
F P
0 g
s
.59045 .46698 m .57587 .45037 L .56435 .45574 L p 0 .317 .941 r
F P
0 g
s
.57587 .45037 m .58851 .46477 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.58851 .46477 m .59045 .46698 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.54692 .49918 m .49243 .43734 L .56006 .37142 L p .856 0 0 r
F P
0 g
s
.54123 .4786 m .54016 .48046 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.55579 .49513 m .55385 .49293 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.55385 .49293 m .54123 .4786 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.54016 .48046 m .5528 .49481 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.5528 .49481 m .55474 .49701 L p .55371 .49318 L 0 .332 .559 r
F P
0 g
s
.56605 .48493 m .5776 .47977 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.55153 .46842 m .56412 .48273 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.56412 .48273 m .56605 .48493 L p .5741 .47825 L 0 .316 .942 r
F P
0 g
s
.5776 .47977 m .56605 .48493 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.56298 .46314 m .57565 .47755 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.57565 .47755 m .5776 .47977 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.56435 .45574 m .57587 .45037 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.57883 .47223 m .5769 .47003 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.5769 .47003 m .56435 .45574 L p .57844 .46933 L 0 .317 .941 r
F P
0 g
s
.55153 .46842 m .56298 .46314 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.56605 .48493 m .56412 .48273 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.56412 .48273 m .55153 .46842 L p .56564 .48204 L 0 .316 .942 r
F P
0 g
s
.58983 .43054 m .60424 .44697 L .61686 .43443 L p 0 .349 .781 r
F P
0 g
s
.61686 .43443 m .60424 .44697 L .61599 .44157 L p 0 .05 .118 r
F P
0 g
s
.61511 .44885 m .62792 .43608 L .61599 .44157 L p 0 .05 .118 r
F P
0 g
s
.60325 .45425 m .61599 .44157 L .60424 .44697 L p 0 .05 .118 r
F P
0 g
s
.61599 .44157 m .60325 .45425 L .61511 .44885 L p 0 .05 .118 r
F P
0 g
s
.60047 .43213 m .61511 .44885 L .62792 .43608 L p 0 .349 .781 r
F P
0 g
s
.62792 .43608 m .61511 .44885 L .60047 .43213 L p 0 .349 .781 r
F P
0 g
s
.62714 .44336 m .61511 .44885 L .60224 .46166 L p 0 .05 .118 r
F P
0 g
s
.60224 .46166 m .61421 .45626 L .62714 .44336 L p 0 .05 .118 r
F P
0 g
s
.63936 .4378 m .62635 .45078 L .61147 .43379 L p 0 .35 .78 r
F P
0 g
s
.61686 .43443 m .6025 .41801 L .58983 .43054 L p 0 .349 .781 r
F P
0 g
s
.62792 .43608 m .61333 .4194 L .60047 .43213 L p 0 .349 .781 r
F P
0 g
s
.60047 .43213 m .61333 .4194 L .62792 .43608 L p 0 .349 .781 r
F P
0 g
s
.61147 .43379 m .62452 .42083 L .63936 .4378 L p 0 .35 .78 r
F P
0 g
s
.63141 .44562 m .66521 .41199 L .66364 .41333 L .889 0 0 r
F
.64035 .37598 m .64052 .39965 L .65783 .4063 L p 0 .349 .781 r
F P
0 g
s
.6382 .40094 m .65046 .39507 L .66521 .41199 L p 0 .318 .939 r
F P
0 g
s
.66521 .41199 m .65046 .39507 L .6382 .40094 L p 0 .318 .939 r
F P
0 g
s
.66501 .38793 m .66521 .41199 L .65046 .39507 L closepath p 0 .35 .78 r
F P
0 g
s
.63752 .40792 m .65046 .39507 L .66521 .41199 L p 0 .35 .78 r
F P
0 g
s
.66364 .41333 m .66521 .41199 L .66557 .4114 L .889 0 0 r
F
.60224 .46166 m .61511 .44885 L .60325 .45425 L p 0 .05 .118 r
F P
0 g
s
.60424 .44697 m .58983 .43054 L .57712 .44311 L p 0 .349 .781 r
F P
0 g
s
.57712 .44311 m .59156 .45957 L .60424 .44697 L p 0 .349 .781 r
F P
0 g
s
.60424 .44697 m .59156 .45957 L .60325 .45425 L p 0 .05 .118 r
F P
0 g
s
.61511 .44885 m .60047 .43213 L .58756 .44493 L p 0 .349 .781 r
F P
0 g
s
.59045 .46698 m .60325 .45425 L .59156 .45957 L p 0 .05 .118 r
F P
0 g
s
.60325 .45425 m .59045 .46698 L .60224 .46166 L p 0 .05 .118 r
F P
0 g
s
.58756 .44493 m .60224 .46166 L .61511 .44885 L p 0 .349 .781 r
F P
0 g
s
.61511 .44885 m .60224 .46166 L .58756 .44493 L p 0 .349 .781 r
F P
0 g
s
.58756 .44493 m .60047 .43213 L .61511 .44885 L p 0 .349 .781 r
F P
0 g
s
.61421 .45626 m .62635 .45078 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.59943 .4394 m .61224 .45402 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.61224 .45402 m .61421 .45626 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.63124 .44591 m .66521 .41199 L .63141 .44562 L .889 0 0 r
F
.61421 .45626 m .60121 .46922 L .61329 .46382 L p 0 .05 .118 r
F P
0 g
s
.61329 .46382 m .62635 .45078 L .61421 .45626 L p 0 .05 .118 r
F P
0 g
s
.62635 .45078 m .61421 .45626 L .61224 .45402 L p 0 .317 .941 r
F P
0 g
s
.61224 .45402 m .59943 .4394 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.62274 .44925 m .62635 .45078 L .61224 .45402 L 0 .317 .941 r
F
.61147 .43379 m .59943 .4394 L p .62274 .44925 L F P
0 g
s
.62635 .45078 m .62437 .44852 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.62437 .44852 m .61147 .43379 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.59943 .4394 m .61147 .43379 L .62437 .44852 L p 0 .317 .941 r
F P
0 g
s
.62437 .44852 m .62635 .45078 L p .62274 .44925 L 0 .317 .941 r
F P
0 g
s
.59943 .4394 m .62437 .44852 L .62274 .44925 L 0 .317 .941 r
F
.60224 .46166 m .58932 .47453 L .60121 .46922 L p 0 .05 .118 r
F P
0 g
s
.60121 .46922 m .61421 .45626 L .60224 .46166 L p 0 .05 .118 r
F P
0 g
s
.57587 .45037 m .59045 .46698 L .60224 .46166 L p 0 .317 .941 r
F P
0 g
s
.58932 .47453 m .60224 .46166 L .59045 .46698 L p 0 .05 .118 r
F P
0 g
s
.60224 .46166 m .58756 .44493 L .57587 .45037 L p 0 .317 .941 r
F P
0 g
s
.58756 .44493 m .60224 .46166 L .59045 .46698 L p 0 .317 .941 r
F P
0 g
s
.56298 .46314 m .57587 .45037 L .59045 .46698 L p 0 .349 .781 r
F P
0 g
s
.5776 .47977 m .59045 .46698 L .57883 .47223 L p 0 .05 .118 r
F P
0 g
s
.5776 .47977 m .59045 .46698 L .57587 .45037 L p 0 .349 .781 r
F P
0 g
s
.59045 .46698 m .57587 .45037 L .58756 .44493 L p 0 .317 .941 r
F P
0 g
s
.57587 .45037 m .56298 .46314 L .5776 .47977 L p 0 .349 .781 r
F P
0 g
s
.5746 .45777 m .58756 .44493 L .60224 .46166 L p 0 .349 .781 r
F P
0 g
s
.59045 .46698 m .5776 .47977 L .56298 .46314 L p 0 .349 .781 r
F P
0 g
s
.59045 .46698 m .5776 .47977 L .58932 .47453 L p 0 .05 .118 r
F P
0 g
s
.60224 .46166 m .58932 .47453 L .5746 .45777 L p 0 .349 .781 r
F P
0 g
s
.58756 .44493 m .60224 .46166 L .61421 .45626 L p 0 .317 .941 r
F P
0 g
s
.61421 .45626 m .60224 .46166 L .58756 .44493 L p 0 .317 .941 r
F P
0 g
s
.58932 .47453 m .60224 .46166 L .58756 .44493 L p 0 .349 .781 r
F P
0 g
s
.61421 .45626 m .59943 .4394 L .58756 .44493 L p 0 .317 .941 r
F P
0 g
s
.58756 .44493 m .59943 .4394 L .61421 .45626 L p 0 .317 .941 r
F P
0 g
s
.60121 .46922 m .61421 .45626 L .59943 .4394 L p 0 .349 .781 r
F P
0 g
s
.58756 .44493 m .5746 .45777 L .58932 .47453 L p 0 .349 .781 r
F P
0 g
s
.61421 .45626 m .60121 .46922 L .5864 .45233 L p 0 .349 .781 r
F P
0 g
s
.59943 .4394 m .5864 .45233 L .60121 .46922 L p 0 .349 .781 r
F P
0 g
s
.61329 .46382 m .60121 .46922 L p .60084 .46625 L 0 .316 .942 r
F P
0 g
s
.5864 .45233 m .59943 .4394 L .61421 .45626 L p 0 .349 .781 r
F P
0 g
s
.59837 .4468 m .6113 .46155 L p .60084 .46625 L 0 .316 .942 r
F P
0 g
s
.6113 .46155 m .61329 .46382 L p .60084 .46625 L 0 .316 .942 r
F P
0 g
s
.61329 .46382 m .60121 .46922 L p .59856 .47763 L 0 .05 .118 r
F P
0 g
s
.60121 .46922 m .61329 .46382 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.5864 .45233 m .59924 .46697 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.59924 .46697 m .60121 .46922 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.60121 .46922 m .58817 .48223 L .59856 .47763 L p 0 .05 .118 r
F P
0 g
s
.59837 .4468 m .5864 .45233 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.61329 .46382 m .6113 .46155 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.6113 .46155 m .59837 .4468 L p .60968 .46228 L 0 .316 .942 r
F P
0 g
s
.58932 .47453 m .57634 .48746 L .58817 .48223 L p 0 .05 .118 r
F P
0 g
s
.58817 .48223 m .60121 .46922 L .58932 .47453 L p 0 .05 .118 r
F P
0 g
s
.5746 .45777 m .58932 .47453 L .5776 .47977 L p 0 .316 .942 r
F P
0 g
s
.57634 .48746 m .58932 .47453 L .5776 .47977 L p 0 .05 .118 r
F P
0 g
s
.56298 .46314 m .5776 .47977 L .58932 .47453 L p 0 .316 .942 r
F P
0 g
s
.58932 .47453 m .5746 .45777 L .56298 .46314 L p 0 .316 .942 r
F P
0 g
s
.5776 .47977 m .56298 .46314 L .5746 .45777 L p 0 .316 .942 r
F P
0 g
s
.55579 .49513 m .56605 .48493 L .55153 .46842 L p 0 .349 .781 r
F P
0 g
s
.55153 .46842 m .54123 .4786 L .55579 .49513 L p 0 .349 .781 r
F P
0 g
s
.55004 .47595 m .56298 .46314 L .5776 .47977 L p 0 .349 .781 r
F P
0 g
s
.56605 .48493 m .55579 .49513 L p .5647 .49261 L 0 .05 .118 r
F P
0 g
s
.5647 .49261 m .5776 .47977 L .56605 .48493 L p 0 .05 .118 r
F P
0 g
s
.5647 .49261 m .5776 .47977 L .56298 .46314 L p 0 .349 .781 r
F P
0 g
s
.56298 .46314 m .55004 .47595 L .5647 .49261 L p 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .5746 .45777 L .58932 .47453 L p 0 .349 .781 r
F P
0 g
s
.5776 .47977 m .5647 .49261 L .57634 .48746 L p 0 .05 .118 r
F P
0 g
s
.5776 .47977 m .5647 .49261 L .55004 .47595 L p 0 .349 .781 r
F P
0 g
s
.58932 .47453 m .57634 .48746 L .56158 .47067 L p 0 .349 .781 r
F P
0 g
s
.58932 .47453 m .5746 .45777 L .5864 .45233 L p 0 .316 .942 r
F P
0 g
s
.5864 .45233 m .60121 .46922 L .58932 .47453 L p 0 .316 .942 r
F P
0 g
s
.5746 .45777 m .58932 .47453 L .60121 .46922 L p 0 .316 .942 r
F P
0 g
s
.57634 .48746 m .58932 .47453 L .5746 .45777 L p 0 .349 .781 r
F P
0 g
s
.60121 .46922 m .5864 .45233 L .5746 .45777 L p 0 .316 .942 r
F P
0 g
s
.58817 .48223 m .60121 .46922 L .5864 .45233 L p 0 .349 .781 r
F P
0 g
s
.5746 .45777 m .56158 .47067 L .57634 .48746 L p 0 .349 .781 r
F P
0 g
s
.60121 .46922 m .58817 .48223 L .57331 .46531 L p 0 .349 .781 r
F P
0 g
s
.5864 .45233 m .57331 .46531 L .58817 .48223 L p 0 .349 .781 r
F P
0 g
s
.59856 .47763 m .58817 .48223 L p .58756 .47936 L 0 .316 .943 r
F P
0 g
s
.57331 .46531 m .5864 .45233 L .60121 .46922 L p 0 .349 .781 r
F P
0 g
s
.58361 .4606 m .59657 .47536 L p .58756 .47936 L 0 .316 .943 r
F P
0 g
s
.59657 .47536 m .59856 .47763 L p .58756 .47936 L 0 .316 .943 r
F P
0 g
s
.58817 .48223 m .59856 .47763 L p .59517 .47598 L 0 .316 .943 r
F P
0 g
s
.57331 .46531 m .58619 .47997 L p .59517 .47598 L 0 .316 .943 r
F P
0 g
s
.58619 .47997 m .58817 .48223 L p .59517 .47598 L 0 .316 .943 r
F P
0 g
s
.5954 .48012 m .59856 .47763 L .58817 .48223 L p 0 .05 .118 r
F P
0 g
s
.59856 .47763 m .58361 .4606 L .57331 .46531 L p 0 .316 .943 r
F P
0 g
s
.59837 .4468 m .61147 .43379 L .62635 .45078 L p 0 .35 .78 r
F P
0 g
s
.62635 .45078 m .61329 .46382 L .59837 .4468 L p 0 .35 .78 r
F P
0 g
s
.57634 .48746 m .56158 .47067 L .57331 .46531 L p 0 .316 .943 r
F P
0 g
s
.57331 .46531 m .58817 .48223 L .57634 .48746 L p 0 .316 .943 r
F P
0 g
s
.58817 .48223 m .57331 .46531 L .56158 .47067 L p 0 .316 .943 r
F P
0 g
s
.58817 .48223 m .57331 .46531 L .58361 .4606 L p 0 .316 .943 r
F P
0 g
s
.56158 .47067 m .57634 .48746 L .58817 .48223 L p 0 .316 .943 r
F P
0 g
s
.58621 .48417 m .58817 .48223 L .57634 .48746 L p 0 .05 .118 r
F P
0 g
s
.58621 .48417 m .58817 .48223 L .57331 .46531 L p 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .57634 .48746 L .5647 .49261 L p 0 .316 .943 r
F P
0 g
s
.57634 .48746 m .56158 .47067 L .55004 .47595 L p 0 .316 .943 r
F P
0 g
s
.55579 .49513 m .55474 .49701 L .5647 .49261 L p 0 .05 .118 r
F P
0 g
s
.55004 .47595 m .5647 .49261 L .55474 .49701 L p 0 .316 .943 r
F P
0 g
s
.5647 .49261 m .55004 .47595 L .54016 .48046 L p 0 .316 .943 r
F P
0 g
s
.5647 .49261 m .55004 .47595 L .56158 .47067 L p 0 .316 .943 r
F P
0 g
s
.55474 .49701 m .54016 .48046 L .55004 .47595 L p 0 .316 .943 r
F P
0 g
s
.54016 .48046 m .55474 .49701 L .5647 .49261 L p 0 .316 .943 r
F P
0 g
s
.55395 .49842 m .55474 .49701 L .54016 .48046 L p 0 .332 .559 r
F P
0 g
s
.54366 .49266 m .55395 .49842 L p .54016 .48046 L 0 .332 .559 r
F P
0 g
s
.54692 .49918 m .54014 .50219 L p .52913 .48722 L .56 0 0 r
F P
0 g
s
.53698 .45189 m .52666 .46205 L .54123 .4786 L p 0 .349 .781 r
F P
0 g
s
.54123 .4786 m .52666 .46205 L .52557 .46389 L p 0 .332 .559 r
F P
0 g
s
.52557 .46389 m .54016 .48046 L .54123 .4786 L p 0 .332 .559 r
F P
0 g
s
.54016 .48046 m .52557 .46389 L .53535 .45927 L p 0 .316 .943 r
F P
0 g
s
.54123 .4786 m .55153 .46842 L .56298 .46314 L p 0 .05 .1 r
F P
0 g
s
.55153 .46842 m .54123 .4786 L p .55004 .47595 L 0 .05 .1 r
F P
0 g
s
.54123 .4786 m .55153 .46842 L .53698 .45189 L p 0 .349 .781 r
F P
0 g
s
.54016 .48046 m .54123 .4786 L p .56298 .46314 L 0 .05 .1 r
F P
0 g
s
.56298 .46314 m .55004 .47595 L .54016 .48046 L p 0 .05 .1 r
F P
0 g
s
.55004 .47595 m .53535 .45927 L .52557 .46389 L p 0 .316 .943 r
F P
0 g
s
.52557 .46389 m .53535 .45927 L p .53153 .46274 L 0 .05 .1 r
F P
0 g
s
.52913 .48722 m .51637 .46988 L .5343 .48486 L .56 0 0 r
F
.51972 .46831 m .5343 .48486 L p .51637 .46988 L F P
0 g
s
.5343 .48486 m .54692 .49918 L p .52913 .48722 L .56 0 0 r
F P
0 g
s
.53608 .48756 m .54016 .48046 L .52557 .46389 L p 0 .332 .559 r
F P
0 g
s
.54123 .4786 m .54016 .48046 L .55004 .47595 L p 0 .05 .1 r
F P
0 g
s
.52557 .46389 m .54016 .48046 L .55004 .47595 L p 0 .316 .943 r
F P
0 g
s
.53478 .48668 m .53608 .48756 L p .52557 .46389 L 0 .332 .559 r
F P
0 g
s
.52701 .48027 m .53478 .48668 L p .52557 .46389 L 0 .332 .559 r
F P
0 g
s
.52557 .46389 m .52006 .47317 L .52701 .48027 L p 0 .332 .559 r
F P
0 g
s
.52006 .47317 m .5242 .4662 L p .53153 .46274 L 0 .05 .1 r
F P
0 g
s
.5242 .4662 m .52557 .46389 L p .53153 .46274 L 0 .05 .1 r
F P
0 g
s
.49243 .43734 m .51972 .46831 L p .51637 .46988 L .56 0 0 r
F P
0 g
s
.54016 .48046 m .55004 .47595 L p .54542 .47979 L 0 .05 .1 r
F P
0 g
s
.53882 .4828 m .5406 .48199 L p .54016 .48046 L 0 .332 .559 r
F P
0 g
s
.54102 .48345 m .53608 .48756 L .54366 .49266 L p 0 .332 .559 r
F P
0 g
s
.53608 .48756 m .53882 .4828 L p .54542 .47979 L 0 .05 .1 r
F P
0 g
s
.53882 .4828 m .54016 .48046 L p .54542 .47979 L 0 .05 .1 r
F P
0 g
s
.5402 .48569 m .55004 .47595 L .5647 .49261 L p 0 .349 .781 r
F P
0 g
s
.55004 .47595 m .5647 .49261 L .57634 .48746 L p 0 .316 .943 r
F P
0 g
s
.56276 .49453 m .5647 .49261 L .55474 .49701 L p 0 .05 .118 r
F P
0 g
s
.56276 .49453 m .5647 .49261 L .55004 .47595 L p 0 .349 .781 r
F P
0 g
s
.5495 .49004 m .56276 .49453 L p .55004 .47595 L 0 .349 .781 r
F P
0 g
s
.55169 .48047 m .56158 .47067 L .57634 .48746 L p 0 .349 .781 r
F P
0 g
s
.5744 .48939 m .57634 .48746 L .5647 .49261 L p 0 .05 .118 r
F P
0 g
s
.5744 .48939 m .57634 .48746 L .56158 .47067 L p 0 .349 .781 r
F P
0 g
s
.56106 .48486 m .5744 .48939 L p .56158 .47067 L 0 .349 .781 r
F P
0 g
s
.56336 .47518 m .57331 .46531 L .58817 .48223 L p 0 .349 .781 r
F P
0 g
s
.57278 .4796 m .58621 .48417 L p .57331 .46531 L 0 .349 .781 r
F P
0 g
s
.57331 .46531 m .56336 .47518 L .57278 .4796 L p 0 .349 .781 r
F P
0 g
s
.56763 .47324 m .58361 .4606 L .59856 .47763 L p 0 .346 .852 r
F P
0 g
s
.57885 .47688 m .56763 .47324 L p .59856 .47763 L 0 .346 .852 r
F P
0 g
s
.60121 .46922 m .5864 .45233 L .59837 .4468 L p 0 .316 .942 r
F P
0 g
s
.58784 .45725 m .59837 .4468 L .61329 .46382 L p 0 .35 .78 r
F P
0 g
s
.59856 .47763 m .6028 .47429 L .61329 .46382 L p 0 .05 .118 r
F P
0 g
s
.61329 .46382 m .6028 .47429 L .58784 .45725 L p 0 .35 .78 r
F P
0 g
s
.59856 .47763 m .5954 .48012 L .57885 .47688 L p 0 .346 .852 r
F P
0 g
s
.6028 .47429 m .59856 .47763 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.58784 .45725 m .6008 .47202 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.6008 .47202 m .6028 .47429 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.58361 .4606 m .58784 .45725 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.59856 .47763 m .59657 .47536 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.59657 .47536 m .58361 .4606 L p .59713 .47492 L 0 .346 .852 r
F P
0 g
s
.6309 .44369 m .66449 .40916 L .63048 .44309 L .884 0 0 r
F
.59977 .47576 m .66531 .41036 L .59963 .47582 L F
.59963 .47582 m .66531 .41036 L .66449 .40916 L F
.63145 .44481 m .66557 .4114 L .66531 .41036 L .949 0 0 r
F
.59722 .47963 m .63158 .44532 L .63145 .44481 L F
.63158 .44532 m .66557 .4114 L .63145 .44481 L F
.58811 .40158 m .61659 .38769 L .6165 .37364 L closepath p 0 .349 .781 r
F P
0 g
s
.6165 .37364 m .62829 .36773 L .59974 .39584 L p 0 .05 .1 r
F P
0 g
s
.59974 .39584 m .58811 .40158 L .6165 .37364 L p 0 .05 .1 r
F P
0 g
s
.6165 .37364 m .6033 .37248 L .58811 .40158 L closepath p 0 .349 .781 r
F P
0 g
s
.62829 .36773 m .6165 .37364 L .58811 .40158 L p 0 .05 .1 r
F P
0 g
s
.61672 .41103 m .61659 .38769 L .58811 .40158 L p 0 .349 .781 r
F P
0 g
s
.5737 .38512 m .58811 .40158 L .6033 .37248 L p 0 .349 .781 r
F P
0 g
s
.6033 .37248 m .58134 .37056 L .5737 .38512 L p 0 .349 .781 r
F P
0 g
s
.58811 .40158 m .59974 .39584 L .62829 .36773 L p 0 .05 .1 r
F P
0 g
s
.58524 .37926 m .59974 .39584 L .58811 .40158 L p 0 .318 .939 r
F P
0 g
s
.58811 .40158 m .5737 .38512 L .58524 .37926 L p 0 .318 .939 r
F P
0 g
s
.59974 .39584 m .58524 .37926 L .5737 .38512 L p 0 .318 .939 r
F P
0 g
s
.61155 .39002 m .59974 .39584 L .62829 .36773 L p 0 .05 .1 r
F P
0 g
s
.62829 .36773 m .64025 .36173 L .61155 .39002 L p 0 .05 .1 r
F P
0 g
s
.64025 .36173 m .62829 .36773 L .59974 .39584 L p 0 .05 .1 r
F P
0 g
s
.58811 .40158 m .6025 .41801 L .61672 .41103 L p 0 .349 .781 r
F P
0 g
s
.62613 .40671 m .61423 .4124 L .59974 .39584 L p 0 .318 .939 r
F P
0 g
s
.59974 .39584 m .61155 .39002 L .62613 .40671 L p 0 .318 .939 r
F P
0 g
s
.61423 .4124 m .62613 .40671 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.61155 .39002 m .59974 .39584 L .61423 .4124 L p 0 .318 .939 r
F P
0 g
s
.59974 .39584 m .61155 .39002 L .64025 .36173 L p 0 .05 .1 r
F P
0 g
s
.61155 .39002 m .59974 .39584 L .58524 .37926 L p 0 .318 .939 r
F P
0 g
s
.58524 .37926 m .59974 .39584 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.59974 .39584 m .61423 .4124 L .6025 .41801 L p 0 .318 .939 r
F P
0 g
s
.6025 .41801 m .58811 .40158 L .59974 .39584 L p 0 .318 .939 r
F P
0 g
s
.6025 .41801 m .61423 .4124 L .59974 .39584 L p 0 .318 .939 r
F P
0 g
s
.59974 .39584 m .58811 .40158 L .6025 .41801 L p 0 .318 .939 r
F P
0 g
s
.59871 .40269 m .61155 .39002 L .59974 .39584 L p 0 .05 .1 r
F P
0 g
s
.59974 .39584 m .61155 .39002 L .59871 .40269 L p 0 .05 .1 r
F P
0 g
s
.58524 .37926 m .59695 .37331 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.61155 .39002 m .59695 .37331 L .58524 .37926 L p 0 .318 .939 r
F P
0 g
s
.6165 .37364 m .62215 .36808 L .63397 .36214 L p 0 .05 .1 r
F P
0 g
s
.6033 .37248 m .6165 .37364 L .62215 .36808 L p 0 .349 .781 r
F P
0 g
s
.63397 .36214 m .62829 .36773 L .6165 .37364 L p 0 .05 .1 r
F P
0 g
s
.62215 .36808 m .6165 .37364 L .62829 .36773 L p 0 .05 .1 r
F P
0 g
s
.62829 .36773 m .63397 .36214 L .62215 .36808 L p 0 .05 .1 r
F P
0 g
s
.62688 .36054 m .61155 .39002 L .59695 .37331 L p 0 .349 .781 r
F P
0 g
s
.59695 .37331 m .60466 .35856 L .62688 .36054 L p 0 .349 .781 r
F P
0 g
s
.60466 .35856 m .59695 .37331 L .61155 .39002 L p 0 .349 .781 r
F P
0 g
s
.60466 .35856 m .58232 .35657 L .59695 .37331 L closepath p 0 .349 .781 r
F P
0 g
s
.59695 .37331 m .58232 .35657 L .60466 .35856 L closepath p 0 .349 .781 r
F P
0 g
s
.62613 .40671 m .61155 .39002 L .59871 .40269 L p 0 .349 .781 r
F P
0 g
s
.59871 .40269 m .61333 .4194 L .62613 .40671 L p 0 .349 .781 r
F P
0 g
s
.62613 .40671 m .61333 .4194 L .59871 .40269 L p 0 .349 .781 r
F P
0 g
s
.59871 .40269 m .61155 .39002 L .62613 .40671 L p 0 .349 .781 r
F P
0 g
s
.64035 .37598 m .64025 .36173 L .61155 .39002 L closepath p 0 .349 .781 r
F P
0 g
s
.61155 .39002 m .64025 .36173 L .64035 .37598 L closepath p 0 .349 .781 r
F P
0 g
s
.62353 .38412 m .61155 .39002 L .64025 .36173 L p 0 .05 .1 r
F P
0 g
s
.65812 .34998 m .64595 .3561 L .67487 .38932 L p 0 .319 .936 r
F P
0 g
s
.64035 .37598 m .67487 .38932 L .64595 .3561 L p 0 .349 .781 r
F P
0 g
s
.67487 .38932 m .64035 .37598 L .64025 .36173 L p 0 .349 .781 r
F P
0 g
s
.64025 .36173 m .64595 .3561 L .67487 .38932 L p 0 .349 .781 r
F P
0 g
s
.64595 .3561 m .64025 .36173 L .64035 .37598 L p 0 .349 .781 r
F P
0 g
s
.64025 .36173 m .65238 .35565 L .62353 .38412 L p 0 .05 .1 r
F P
0 g
s
.65238 .35565 m .64025 .36173 L .61155 .39002 L p 0 .05 .1 r
F P
0 g
s
.61155 .39002 m .64025 .36173 L .62688 .36054 L closepath p 0 .349 .781 r
F P
0 g
s
.62688 .36054 m .64025 .36173 L .61155 .39002 L closepath p 0 .349 .781 r
F P
0 g
s
.61155 .39002 m .62688 .36054 L .60466 .35856 L p 0 .349 .781 r
F P
0 g
s
.61155 .39002 m .62353 .38412 L .65238 .35565 L p 0 .05 .1 r
F P
0 g
s
.62353 .38412 m .61155 .39002 L .59695 .37331 L p 0 .318 .939 r
F P
0 g
s
.59695 .37331 m .60883 .36728 L .62353 .38412 L p 0 .318 .939 r
F P
0 g
s
.60883 .36728 m .59695 .37331 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.5737 .38512 m .58811 .40158 L .59974 .39584 L p 0 .318 .939 r
F P
0 g
s
.6025 .41801 m .58811 .40158 L .57541 .41408 L p 0 .349 .781 r
F P
0 g
s
.58697 .40842 m .59974 .39584 L .58811 .40158 L p 0 .05 .1 r
F P
0 g
s
.58811 .40158 m .59974 .39584 L .58697 .40842 L p 0 .05 .1 r
F P
0 g
s
.59974 .39584 m .58697 .40842 L .59871 .40269 L p 0 .05 .1 r
F P
0 g
s
.59871 .40269 m .58697 .40842 L .59974 .39584 L p 0 .05 .1 r
F P
0 g
s
.59871 .40269 m .61155 .39002 L .59695 .37331 L p 0 .349 .781 r
F P
0 g
s
.64035 .37598 m .61155 .39002 L .62613 .40671 L p 0 .349 .781 r
F P
0 g
s
.61155 .39002 m .64035 .37598 L .64052 .39965 L p 0 .349 .781 r
F P
0 g
s
.64052 .39965 m .62613 .40671 L .61155 .39002 L p 0 .349 .781 r
F P
0 g
s
.62613 .40671 m .64052 .39965 L .64035 .37598 L p 0 .349 .781 r
F P
0 g
s
.6382 .40094 m .62613 .40671 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.61155 .39002 m .62613 .40671 L .6382 .40094 L p 0 .318 .939 r
F P
0 g
s
.61155 .39002 m .62353 .38412 L .6382 .40094 L p 0 .318 .939 r
F P
0 g
s
.6382 .40094 m .62353 .38412 L .61155 .39002 L p 0 .318 .939 r
F P
0 g
s
.62353 .38412 m .61155 .39002 L .59871 .40269 L p 0 .05 .1 r
F P
0 g
s
.59871 .40269 m .61155 .39002 L .62353 .38412 L p 0 .05 .1 r
F P
0 g
s
.59695 .37331 m .61155 .39002 L .59871 .40269 L p 0 .349 .781 r
F P
0 g
s
.60883 .36728 m .59695 .37331 L .58232 .35657 L p 0 .318 .939 r
F P
0 g
s
.58232 .35657 m .5941 .35041 L .60883 .36728 L p 0 .318 .939 r
F P
0 g
s
.59695 .37331 m .60883 .36728 L .5941 .35041 L p 0 .318 .939 r
F P
0 g
s
.59695 .37331 m .58406 .38595 L .59871 .40269 L p 0 .349 .781 r
F P
0 g
s
.59871 .40269 m .58406 .38595 L .59695 .37331 L p 0 .349 .781 r
F P
0 g
s
.61333 .4194 m .59871 .40269 L .58581 .4154 L p 0 .349 .781 r
F P
0 g
s
.58581 .4154 m .59871 .40269 L .61333 .4194 L p 0 .349 .781 r
F P
0 g
s
.61061 .39686 m .59871 .40269 L .58581 .4154 L p 0 .05 .1 r
F P
0 g
s
.59871 .40269 m .61061 .39686 L .62353 .38412 L p 0 .05 .1 r
F P
0 g
s
.62353 .38412 m .61061 .39686 L .59871 .40269 L p 0 .05 .1 r
F P
0 g
s
.58581 .4154 m .59871 .40269 L .61061 .39686 L p 0 .05 .1 r
F P
0 g
s
.58581 .4154 m .59765 .40966 L .61061 .39686 L p 0 .05 .1 r
F P
0 g
s
.61061 .39686 m .59765 .40966 L .58581 .4154 L p 0 .05 .1 r
F P
0 g
s
.6382 .40094 m .62353 .38412 L .63568 .37813 L p 0 .318 .939 r
F P
0 g
s
.63568 .37813 m .65046 .39507 L .6382 .40094 L p 0 .318 .939 r
F P
0 g
s
.62353 .38412 m .6382 .40094 L .65046 .39507 L p 0 .318 .939 r
F P
0 g
s
.65046 .39507 m .63568 .37813 L .62353 .38412 L p 0 .318 .939 r
F P
0 g
s
.63568 .37813 m .62353 .38412 L .61061 .39686 L p 0 .05 .1 r
F P
0 g
s
.61061 .39686 m .62353 .38412 L .63568 .37813 L p 0 .05 .1 r
F P
0 g
s
.6227 .39095 m .61061 .39686 L .59765 .40966 L p 0 .05 .1 r
F P
0 g
s
.61061 .39686 m .6227 .39095 L .63568 .37813 L p 0 .05 .1 r
F P
0 g
s
.63568 .37813 m .6227 .39095 L .61061 .39686 L p 0 .05 .1 r
F P
0 g
s
.59765 .40966 m .61061 .39686 L .6227 .39095 L p 0 .05 .1 r
F P
0 g
s
.59765 .40966 m .60966 .40383 L .6227 .39095 L p 0 .05 .1 r
F P
0 g
s
.6227 .39095 m .60966 .40383 L .59765 .40966 L p 0 .05 .1 r
F P
0 g
s
.57541 .41408 m .58983 .43054 L .6025 .41801 L p 0 .349 .781 r
F P
0 g
s
.61155 .39002 m .62353 .38412 L .60883 .36728 L p 0 .318 .939 r
F P
0 g
s
.58581 .4154 m .60047 .43213 L .61333 .4194 L p 0 .349 .781 r
F P
0 g
s
.61333 .4194 m .60047 .43213 L .58581 .4154 L p 0 .349 .781 r
F P
0 g
s
.63568 .37813 m .62353 .38412 L .65238 .35565 L p 0 .05 .1 r
F P
0 g
s
.67487 .38932 m .68723 .38345 L .65812 .34998 L p 0 .319 .936 r
F P
0 g
s
.67046 .34377 m .65812 .34998 L .68723 .38345 L p 0 .319 .936 r
F P
0 g
s
.65238 .35565 m .66469 .34947 L .63568 .37813 L p 0 .05 .1 r
F P
0 g
s
.66469 .34947 m .65238 .35565 L .62353 .38412 L p 0 .05 .1 r
F P
0 g
s
.62353 .38412 m .60883 .36728 L .62088 .36116 L p 0 .318 .939 r
F P
0 g
s
.62353 .38412 m .63568 .37813 L .66469 .34947 L p 0 .05 .1 r
F P
0 g
s
.62088 .36116 m .63568 .37813 L .62353 .38412 L p 0 .318 .939 r
F P
0 g
s
.62088 .36116 m .60883 .36728 L .62353 .38412 L p 0 .318 .939 r
F P
0 g
s
.62353 .38412 m .63568 .37813 L .62088 .36116 L p 0 .318 .939 r
F P
0 g
s
.62088 .36116 m .60883 .36728 L .5941 .35041 L p 0 .318 .939 r
F P
0 g
s
.5941 .35041 m .60606 .34416 L .62088 .36116 L p 0 .318 .939 r
F P
0 g
s
.60606 .34416 m .5941 .35041 L .60883 .36728 L p 0 .318 .939 r
F P
0 g
s
.60883 .36728 m .62088 .36116 L .60606 .34416 L p 0 .318 .939 r
F P
0 g
s
.66469 .34947 m .66481 .36393 L .63568 .37813 L closepath p 0 .35 .78 r
F P
0 g
s
.64595 .3561 m .65812 .34998 L .65238 .35565 L p 0 .05 .1 r
F P
0 g
s
.65238 .35565 m .64025 .36173 L .64595 .3561 L p 0 .05 .1 r
F P
0 g
s
.65812 .34998 m .64595 .3561 L .64025 .36173 L p 0 .05 .1 r
F P
0 g
s
.64025 .36173 m .65238 .35565 L .65812 .34998 L p 0 .05 .1 r
F P
0 g
s
.65238 .35565 m .65812 .34998 L .67046 .34377 L p 0 .05 .1 r
F P
0 g
s
.65812 .34998 m .67046 .34377 L .64106 .30994 L p 0 .319 .936 r
F P
0 g
s
.67046 .34377 m .66469 .34947 L .65238 .35565 L p 0 .05 .1 r
F P
0 g
s
.65812 .34998 m .65238 .35565 L .66469 .34947 L p 0 .05 .1 r
F P
0 g
s
.66469 .34947 m .67046 .34377 L .65812 .34998 L p 0 .05 .1 r
F P
0 g
s
.63568 .37813 m .65117 .34824 L .66469 .34947 L closepath p 0 .35 .78 r
F P
0 g
s
.65046 .39507 m .63568 .37813 L .66481 .36393 L p 0 .35 .78 r
F P
0 g
s
.66481 .36393 m .66501 .38793 L .65046 .39507 L p 0 .35 .78 r
F P
0 g
s
.64595 .3561 m .64025 .36173 L .62688 .36054 L p 0 .349 .781 r
F P
0 g
s
.62867 .34621 m .65117 .34824 L .63568 .37813 L p 0 .35 .78 r
F P
0 g
s
.58983 .43054 m .57541 .41408 L .56265 .42663 L p 0 .349 .781 r
F P
0 g
s
.56265 .42663 m .57712 .44311 L .58983 .43054 L p 0 .349 .781 r
F P
0 g
s
.60047 .43213 m .58581 .4154 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .58581 .4154 L .60047 .43213 L p 0 .349 .781 r
F P
0 g
s
.60966 .40383 m .59765 .40966 L .58463 .42251 L p 0 .05 .1 r
F P
0 g
s
.58463 .42251 m .59765 .40966 L .60966 .40383 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .59943 .4394 L .61147 .43379 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .58756 .44493 L .60047 .43213 L p 0 .349 .781 r
F P
0 g
s
.60047 .43213 m .58756 .44493 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.58463 .42251 m .59943 .4394 L .61147 .43379 L p 0 .317 .941 r
F P
0 g
s
.59837 .4468 m .61147 .43379 L .59943 .4394 L p 0 .05 .1 r
F P
0 g
s
.61147 .43379 m .59943 .4394 L .58463 .42251 L p 0 .317 .941 r
F P
0 g
s
.61147 .43379 m .59657 .41676 L .58463 .42251 L p 0 .317 .941 r
F P
0 g
s
.58463 .42251 m .59657 .41676 L .60966 .40383 L p 0 .05 .1 r
F P
0 g
s
.60966 .40383 m .59657 .41676 L .58463 .42251 L p 0 .05 .1 r
F P
0 g
s
.58463 .42251 m .59657 .41676 L .61147 .43379 L p 0 .317 .941 r
F P
0 g
s
.63568 .37813 m .62088 .36116 L .62867 .34621 L p 0 .35 .78 r
F P
0 g
s
.62088 .36116 m .60606 .34416 L .62867 .34621 L closepath p 0 .35 .78 r
F P
0 g
s
.65046 .39507 m .63752 .40792 L .6227 .39095 L p 0 .35 .78 r
F P
0 g
s
.6227 .39095 m .63568 .37813 L .65046 .39507 L p 0 .35 .78 r
F P
0 g
s
.62088 .36116 m .63568 .37813 L .6227 .39095 L p 0 .35 .78 r
F P
0 g
s
.61147 .43379 m .59837 .4468 L .5864 .45233 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .62088 .36116 L .60786 .37395 L p 0 .35 .78 r
F P
0 g
s
.6227 .39095 m .60786 .37395 L .62088 .36116 L p 0 .35 .78 r
F P
0 g
s
.63752 .40792 m .62452 .42083 L .60966 .40383 L p 0 .35 .78 r
F P
0 g
s
.60966 .40383 m .6227 .39095 L .63752 .40792 L p 0 .35 .78 r
F P
0 g
s
.5941 .35041 m .58232 .35657 L .59695 .37331 L p 0 .318 .939 r
F P
0 g
s
.60786 .37395 m .59299 .35693 L .60606 .34416 L p 0 .35 .78 r
F P
0 g
s
.60786 .37395 m .6227 .39095 L .60966 .40383 L p 0 .35 .78 r
F P
0 g
s
.58134 .37056 m .55927 .36863 L .5737 .38512 L closepath p 0 .349 .781 r
F P
0 g
s
.59695 .37331 m .58524 .37926 L .57071 .36264 L p 0 .318 .939 r
F P
0 g
s
.57071 .36264 m .58524 .37926 L .59695 .37331 L p 0 .318 .939 r
F P
0 g
s
.57071 .36264 m .58232 .35657 L .59695 .37331 L p 0 .318 .939 r
F P
0 g
s
.59695 .37331 m .58232 .35657 L .57071 .36264 L p 0 .318 .939 r
F P
0 g
s
.58524 .37926 m .5737 .38512 L .55927 .36863 L p 0 .318 .939 r
F P
0 g
s
.55927 .36863 m .5737 .38512 L .58524 .37926 L p 0 .318 .939 r
F P
0 g
s
.55927 .36863 m .57071 .36264 L .58524 .37926 L p 0 .318 .939 r
F P
0 g
s
.58524 .37926 m .57071 .36264 L .55927 .36863 L p 0 .318 .939 r
F P
0 g
s
.58406 .38595 m .59695 .37331 L .58232 .35657 L p 0 .349 .781 r
F P
0 g
s
.58232 .35657 m .59695 .37331 L .58406 .38595 L p 0 .349 .781 r
F P
0 g
s
.59299 .35693 m .60786 .37395 L .59478 .38681 L p 0 .35 .78 r
F P
0 g
s
.60966 .40383 m .59478 .38681 L .60786 .37395 L p 0 .35 .78 r
F P
0 g
s
.62452 .42083 m .61147 .43379 L .59657 .41676 L p 0 .35 .78 r
F P
0 g
s
.59657 .41676 m .60966 .40383 L .62452 .42083 L p 0 .35 .78 r
F P
0 g
s
.58581 .4154 m .59871 .40269 L .58697 .40842 L p 0 .05 .1 r
F P
0 g
s
.58697 .40842 m .59871 .40269 L .58581 .4154 L p 0 .05 .1 r
F P
0 g
s
.57541 .41408 m .58811 .40158 L .5737 .38512 L p 0 .349 .781 r
F P
0 g
s
.58811 .40158 m .57541 .41408 L .58697 .40842 L p 0 .05 .1 r
F P
0 g
s
.58697 .40842 m .57541 .41408 L .58811 .40158 L p 0 .05 .1 r
F P
0 g
s
.57415 .42105 m .58697 .40842 L .57541 .41408 L p 0 .05 .1 r
F P
0 g
s
.57541 .41408 m .58697 .40842 L .57415 .42105 L p 0 .05 .1 r
F P
0 g
s
.58697 .40842 m .57415 .42105 L .58581 .4154 L p 0 .05 .1 r
F P
0 g
s
.58581 .4154 m .57415 .42105 L .58697 .40842 L p 0 .05 .1 r
F P
0 g
s
.58581 .4154 m .59871 .40269 L .58406 .38595 L p 0 .349 .781 r
F P
0 g
s
.58406 .38595 m .59871 .40269 L .58581 .4154 L p 0 .349 .781 r
F P
0 g
s
.59765 .40966 m .58581 .4154 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .58581 .4154 L .59765 .40966 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .58463 .42251 L .59765 .40966 L p 0 .05 .1 r
F P
0 g
s
.59765 .40966 m .58463 .42251 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.59478 .38681 m .60966 .40383 L .59657 .41676 L p 0 .35 .78 r
F P
0 g
s
.59943 .4394 m .58463 .42251 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.57286 .42816 m .58463 .42251 L .59943 .4394 L p 0 .317 .941 r
F P
0 g
s
.56298 .46314 m .57587 .45037 L .58756 .44493 L p 0 .05 .1 r
F P
0 g
s
.57712 .44311 m .56265 .42663 L .54985 .43923 L p 0 .349 .781 r
F P
0 g
s
.54985 .43923 m .56435 .45574 L .57712 .44311 L p 0 .349 .781 r
F P
0 g
s
.56127 .43374 m .57587 .45037 L .58756 .44493 L p 0 .317 .941 r
F P
0 g
s
.5746 .45777 m .58756 .44493 L .57587 .45037 L p 0 .05 .1 r
F P
0 g
s
.58756 .44493 m .57286 .42816 L .56127 .43374 L p 0 .317 .941 r
F P
0 g
s
.57286 .42816 m .58756 .44493 L .57587 .45037 L p 0 .317 .941 r
F P
0 g
s
.58756 .44493 m .5746 .45777 L .56298 .46314 L p 0 .05 .1 r
F P
0 g
s
.54985 .43923 m .56435 .45574 L .57587 .45037 L p 0 .317 .941 r
F P
0 g
s
.57587 .45037 m .56127 .43374 L .54985 .43923 L p 0 .317 .941 r
F P
0 g
s
.56435 .45574 m .54985 .43923 L .56127 .43374 L p 0 .317 .941 r
F P
0 g
s
.56127 .43374 m .57587 .45037 L .56435 .45574 L p 0 .317 .941 r
F P
0 g
s
.55153 .46842 m .56435 .45574 L .54985 .43923 L p 0 .349 .781 r
F P
0 g
s
.54985 .43923 m .53698 .45189 L .55153 .46842 L p 0 .349 .781 r
F P
0 g
s
.54834 .44648 m .56127 .43374 L .57587 .45037 L p 0 .349 .781 r
F P
0 g
s
.55153 .46842 m .56435 .45574 L .57587 .45037 L p 0 .05 .1 r
F P
0 g
s
.56435 .45574 m .55153 .46842 L .56298 .46314 L p 0 .05 .1 r
F P
0 g
s
.56298 .46314 m .57587 .45037 L .56435 .45574 L p 0 .05 .1 r
F P
0 g
s
.57587 .45037 m .56298 .46314 L .55153 .46842 L p 0 .05 .1 r
F P
0 g
s
.56298 .46314 m .57587 .45037 L .56127 .43374 L p 0 .349 .781 r
F P
0 g
s
.57587 .45037 m .56127 .43374 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.56127 .43374 m .54834 .44648 L .56298 .46314 L p 0 .349 .781 r
F P
0 g
s
.55986 .44098 m .57286 .42816 L .58756 .44493 L p 0 .349 .781 r
F P
0 g
s
.57587 .45037 m .56298 .46314 L .54834 .44648 L p 0 .349 .781 r
F P
0 g
s
.57587 .45037 m .56298 .46314 L .5746 .45777 L p 0 .05 .1 r
F P
0 g
s
.58756 .44493 m .5746 .45777 L .55986 .44098 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .58756 .44493 L .59943 .4394 L p 0 .317 .941 r
F P
0 g
s
.59943 .4394 m .58756 .44493 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.5746 .45777 m .58756 .44493 L .59943 .4394 L p 0 .05 .1 r
F P
0 g
s
.58756 .44493 m .5746 .45777 L .5864 .45233 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .59943 .4394 L .58756 .44493 L p 0 .05 .1 r
F P
0 g
s
.5746 .45777 m .58756 .44493 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.59943 .4394 m .5864 .45233 L .5746 .45777 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .59943 .4394 L .58463 .42251 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .55986 .44098 L .5746 .45777 L p 0 .349 .781 r
F P
0 g
s
.57155 .43541 m .58463 .42251 L .59943 .4394 L p 0 .349 .781 r
F P
0 g
s
.58463 .42251 m .57155 .43541 L .5864 .45233 L p 0 .349 .781 r
F P
0 g
s
.58342 .42975 m .59657 .41676 L .61147 .43379 L p 0 .35 .78 r
F P
0 g
s
.59943 .4394 m .5864 .45233 L .59837 .4468 L p 0 .05 .1 r
F P
0 g
s
.59943 .4394 m .5864 .45233 L .57155 .43541 L p 0 .349 .781 r
F P
0 g
s
.61147 .43379 m .59837 .4468 L .58342 .42975 L p 0 .35 .78 r
F P
0 g
s
.59609 .47739 m .66449 .40916 L .60924 .3458 L p .858 0 0 r
F P
0 g
s
.55328 .37495 m .56006 .37142 L p .51778 .41086 L .1 0 0 r
F P
0 g
s
.51494 .41231 m .55328 .37495 L p .51778 .41086 L .1 0 0 r
F P
0 g
s
.53374 .39368 m .55896 .36922 L .53379 .39374 L .932 0 0 r
F
.53374 .39368 m .53379 .39374 L .52531 .40201 L F
.52546 .40172 m .53374 .39368 L .52531 .40201 L F
.50709 .42232 m .51874 .41037 L .50415 .4238 L .1 0 0 r
F
.51874 .41037 m .51494 .41231 L .48587 .44063 L F
.48587 .44063 m .51494 .41231 L p .51778 .41086 L F P
0 g
s
.49158 .43458 m .52546 .40172 L .49129 .43515 L .932 0 0 r
F
.52546 .40172 m .52531 .40201 L .49129 .43515 L F
.51874 .41037 m .55328 .37495 L .51494 .41231 L .1 0 0 r
F
.49129 .43515 m .52531 .40201 L .52546 .40252 L .941 0 0 r
F
.49243 .43734 m .50093 .42862 L .48587 .44063 L .1 0 0 r
F
.50093 .42862 m .50709 .42232 L .50231 .42644 L F
.50093 .42862 m .50231 .42644 L .48587 .44063 L F
.50709 .42232 m .50415 .4238 L .48587 .44063 L F
.53532 .4227 m .52242 .43533 L .53698 .45189 L p 0 .349 .781 r
F P
0 g
s
.53532 .4227 m .52242 .43533 L .53367 .42979 L p 0 .05 .1 r
F P
0 g
s
.56006 .37142 m .5216 .40892 L p .51778 .41086 L .1 0 0 r
F P
0 g
s
.5216 .40892 m .50867 .42152 L p .51778 .41086 L .1 0 0 r
F P
0 g
s
.51095 .44729 m .51206 .44547 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.50024 .42974 m .49243 .43734 L p .50124 .42815 L .1 0 0 r
F P
0 g
s
.49243 .43734 m .48587 .44063 L p .50362 .42407 L .1 0 0 r
F P
0 g
s
.50362 .42407 m .50656 .42258 L .49243 .43734 L .1 0 0 r
F
.49129 .43515 m .49823 .42852 L .4916 .43616 L .941 0 0 r
F
.49823 .42852 m .49904 .42878 L .4916 .43616 L F
.50362 .42407 m .51778 .41086 L .50656 .42258 L .1 0 0 r
F
.52546 .40252 m .52561 .40302 L .4916 .43616 L .941 0 0 r
F
.50867 .42152 m .50024 .42974 L p .50656 .42258 L .1 0 0 r
F P
0 g
s
.50656 .42258 m .50024 .42974 L .50124 .42815 L .1 0 0 r
F
.51778 .41086 m .50867 .42152 L .50656 .42258 L F
.51874 .41037 m .56006 .37142 L .55328 .37495 L F
.49243 .43734 m .5216 .40892 L .51874 .41037 L F
.5216 .40892 m .56006 .37142 L .51874 .41037 L F
.4916 .43616 m .52113 .40824 L .49243 .43734 L .881 0 0 r
F
.52113 .40824 m .52602 .40361 L .52124 .40841 L F
.52113 .40824 m .52124 .40841 L .49243 .43734 L F
.49823 .42852 m .52546 .40252 L .49904 .42878 L .941 0 0 r
F
.52602 .40361 m .56006 .37142 L .52643 .4042 L .881 0 0 r
F
.52602 .40361 m .52643 .4042 L .49243 .43734 L F
.55925 .37024 m .55328 .37495 L .56006 .37142 L .577 0 0 r
F
.4916 .43616 m .55925 .37024 L .56006 .37142 L .881 0 0 r
F
.49158 .43458 m .55927 .36863 L .55896 .36922 L .932 0 0 r
F
.52546 .40252 m .5337 .39433 L .53372 .39463 L .941 0 0 r
F
.5337 .39433 m .55896 .36922 L .53372 .39463 L F
.53372 .39463 m .55896 .36922 L .55925 .37024 L F
.52531 .40201 m .55896 .36922 L .52546 .40252 L F
.52546 .40252 m .55925 .37024 L .52561 .40302 L F
.53366 .39358 m .52077 .40614 L .53532 .4227 L p 0 .349 .781 r
F P
0 g
s
.532 .40039 m .52077 .40614 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.53395 .40262 m .532 .40039 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.52077 .40614 m .532 .40039 L .53395 .40262 L p 0 .317 .941 r
F P
0 g
s
.53532 .4227 m .54817 .41012 L .53366 .39358 L p 0 .349 .781 r
F P
0 g
s
.54817 .41012 m .53532 .4227 L .54985 .43923 L p 0 .349 .781 r
F P
0 g
s
.54664 .41708 m .53395 .40262 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.53395 .40262 m .54664 .41708 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.5242 .40759 m .52077 .40614 L .53395 .40262 L 0 .317 .941 r
F
.4963 .43066 m .49826 .43288 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.49826 .43288 m .51095 .44729 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.52077 .40614 m .50783 .41874 L .52242 .43533 L p 0 .349 .781 r
F P
0 g
s
.51898 .41308 m .50783 .41874 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.52242 .43533 m .52978 .42813 L p .52182 .42472 L 0 .349 .781 r
F P
0 g
s
.52978 .42813 m .53532 .4227 L p .52182 .42472 L 0 .349 .781 r
F P
0 g
s
.53532 .4227 m .52077 .40614 L p .52182 .42472 L 0 .349 .781 r
F P
0 g
s
.54985 .43923 m .56265 .42663 L .54817 .41012 L p 0 .349 .781 r
F P
0 g
s
.56265 .42663 m .54985 .43923 L .56127 .43374 L p 0 .05 .1 r
F P
0 g
s
.56127 .43374 m .54985 .43923 L .56265 .42663 L p 0 .05 .1 r
F P
0 g
s
.53532 .4227 m .54985 .43923 L .56127 .43374 L p 0 .317 .941 r
F P
0 g
s
.53698 .45189 m .54985 .43923 L .53532 .4227 L p 0 .349 .781 r
F P
0 g
s
.56127 .43374 m .54985 .43923 L .53532 .4227 L p 0 .317 .941 r
F P
0 g
s
.56127 .43374 m .54664 .41708 L .53532 .4227 L p 0 .317 .941 r
F P
0 g
s
.53532 .4227 m .54664 .41708 L .56127 .43374 L p 0 .317 .941 r
F P
0 g
s
.52242 .43533 m .53532 .4227 L .54664 .41708 L p 0 .05 .1 r
F P
0 g
s
.54664 .41708 m .53367 .42979 L .52242 .43533 L p 0 .05 .1 r
F P
0 g
s
.53367 .42979 m .52094 .41531 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.52094 .41531 m .51898 .41308 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.52242 .43533 m .53367 .42979 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.50783 .41874 m .50978 .42096 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.50978 .42096 m .52242 .43533 L p .51125 .42021 L 0 .316 .942 r
F P
0 g
s
.49744 .42887 m .4963 .43066 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.51206 .44547 m .49939 .43108 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.49939 .43108 m .49744 .42887 L p .49841 .43264 L 0 .332 .559 r
F P
0 g
s
.50783 .41874 m .51898 .41308 L p .51945 .41607 L 0 .316 .942 r
F P
0 g
s
.52242 .43533 m .50978 .42096 L p .51945 .41607 L 0 .316 .942 r
F P
0 g
s
.50978 .42096 m .50783 .41874 L p .51945 .41607 L 0 .316 .942 r
F P
0 g
s
.53532 .4227 m .54664 .41708 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.52271 .40835 m .53532 .4227 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.54664 .41708 m .53532 .4227 L .52271 .40835 L p 0 .317 .941 r
F P
0 g
s
.52077 .40614 m .52271 .40835 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.52271 .40835 m .52077 .40614 L p .5242 .40759 L 0 .317 .941 r
F P
0 g
s
.54664 .41708 m .52271 .40835 L .5242 .40759 L 0 .317 .941 r
F
.56096 .39759 m .5737 .38512 L .5612 .37083 L p 0 .349 .781 r
F P
0 g
s
.5612 .37083 m .55927 .36863 L p .5595 .37249 L 0 .349 .781 r
F P
0 g
s
.56096 .39759 m .5612 .37083 L .5595 .37249 L 0 .349 .781 r
F
.5737 .38512 m .56096 .39759 L .57541 .41408 L p F P
0 g
s
.55927 .36863 m .54649 .38108 L .56096 .39759 L p 0 .349 .781 r
F P
0 g
s
.56265 .42663 m .57541 .41408 L .56096 .39759 L p 0 .349 .781 r
F P
0 g
s
.57541 .41408 m .56265 .42663 L .57415 .42105 L p 0 .05 .1 r
F P
0 g
s
.57415 .42105 m .56265 .42663 L .57541 .41408 L p 0 .05 .1 r
F P
0 g
s
.54817 .41012 m .56096 .39759 L .54649 .38108 L p 0 .349 .781 r
F P
0 g
s
.56096 .39759 m .54817 .41012 L .56265 .42663 L p 0 .349 .781 r
F P
0 g
s
.54649 .38108 m .53366 .39358 L .54817 .41012 L p 0 .349 .781 r
F P
0 g
s
.56127 .43374 m .57415 .42105 L .56265 .42663 L p 0 .05 .1 r
F P
0 g
s
.56265 .42663 m .57415 .42105 L .56127 .43374 L p 0 .05 .1 r
F P
0 g
s
.53698 .45189 m .54985 .43923 L .56127 .43374 L p 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .56127 .43374 L .54985 .43923 L p 0 .05 .1 r
F P
0 g
s
.53367 .42979 m .54664 .41708 L .53532 .4227 L p 0 .05 .1 r
F P
0 g
s
.56127 .43374 m .54834 .44648 L .53698 .45189 L p 0 .05 .1 r
F P
0 g
s
.57415 .42105 m .56127 .43374 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .58581 .4154 L .57415 .42105 L p 0 .05 .1 r
F P
0 g
s
.57415 .42105 m .58581 .4154 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .56127 .43374 L .57415 .42105 L p 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .56127 .43374 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.53367 .42979 m .54664 .41708 L .56127 .43374 L p 0 .349 .781 r
F P
0 g
s
.54985 .43923 m .53698 .45189 L .54834 .44648 L p 0 .05 .1 r
F P
0 g
s
.56127 .43374 m .54834 .44648 L .53367 .42979 L p 0 .349 .781 r
F P
0 g
s
.54664 .41708 m .56127 .43374 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.55986 .44098 m .57286 .42816 L .56127 .43374 L p 0 .05 .1 r
F P
0 g
s
.56127 .43374 m .54834 .44648 L .55986 .44098 L p 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .56127 .43374 L .54664 .41708 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .56127 .43374 L .54664 .41708 L p 0 .317 .941 r
F P
0 g
s
.51898 .41308 m .532 .40039 L .54664 .41708 L p 0 .349 .781 r
F P
0 g
s
.54664 .41708 m .53367 .42979 L .51898 .41308 L p 0 .349 .781 r
F P
0 g
s
.532 .40039 m .54664 .41708 L .55814 .41138 L p 0 .317 .941 r
F P
0 g
s
.57286 .42816 m .55814 .41138 L .54664 .41708 L p 0 .317 .941 r
F P
0 g
s
.54664 .41708 m .53367 .42979 L .54834 .44648 L p 0 .349 .781 r
F P
0 g
s
.54664 .41708 m .55814 .41138 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.54509 .42417 m .55814 .41138 L .54664 .41708 L p 0 .05 .1 r
F P
0 g
s
.54664 .41708 m .53367 .42979 L .54509 .42417 L p 0 .05 .1 r
F P
0 g
s
.53367 .42979 m .54664 .41708 L .532 .40039 L p 0 .349 .781 r
F P
0 g
s
.53367 .42979 m .54664 .41708 L .55814 .41138 L p 0 .05 .1 r
F P
0 g
s
.55814 .41138 m .54664 .41708 L .532 .40039 L p 0 .317 .941 r
F P
0 g
s
.55814 .41138 m .54339 .39456 L .532 .40039 L p 0 .317 .941 r
F P
0 g
s
.532 .40039 m .54339 .39456 L .55814 .41138 L p 0 .317 .941 r
F P
0 g
s
.57286 .42816 m .55986 .44098 L .54834 .44648 L p 0 .05 .1 r
F P
0 g
s
.58232 .35657 m .5694 .36918 L .58406 .38595 L p 0 .349 .781 r
F P
0 g
s
.58406 .38595 m .5694 .36918 L .58232 .35657 L p 0 .349 .781 r
F P
0 g
s
.55814 .41138 m .54509 .42417 L .53367 .42979 L p 0 .05 .1 r
F P
0 g
s
.57113 .39864 m .58406 .38595 L .5694 .36918 L p 0 .349 .781 r
F P
0 g
s
.58406 .38595 m .57113 .39864 L .58581 .4154 L p 0 .349 .781 r
F P
0 g
s
.5694 .36918 m .58406 .38595 L .57113 .39864 L p 0 .349 .781 r
F P
0 g
s
.58581 .4154 m .57113 .39864 L .58406 .38595 L p 0 .349 .781 r
F P
0 g
s
.5694 .36918 m .55642 .38185 L .57113 .39864 L p 0 .349 .781 r
F P
0 g
s
.57113 .39864 m .55642 .38185 L .5694 .36918 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .58581 .4154 L .57113 .39864 L p 0 .349 .781 r
F P
0 g
s
.57113 .39864 m .58581 .4154 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.55814 .41138 m .57113 .39864 L .55642 .38185 L p 0 .349 .781 r
F P
0 g
s
.57113 .39864 m .55814 .41138 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.55642 .38185 m .57113 .39864 L .55814 .41138 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .55814 .41138 L .57113 .39864 L p 0 .349 .781 r
F P
0 g
s
.55642 .38185 m .54339 .39456 L .55814 .41138 L p 0 .349 .781 r
F P
0 g
s
.55814 .41138 m .54339 .39456 L .55642 .38185 L p 0 .349 .781 r
F P
0 g
s
.54509 .42417 m .55814 .41138 L .57286 .42816 L p 0 .349 .781 r
F P
0 g
s
.57286 .42816 m .55986 .44098 L .54509 .42417 L p 0 .349 .781 r
F P
0 g
s
.55814 .41138 m .57286 .42816 L .58463 .42251 L p 0 .317 .941 r
F P
0 g
s
.58463 .42251 m .5698 .40559 L .55814 .41138 L p 0 .317 .941 r
F P
0 g
s
.5698 .40559 m .58463 .42251 L .57286 .42816 L p 0 .317 .941 r
F P
0 g
s
.57286 .42816 m .55814 .41138 L .5698 .40559 L p 0 .317 .941 r
F P
0 g
s
.55986 .44098 m .57286 .42816 L .58463 .42251 L p 0 .05 .1 r
F P
0 g
s
.57155 .43541 m .58463 .42251 L .57286 .42816 L p 0 .05 .1 r
F P
0 g
s
.57286 .42816 m .55986 .44098 L .57155 .43541 L p 0 .05 .1 r
F P
0 g
s
.55986 .44098 m .57286 .42816 L .55814 .41138 L p 0 .349 .781 r
F P
0 g
s
.532 .40039 m .51898 .41308 L .53367 .42979 L p 0 .349 .781 r
F P
0 g
s
.53031 .40733 m .54339 .39456 L .55814 .41138 L p 0 .349 .781 r
F P
0 g
s
.55814 .41138 m .54509 .42417 L .53031 .40733 L p 0 .349 .781 r
F P
0 g
s
.54339 .39456 m .55814 .41138 L .5698 .40559 L p 0 .317 .941 r
F P
0 g
s
.5698 .40559 m .55496 .38864 L .54339 .39456 L p 0 .317 .941 r
F P
0 g
s
.55496 .38864 m .5698 .40559 L .55814 .41138 L p 0 .317 .941 r
F P
0 g
s
.55814 .41138 m .54339 .39456 L .55496 .38864 L p 0 .317 .941 r
F P
0 g
s
.55814 .41138 m .54509 .42417 L .55986 .44098 L p 0 .349 .781 r
F P
0 g
s
.55669 .41847 m .5698 .40559 L .55814 .41138 L p 0 .05 .1 r
F P
0 g
s
.55814 .41138 m .54509 .42417 L .55669 .41847 L p 0 .05 .1 r
F P
0 g
s
.54509 .42417 m .55814 .41138 L .54339 .39456 L p 0 .349 .781 r
F P
0 g
s
.54509 .42417 m .55814 .41138 L .5698 .40559 L p 0 .05 .1 r
F P
0 g
s
.56158 .47067 m .5746 .45777 L .5864 .45233 L p 0 .05 .1 r
F P
0 g
s
.5746 .45777 m .55986 .44098 L .57155 .43541 L p 0 .316 .942 r
F P
0 g
s
.57155 .43541 m .5864 .45233 L .5746 .45777 L p 0 .316 .942 r
F P
0 g
s
.55986 .44098 m .5746 .45777 L .5864 .45233 L p 0 .316 .942 r
F P
0 g
s
.57331 .46531 m .5864 .45233 L .5746 .45777 L p 0 .05 .1 r
F P
0 g
s
.54339 .39456 m .53031 .40733 L .54509 .42417 L p 0 .349 .781 r
F P
0 g
s
.58463 .42251 m .57155 .43541 L .55986 .44098 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .57155 .43541 L .55986 .44098 L p 0 .316 .942 r
F P
0 g
s
.55153 .46842 m .53698 .45189 L .54834 .44648 L p 0 .316 .942 r
F P
0 g
s
.54834 .44648 m .56298 .46314 L .55153 .46842 L p 0 .316 .942 r
F P
0 g
s
.56298 .46314 m .54834 .44648 L .53698 .45189 L p 0 .316 .942 r
F P
0 g
s
.56298 .46314 m .54834 .44648 L .55986 .44098 L p 0 .316 .942 r
F P
0 g
s
.55986 .44098 m .5746 .45777 L .56298 .46314 L p 0 .316 .942 r
F P
0 g
s
.53698 .45189 m .55153 .46842 L .56298 .46314 L p 0 .316 .942 r
F P
0 g
s
.53535 .45927 m .54834 .44648 L .56298 .46314 L p 0 .349 .781 r
F P
0 g
s
.54834 .44648 m .56298 .46314 L .5746 .45777 L p 0 .316 .942 r
F P
0 g
s
.55004 .47595 m .56298 .46314 L .55153 .46842 L p 0 .05 .1 r
F P
0 g
s
.55004 .47595 m .56298 .46314 L .54834 .44648 L p 0 .349 .781 r
F P
0 g
s
.5746 .45777 m .55986 .44098 L .54834 .44648 L p 0 .316 .942 r
F P
0 g
s
.54834 .44648 m .53535 .45927 L .55004 .47595 L p 0 .349 .781 r
F P
0 g
s
.5468 .45386 m .55986 .44098 L .5746 .45777 L p 0 .349 .781 r
F P
0 g
s
.55004 .47595 m .56298 .46314 L .5746 .45777 L p 0 .05 .1 r
F P
0 g
s
.56298 .46314 m .55004 .47595 L .53535 .45927 L p 0 .349 .781 r
F P
0 g
s
.56298 .46314 m .55004 .47595 L .56158 .47067 L p 0 .05 .1 r
F P
0 g
s
.56158 .47067 m .5746 .45777 L .56298 .46314 L p 0 .05 .1 r
F P
0 g
s
.5746 .45777 m .56158 .47067 L .55004 .47595 L p 0 .05 .1 r
F P
0 g
s
.56158 .47067 m .5746 .45777 L .55986 .44098 L p 0 .349 .781 r
F P
0 g
s
.55986 .44098 m .5468 .45386 L .56158 .47067 L p 0 .349 .781 r
F P
0 g
s
.5468 .45386 m .55986 .44098 L .57155 .43541 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .57155 .43541 L .55986 .44098 L p 0 .316 .942 r
F P
0 g
s
.55986 .44098 m .54509 .42417 L .55669 .41847 L p 0 .316 .942 r
F P
0 g
s
.54509 .42417 m .55986 .44098 L .57155 .43541 L p 0 .316 .942 r
F P
0 g
s
.55842 .44837 m .57155 .43541 L .55986 .44098 L p 0 .05 .1 r
F P
0 g
s
.5698 .40559 m .55669 .41847 L .54509 .42417 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .54509 .42417 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.5418 .4015 m .54378 .40376 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.54378 .40376 m .55669 .41847 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.53031 .40733 m .5418 .4015 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.54509 .42417 m .53228 .40958 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.53228 .40958 m .53031 .40733 L p .54224 .40454 L 0 .316 .942 r
F P
0 g
s
.53031 .40733 m .54509 .42417 L .55669 .41847 L p 0 .316 .942 r
F P
0 g
s
.54509 .42417 m .55986 .44098 L .54834 .44648 L p 0 .316 .942 r
F P
0 g
s
.54834 .44648 m .53367 .42979 L .54509 .42417 L p 0 .316 .942 r
F P
0 g
s
.55986 .44098 m .54509 .42417 L .53367 .42979 L p 0 .316 .942 r
F P
0 g
s
.53367 .42979 m .54834 .44648 L .53698 .45189 L p 0 .316 .942 r
F P
0 g
s
.53698 .45189 m .52242 .43533 L .53367 .42979 L p 0 .316 .942 r
F P
0 g
s
.54834 .44648 m .53367 .42979 L .52242 .43533 L p 0 .316 .942 r
F P
0 g
s
.52242 .43533 m .53698 .45189 L .54834 .44648 L p 0 .316 .942 r
F P
0 g
s
.52666 .46205 m .53698 .45189 L .52242 .43533 L p 0 .349 .781 r
F P
0 g
s
.52242 .43533 m .51206 .44547 L .52666 .46205 L p 0 .349 .781 r
F P
0 g
s
.52065 .44256 m .53367 .42979 L .54834 .44648 L p 0 .349 .781 r
F P
0 g
s
.52666 .46205 m .53698 .45189 L .54834 .44648 L p 0 .05 .1 r
F P
0 g
s
.53535 .45927 m .54834 .44648 L .53698 .45189 L p 0 .05 .1 r
F P
0 g
s
.52557 .46389 m .53535 .45927 L p .53698 .45189 L 0 .05 .1 r
F P
0 g
s
.53698 .45189 m .52666 .46205 L .52557 .46389 L p 0 .05 .1 r
F P
0 g
s
.52557 .46389 m .52666 .46205 L p .54834 .44648 L 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .53535 .45927 L .52557 .46389 L p 0 .05 .1 r
F P
0 g
s
.53535 .45927 m .54834 .44648 L .53367 .42979 L p 0 .349 .781 r
F P
0 g
s
.53367 .42979 m .54834 .44648 L .55986 .44098 L p 0 .316 .942 r
F P
0 g
s
.53367 .42979 m .52065 .44256 L .53535 .45927 L p 0 .349 .781 r
F P
0 g
s
.532 .43702 m .54509 .42417 L .55986 .44098 L p 0 .349 .781 r
F P
0 g
s
.53535 .45927 m .54834 .44648 L .55986 .44098 L p 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .53535 .45927 L .52065 .44256 L p 0 .349 .781 r
F P
0 g
s
.5468 .45386 m .55986 .44098 L .54834 .44648 L p 0 .05 .1 r
F P
0 g
s
.54834 .44648 m .53535 .45927 L .5468 .45386 L p 0 .05 .1 r
F P
0 g
s
.55986 .44098 m .5468 .45386 L .53535 .45927 L p 0 .05 .1 r
F P
0 g
s
.5468 .45386 m .55986 .44098 L .54509 .42417 L p 0 .349 .781 r
F P
0 g
s
.57155 .43541 m .55669 .41847 L .54509 .42417 L p 0 .316 .942 r
F P
0 g
s
.54509 .42417 m .532 .43702 L .5468 .45386 L p 0 .349 .781 r
F P
0 g
s
.54351 .4314 m .55669 .41847 L .54509 .42417 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .54509 .42417 L .55669 .41847 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .57331 .46531 L .56158 .47067 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .5418 .4015 L .53031 .40733 L p 0 .316 .942 r
F P
0 g
s
.57155 .43541 m .55842 .44837 L .5468 .45386 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .54351 .4314 L .532 .43702 L p 0 .05 .1 r
F P
0 g
s
.57155 .43541 m .58463 .42251 L .59657 .41676 L p 0 .05 .1 r
F P
0 g
s
.5698 .40559 m .58463 .42251 L .59657 .41676 L p 0 .317 .941 r
F P
0 g
s
.58342 .42975 m .59657 .41676 L .58463 .42251 L p 0 .05 .1 r
F P
0 g
s
.58463 .42251 m .57155 .43541 L .58342 .42975 L p 0 .05 .1 r
F P
0 g
s
.57155 .43541 m .58463 .42251 L .5698 .40559 L p 0 .349 .781 r
F P
0 g
s
.55669 .41847 m .5698 .40559 L .58463 .42251 L p 0 .349 .781 r
F P
0 g
s
.58463 .42251 m .57155 .43541 L .55669 .41847 L p 0 .349 .781 r
F P
0 g
s
.59657 .41676 m .58164 .39971 L .5698 .40559 L p 0 .317 .941 r
F P
0 g
s
.58164 .39971 m .59657 .41676 L .58463 .42251 L p 0 .317 .941 r
F P
0 g
s
.58463 .42251 m .5698 .40559 L .58164 .39971 L p 0 .317 .941 r
F P
0 g
s
.5698 .40559 m .58164 .39971 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.55496 .38864 m .55694 .39091 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.55694 .39091 m .5698 .40559 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.5698 .40559 m .55669 .41847 L .57155 .43541 L p 0 .349 .781 r
F P
0 g
s
.56845 .41268 m .58164 .39971 L .5698 .40559 L p 0 .05 .1 r
F P
0 g
s
.5698 .40559 m .55669 .41847 L .56845 .41268 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .5698 .40559 L .55496 .38864 L p 0 .349 .781 r
F P
0 g
s
.5418 .4015 m .55496 .38864 L .5698 .40559 L p 0 .349 .781 r
F P
0 g
s
.5698 .40559 m .55669 .41847 L .5418 .4015 L p 0 .349 .781 r
F P
0 g
s
.55669 .41847 m .5698 .40559 L .58164 .39971 L p 0 .05 .1 r
F P
0 g
s
.56669 .38264 m .55496 .38864 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.58164 .39971 m .56869 .38492 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.56869 .38492 m .56669 .38264 L p .55849 .39011 L 0 .317 .941 r
F P
0 g
s
.58164 .39971 m .5698 .40559 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.56869 .38492 m .58164 .39971 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.55496 .38864 m .56669 .38264 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.5698 .40559 m .55694 .39091 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.55694 .39091 m .55496 .38864 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.57331 .46531 m .5864 .45233 L .59837 .4468 L p 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .57331 .46531 L .58361 .4606 L p 0 .05 .1 r
F P
0 g
s
.59837 .4468 m .5864 .45233 L p .58361 .4606 L 0 .05 .1 r
F P
0 g
s
.5864 .45233 m .57155 .43541 L .58342 .42975 L p 0 .316 .942 r
F P
0 g
s
.58342 .42975 m .59837 .4468 L .5864 .45233 L p 0 .316 .942 r
F P
0 g
s
.57155 .43541 m .5864 .45233 L .59837 .4468 L p 0 .316 .942 r
F P
0 g
s
.5746 .45777 m .56158 .47067 L .5468 .45386 L p 0 .349 .781 r
F P
0 g
s
.5746 .45777 m .56158 .47067 L .57331 .46531 L p 0 .05 .1 r
F P
0 g
s
.57331 .46531 m .5864 .45233 L .57155 .43541 L p 0 .349 .781 r
F P
0 g
s
.55842 .44837 m .57155 .43541 L .5864 .45233 L p 0 .349 .781 r
F P
0 g
s
.5864 .45233 m .57331 .46531 L .55842 .44837 L p 0 .349 .781 r
F P
0 g
s
.55496 .38864 m .5418 .4015 L .55669 .41847 L p 0 .349 .781 r
F P
0 g
s
.59657 .41676 m .58342 .42975 L .57155 .43541 L p 0 .05 .1 r
F P
0 g
s
.59837 .4468 m .58342 .42975 L .57155 .43541 L p 0 .316 .942 r
F P
0 g
s
.57155 .43541 m .55842 .44837 L .57331 .46531 L p 0 .349 .781 r
F P
0 g
s
.55842 .44837 m .57155 .43541 L .58342 .42975 L p 0 .05 .1 r
F P
0 g
s
.56845 .41268 m .58342 .42975 L .57155 .43541 L p 0 .316 .942 r
F P
0 g
s
.57155 .43541 m .55669 .41847 L .56845 .41268 L p 0 .316 .942 r
F P
0 g
s
.57286 .44018 m .58342 .42975 L .57155 .43541 L p 0 .05 .1 r
F P
0 g
s
.56863 .44354 m .57286 .44018 L p .57155 .43541 L 0 .05 .1 r
F P
0 g
s
.57155 .43541 m .55842 .44837 L .56863 .44354 L p 0 .05 .1 r
F P
0 g
s
.55986 .44098 m .5468 .45386 L .532 .43702 L p 0 .349 .781 r
F P
0 g
s
.55986 .44098 m .5468 .45386 L .55842 .44837 L p 0 .05 .1 r
F P
0 g
s
.55842 .44837 m .57155 .43541 L .55669 .41847 L p 0 .349 .781 r
F P
0 g
s
.54351 .4314 m .55669 .41847 L .57155 .43541 L p 0 .349 .781 r
F P
0 g
s
.57155 .43541 m .55842 .44837 L .54351 .4314 L p 0 .349 .781 r
F P
0 g
s
.55669 .41847 m .57155 .43541 L .58342 .42975 L p 0 .316 .942 r
F P
0 g
s
.58164 .39971 m .56845 .41268 L .55669 .41847 L p 0 .05 .1 r
F P
0 g
s
.56845 .41268 m .55669 .41847 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.55346 .39558 m .55546 .39786 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.55546 .39786 m .56845 .41268 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.5418 .4015 m .55346 .39558 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.55669 .41847 m .54378 .40376 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.54378 .40376 m .5418 .4015 L p .55389 .39865 L 0 .316 .942 r
F P
0 g
s
.5418 .4015 m .55669 .41847 L .56845 .41268 L p 0 .316 .942 r
F P
0 g
s
.58342 .42975 m .56845 .41268 L .55669 .41847 L p 0 .316 .942 r
F P
0 g
s
.55786 .42309 m .56845 .41268 L .55669 .41847 L p 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .54351 .4314 L .55842 .44837 L p 0 .349 .781 r
F P
0 g
s
.55364 .42646 m .55786 .42309 L p .55669 .41847 L 0 .05 .1 r
F P
0 g
s
.55669 .41847 m .54351 .4314 L .55364 .42646 L p 0 .05 .1 r
F P
0 g
s
.53031 .40733 m .54509 .42417 L .53367 .42979 L p 0 .316 .942 r
F P
0 g
s
.51898 .41308 m .53367 .42979 L .54509 .42417 L p 0 .316 .942 r
F P
0 g
s
.532 .43702 m .54509 .42417 L .53367 .42979 L p 0 .05 .1 r
F P
0 g
s
.52065 .44256 m .53367 .42979 L .54509 .42417 L p 0 .05 .1 r
F P
0 g
s
.54509 .42417 m .53031 .40733 L .51898 .41308 L p 0 .316 .942 r
F P
0 g
s
.54509 .42417 m .532 .43702 L .52065 .44256 L p 0 .05 .1 r
F P
0 g
s
.51898 .41308 m .53367 .42979 L .52242 .43533 L p 0 .316 .942 r
F P
0 g
s
.53367 .42979 m .51898 .41308 L .53031 .40733 L p 0 .316 .942 r
F P
0 g
s
.51206 .44547 m .52242 .43533 L .50783 .41874 L p 0 .349 .781 r
F P
0 g
s
.50783 .41874 m .49744 .42887 L .51206 .44547 L p 0 .349 .781 r
F P
0 g
s
.50592 .42582 m .51898 .41308 L .53367 .42979 L p 0 .349 .781 r
F P
0 g
s
.52065 .44256 m .53367 .42979 L .52242 .43533 L p 0 .05 .1 r
F P
0 g
s
.52666 .46205 m .51206 .44547 L .51095 .44729 L p 0 .332 .559 r
F P
0 g
s
.51095 .44729 m .52065 .44256 L p .52242 .43533 L 0 .05 .1 r
F P
0 g
s
.52242 .43533 m .51206 .44547 L .51095 .44729 L p 0 .05 .1 r
F P
0 g
s
.52242 .43533 m .53367 .42979 L p .51095 .44729 L 0 .05 .1 r
F P
0 g
s
.51095 .44729 m .51206 .44547 L .52242 .43533 L p 0 .05 .1 r
F P
0 g
s
.53367 .42979 m .52065 .44256 L .51095 .44729 L p 0 .05 .1 r
F P
0 g
s
.52065 .44256 m .53367 .42979 L .51898 .41308 L p 0 .349 .781 r
F P
0 g
s
.51898 .41308 m .50592 .42582 L .52065 .44256 L p 0 .349 .781 r
F P
0 g
s
.51717 .42016 m .53031 .40733 L .54509 .42417 L p 0 .349 .781 r
F P
0 g
s
.53367 .42979 m .52065 .44256 L .50592 .42582 L p 0 .349 .781 r
F P
0 g
s
.53367 .42979 m .52065 .44256 L .532 .43702 L p 0 .05 .1 r
F P
0 g
s
.54509 .42417 m .532 .43702 L .51717 .42016 L p 0 .349 .781 r
F P
0 g
s
.54509 .42417 m .532 .43702 L .54351 .4314 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .54509 .42417 L .53031 .40733 L p 0 .349 .781 r
F P
0 g
s
.54351 .4314 m .55669 .41847 L .5418 .4015 L p 0 .349 .781 r
F P
0 g
s
.53031 .40733 m .51717 .42016 L .532 .43702 L p 0 .349 .781 r
F P
0 g
s
.52858 .4144 m .5418 .4015 L .55669 .41847 L p 0 .349 .781 r
F P
0 g
s
.55669 .41847 m .54351 .4314 L .52858 .4144 L p 0 .349 .781 r
F P
0 g
s
.54351 .4314 m .55669 .41847 L .56845 .41268 L p 0 .05 .1 r
F P
0 g
s
.58361 .4606 m .57331 .46531 L p .59837 .4468 L 0 .05 .1 r
F P
0 g
s
.57331 .46531 m .55842 .44837 L .56863 .44354 L p 0 .316 .943 r
F P
0 g
s
.56863 .44354 m .58361 .4606 L .57331 .46531 L p 0 .316 .943 r
F P
0 g
s
.55842 .44837 m .57331 .46531 L .58361 .4606 L p 0 .316 .943 r
F P
0 g
s
.56336 .47518 m .57331 .46531 L .58361 .4606 L p 0 .05 .1 r
F P
0 g
s
.56763 .47324 m .58361 .4606 L .57331 .46531 L p 0 .05 .1 r
F P
0 g
s
.56845 .41268 m .55346 .39558 L .5418 .4015 L p 0 .316 .942 r
F P
0 g
s
.5418 .4015 m .52858 .4144 L .54351 .4314 L p 0 .349 .781 r
F P
0 g
s
.56863 .44354 m .55842 .44837 L p .58342 .42975 L 0 .05 .1 r
F P
0 g
s
.58361 .4606 m .56863 .44354 L .55842 .44837 L p 0 .316 .943 r
F P
0 g
s
.55004 .47595 m .53535 .45927 L .5468 .45386 L p 0 .316 .943 r
F P
0 g
s
.5468 .45386 m .56158 .47067 L .55004 .47595 L p 0 .316 .943 r
F P
0 g
s
.56158 .47067 m .5468 .45386 L .53535 .45927 L p 0 .316 .943 r
F P
0 g
s
.53535 .45927 m .55004 .47595 L .54016 .48046 L p 0 .316 .943 r
F P
0 g
s
.52231 .47211 m .53535 .45927 L .55004 .47595 L p 0 .349 .781 r
F P
0 g
s
.53535 .45927 m .55004 .47595 L .56158 .47067 L p 0 .316 .943 r
F P
0 g
s
.54016 .48046 m .53608 .48756 L .5402 .48569 L p 0 .05 .1 r
F P
0 g
s
.5402 .48569 m .55004 .47595 L .54016 .48046 L p 0 .05 .1 r
F P
0 g
s
.55004 .47595 m .5402 .48569 L .53608 .48756 L p 0 .05 .1 r
F P
0 g
s
.5402 .48569 m .55004 .47595 L .53535 .45927 L p 0 .349 .781 r
F P
0 g
s
.53861 .48494 m .5402 .48569 L p .53535 .45927 L 0 .349 .781 r
F P
0 g
s
.52966 .47905 m .53861 .48494 L p .53535 .45927 L 0 .349 .781 r
F P
0 g
s
.53369 .46679 m .5468 .45386 L .56158 .47067 L p 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .5468 .45386 L .55842 .44837 L p 0 .316 .943 r
F P
0 g
s
.55842 .44837 m .57331 .46531 L .56158 .47067 L p 0 .316 .943 r
F P
0 g
s
.5468 .45386 m .56158 .47067 L .57331 .46531 L p 0 .316 .943 r
F P
0 g
s
.55004 .47595 m .5402 .48569 L .5495 .49004 L p 0 .349 .781 r
F P
0 g
s
.5402 .48569 m .55004 .47595 L .56158 .47067 L p 0 .05 .1 r
F P
0 g
s
.55169 .48047 m .56158 .47067 L .55004 .47595 L p 0 .05 .1 r
F P
0 g
s
.56158 .47067 m .55169 .48047 L .5402 .48569 L p 0 .05 .1 r
F P
0 g
s
.55169 .48047 m .56158 .47067 L .5468 .45386 L p 0 .349 .781 r
F P
0 g
s
.57331 .46531 m .55842 .44837 L .5468 .45386 L p 0 .316 .943 r
F P
0 g
s
.52966 .47905 m .52231 .47211 L p .55004 .47595 L 0 .349 .781 r
F P
0 g
s
.53861 .48494 m .52966 .47905 L p .55004 .47595 L 0 .349 .781 r
F P
0 g
s
.55004 .47595 m .5402 .48569 L .53861 .48494 L p 0 .349 .781 r
F P
0 g
s
.55004 .47595 m .5402 .48569 L .55169 .48047 L p 0 .05 .1 r
F P
0 g
s
.55009 .47972 m .55169 .48047 L p .5468 .45386 L 0 .349 .781 r
F P
0 g
s
.54108 .47377 m .55009 .47972 L p .5468 .45386 L 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .55169 .48047 L .56106 .48486 L p 0 .349 .781 r
F P
0 g
s
.55169 .48047 m .56158 .47067 L .57331 .46531 L p 0 .05 .1 r
F P
0 g
s
.56336 .47518 m .57331 .46531 L .56158 .47067 L p 0 .05 .1 r
F P
0 g
s
.57331 .46531 m .56336 .47518 L .55169 .48047 L p 0 .05 .1 r
F P
0 g
s
.56336 .47518 m .57331 .46531 L .55842 .44837 L p 0 .349 .781 r
F P
0 g
s
.54524 .46138 m .55842 .44837 L .57331 .46531 L p 0 .349 .781 r
F P
0 g
s
.54108 .47377 m .53369 .46679 L p .56158 .47067 L 0 .349 .781 r
F P
0 g
s
.55009 .47972 m .54108 .47377 L p .56158 .47067 L 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .55169 .48047 L .55009 .47972 L p 0 .349 .781 r
F P
0 g
s
.56158 .47067 m .55169 .48047 L .56336 .47518 L p 0 .05 .1 r
F P
0 g
s
.56175 .47442 m .56336 .47518 L p .55842 .44837 L 0 .349 .781 r
F P
0 g
s
.55268 .46843 m .56175 .47442 L p .55842 .44837 L 0 .349 .781 r
F P
0 g
s
.55842 .44837 m .54524 .46138 L .55268 .46843 L p 0 .349 .781 r
F P
0 g
s
.54524 .46138 m .55842 .44837 L .56863 .44354 L p 0 .05 .1 r
F P
0 g
s
.55364 .42646 m .56863 .44354 L .55842 .44837 L p 0 .316 .943 r
F P
0 g
s
.55842 .44837 m .54351 .4314 L .55364 .42646 L p 0 .316 .943 r
F P
0 g
s
.54351 .4314 m .55842 .44837 L .56863 .44354 L p 0 .316 .943 r
F P
0 g
s
.54757 .46029 m .56863 .44354 L .55842 .44837 L p 0 .05 .1 r
F P
0 g
s
.59478 .38681 m .57987 .36976 L .59299 .35693 L p 0 .35 .78 r
F P
0 g
s
.55786 .42309 m .55364 .42646 L .54351 .4314 L p 0 .05 .1 r
F P
0 g
s
.56845 .41268 m .55786 .42309 L p .54351 .4314 L 0 .05 .1 r
F P
0 g
s
.55364 .42646 m .54351 .4314 L p .53927 .41231 L 0 .316 .943 r
F P
0 g
s
.53862 .40935 m .54062 .41163 L p .53927 .41231 L 0 .316 .943 r
F P
0 g
s
.54062 .41163 m .55364 .42646 L p .53927 .41231 L 0 .316 .943 r
F P
0 g
s
.52858 .4144 m .54351 .4314 L .55364 .42646 L p 0 .316 .943 r
F P
0 g
s
.54351 .4314 m .55842 .44837 L .5468 .45386 L p 0 .316 .943 r
F P
0 g
s
.5468 .45386 m .532 .43702 L .54351 .4314 L p 0 .316 .943 r
F P
0 g
s
.55842 .44837 m .54351 .4314 L .532 .43702 L p 0 .316 .943 r
F P
0 g
s
.53535 .45927 m .52231 .47211 L .52966 .47905 L p 0 .349 .781 r
F P
0 g
s
.52231 .47211 m .53535 .45927 L .5468 .45386 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .5468 .45386 L .53535 .45927 L p 0 .316 .943 r
F P
0 g
s
.52065 .44256 m .53535 .45927 L .5468 .45386 L p 0 .316 .943 r
F P
0 g
s
.53369 .46679 m .5468 .45386 L .53535 .45927 L p 0 .05 .1 r
F P
0 g
s
.5468 .45386 m .532 .43702 L .52065 .44256 L p 0 .316 .943 r
F P
0 g
s
.5468 .45386 m .53369 .46679 L .52231 .47211 L p 0 .05 .1 r
F P
0 g
s
.51095 .44729 m .52557 .46389 L .52666 .46205 L p 0 .332 .559 r
F P
0 g
s
.52065 .44256 m .53535 .45927 L .52557 .46389 L p 0 .316 .943 r
F P
0 g
s
.53535 .45927 m .52065 .44256 L .51095 .44729 L p 0 .316 .943 r
F P
0 g
s
.53535 .45927 m .52065 .44256 L .532 .43702 L p 0 .316 .943 r
F P
0 g
s
.52006 .47317 m .52557 .46389 L .51095 .44729 L p 0 .332 .559 r
F P
0 g
s
.52557 .46389 m .51095 .44729 L .52065 .44256 L p 0 .316 .943 r
F P
0 g
s
.51095 .44729 m .52557 .46389 L .53535 .45927 L p 0 .316 .943 r
F P
0 g
s
.51366 .46512 m .52006 .47317 L p .51095 .44729 L 0 .332 .559 r
F P
0 g
s
.50758 .45581 m .51366 .46512 L p .51095 .44729 L 0 .332 .559 r
F P
0 g
s
.51075 .45226 m .52065 .44256 L .53535 .45927 L p 0 .349 .781 r
F P
0 g
s
.52231 .47211 m .53535 .45927 L .52557 .46389 L p 0 .05 .1 r
F P
0 g
s
.52557 .46389 m .52006 .47317 L .52231 .47211 L p 0 .05 .1 r
F P
0 g
s
.53535 .45927 m .52231 .47211 L .52006 .47317 L p 0 .05 .1 r
F P
0 g
s
.52231 .47211 m .53535 .45927 L .52065 .44256 L p 0 .349 .781 r
F P
0 g
s
.52204 .44678 m .532 .43702 L .5468 .45386 L p 0 .349 .781 r
F P
0 g
s
.52264 .44853 m .52204 .44678 L p .5468 .45386 L 0 .349 .781 r
F P
0 g
s
.51134 .45399 m .51075 .45226 L p .53535 .45927 L 0 .349 .781 r
F P
0 g
s
.51628 .46387 m .51134 .45399 L p .53535 .45927 L 0 .349 .781 r
F P
0 g
s
.52762 .45848 m .52264 .44853 L p .5468 .45386 L 0 .349 .781 r
F P
0 g
s
.53535 .45927 m .52231 .47211 L .51628 .46387 L p 0 .349 .781 r
F P
0 g
s
.53535 .45927 m .52231 .47211 L .53369 .46679 L p 0 .05 .1 r
F P
0 g
s
.5468 .45386 m .53369 .46679 L .52762 .45848 L p 0 .349 .781 r
F P
0 g
s
.5468 .45386 m .53369 .46679 L .54108 .47377 L p 0 .349 .781 r
F P
0 g
s
.53369 .46679 m .5468 .45386 L .55842 .44837 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .5468 .45386 L .55842 .44837 L p 0 .316 .943 r
F P
0 g
s
.54524 .46138 m .55842 .44837 L .5468 .45386 L p 0 .05 .1 r
F P
0 g
s
.5468 .45386 m .53369 .46679 L .54524 .46138 L p 0 .05 .1 r
F P
0 g
s
.53369 .46679 m .5468 .45386 L .532 .43702 L p 0 .349 .781 r
F P
0 g
s
.55842 .44837 m .54524 .46138 L .53369 .46679 L p 0 .05 .1 r
F P
0 g
s
.54524 .46138 m .55842 .44837 L .54351 .4314 L p 0 .349 .781 r
F P
0 g
s
.5335 .44123 m .54351 .4314 L .55842 .44837 L p 0 .349 .781 r
F P
0 g
s
.56863 .44354 m .55364 .42646 L .54351 .4314 L p 0 .316 .943 r
F P
0 g
s
.53912 .45301 m .54524 .46138 L p .54351 .4314 L 0 .349 .781 r
F P
0 g
s
.53411 .44299 m .53912 .45301 L p .54351 .4314 L 0 .349 .781 r
F P
0 g
s
.55364 .42646 m .54351 .4314 L p .5416 .43397 L 0 .05 .1 r
F P
0 g
s
.5377 .4392 m .54837 .43067 L p .5416 .43397 L 0 .05 .1 r
F P
0 g
s
.54837 .43067 m .55364 .42646 L p .5416 .43397 L 0 .05 .1 r
F P
0 g
s
.54351 .4314 m .5335 .44123 L .53411 .44299 L p 0 .349 .781 r
F P
0 g
s
.5335 .44123 m .54351 .4314 L .55364 .42646 L p 0 .05 .1 r
F P
0 g
s
.58361 .4606 m .56763 .47324 L .56336 .47518 L p 0 .05 .1 r
F P
0 g
s
.53862 .40935 m .52858 .4144 L p .53191 .416 L 0 .316 .943 r
F P
0 g
s
.55364 .42646 m .54062 .41163 L p .53191 .416 L 0 .316 .943 r
F P
0 g
s
.54062 .41163 m .53862 .40935 L p .53191 .416 L 0 .316 .943 r
F P
0 g
s
.57987 .36976 m .59478 .38681 L .58164 .39971 L p 0 .35 .78 r
F P
0 g
s
.59657 .41676 m .58164 .39971 L .59478 .38681 L p 0 .35 .78 r
F P
0 g
s
.56863 .44354 m .54757 .46029 L .54524 .46138 L p 0 .05 .1 r
F P
0 g
s
.55364 .42646 m .5377 .4392 L .5335 .44123 L p 0 .05 .1 r
F P
0 g
s
.58164 .39971 m .56669 .38264 L .57987 .36976 L p 0 .35 .78 r
F P
0 g
s
.56845 .41268 m .58164 .39971 L .59657 .41676 L p 0 .35 .78 r
F P
0 g
s
.59657 .41676 m .58342 .42975 L .56845 .41268 L p 0 .35 .78 r
F P
0 g
s
.55268 .46843 m .54524 .46138 L p .57331 .46531 L 0 .349 .781 r
F P
0 g
s
.55542 .46716 m .54757 .46029 L p .58361 .4606 L 0 .346 .852 r
F P
0 g
s
.56175 .47442 m .55268 .46843 L p .57331 .46531 L 0 .349 .781 r
F P
0 g
s
.57331 .46531 m .56336 .47518 L .56175 .47442 L p 0 .349 .781 r
F P
0 g
s
.57331 .46531 m .56336 .47518 L .56763 .47324 L p 0 .05 .1 r
F P
0 g
s
.56571 .47262 m .55542 .46716 L p .58361 .4606 L 0 .346 .852 r
F P
0 g
s
.58361 .4606 m .56763 .47324 L .56571 .47262 L p 0 .346 .852 r
F P
0 g
s
.54757 .46029 m .56863 .44354 L .58361 .4606 L p 0 .346 .852 r
F P
0 g
s
.55842 .44837 m .54524 .46138 L .54757 .46029 L p 0 .05 .1 r
F P
0 g
s
.53411 .44299 m .5335 .44123 L p .55842 .44837 L 0 .349 .781 r
F P
0 g
s
.53912 .45301 m .53411 .44299 L p .55842 .44837 L 0 .349 .781 r
F P
0 g
s
.55842 .44837 m .54524 .46138 L .53912 .45301 L p 0 .349 .781 r
F P
0 g
s
.56863 .44354 m .54757 .46029 L .54184 .45172 L p 0 .346 .852 r
F P
0 g
s
.56669 .38264 m .56869 .38492 L p .56711 .38572 L 0 .317 .941 r
F P
0 g
s
.55346 .39558 m .56669 .38264 L .58164 .39971 L p 0 .35 .78 r
F P
0 g
s
.58164 .39971 m .56845 .41268 L .55346 .39558 L p 0 .35 .78 r
F P
0 g
s
.54184 .45172 m .538 .44111 L p .56863 .44354 L 0 .346 .852 r
F P
0 g
s
.59837 .4468 m .58784 .45725 L .58361 .4606 L p 0 .05 .1 r
F P
0 g
s
.58361 .4606 m .58784 .45725 L .59837 .4468 L p 0 .05 .1 r
F P
0 g
s
.57286 .44018 m .58342 .42975 L .59837 .4468 L p 0 .35 .78 r
F P
0 g
s
.59837 .4468 m .58784 .45725 L .57286 .44018 L p 0 .35 .78 r
F P
0 g
s
.538 .44111 m .5377 .4392 L p .56863 .44354 L 0 .346 .852 r
F P
0 g
s
.52858 .4144 m .54351 .4314 L .532 .43702 L p 0 .316 .943 r
F P
0 g
s
.51717 .42016 m .532 .43702 L .54351 .4314 L p 0 .316 .943 r
F P
0 g
s
.5335 .44123 m .54351 .4314 L .532 .43702 L p 0 .05 .1 r
F P
0 g
s
.52762 .45848 m .53369 .46679 L p .532 .43702 L 0 .349 .781 r
F P
0 g
s
.52264 .44853 m .52762 .45848 L p .532 .43702 L 0 .349 .781 r
F P
0 g
s
.532 .43702 m .52204 .44678 L .52264 .44853 L p 0 .349 .781 r
F P
0 g
s
.52204 .44678 m .532 .43702 L .54351 .4314 L p 0 .05 .1 r
F P
0 g
s
.54351 .4314 m .52858 .4144 L .51717 .42016 L p 0 .316 .943 r
F P
0 g
s
.54351 .4314 m .5335 .44123 L .52204 .44678 L p 0 .05 .1 r
F P
0 g
s
.54351 .4314 m .52858 .4144 L .53862 .40935 L p 0 .316 .943 r
F P
0 g
s
.54351 .4314 m .5335 .44123 L .5377 .4392 L p 0 .05 .1 r
F P
0 g
s
.54351 .4314 m .52858 .4144 L p .53021 .42326 L 0 .349 .781 r
F P
0 g
s
.5335 .44123 m .54021 .43464 L p .53021 .42326 L 0 .349 .781 r
F P
0 g
s
.54021 .43464 m .54351 .4314 L p .53021 .42326 L 0 .349 .781 r
F P
0 g
s
.55927 .36863 m .57071 .36264 L .55786 .37518 L p 0 .05 .1 r
F P
0 g
s
.55786 .37518 m .54649 .38108 L .55927 .36863 L p 0 .05 .1 r
F P
0 g
s
.54649 .38108 m .55786 .37518 L .54496 .38776 L p 0 .05 .1 r
F P
0 g
s
.54496 .38776 m .53366 .39358 L .54649 .38108 L p 0 .05 .1 r
F P
0 g
s
.53366 .39358 m .54496 .38776 L .532 .40039 L p 0 .05 .1 r
F P
0 g
s
.532 .40039 m .52077 .40614 L .53366 .39358 L p 0 .05 .1 r
F P
0 g
s
.57071 .36264 m .58232 .35657 L .5694 .36918 L p 0 .05 .1 r
F P
0 g
s
.5694 .36918 m .55786 .37518 L .57071 .36264 L p 0 .05 .1 r
F P
0 g
s
.55786 .37518 m .5694 .36918 L .55642 .38185 L p 0 .05 .1 r
F P
0 g
s
.55642 .38185 m .54496 .38776 L .55786 .37518 L p 0 .05 .1 r
F P
0 g
s
.5694 .36918 m .58232 .35657 L .5941 .35041 L p 0 .05 .1 r
F P
0 g
s
.5941 .35041 m .58111 .3631 L .5694 .36918 L p 0 .05 .1 r
F P
0 g
s
.55642 .38185 m .5694 .36918 L .58111 .3631 L p 0 .05 .1 r
F P
0 g
s
.58111 .3631 m .5941 .35041 L .60606 .34416 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .55927 .36863 L .52561 .40142 L p .1 0 0 r
F P
0 g
s
.50783 .41874 m .52077 .40614 L .532 .40039 L p 0 .05 .1 r
F P
0 g
s
.532 .40039 m .51898 .41308 L .50783 .41874 L p 0 .05 .1 r
F P
0 g
s
.50783 .41874 m .51898 .41308 L p .4963 .43066 L 0 .05 .1 r
F P
0 g
s
.4963 .43066 m .49744 .42887 L .50783 .41874 L p 0 .05 .1 r
F P
0 g
s
.51095 .44729 m .4963 .43066 L p .49973 .43842 L 0 .332 .559 r
F P
0 g
s
.5067 .45422 m .50955 .44957 L p .49973 .43842 L 0 .332 .559 r
F P
0 g
s
.50955 .44957 m .51095 .44729 L p .49973 .43842 L 0 .332 .559 r
F P
0 g
s
.51095 .44729 m .4963 .43066 L .50592 .42582 L p 0 .316 .943 r
F P
0 g
s
.4963 .43066 m .51095 .44729 L .52065 .44256 L p 0 .316 .943 r
F P
0 g
s
.51898 .41308 m .50592 .42582 L .4963 .43066 L p 0 .05 .1 r
F P
0 g
s
.52065 .44256 m .50592 .42582 L .4963 .43066 L p 0 .316 .943 r
F P
0 g
s
.50158 .44491 m .5067 .45422 L p .4963 .43066 L 0 .332 .559 r
F P
0 g
s
.4963 .43066 m .49545 .43201 L .50158 .44491 L p 0 .332 .559 r
F P
0 g
s
.49545 .43201 m .4963 .43066 L .50592 .42582 L p 0 .05 .1 r
F P
0 g
s
.50208 .42434 m .49158 .43458 L p .49725 .4301 L .1 0 0 r
F P
0 g
s
.54496 .38776 m .55642 .38185 L .54339 .39456 L p 0 .05 .1 r
F P
0 g
s
.54339 .39456 m .532 .40039 L .54496 .38776 L p 0 .05 .1 r
F P
0 g
s
.51898 .41308 m .532 .40039 L .54339 .39456 L p 0 .05 .1 r
F P
0 g
s
.49725 .4301 m .54828 .38979 L .50208 .42434 L .1 0 0 r
F
.52561 .40142 m .50208 .42434 L p .54828 .38979 L F P
0 g
s
.50592 .42582 m .52065 .44256 L .51095 .44729 L p 0 .316 .943 r
F P
0 g
s
.50158 .44491 m .49545 .43201 L .50396 .42773 L p 0 .23 .804 r
F P
0 g
s
.50592 .42582 m .50396 .42773 L .49545 .43201 L p 0 .05 .1 r
F P
0 g
s
.50396 .42773 m .50729 .4421 L .50158 .44491 L p 0 .23 .804 r
F P
0 g
s
.54339 .39456 m .53031 .40733 L .51898 .41308 L p 0 .05 .1 r
F P
0 g
s
.50592 .42582 m .51898 .41308 L .53031 .40733 L p 0 .05 .1 r
F P
0 g
s
.51717 .42016 m .532 .43702 L .52065 .44256 L p 0 .316 .943 r
F P
0 g
s
.52065 .44256 m .50592 .42582 L .51717 .42016 L p 0 .316 .943 r
F P
0 g
s
.50396 .42773 m .50592 .42582 L .52065 .44256 L p 0 .349 .781 r
F P
0 g
s
.52065 .44256 m .51438 .44234 L .50396 .42773 L 0 .349 .781 r
F
.50729 .4421 m .50484 .43151 L p .51438 .44234 L F P
0 g
s
.50484 .43151 m .50396 .42773 L p .51438 .44234 L 0 .349 .781 r
F P
0 g
s
.49158 .43458 m .50264 .42901 L p .50666 .42267 L .1 0 0 r
F P
0 g
s
.50592 .42582 m .52065 .44256 L .532 .43702 L p 0 .316 .943 r
F P
0 g
s
.51095 .44729 m .5067 .45422 L .50758 .45581 L p 0 .332 .559 r
F P
0 g
s
.51075 .45226 m .52065 .44256 L .51095 .44729 L p 0 .05 .1 r
F P
0 g
s
.51095 .44729 m .5067 .45422 L .51075 .45226 L p 0 .05 .1 r
F P
0 g
s
.5067 .45422 m .51095 .44729 L .52065 .44256 L p 0 .05 .1 r
F P
0 g
s
.52065 .44256 m .51075 .45226 L .5067 .45422 L p 0 .05 .1 r
F P
0 g
s
.51075 .45226 m .52065 .44256 L .50592 .42582 L p 0 .349 .781 r
F P
0 g
s
.53031 .40733 m .51717 .42016 L .50592 .42582 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .51717 .42016 L .50592 .42582 L p 0 .316 .943 r
F P
0 g
s
.50729 .4421 m .51075 .45226 L p .50592 .42582 L 0 .349 .781 r
F P
0 g
s
.50592 .42582 m .50396 .42773 L .50729 .4421 L p 0 .349 .781 r
F P
0 g
s
.50396 .42773 m .50592 .42582 L .51717 .42016 L p 0 .05 .1 r
F P
0 g
s
.50729 .4421 m .50396 .42773 L .5152 .42207 L p 0 .23 .804 r
F P
0 g
s
.51717 .42016 m .5152 .42207 L .50396 .42773 L p 0 .05 .1 r
F P
0 g
s
.5152 .42207 m .51855 .43655 L .50729 .4421 L p 0 .23 .804 r
F P
0 g
s
.51717 .42016 m .53031 .40733 L .5418 .4015 L p 0 .05 .1 r
F P
0 g
s
.5152 .42207 m .51717 .42016 L .532 .43702 L p 0 .349 .781 r
F P
0 g
s
.532 .43702 m .52569 .4368 L .5152 .42207 L 0 .349 .781 r
F
.51855 .43655 m .51608 .42588 L p .52569 .4368 L F P
0 g
s
.51608 .42588 m .5152 .42207 L p .52569 .4368 L 0 .349 .781 r
F P
0 g
s
.532 .43702 m .51717 .42016 L .52858 .4144 L p 0 .316 .943 r
F P
0 g
s
.52204 .44678 m .532 .43702 L .52065 .44256 L p 0 .05 .1 r
F P
0 g
s
.51628 .46387 m .52231 .47211 L p .52065 .44256 L 0 .349 .781 r
F P
0 g
s
.51134 .45399 m .51628 .46387 L p .52065 .44256 L 0 .349 .781 r
F P
0 g
s
.52065 .44256 m .51075 .45226 L .51134 .45399 L p 0 .349 .781 r
F P
0 g
s
.51075 .45226 m .52065 .44256 L .532 .43702 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .52204 .44678 L .51075 .45226 L p 0 .05 .1 r
F P
0 g
s
.52204 .44678 m .532 .43702 L .51717 .42016 L p 0 .349 .781 r
F P
0 g
s
.5418 .4015 m .52858 .4144 L .51717 .42016 L p 0 .05 .1 r
F P
0 g
s
.52065 .44256 m .51075 .45226 L .50729 .4421 L p 0 .349 .781 r
F P
0 g
s
.52065 .44256 m .51075 .45226 L .52204 .44678 L p 0 .05 .1 r
F P
0 g
s
.51855 .43655 m .52204 .44678 L p .51717 .42016 L 0 .349 .781 r
F P
0 g
s
.51717 .42016 m .5152 .42207 L .51855 .43655 L p 0 .349 .781 r
F P
0 g
s
.5152 .42207 m .51717 .42016 L .52858 .4144 L p 0 .05 .1 r
F P
0 g
s
.52858 .4144 m .52661 .41634 L .5152 .42207 L p 0 .05 .1 r
F P
0 g
s
.51855 .43655 m .5152 .42207 L .52661 .41634 L p 0 .23 .804 r
F P
0 g
s
.52661 .41634 m .52999 .43092 L .51855 .43655 L p 0 .23 .804 r
F P
0 g
s
.52661 .41634 m .52858 .4144 L .54351 .4314 L p 0 .349 .781 r
F P
0 g
s
.52999 .43092 m .52661 .41634 L p .54351 .4314 L 0 .349 .781 r
F P
0 g
s
.52999 .43092 m .5335 .44123 L p .52858 .4144 L 0 .349 .781 r
F P
0 g
s
.52858 .4144 m .52661 .41634 L .52999 .43092 L p 0 .349 .781 r
F P
0 g
s
.52661 .41634 m .52858 .4144 L .53862 .40935 L p 0 .05 .1 r
F P
0 g
s
.53862 .40935 m .53547 .41187 L .52661 .41634 L p 0 .05 .1 r
F P
0 g
s
.52999 .43092 m .52661 .41634 L .53547 .41187 L p 0 .23 .804 r
F P
0 g
s
.53547 .41187 m .53591 .42801 L .52999 .43092 L p 0 .23 .804 r
F P
0 g
s
.55364 .42646 m .5453 .42719 L .53547 .41187 L 0 .346 .852 r
F
.53591 .42801 m .53559 .41612 L p .5453 .42719 L F P
0 g
s
.53559 .41612 m .53547 .41187 L p .5453 .42719 L 0 .346 .852 r
F P
0 g
s
.53547 .41187 m .53862 .40935 L .55364 .42646 L p 0 .346 .852 r
F P
0 g
s
.50264 .42901 m .53684 .41182 L p .50666 .42267 L .1 0 0 r
F P
0 g
s
.58111 .3631 m .56806 .37585 L .55642 .38185 L p 0 .05 .1 r
F P
0 g
s
.54339 .39456 m .55642 .38185 L .56806 .37585 L p 0 .05 .1 r
F P
0 g
s
.56806 .37585 m .55496 .38864 L .54339 .39456 L p 0 .05 .1 r
F P
0 g
s
.53031 .40733 m .54339 .39456 L .55496 .38864 L p 0 .05 .1 r
F P
0 g
s
.55496 .38864 m .5418 .4015 L .53031 .40733 L p 0 .05 .1 r
F P
0 g
s
.60606 .34416 m .59299 .35693 L .58111 .3631 L p 0 .05 .1 r
F P
0 g
s
.56806 .37585 m .58111 .3631 L .59299 .35693 L p 0 .05 .1 r
F P
0 g
s
.55496 .38864 m .56806 .37585 L .57987 .36976 L p 0 .05 .1 r
F P
0 g
s
.59299 .35693 m .57987 .36976 L .56806 .37585 L p 0 .05 .1 r
F P
0 g
s
.5418 .4015 m .55496 .38864 L .56669 .38264 L p 0 .05 .1 r
F P
0 g
s
.57987 .36976 m .56669 .38264 L .55496 .38864 L p 0 .05 .1 r
F P
0 g
s
.56669 .38264 m .55346 .39558 L .5418 .4015 L p 0 .05 .1 r
F P
0 g
s
.52858 .4144 m .5418 .4015 L .55346 .39558 L p 0 .05 .1 r
F P
0 g
s
.54283 .40596 m .53862 .40935 L .52858 .4144 L p 0 .05 .1 r
F P
0 g
s
.55346 .39558 m .54283 .40596 L p .52858 .4144 L 0 .05 .1 r
F P
0 g
s
.53862 .40935 m .54283 .40596 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.55364 .42646 m .54062 .41163 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.54062 .41163 m .53862 .40935 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.54351 .4314 m .5335 .44123 L .52999 .43092 L p 0 .349 .781 r
F P
0 g
s
.55364 .42646 m .5377 .4392 L .53591 .42801 L p 0 .346 .852 r
F P
0 g
s
.5377 .4392 m .55364 .42646 L .56863 .44354 L p 0 .346 .852 r
F P
0 g
s
.58342 .42975 m .57286 .44018 L .56863 .44354 L p 0 .05 .1 r
F P
0 g
s
.57286 .44018 m .58784 .45725 L .58361 .4606 L p 0 .346 .852 r
F P
0 g
s
.58361 .4606 m .56863 .44354 L .57286 .44018 L p 0 .346 .852 r
F P
0 g
s
.56863 .44354 m .55364 .42646 L .55786 .42309 L p 0 .346 .852 r
F P
0 g
s
.55786 .42309 m .57286 .44018 L .56863 .44354 L p 0 .346 .852 r
F P
0 g
s
.55786 .42309 m .55364 .42646 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.54283 .40596 m .54484 .40825 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.54484 .40825 m .55786 .42309 L p .54428 .4087 L 0 .346 .852 r
F P
0 g
s
.55786 .42309 m .56845 .41268 L .58342 .42975 L p 0 .35 .78 r
F P
0 g
s
.58342 .42975 m .57286 .44018 L .55786 .42309 L p 0 .35 .78 r
F P
0 g
s
.54283 .40596 m .55346 .39558 L .56845 .41268 L p 0 .35 .78 r
F P
0 g
s
.56845 .41268 m .55786 .42309 L .54283 .40596 L p 0 .35 .78 r
F P
0 g
s
.5976 .46224 m .54801 .40571 L .54002 .41352 L .858 0 0 r
F
.54335 .41027 m .54801 .40571 L p .54368 .4101 L .1 0 0 r
F P
0 g
s
.5976 .46224 m .60924 .3458 L .54801 .40571 L .858 0 0 r
F
.54801 .40571 m .55664 .39726 L p .54857 .40525 L .1 0 0 r
F P
0 g
s
.54801 .40571 m .54857 .40525 L .54368 .4101 L .1 0 0 r
F
.54002 .41352 m .59609 .47739 L p .5976 .46224 L .858 0 0 r
F P
0 g
s
.55063 .4036 m .55664 .39726 L .55832 .39641 L .1 0 0 r
F
.54368 .4101 m .54857 .40525 L .55063 .4036 L F
.54857 .40525 m .55664 .39726 L .55063 .4036 L F
.53684 .41182 m .57164 .3778 L p .50666 .42267 L F P
0 g
s
.57164 .3778 m .60606 .34416 L p .54828 .38979 L .1 0 0 r
F P
0 g
s
.50666 .42267 m .57164 .3778 L .54828 .38979 L .1 0 0 r
F
.54828 .38979 m .60606 .34416 L .52561 .40142 L F
.53684 .41182 m .60606 .34416 L .59418 .33054 L .858 0 0 r
F
.53769 .41184 m .60606 .34416 L .53684 .41182 L .553 0 0 r
F
.53769 .41184 m .60693 .34415 L .60606 .34416 L F
.59418 .33054 m .60606 .34416 L .53684 .41182 L p .858 0 0 r
F P
0 g
s
.53886 .41246 m .60693 .34415 L .53769 .41184 L .761 0 0 r
F
.53886 .41246 m .60809 .34475 L .60693 .34415 L F
.54002 .41352 m .60809 .34475 L .53886 .41246 L .832 0 0 r
F
.54002 .41352 m .60924 .3458 L .60809 .34475 L F
.56641 .29869 m .59418 .33054 L .55968 .36413 L p .858 0 0 r
F P
0 g
s
.55968 .36413 m .59418 .33054 L .56641 .29869 L .858 0 0 r
F
.53684 .41182 m .52479 .3981 L .59418 .33054 L p F P
0 g
s
.53684 .41182 m .59418 .33054 L .52479 .3981 L .858 0 0 r
F
.56568 .3641 m .59418 .33054 L .55968 .36413 L .55 0 0 r
F
.61694 .32279 m .64106 .30994 L .55824 .21464 L p 0 .319 .936 r
F P
0 g
s
.62361 .327 m .61156 .33336 L .62891 .31641 L p 0 .05 .1 r
F P
0 g
s
.62891 .31641 m .64106 .30994 L .62361 .327 L p 0 .05 .1 r
F P
0 g
s
.55824 .21464 m .64106 .30994 L .60606 .34416 L p 0 .35 .78 r
F P
0 g
s
.60606 .34416 m .52261 .24846 L .55824 .21464 L p 0 .35 .78 r
F P
0 g
s
.60665 .34385 m .59418 .33054 L .60606 .34416 L .577 0 0 r
F
.60693 .34415 m .60024 .33043 L .59418 .33054 L F
.56568 .3641 m .60024 .33043 L .59418 .33054 L .55 0 0 r
F
.56568 .3641 m .59418 .33054 L .60024 .33043 L F
.53074 .39815 m .56268 .36411 L .56568 .3641 L F
.56268 .36411 m .59418 .33054 L .56568 .3641 L F
.57386 .36837 m .60024 .33043 L .56568 .3641 L .761 0 0 r
F
.60809 .34475 m .60024 .33043 L .60693 .34415 L .577 0 0 r
F
.60809 .34475 m .60843 .33462 L .60024 .33043 L F
.57386 .36837 m .60843 .33462 L .60024 .33043 L .761 0 0 r
F
.57386 .36837 m .60024 .33043 L .60843 .33462 L F
.5389 .40251 m .56977 .36624 L .57386 .36837 L F
.56977 .36624 m .60024 .33043 L .57386 .36837 L F
.61652 .342 m .60924 .3458 L .66449 .40916 L p .577 0 0 r
F P
0 g
s
.55832 .39641 m .56374 .39367 L .61652 .342 L .1 0 0 r
F
.61652 .342 m .56374 .39367 L p .55832 .39641 L F P
0 g
s
.56987 .38431 m .60924 .3458 L p .57115 .38367 L .1 0 0 r
F P
0 g
s
.57293 .38276 m .60924 .3458 L .60891 .34912 L .1 0 0 r
F
.57115 .38367 m .60924 .3458 L .57293 .38276 L F
.57293 .38276 m .61652 .342 L .57165 .38341 L F
.56987 .38431 m .61652 .342 L .60924 .3458 L F
.57165 .38341 m .61652 .342 L .56987 .38431 L F
.58199 .37581 m .60843 .33462 L .57386 .36837 L .832 0 0 r
F
.54335 .41027 m .55832 .39641 L .55664 .39726 L .1 0 0 r
F
.54368 .4101 m .55832 .39641 L .54335 .41027 L F
.54002 .41352 m .54706 .41 L .56374 .39367 L F
.54002 .41352 m .56374 .39367 L .55832 .39641 L F
.54706 .41 m .54002 .41352 L p .55832 .39641 L F P
0 g
s
.56374 .39367 m .54706 .41 L p .55832 .39641 L .1 0 0 r
F P
0 g
s
.55664 .39726 m .56987 .38431 L .55832 .39641 L .1 0 0 r
F
.56987 .38431 m .57115 .38367 L .55832 .39641 L F
.55832 .39641 m .57115 .38367 L .57293 .38276 L F
.55832 .39641 m .57293 .38276 L .55664 .39726 L F
.57293 .38276 m .57165 .38341 L .55664 .39726 L F
.55664 .39726 m .57165 .38341 L .56987 .38431 L F
.60924 .3458 m .61652 .342 L p .60891 .34912 L F P
0 g
s
.60924 .3458 m .60843 .33462 L .60809 .34475 L .577 0 0 r
F
.60924 .3458 m .61652 .342 L .60843 .33462 L F
.54706 .41 m .60843 .33462 L .61652 .342 L .832 0 0 r
F
.54706 .41 m .5389 .40251 L .60843 .33462 L F
.58035 .37177 m .57386 .36837 L .57394 .36406 L .569 0 0 r
F
.58126 .37287 m .57386 .36837 L .58035 .37177 L F
.53074 .39815 m .52479 .3981 L .55968 .36413 L .55 0 0 r
F
.56268 .36411 m .55968 .36413 L .59418 .33054 L F
.53074 .39815 m .55968 .36413 L .56268 .36411 L F
.55968 .36413 m .56641 .29869 L .5317 .33216 L .858 0 0 r
F
.55968 .36413 m .5317 .33216 L .56641 .29869 L p F P
0 g
s
.5389 .40251 m .53074 .39815 L .56568 .3641 L .761 0 0 r
F
.56977 .36624 m .56568 .3641 L .60024 .33043 L F
.5389 .40251 m .56568 .3641 L .56977 .36624 L F
.58199 .37581 m .61652 .342 L .60843 .33462 L .832 0 0 r
F
.62361 .327 m .64106 .30994 L .65117 .34824 L p 0 .35 .78 r
F P
0 g
s
.65117 .34824 m .62867 .34621 L .62361 .327 L p 0 .35 .78 r
F P
0 g
s
.66449 .40916 m .672 .40566 L .61652 .342 L p .577 0 0 r
F P
0 g
s
.63376 .33302 m .61652 .342 L .672 .40566 L p .577 0 0 r
F P
0 g
s
.66557 .4114 m .67773 .41413 L .66531 .41036 L .577 0 0 r
F
.59688 .4802 m .63141 .44562 L .59722 .47963 L .889 0 0 r
F
.63141 .44562 m .66557 .4114 L .63158 .44532 L F
.63141 .44562 m .63158 .44532 L .59722 .47963 L F
.6309 .44369 m .63048 .44309 L .59609 .47739 L .884 0 0 r
F
.66449 .40916 m .62559 .44796 L p .62843 .44538 L .164 0 0 r
F P
0 g
s
.59693 .4786 m .6309 .44369 L .59609 .47739 L .884 0 0 r
F
.62559 .44796 m .66449 .40916 L .62875 .44653 L .164 0 0 r
F
.66531 .41036 m .67773 .41413 L .672 .40566 L .577 0 0 r
F
.59722 .47963 m .63145 .44481 L .59693 .4786 L .949 0 0 r
F
.63145 .44481 m .66531 .41036 L .63131 .44429 L F
.63145 .44481 m .63131 .44429 L .59693 .4786 L F
.62875 .44653 m .63297 .44462 L .672 .40566 L .164 0 0 r
F
.59609 .47739 m .60662 .46744 L .60547 .46982 L F
.59688 .4802 m .63124 .44591 L .63141 .44562 L .889 0 0 r
F
.59609 .47739 m .60547 .46982 L .60337 .47417 L .164 0 0 r
F
.60662 .46744 m .61426 .46023 L .61182 .46335 L F
.60662 .46744 m .61182 .46335 L .60337 .47417 L F
.60662 .46744 m .62559 .44796 L .62107 .45379 L F
.59973 .47396 m .60472 .46894 L .60662 .46744 L F
.60472 .46894 m .62559 .44796 L .60662 .46744 L F
.62107 .45379 m .62559 .44796 L .62875 .44653 L F
.59938 .47411 m .62559 .44796 L .59973 .47396 L F
.61252 .46101 m .59938 .47411 L p .61426 .46023 L F P
0 g
s
.59973 .47396 m .61426 .46023 L .59938 .47411 L .164 0 0 r
F
.61426 .46023 m .62875 .44653 L .61751 .45876 L F
.61426 .46023 m .61751 .45876 L .60337 .47417 L F
.62559 .44796 m .61252 .46101 L p .62875 .44653 L F P
0 g
s
.61426 .46023 m .62875 .44653 L .61252 .46101 L .164 0 0 r
F
.61426 .46023 m .63297 .44462 L .62875 .44653 L F
.59609 .47739 m .61658 .45918 L .61426 .46023 L F
.61658 .45918 m .63297 .44462 L .61426 .46023 L F
.60337 .47417 m .63297 .44462 L p .59834 .47539 L F P
0 g
s
.62875 .44653 m .672 .40566 L .63297 .44462 L .164 0 0 r
F
.62875 .44653 m .63297 .44462 L .60337 .47417 L F
.66531 .41036 m .672 .40566 L .66449 .40916 L .577 0 0 r
F
.672 .40566 m .66495 .40894 L p .62843 .44538 L .164 0 0 r
F P
0 g
s
.66495 .40894 m .66449 .40916 L p .62843 .44538 L .164 0 0 r
F P
0 g
s
.62875 .44653 m .672 .40566 L .62559 .44796 L .164 0 0 r
F
.62875 .44653 m .66449 .40916 L .672 .40566 L F
.61652 .342 m .672 .40566 L .60337 .47417 L p .858 0 0 r
F P
0 g
s
.672 .40566 m .61652 .342 L p .63788 .43972 L .858 0 0 r
F P
0 g
s
.64367 .44821 m .67773 .41413 L .672 .40566 L .885 0 0 r
F
.60924 .48266 m .672 .40566 L .67773 .41413 L F
.67773 .41413 m .68978 .39738 L .672 .40566 L .577 0 0 r
F
.64367 .44821 m .672 .40566 L .63788 .43972 L .885 0 0 r
F
.60924 .48266 m .60337 .47417 L .672 .40566 L F
.63788 .43972 m .672 .40566 L .68978 .39738 L .164 0 0 r
F
.68978 .39738 m .672 .40566 L .63788 .43972 L p F P
0 g
s
.61652 .342 m .58199 .37581 L .63788 .43972 L p .858 0 0 r
F P
0 g
s
.63788 .43972 m .68978 .39738 L .65539 .43176 L .164 0 0 r
F
.63788 .43972 m .65539 .43176 L .68978 .39738 L p F P
0 g
s
.65539 .43176 m .63788 .43972 L p .62234 .41075 L .569 0 0 r
F P
0 g
s
.60337 .47417 m .54706 .41 L .61652 .342 L p .858 0 0 r
F P
0 g
s
.59896 .36714 m .61585 .38649 L p .62234 .41075 L .569 0 0 r
F P
0 g
s
.61585 .38649 m .65539 .43176 L p .62234 .41075 L .569 0 0 r
F P
0 g
s
.63649 .43714 m .62666 .42689 L .62234 .41075 L .569 0 0 r
F
.63788 .43972 m .63613 .43773 L p .63649 .43714 L F P
0 g
s
.63613 .43773 m .62666 .42689 L p .63649 .43714 L .569 0 0 r
F P
0 g
s
.58199 .37581 m .61652 .342 L .63376 .33302 L p .1 0 0 r
F P
0 g
s
.58199 .37581 m .63376 .33302 L .61652 .342 L .1 0 0 r
F
.58199 .37581 m .59896 .36714 L .63376 .33302 L F
.63376 .33302 m .59896 .36714 L .58199 .37581 L p F P
0 g
s
.58507 .37424 m .57431 .34462 L .59896 .36714 L .569 0 0 r
F
.58199 .37581 m .58109 .37216 L .58507 .37424 L F
.58109 .37216 m .57431 .34462 L .58507 .37424 L F
.57101 .36408 m .56568 .3641 L .54963 .33183 L F
.57386 .36837 m .56568 .3641 L .57101 .36408 L F
.57909 .36404 m .57394 .36406 L .57431 .34462 L F
.58126 .37287 m .57394 .36406 L .57909 .36404 L F
.58199 .37581 m .57966 .37369 L .58126 .37287 L F
.57966 .37369 m .57386 .36837 L .58126 .37287 L F
.52479 .3981 m .53684 .41182 L .53335 .41358 L p .56 0 0 r
F P
0 g
s
.53335 .41358 m .52527 .41764 L p .52493 .40399 L .56 0 0 r
F P
0 g
s
.52493 .40399 m .52479 .3981 L .53335 .41358 L .56 0 0 r
F
.52527 .41764 m .51387 .42337 L p .51629 .40743 L F P
0 g
s
.51387 .42337 m .50264 .42901 L p .50942 .4183 L .56 0 0 r
F P
0 g
s
.50942 .4183 m .51629 .40743 L .51387 .42337 L .56 0 0 r
F
.50264 .42901 m .49488 .43292 L p .50035 .42641 L F P
0 g
s
.50035 .42641 m .51629 .40743 L .50264 .42901 L .56 0 0 r
F
.49488 .43292 m .49158 .43458 L p .494 .43192 L F P
0 g
s
.494 .43192 m .51629 .40743 L .49488 .43292 L .56 0 0 r
F
.51629 .40743 m .52479 .3981 L .52527 .41764 L F
.54002 .41352 m .54335 .41027 L p .54368 .4101 L .1 0 0 r
F P
0 g
s
.55851 .42573 m .54002 .41352 L .54706 .41 L .56 0 0 r
F
.59609 .47739 m .55306 .42839 L p .55851 .42573 L F P
0 g
s
.55306 .42839 m .54002 .41352 L p .55851 .42573 L .56 0 0 r
F P
0 g
s
.54002 .41352 m .54368 .4101 L .54335 .41027 L .1 0 0 r
F
.62234 .41075 m .59321 .38864 L .59896 .36714 L .569 0 0 r
F
.62666 .42689 m .59321 .38864 L p .62234 .41075 L F P
0 g
s
.59321 .38864 m .58199 .37581 L .58379 .37489 L p .569 0 0 r
F P
0 g
s
.58379 .37489 m .59896 .36714 L p .59321 .38864 L .569 0 0 r
F P
0 g
s
.59609 .47739 m .59938 .47411 L .59973 .47396 L .164 0 0 r
F
.59938 .47411 m .59609 .47739 L p .59973 .47396 L F P
0 g
s
.59693 .4786 m .59977 .47576 L .59963 .47582 L .884 0 0 r
F
.59609 .47739 m .59653 .4772 L p .59834 .47539 L .164 0 0 r
F P
0 g
s
.59653 .4772 m .60337 .47417 L p .59834 .47539 L .164 0 0 r
F P
0 g
s
.62208 .51128 m .64606 .50132 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.64606 .50132 m .67076 .49107 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.65506 .47807 m .62208 .51128 L p .66277 .48445 L .212 0 0 r
F P
0 g
s
.4916 .43616 m .48587 .44063 L .48008 .43239 L .56 0 0 r
F
.49129 .43515 m .4916 .43616 L .48008 .43239 L F
.48609 .42111 m .49731 .41535 L p .48797 .41928 L .1 0 0 r
F P
0 g
s
.48609 .42111 m .48797 .41928 L .478 .42391 L .1 0 0 r
F
.49731 .41535 m .49809 .41459 L .48797 .41928 L F
.48689 .41528 m .4792 .41926 L p .478 .42391 L F P
0 g
s
.49731 .41535 m .48609 .42111 L p .44459 .35544 L .556 0 0 r
F P
0 g
s
.48609 .42111 m .46414 .43238 L p .45121 .38152 L .556 0 0 r
F P
0 g
s
.45121 .38152 m .44459 .35544 L .48609 .42111 L .556 0 0 r
F
.48475 .41959 m .48138 .43358 L .49258 .4279 L p 0 .117 .6 r
F P
0 g
s
.49258 .4279 m .49597 .41382 L .48475 .41959 L p 0 .117 .6 r
F P
0 g
s
.48904 .43769 m .49258 .4279 L .48138 .43358 L p 0 .082 .528 r
F P
0 g
s
.49258 .4279 m .48904 .43769 L p .49234 .42017 L 0 .349 .781 r
F P
0 g
s
.48277 .41735 m .48475 .41959 L .49597 .41382 L p 0 .315 .944 r
F P
0 g
s
.49597 .41382 m .49397 .41155 L .48277 .41735 L p 0 .315 .944 r
F P
0 g
s
.49397 .41155 m .49332 .41923 L .49234 .42017 L 0 .349 .781 r
F
.49332 .41923 m .49258 .4279 L .49234 .42017 L F
.49731 .41535 m .50527 .41126 L p .49809 .41459 L .1 0 0 r
F P
0 g
s
.44473 .41631 m .44011 .41876 L .4395 .41842 L .556 0 0 r
F
.46333 .43292 m .46251 .43098 L .46222 .43382 L .1 0 0 r
F
.39443 .35483 m .46333 .43292 L .46222 .43382 L .777 0 0 r
F
.39521 .35427 m .46333 .43292 L .39443 .35483 L .681 0 0 r
F
.39521 .35427 m .46414 .43238 L .46333 .43292 L F
.46414 .43238 m .39521 .35427 L .43785 .32892 L p .556 0 0 r
F P
0 g
s
.43466 .39898 m .44777 .41384 L .45855 .4081 L p 0 .315 .944 r
F P
0 g
s
.42529 .40491 m .43509 .41601 L p .42655 .40423 L .556 0 0 r
F P
0 g
s
.4395 .41842 m .39218 .35677 L .43509 .41601 L .556 0 0 r
F
.43509 .41601 m .45464 .43815 L p .4395 .41842 L F P
0 g
s
.45464 .43815 m .46109 .43485 L .44473 .41631 L p .556 0 0 r
F P
0 g
s
.44473 .41631 m .39218 .35677 L p .43986 .4189 L .556 0 0 r
F P
0 g
s
.45464 .43815 m .44473 .41631 L .43986 .4189 L .556 0 0 r
F
.44777 .41384 m .45825 .42571 L p .47174 .42305 L 0 .315 .944 r
F P
0 g
s
.44495 .41656 m .45324 .42595 L p .43914 .42756 L .856 0 0 r
F P
0 g
s
.39975 .43204 m .44495 .41656 L .43914 .42756 L .856 0 0 r
F
.43162 .40146 m .44495 .41656 L p .39975 .43204 L F P
0 g
s
.45324 .42595 m .46109 .43485 L p .44481 .4341 L .856 0 0 r
F P
0 g
s
.39975 .43204 m .45324 .42595 L .44481 .4341 L .856 0 0 r
F
.39332 .35575 m .46222 .43382 L .46109 .43485 L .831 0 0 r
F
.39443 .35483 m .46222 .43382 L .39332 .35575 L .777 0 0 r
F
.39332 .35575 m .46109 .43485 L .39218 .35677 L .831 0 0 r
F
.45825 .42571 m .44777 .41384 L .43291 .42816 L p 0 .349 .781 r
F P
0 g
s
.47174 .42305 m .45855 .4081 L .44777 .41384 L p 0 .315 .944 r
F P
0 g
s
.45855 .4081 m .44777 .41384 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.44361 .42252 m .45657 .41002 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.45657 .41002 m .45855 .4081 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.44777 .41384 m .43466 .39898 L .41976 .41327 L p 0 .349 .781 r
F P
0 g
s
.45855 .4081 m .44535 .39312 L .43466 .39898 L p 0 .315 .944 r
F P
0 g
s
.44535 .39312 m .43466 .39898 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.44336 .39504 m .44535 .39312 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.43466 .39898 m .44535 .39312 L p .44192 .39582 L 0 .05 .1 r
F P
0 g
s
.43037 .40752 m .44336 .39504 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.41976 .41327 m .43037 .40752 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.43268 .40088 m .41976 .41327 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.41976 .41327 m .43268 .40088 L p .44192 .39582 L 0 .05 .1 r
F P
0 g
s
.43466 .39898 m .43268 .40088 L p .43409 .4001 L 0 .05 .1 r
F P
0 g
s
.43268 .40088 m .43466 .39898 L p .44192 .39582 L 0 .05 .1 r
F P
0 g
s
.39218 .35677 m .38602 .36044 L .42529 .40491 L p .556 0 0 r
F P
0 g
s
.42655 .40423 m .39218 .35677 L .42529 .40491 L .556 0 0 r
F
.43339 .4617 m .44826 .44729 L p .43117 .46282 L .1 0 0 r
F P
0 g
s
.3992 .49188 m .44826 .44729 L .44677 .44804 L .1 0 0 r
F
.3992 .49188 m .40545 .48879 L .41845 .47618 L p F P
0 g
s
.41845 .47618 m .43339 .4617 L p .41507 .47787 L .1 0 0 r
F P
0 g
s
.3992 .49188 m .41845 .47618 L .41507 .47787 L .1 0 0 r
F
.3992 .49188 m .43339 .4617 L .43117 .46282 L F
.43339 .4617 m .40545 .48879 L p .40746 .4324 L .856 0 0 r
F P
0 g
s
.44826 .44729 m .46109 .43485 L p .44677 .44804 L .1 0 0 r
F P
0 g
s
.46109 .43485 m .43339 .4617 L p .40746 .4324 L .856 0 0 r
F P
0 g
s
.45294 .46806 m .43258 .45672 L .41761 .47122 L p 0 .275 .685 r
F P
0 g
s
.44512 .4741 m .45294 .46806 L p .42643 .47043 L 0 .275 .685 r
F P
0 g
s
.41761 .47122 m .42484 .47198 L .42643 .47043 L 0 .275 .685 r
F
.42484 .47198 m .44512 .4741 L .42643 .47043 L F
.40449 .49021 m .39243 .50191 L p .39646 .4995 L .1 0 0 r
F P
0 g
s
.4349 .47922 m .44512 .4741 L p .42484 .47198 L 0 .275 .685 r
F P
0 g
s
.41761 .47122 m .42303 .47373 L .42484 .47198 L 0 .275 .685 r
F
.42303 .47373 m .4349 .47922 L .42484 .47198 L F
.43689 .47795 m .43536 .47623 L p .43411 .47698 L 0 .313 .947 r
F P
0 g
s
.43536 .47623 m .43015 .47034 L p .43411 .47698 L 0 .313 .947 r
F P
0 g
s
.42395 .47344 m .43411 .47698 L .43015 .47034 L 0 .313 .947 r
F
.41761 .47122 m .433 .47986 L .4349 .47922 L p 0 .275 .685 r
F P
0 g
s
.41761 .47122 m .433 .47986 L .43689 .47795 L p 0 .313 .947 r
F P
0 g
s
.433 .47986 m .41761 .47122 L .42682 .46659 L p 0 .313 .947 r
F P
0 g
s
.40545 .48879 m .39975 .43204 L .40746 .4324 L .856 0 0 r
F
.39218 .35677 m .428 .40344 L .38602 .36044 L .556 0 0 r
F
.428 .40344 m .42645 .40428 L .38602 .36044 L F
.38602 .36044 m .42039 .39936 L .36454 .45285 L p .856 0 0 r
F P
0 g
s
.36454 .45285 m .32977 .41368 L .38602 .36044 L p .856 0 0 r
F P
0 g
s
.38602 .36044 m .32977 .41368 L .3992 .49188 L p .856 0 0 r
F P
0 g
s
.40545 .48879 m .33573 .41022 L .39218 .35677 L p .856 0 0 r
F P
0 g
s
.433 .47986 m .41761 .47122 L .40458 .48384 L p 0 .275 .685 r
F P
0 g
s
.39751 .47984 m .40214 .48506 L p .38381 .47209 L .54 0 0 r
F P
0 g
s
.40214 .48506 m .40545 .48879 L p .40122 .48552 L .54 0 0 r
F P
0 g
s
.38381 .47209 m .40214 .48506 L .40122 .48552 L .54 0 0 r
F
.42682 .46659 m .41761 .47122 L p .42395 .47344 L 0 .313 .947 r
F P
0 g
s
.41761 .47122 m .42682 .46659 L p .4058 .48324 L 0 .05 .1 r
F P
0 g
s
.40214 .48506 m .3992 .49188 L .40545 .48879 L .54 0 0 r
F
.39751 .47984 m .3985 .48688 L .40214 .48506 L F
.3985 .48688 m .3992 .49188 L .40214 .48506 L F
.34993 .39714 m .36322 .41214 L .37835 .39776 L p 0 .349 .781 r
F P
0 g
s
.37835 .39776 m .3651 .38278 L .34993 .39714 L p 0 .349 .781 r
F P
0 g
s
.33573 .41022 m .38381 .47209 L .38442 .47243 L .54 0 0 r
F
.37563 .45519 m .38442 .47243 L .3889 .47013 L F
.33573 .41022 m .37231 .45695 L .37563 .45519 L F
.37231 .45695 m .38442 .47243 L .37563 .45519 L F
.41799 .44255 m .40479 .42764 L .38975 .44208 L p 0 .349 .781 r
F P
0 g
s
.38975 .44208 m .40299 .45701 L .41799 .44255 L p 0 .349 .781 r
F P
0 g
s
.42853 .45447 m .41799 .44255 L .40299 .45701 L p 0 .349 .781 r
F P
0 g
s
.41799 .44255 m .40299 .45701 L .41351 .45156 L p 0 .05 .1 r
F P
0 g
s
.44342 .44005 m .43291 .42816 L .41799 .44255 L p 0 .349 .781 r
F P
0 g
s
.41799 .44255 m .42853 .45447 L .44342 .44005 L p 0 .349 .781 r
F P
0 g
s
.44342 .44005 m .42853 .45447 L .43258 .45672 L p 0 .275 .685 r
F P
0 g
s
.41799 .44255 m .42853 .45447 L .43258 .45672 L p 0 .314 .946 r
F P
0 g
s
.42853 .45447 m .41799 .44255 L .4286 .437 L p 0 .314 .946 r
F P
0 g
s
.43258 .45672 m .44748 .44229 L .44342 .44005 L p 0 .275 .685 r
F P
0 g
s
.46289 .4508 m .44748 .44229 L .43258 .45672 L p 0 .275 .685 r
F P
0 g
s
.44748 .44229 m .43258 .45672 L .44187 .45201 L p 0 .05 .1 r
F P
0 g
s
.44748 .44229 m .46289 .4508 L .46476 .442 L p 0 .275 .685 r
F P
0 g
s
.44748 .44229 m .45256 .4451 L p .45385 .44444 L 0 .314 .945 r
F P
0 g
s
.44748 .44229 m .45559 .44216 L .46371 .43169 L 0 .275 .685 r
F
.46476 .442 m .46519 .43285 L p .45559 .44216 L F P
0 g
s
.46519 .43285 m .46534 .42959 L p .45559 .44216 L 0 .275 .685 r
F P
0 g
s
.44748 .44229 m .45684 .4375 L p .45884 .4419 L 0 .314 .945 r
F P
0 g
s
.45256 .4451 m .44748 .44229 L p .45884 .4419 L 0 .314 .945 r
F P
0 g
s
.46476 .442 m .46289 .4508 L .46684 .44882 L p 0 .082 .528 r
F P
0 g
s
.46684 .44882 m .45684 .4375 L .44748 .44229 L p 0 .314 .945 r
F P
0 g
s
.43258 .45672 m .44748 .44229 L .45684 .4375 L p 0 .05 .1 r
F P
0 g
s
.45684 .4375 m .44187 .45201 L .43258 .45672 L p 0 .05 .1 r
F P
0 g
s
.44187 .45201 m .4286 .437 L .41799 .44255 L p 0 .314 .946 r
F P
0 g
s
.43258 .45672 m .44187 .45201 L p .41799 .44255 L 0 .314 .946 r
F P
0 g
s
.40299 .45701 m .41799 .44255 L .4286 .437 L p 0 .05 .1 r
F P
0 g
s
.4286 .437 m .41351 .45156 L .40299 .45701 L p 0 .05 .1 r
F P
0 g
s
.38975 .44208 m .40299 .45701 L .41351 .45156 L p 0 .313 .947 r
F P
0 g
s
.37563 .45519 m .3889 .47013 L p .37212 .45705 L .54 0 0 r
F P
0 g
s
.38381 .47209 m .37212 .45705 L .3889 .47013 L .54 0 0 r
F
.3889 .47013 m .39751 .47984 L p .38442 .47243 L F P
0 g
s
.38381 .47209 m .3889 .47013 L .38442 .47243 L .54 0 0 r
F
.3889 .47013 m .38442 .47243 L .39751 .47984 L F
.38381 .47209 m .3992 .49188 L .39751 .47984 L F
.37585 .45542 m .40545 .48879 L .37533 .45592 L .884 0 0 r
F
.40545 .48879 m .3992 .49188 L p .38381 .47209 L .54 0 0 r
F P
0 g
s
.40545 .48879 m .3992 .49188 L .39317 .49819 L .1 0 0 r
F
.40545 .48879 m .39317 .49819 L .40459 .48969 L F
.37533 .45592 m .40545 .48879 L .40459 .48969 L .884 0 0 r
F
.33573 .41022 m .37563 .45519 L p .37212 .45705 L .54 0 0 r
F P
0 g
s
.3992 .49188 m .32977 .41368 L .33573 .41022 L p .54 0 0 r
F P
0 g
s
.33573 .41022 m .32977 .41368 L .3992 .49188 L .54 0 0 r
F
.33485 .41111 m .40459 .48969 L .40424 .49021 L .969 0 0 r
F
.33573 .41022 m .40459 .48969 L .33485 .41111 L .884 0 0 r
F
.33485 .41111 m .40424 .49021 L .33447 .4116 L .969 0 0 r
F
.40299 .45701 m .38975 .44208 L .37464 .45658 L p 0 .349 .781 r
F P
0 g
s
.40299 .45701 m .38975 .44208 L .40019 .43651 L p 0 .313 .947 r
F P
0 g
s
.41351 .45156 m .40019 .43651 L .38975 .44208 L p 0 .313 .947 r
F P
0 g
s
.40019 .43651 m .38975 .44208 L .37666 .45464 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .37666 .45464 L .37803 .45391 L 0 .05 .1 r
F
.38975 .44208 m .40019 .43651 L p .37803 .45391 L F P
0 g
s
.37666 .45464 m .37464 .45658 L p .37803 .45391 L 0 .05 .1 r
F P
0 g
s
.37464 .45658 m .37666 .45464 L p .37803 .45391 L 0 .05 .1 r
F P
0 g
s
.37666 .45464 m .38975 .44208 L p .37803 .45391 L 0 .05 .1 r
F P
0 g
s
.40299 .45701 m .41356 .46895 L .42853 .45447 L p 0 .349 .781 r
F P
0 g
s
.42853 .45447 m .41356 .46895 L .41761 .47122 L p 0 .275 .685 r
F P
0 g
s
.40299 .45701 m .41356 .46895 L .41761 .47122 L p 0 .313 .947 r
F P
0 g
s
.41761 .47122 m .41356 .46895 L .40299 .45701 L p 0 .313 .947 r
F P
0 g
s
.41356 .46895 m .40299 .45701 L .38792 .47154 L p 0 .349 .781 r
F P
0 g
s
.41761 .47122 m .43258 .45672 L .42853 .45447 L p 0 .275 .685 r
F P
0 g
s
.43258 .45672 m .41761 .47122 L .42682 .46659 L p 0 .05 .1 r
F P
0 g
s
.46257 .45231 m .46289 .4508 L p .43258 .45672 L 0 .275 .685 r
F P
0 g
s
.45868 .46089 m .46257 .45231 L p .43258 .45672 L 0 .275 .685 r
F P
0 g
s
.43258 .45672 m .45294 .46806 L .45868 .46089 L p 0 .275 .685 r
F P
0 g
s
.44187 .45201 m .43258 .45672 L p .43819 .45928 L 0 .314 .946 r
F P
0 g
s
.45868 .46089 m .45294 .46806 L .45511 .46699 L p 0 .05 .188 r
F P
0 g
s
.43258 .45672 m .45294 .46806 L .45511 .46699 L p 0 .314 .946 r
F P
0 g
s
.45294 .46806 m .43258 .45672 L .44187 .45201 L p 0 .314 .946 r
F P
0 g
s
.41761 .47122 m .43258 .45672 L .44187 .45201 L p 0 .05 .1 r
F P
0 g
s
.44187 .45201 m .42682 .46659 L .41761 .47122 L p 0 .05 .1 r
F P
0 g
s
.42682 .46659 m .41351 .45156 L .40299 .45701 L p 0 .313 .947 r
F P
0 g
s
.41761 .47122 m .42682 .46659 L p .40299 .45701 L 0 .313 .947 r
F P
0 g
s
.40299 .45701 m .41351 .45156 L p .41761 .47122 L 0 .313 .947 r
F P
0 g
s
.40299 .45701 m .41351 .45156 L p .39132 .46889 L 0 .05 .1 r
F P
0 g
s
.38792 .47154 m .38993 .4696 L p .39132 .46889 L 0 .05 .1 r
F P
0 g
s
.38993 .4696 m .40299 .45701 L p .39132 .46889 L 0 .05 .1 r
F P
0 g
s
.33573 .41022 m .37585 .45542 L .37533 .45592 L .884 0 0 r
F
.36322 .41214 m .34993 .39714 L .3347 .41157 L p 0 .349 .781 r
F P
0 g
s
.34993 .39714 m .36009 .39122 L p .33807 .40887 L 0 .05 .1 r
F P
0 g
s
.3347 .41157 m .33673 .40964 L p .33807 .40887 L 0 .05 .1 r
F P
0 g
s
.33673 .40964 m .34993 .39714 L p .33807 .40887 L 0 .05 .1 r
F P
0 g
s
.38792 .47154 m .39836 .46618 L p .39898 .46495 L 0 .05 .1 r
F P
0 g
s
.40299 .45701 m .38993 .4696 L p .39898 .46495 L 0 .05 .1 r
F P
0 g
s
.38993 .4696 m .38792 .47154 L p .39898 .46495 L 0 .05 .1 r
F P
0 g
s
.40485 .48399 m .40258 .48579 L p .40663 .485 L 0 .275 .685 r
F P
0 g
s
.40663 .485 m .433 .47986 L .40458 .48384 L 0 .275 .685 r
F
.40258 .48579 m .40458 .48384 L p .4058 .48324 L 0 .05 .1 r
F P
0 g
s
.40458 .48384 m .41761 .47122 L p .4058 .48324 L 0 .05 .1 r
F P
0 g
s
.39853 .4835 m .40258 .48579 L p .40404 .48354 L 0 .275 .685 r
F P
0 g
s
.41356 .46895 m .40054 .48155 L p .40404 .48354 L 0 .275 .685 r
F P
0 g
s
.40054 .48155 m .39853 .4835 L p .40404 .48354 L 0 .275 .685 r
F P
0 g
s
.40258 .48579 m .41171 .48124 L p .4125 .47989 L 0 .05 .1 r
F P
0 g
s
.41761 .47122 m .40458 .48384 L p .4125 .47989 L 0 .05 .1 r
F P
0 g
s
.40458 .48384 m .40258 .48579 L p .4125 .47989 L 0 .05 .1 r
F P
0 g
s
.42189 .48363 m .433 .47986 L p .40258 .48579 L 0 .275 .685 r
F P
0 g
s
.43851 .47744 m .44764 .47285 L .44512 .4741 L p 0 .05 .1 r
F P
0 g
s
.44512 .4741 m .4349 .47922 L .43851 .47744 L p 0 .05 .1 r
F P
0 g
s
.43689 .47795 m .43851 .47744 L .4349 .47922 L p 0 .485 .947 r
F P
0 g
s
.4349 .47922 m .433 .47986 L .43689 .47795 L p 0 .485 .947 r
F P
0 g
s
.42682 .46659 m .43689 .47795 L .433 .47986 L p 0 .313 .947 r
F P
0 g
s
.42735 .48094 m .43689 .47795 L .433 .47986 L p 0 .485 .947 r
F P
0 g
s
.433 .47986 m .42189 .48363 L .42735 .48094 L p 0 .485 .947 r
F P
0 g
s
.45511 .46699 m .44518 .45576 L p .43819 .45928 L 0 .314 .946 r
F P
0 g
s
.44764 .47285 m .45511 .46699 L .45294 .46806 L p 0 .05 .1 r
F P
0 g
s
.45294 .46806 m .44512 .4741 L .44764 .47285 L p 0 .05 .1 r
F P
0 g
s
.44187 .45201 m .45511 .46699 L .45294 .46806 L p 0 .314 .946 r
F P
0 g
s
.45511 .46699 m .44764 .47285 L p .44339 .4575 L 0 .349 .781 r
F P
0 g
s
.44518 .45576 m .44187 .45201 L p .43819 .45928 L 0 .314 .946 r
F P
0 g
s
.44187 .45201 m .44518 .45576 L p .44339 .4575 L 0 .349 .781 r
F P
0 g
s
.44518 .45576 m .45511 .46699 L p .44339 .4575 L 0 .349 .781 r
F P
0 g
s
.39646 .4995 m .40595 .49383 L .40764 .48866 L .1 0 0 r
F
.40258 .48579 m .4056 .4875 L .42189 .48363 L p 0 .275 .685 r
F P
0 g
s
.42189 .48363 m .4056 .4875 L .4137 .48348 L p 0 .492 1 r
F P
0 g
s
.4137 .48348 m .42735 .48094 L .42189 .48363 L p 0 .492 1 r
F P
0 g
s
.44764 .47285 m .45511 .46699 L p .43391 .46669 L 0 .349 .781 r
F P
0 g
s
.42682 .46659 m .43231 .46824 L .43391 .46669 L 0 .349 .781 r
F
.43231 .46824 m .44764 .47285 L .43391 .46669 L F
.43689 .47795 m .42682 .46659 L .44187 .45201 L p F P
0 g
s
.43851 .47744 m .43689 .47795 L p .44187 .45201 L 0 .349 .781 r
F P
0 g
s
.44764 .47285 m .43851 .47744 L p .44187 .45201 L 0 .349 .781 r
F P
0 g
s
.43851 .47744 m .44764 .47285 L p .42682 .46659 L 0 .349 .781 r
F P
0 g
s
.44764 .47285 m .43851 .47744 L .44937 .47211 L p 0 .05 .1 r
F P
0 g
s
.45511 .46699 m .44764 .47285 L .45855 .46749 L p 0 .05 .1 r
F P
0 g
s
.44773 .47262 m .44937 .47211 L .43851 .47744 L p 0 .485 .947 r
F P
0 g
s
.42682 .46659 m .43689 .47795 L .43851 .47744 L p 0 .349 .781 r
F P
0 g
s
.43851 .47744 m .43689 .47795 L .44773 .47262 L p 0 .485 .947 r
F P
0 g
s
.42682 .46659 m .43689 .47795 L .44773 .47262 L p 0 .313 .947 r
F P
0 g
s
.45511 .46699 m .44187 .45201 L .42682 .46659 L p 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .44773 .47262 L .43689 .47795 L p 0 .313 .947 r
F P
0 g
s
.43689 .47795 m .42682 .46659 L .4376 .46117 L p 0 .313 .947 r
F P
0 g
s
.43015 .47034 m .42682 .46659 L p .42395 .47344 L 0 .313 .947 r
F P
0 g
s
.42682 .46659 m .43689 .47795 L .42735 .48094 L p 0 .349 .781 r
F P
0 g
s
.43814 .47562 m .44773 .47262 L .43689 .47795 L p 0 .485 .947 r
F P
0 g
s
.43689 .47795 m .42682 .46659 L .41171 .48124 L p 0 .349 .781 r
F P
0 g
s
.42735 .48094 m .43689 .47795 L p .41171 .48124 L 0 .349 .781 r
F P
0 g
s
.43689 .47795 m .42735 .48094 L .43814 .47562 L p 0 .485 .947 r
F P
0 g
s
.44773 .47262 m .4376 .46117 L .42682 .46659 L p 0 .313 .947 r
F P
0 g
s
.42735 .48094 m .4137 .48348 L p .42682 .46659 L 0 .349 .781 r
F P
0 g
s
.4244 .47818 m .43814 .47562 L .42735 .48094 L p 0 .492 1 r
F P
0 g
s
.46289 .4508 m .46684 .44882 L p .45385 .44444 L 0 .314 .945 r
F P
0 g
s
.45256 .4451 m .46289 .4508 L p .45385 .44444 L 0 .314 .945 r
F P
0 g
s
.46289 .4508 m .45256 .4451 L p .45884 .4419 L 0 .314 .945 r
F P
0 g
s
.45684 .4375 m .46684 .44882 L .46289 .4508 L p 0 .314 .945 r
F P
0 g
s
.46684 .44882 m .45684 .4375 L .44187 .45201 L p 0 .349 .781 r
F P
0 g
s
.46624 .45047 m .46684 .44882 L .46289 .4508 L p 0 .082 .528 r
F P
0 g
s
.46624 .45047 m .46684 .44882 L p .44187 .45201 L 0 .349 .781 r
F P
0 g
s
.46289 .4508 m .46257 .45231 L .46624 .45047 L p 0 .082 .528 r
F P
0 g
s
.46257 .45231 m .45868 .46089 L .46123 .45963 L p 0 .05 .405 r
F P
0 g
s
.46123 .45963 m .46624 .45047 L .46257 .45231 L p 0 .05 .405 r
F P
0 g
s
.46123 .45963 m .46624 .45047 L p .44187 .45201 L 0 .349 .781 r
F P
0 g
s
.45511 .46699 m .44187 .45201 L .45684 .4375 L p 0 .349 .781 r
F P
0 g
s
.45511 .46699 m .46123 .45963 L .45868 .46089 L p 0 .05 .188 r
F P
0 g
s
.44187 .45201 m .45511 .46699 L .46123 .45963 L p 0 .349 .781 r
F P
0 g
s
.46123 .45963 m .45511 .46699 L p .45684 .4375 L 0 .349 .781 r
F P
0 g
s
.46123 .45963 m .45511 .46699 L .46607 .46159 L p 0 .05 .188 r
F P
0 g
s
.44187 .45201 m .45511 .46699 L .46607 .46159 L p 0 .314 .946 r
F P
0 g
s
.45511 .46699 m .44187 .45201 L .45273 .44649 L p 0 .314 .946 r
F P
0 g
s
.46624 .45047 m .46123 .45963 L p .45684 .4375 L 0 .349 .781 r
F P
0 g
s
.46624 .45047 m .46123 .45963 L .47222 .45418 L p 0 .05 .405 r
F P
0 g
s
.46607 .46159 m .47222 .45418 L .46123 .45963 L p 0 .05 .188 r
F P
0 g
s
.46607 .46159 m .45273 .44649 L .44187 .45201 L p 0 .314 .946 r
F P
0 g
s
.4376 .46117 m .45273 .44649 L p .45108 .45511 L 0 .349 .781 r
F P
0 g
s
.44773 .47262 m .44095 .46495 L p .45108 .45511 L 0 .349 .781 r
F P
0 g
s
.44095 .46495 m .4376 .46117 L p .45108 .45511 L 0 .349 .781 r
F P
0 g
s
.45855 .46749 m .46607 .46159 L .45511 .46699 L p 0 .05 .1 r
F P
0 g
s
.45273 .44649 m .46607 .46159 L .45511 .46699 L p 0 .314 .946 r
F P
0 g
s
.44937 .47211 m .45855 .46749 L .44764 .47285 L p 0 .05 .1 r
F P
0 g
s
.44937 .47211 m .45855 .46749 L p .44313 .46283 L 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .4413 .46461 L .44313 .46283 L 0 .349 .781 r
F
.4413 .46461 m .44937 .47211 L .44313 .46283 L F
.40595 .49383 m .41966 .48563 L .41504 .485 L .1 0 0 r
F
.41171 .48124 m .4137 .48348 L .42735 .48094 L p 0 .349 .781 r
F P
0 g
s
.42735 .48094 m .4137 .48348 L .4244 .47818 L p 0 .492 1 r
F P
0 g
s
.4376 .46117 m .44773 .47262 L .44937 .47211 L p 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .44773 .47262 L .43814 .47562 L p 0 .349 .781 r
F P
0 g
s
.45273 .44649 m .46607 .46159 L .45855 .46749 L p 0 .349 .781 r
F P
0 g
s
.45855 .46749 m .46607 .46159 L p .4376 .46117 L 0 .349 .781 r
F P
0 g
s
.44937 .47211 m .44773 .47262 L p .45273 .44649 L 0 .349 .781 r
F P
0 g
s
.45855 .46749 m .44937 .47211 L p .45273 .44649 L 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .44773 .47262 L .45874 .46721 L p 0 .313 .947 r
F P
0 g
s
.46607 .46159 m .45273 .44649 L .4376 .46117 L p 0 .349 .781 r
F P
0 g
s
.44773 .47262 m .4376 .46117 L .44854 .45566 L p 0 .313 .947 r
F P
0 g
s
.44773 .47262 m .4376 .46117 L .4224 .47591 L p 0 .349 .781 r
F P
0 g
s
.43814 .47562 m .44773 .47262 L p .4224 .47591 L 0 .349 .781 r
F P
0 g
s
.43814 .47562 m .4244 .47818 L p .4376 .46117 L 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .45874 .46721 L .44773 .47262 L p 0 .313 .947 r
F P
0 g
s
.43527 .47279 m .44909 .47023 L .43814 .47562 L p 0 .492 1 r
F P
0 g
s
.4224 .47591 m .4244 .47818 L .43814 .47562 L p 0 .349 .781 r
F P
0 g
s
.43814 .47562 m .4244 .47818 L .43527 .47279 L p 0 .492 1 r
F P
0 g
s
.44909 .47023 m .45874 .46721 L p .44168 .46942 L 0 .349 .781 r
F P
0 g
s
.43325 .47051 m .44069 .47038 L .44168 .46942 L 0 .349 .781 r
F
.44069 .47038 m .44909 .47023 L .44168 .46942 L F
.41966 .48563 m .43356 .47731 L .42576 .4797 L .1 0 0 r
F
.45874 .46721 m .44854 .45566 L .4376 .46117 L p 0 .313 .947 r
F P
0 g
s
.44854 .45566 m .4488 .4625 L .43527 .47279 L 0 .349 .781 r
F
.44909 .47023 m .43891 .47212 L p .4488 .4625 L F P
0 g
s
.43891 .47212 m .43527 .47279 L p .4488 .4625 L 0 .349 .781 r
F P
0 g
s
.44773 .47262 m .43814 .47562 L .44909 .47023 L p 0 .485 .947 r
F P
0 g
s
.45874 .46721 m .44854 .45566 L .43325 .47051 L p 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .45874 .46721 L .44909 .47023 L p 0 .349 .781 r
F P
0 g
s
.44371 .4686 m .45476 .46743 L .44909 .47023 L p 0 .492 1 r
F P
0 g
s
.43325 .47051 m .43527 .47279 L .44909 .47023 L p 0 .349 .781 r
F P
0 g
s
.44909 .47023 m .43527 .47279 L .44371 .4686 L p 0 .492 1 r
F P
0 g
s
.43532 .48089 m .44767 .46887 L p .43356 .47731 L .1 0 0 r
F P
0 g
s
.41966 .48563 m .42743 .48328 L .43356 .47731 L .1 0 0 r
F
.42743 .48328 m .43532 .48089 L .43356 .47731 L F
.44767 .46887 m .43663 .47433 L p .43356 .47731 L F P
0 g
s
.43663 .47433 m .42576 .4797 L p .43356 .47731 L .1 0 0 r
F P
0 g
s
.42576 .4797 m .41504 .485 L p .41966 .48563 L .1 0 0 r
F P
0 g
s
.40595 .49383 m .41559 .48958 L .41966 .48563 L .1 0 0 r
F
.41559 .48958 m .43532 .48089 L .41966 .48563 L F
.39646 .4995 m .40365 .49606 L .40595 .49383 L F
.40365 .49606 m .43532 .48089 L .40595 .49383 L F
.41504 .485 m .40764 .48866 L p .40595 .49383 L F P
0 g
s
.39243 .50191 m .39556 .50038 L p .39646 .4995 L .1 0 0 r
F P
0 g
s
.39556 .50038 m .43532 .48089 L p .39646 .4995 L .1 0 0 r
F P
0 g
s
.40764 .48866 m .40449 .49021 L p .39646 .4995 L .1 0 0 r
F P
0 g
s
.46296 .43128 m .46371 .43169 L .46534 .42959 L 0 .275 .685 r
F
.44748 .44229 m .46371 .43169 L .46296 .43128 L F
.46534 .42959 m .46476 .442 L .47034 .43917 L p 0 .117 .6 r
F P
0 g
s
.47034 .43917 m .4737 .42528 L .46534 .42959 L p 0 .117 .6 r
F P
0 g
s
.45684 .4375 m .46318 .43828 L .4737 .42528 L 0 .349 .781 r
F
.47034 .43917 m .47282 .42893 L p .46318 .43828 L F P
0 g
s
.47282 .42893 m .4737 .42528 L p .46318 .43828 L 0 .349 .781 r
F P
0 g
s
.46231 .42793 m .46534 .42959 L .4737 .42528 L p 0 .315 .944 r
F P
0 g
s
.4737 .42528 m .47174 .42305 L .46231 .42793 L p 0 .315 .944 r
F P
0 g
s
.47174 .42305 m .4737 .42528 L .47282 .42893 L p 0 .349 .781 r
F P
0 g
s
.47282 .42893 m .47034 .43917 L p .47108 .43062 L 0 .349 .781 r
F P
0 g
s
.47174 .42305 m .47282 .42893 L .47108 .43062 L 0 .349 .781 r
F
.47174 .42305 m .4737 .42528 L .48475 .41959 L p 0 .315 .944 r
F P
0 g
s
.4737 .42528 m .47034 .43917 L .48138 .43358 L p 0 .117 .6 r
F P
0 g
s
.48138 .43358 m .48475 .41959 L .4737 .42528 L p 0 .117 .6 r
F P
0 g
s
.46534 .42959 m .46231 .42793 L .44748 .44229 L p 0 .275 .685 r
F P
0 g
s
.46684 .44882 m .47034 .43917 L .46476 .442 L p 0 .082 .528 r
F P
0 g
s
.46684 .44882 m .45684 .4375 L .47174 .42305 L p 0 .349 .781 r
F P
0 g
s
.47034 .43917 m .46684 .44882 L p .47174 .42305 L 0 .349 .781 r
F P
0 g
s
.48475 .41959 m .48277 .41735 L .47174 .42305 L p 0 .315 .944 r
F P
0 g
s
.46779 .43188 m .48277 .41735 L p .48115 .42591 L 0 .349 .781 r
F P
0 g
s
.47785 .4433 m .48138 .43358 L .47034 .43917 L p 0 .082 .528 r
F P
0 g
s
.47785 .4433 m .47111 .43565 L p .48115 .42591 L 0 .349 .781 r
F P
0 g
s
.47111 .43565 m .46779 .43188 L p .48115 .42591 L 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .47417 .43268 L .48475 .41959 L 0 .349 .781 r
F
.48138 .43358 m .48386 .42327 L p .47417 .43268 L F P
0 g
s
.48386 .42327 m .48475 .41959 L p .47417 .43268 L 0 .349 .781 r
F P
0 g
s
.48277 .41735 m .48475 .41959 L .48386 .42327 L p 0 .349 .781 r
F P
0 g
s
.48386 .42327 m .48138 .43358 L p .48212 .42497 L 0 .349 .781 r
F P
0 g
s
.48277 .41735 m .48386 .42327 L .48212 .42497 L 0 .349 .781 r
F
.48138 .43358 m .47785 .4433 L p .48277 .41735 L F P
0 g
s
.4789 .42619 m .49397 .41155 L p .49234 .42017 L 0 .349 .781 r
F P
0 g
s
.48904 .43769 m .48225 .42999 L p .49234 .42017 L 0 .349 .781 r
F P
0 g
s
.48225 .42999 m .4789 .42619 L p .49234 .42017 L 0 .349 .781 r
F P
0 g
s
.4789 .42619 m .48533 .42699 L .49597 .41382 L 0 .349 .781 r
F
.49258 .4279 m .49507 .41752 L p .48533 .42699 L F P
0 g
s
.49507 .41752 m .49597 .41382 L p .48533 .42699 L 0 .349 .781 r
F P
0 g
s
.50631 .4066 m .50527 .41126 L .51641 .40042 L .1 0 0 r
F
.49978 .41294 m .50527 .41126 L .50631 .4066 L F
.50527 .41126 m .5087 .4095 L p .51641 .40042 L F P
0 g
s
.43785 .32892 m .5087 .4095 L .49731 .41535 L p .556 0 0 r
F P
0 g
s
.44459 .35544 m .43785 .32892 L .49731 .41535 L .556 0 0 r
F
.49397 .41155 m .49597 .41382 L .49507 .41752 L p 0 .349 .781 r
F P
0 g
s
.49507 .41752 m .49258 .4279 L p .49332 .41923 L 0 .349 .781 r
F P
0 g
s
.49397 .41155 m .49507 .41752 L .49332 .41923 L 0 .349 .781 r
F
.49397 .41155 m .49597 .41382 L .50468 .40933 L p 0 .315 .944 r
F P
0 g
s
.49597 .41382 m .49258 .4279 L .49837 .42497 L p 0 .117 .6 r
F P
0 g
s
.49837 .42497 m .50468 .40933 L .49597 .41382 L p 0 .117 .6 r
F P
0 g
s
.50468 .40933 m .50382 .40646 L .49397 .41155 L p 0 .315 .944 r
F P
0 g
s
.48867 .42118 m .50382 .40646 L p .50028 .41611 L 0 .432 .873 r
F P
0 g
s
.50028 .41611 m .49816 .42189 L .49461 .42162 L 0 .432 .873 r
F
.50028 .41611 m .49461 .42162 L .48867 .42118 L F
.52077 .39776 m .50931 .40369 L p .50631 .4066 L .1 0 0 r
F P
0 g
s
.4501 .31729 m .52077 .39776 L .5087 .4095 L p .858 0 0 r
F P
0 g
s
.43785 .32892 m .52077 .39776 L .4501 .31729 L .858 0 0 r
F
.45206 .31679 m .4855 .3576 L .4501 .31729 L .175 0 0 r
F
.5087 .4095 m .43785 .32892 L .4501 .31729 L p .858 0 0 r
F P
0 g
s
.43813 .32885 m .4501 .31729 L .45206 .31679 L .1 0 0 r
F
.45206 .31679 m .48757 .35722 L .4855 .3576 L .175 0 0 r
F
.44967 .32007 m .45206 .31679 L .48757 .35722 L .978 0 0 r
F
.48653 .35741 m .4855 .3576 L .52077 .39776 L .175 0 0 r
F
.48653 .35741 m .52077 .39776 L .48757 .35722 L F
.48642 .35891 m .48757 .35722 L .52294 .3975 L .978 0 0 r
F
.44967 .32007 m .48757 .35722 L .48642 .35891 L F
.48757 .35722 m .51369 .33051 L .49068 .35262 L .1 0 0 r
F
.43291 .42816 m .44361 .42252 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.44777 .41384 m .44579 .41574 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.44579 .41574 m .43291 .42816 L p .44722 .41498 L 0 .05 .1 r
F P
0 g
s
.41976 .41327 m .43291 .42816 L .44777 .41384 L p 0 .349 .781 r
F P
0 g
s
.43291 .42816 m .44777 .41384 L .45855 .4081 L p 0 .05 .1 r
F P
0 g
s
.45855 .4081 m .44361 .42252 L .43291 .42816 L p 0 .05 .1 r
F P
0 g
s
.44535 .39312 m .45855 .4081 L .44361 .42252 L p 0 .349 .781 r
F P
0 g
s
.44535 .39312 m .45855 .4081 L .4695 .40228 L p 0 .315 .944 r
F P
0 g
s
.45855 .4081 m .44535 .39312 L .43037 .40752 L p 0 .349 .781 r
F P
0 g
s
.44361 .42252 m .43037 .40752 L .44535 .39312 L p 0 .349 .781 r
F P
0 g
s
.4695 .40228 m .4562 .38718 L .44535 .39312 L p 0 .315 .944 r
F P
0 g
s
.44535 .39312 m .43037 .40752 L .44113 .40167 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .4562 .38718 L .44535 .39312 L p 0 .05 .1 r
F P
0 g
s
.43037 .40752 m .44535 .39312 L .4562 .38718 L p 0 .05 .1 r
F P
0 g
s
.43213 .37813 m .44535 .39312 L .4562 .38718 L p 0 .315 .944 r
F P
0 g
s
.4562 .38718 m .44289 .37207 L .43213 .37813 L p 0 .315 .944 r
F P
0 g
s
.4562 .38718 m .44113 .40167 L .43037 .40752 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .4562 .38718 L .45121 .38152 L p 0 .349 .781 r
F P
0 g
s
.42153 .38409 m .43466 .39898 L .44535 .39312 L p 0 .315 .944 r
F P
0 g
s
.44535 .39312 m .43213 .37813 L .42153 .38409 L p 0 .315 .944 r
F P
0 g
s
.44535 .39312 m .43037 .40752 L .41976 .41327 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .45121 .38152 L .44179 .39056 L 0 .349 .781 r
F
.4562 .38718 m .44113 .40167 L p .44179 .39056 L F P
0 g
s
.45121 .38152 m .44289 .37207 L p .44179 .39056 L 0 .349 .781 r
F P
0 g
s
.44289 .37207 m .45121 .38152 L p .44179 .39056 L 0 .349 .781 r
F P
0 g
s
.45121 .38152 m .4562 .38718 L p .44179 .39056 L 0 .349 .781 r
F P
0 g
s
.4916 .43616 m .49243 .43734 L .48587 .44063 L .56 0 0 r
F
.49258 .4279 m .48904 .43769 L .49313 .43564 L p 0 .082 .528 r
F P
0 g
s
.49313 .43564 m .49837 .42497 L .49258 .4279 L p 0 .082 .528 r
F P
0 g
s
.4789 .42619 m .48904 .43769 L .49258 .4279 L p 0 .349 .781 r
F P
0 g
s
.49313 .43564 m .49103 .42883 L p .49816 .42189 L 0 .432 .873 r
F P
0 g
s
.49103 .42883 m .48867 .42118 L p .49816 .42189 L 0 .432 .873 r
F P
0 g
s
.52479 .3981 m .52017 .40048 L p .53414 .38688 L .1 0 0 r
F P
0 g
s
.55968 .36413 m .52479 .3981 L p .54799 .37027 L .1 0 0 r
F P
0 g
s
.56355 .36209 m .55968 .36413 L .5317 .33216 L .569 0 0 r
F
.56568 .3641 m .55968 .36413 L .56355 .36209 L F
.52261 .24846 m .5 .26235 L .41621 .34178 L p 0 .05 .1 r
F P
0 g
s
.41621 .34178 m .43785 .32892 L .52261 .24846 L p 0 .05 .1 r
F P
0 g
s
.45639 .30369 m .4785 .29034 L p .44239 .31697 L .1 0 0 r
F P
0 g
s
.40718 .34294 m .45639 .30369 L .44239 .31697 L .1 0 0 r
F
.41621 .34178 m .42832 .3303 L p .42745 .33083 L 0 .05 .1 r
F P
0 g
s
.4785 .29034 m .4501 .31729 L .42832 .3303 L p .1 0 0 r
F P
0 g
s
.42832 .3303 m .40718 .34294 L p .44239 .31697 L .1 0 0 r
F P
0 g
s
.44239 .31697 m .4785 .29034 L .42832 .3303 L .1 0 0 r
F
.42832 .3303 m .5 .26235 L p .5 .26235 L 0 .349 .781 r
F P
0 g
s
.42832 .3303 m .5 .26235 L .42318 .32446 L 0 .349 .781 r
F
.42832 .3303 m .5 .26235 L .42832 .3303 L F
.39521 .35427 m .40718 .34294 L .42832 .3303 L p .1 0 0 r
F P
0 g
s
.42832 .3303 m .4501 .31729 L p .42227 .33604 L .1 0 0 r
F P
0 g
s
.39521 .35427 m .42832 .3303 L .42227 .33604 L .1 0 0 r
F
.4501 .31729 m .43785 .32892 L .41621 .34178 L p F P
0 g
s
.41621 .34178 m .39521 .35427 L p .42227 .33604 L .1 0 0 r
F P
0 g
s
.42227 .33604 m .4501 .31729 L .41621 .34178 L .1 0 0 r
F
.48896 .24314 m .48895 .26914 L .5 .26235 L p 0 .181 .719 r
F P
0 g
s
.48895 .26914 m .48896 .24314 L .5 .23617 L p 0 .181 .719 r
F P
0 g
s
.5 .23617 m .5 .26235 L .48895 .26914 L p 0 .181 .719 r
F P
0 g
s
.44303 .23581 m .47805 .27583 L .5 .26235 L p 0 .318 .939 r
F P
0 g
s
.47133 .249 m .46056 .25584 L .44303 .23581 L p 0 .318 .939 r
F P
0 g
s
.44303 .23581 m .45368 .22882 L .47133 .249 L p 0 .318 .939 r
F P
0 g
s
.5 .26235 m .4645 .22171 L .44303 .23581 L p 0 .318 .939 r
F P
0 g
s
.47133 .249 m .45368 .22882 L .4645 .22171 L p 0 .318 .939 r
F P
0 g
s
.41621 .34178 m .38008 .30075 L .4645 .22171 L p 0 .349 .781 r
F P
0 g
s
.42832 .3303 m .41621 .34178 L p .42318 .32446 L 0 .349 .781 r
F P
0 g
s
.41621 .34178 m .42832 .3303 L p .42318 .32446 L 0 .349 .781 r
F P
0 g
s
.41621 .34178 m .39521 .35427 L .35957 .31387 L p 0 .315 .944 r
F P
0 g
s
.46056 .25584 m .47133 .249 L .48895 .26914 L p 0 .318 .939 r
F P
0 g
s
.48895 .26914 m .47133 .249 L .48227 .24205 L p 0 .318 .939 r
F P
0 g
s
.48227 .24205 m .5 .26235 L .48895 .26914 L p 0 .318 .939 r
F P
0 g
s
.4645 .22171 m .48227 .24205 L .47133 .249 L p 0 .318 .939 r
F P
0 g
s
.5 .26235 m .4645 .22171 L p .42318 .32446 L 0 .349 .781 r
F P
0 g
s
.44342 .44005 m .44748 .44229 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.45825 .42571 m .45628 .42762 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.45628 .42762 m .44342 .44005 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.39218 .35677 m .43162 .40146 L p .39975 .43204 L .856 0 0 r
F P
0 g
s
.46231 .42793 m .45825 .42571 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.44748 .44229 m .46033 .42984 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.46033 .42984 m .46231 .42793 L p .45682 .42792 L 0 .275 .685 r
F P
0 g
s
.32977 .41368 m .36454 .45285 L .35844 .4591 L .884 0 0 r
F
.33447 .4116 m .40424 .49021 L .40449 .49021 L .1 0 0 r
F
.40424 .49021 m .39243 .50191 L .40449 .49021 L F
.33447 .4116 m .40449 .49021 L .3347 .41157 L F
.39243 .50191 m .40449 .49021 L .3347 .41157 L p .856 0 0 r
F P
0 g
s
.32359 .41986 m .35715 .46088 L .35844 .4591 L .968 0 0 r
F
.32977 .41368 m .35844 .4591 L .32359 .41986 L .884 0 0 r
F
.37835 .39776 m .3934 .38344 L .38019 .36849 L p 0 .349 .781 r
F P
0 g
s
.3934 .38344 m .37835 .39776 L .39158 .41271 L p 0 .349 .781 r
F P
0 g
s
.38019 .36849 m .3651 .38278 L .37835 .39776 L p 0 .349 .781 r
F P
0 g
s
.3765 .42712 m .38975 .44208 L .40479 .42764 L p 0 .349 .781 r
F P
0 g
s
.40479 .42764 m .39158 .41271 L .3765 .42712 L p 0 .349 .781 r
F P
0 g
s
.43291 .42816 m .41976 .41327 L .40479 .42764 L p 0 .349 .781 r
F P
0 g
s
.40479 .42764 m .41799 .44255 L .43291 .42816 L p 0 .349 .781 r
F P
0 g
s
.43291 .42816 m .41799 .44255 L .4286 .437 L p 0 .05 .1 r
F P
0 g
s
.43291 .42816 m .44342 .44005 L .45825 .42571 L p 0 .349 .781 r
F P
0 g
s
.44342 .44005 m .43291 .42816 L .44361 .42252 L p 0 .314 .945 r
F P
0 g
s
.44748 .44229 m .46231 .42793 L .47174 .42305 L p 0 .05 .1 r
F P
0 g
s
.46231 .42793 m .44748 .44229 L .45684 .4375 L p 0 .05 .1 r
F P
0 g
s
.47174 .42305 m .45684 .4375 L .44748 .44229 L p 0 .05 .1 r
F P
0 g
s
.43291 .42816 m .44342 .44005 L p .45684 .4375 L 0 .314 .945 r
F P
0 g
s
.45684 .4375 m .44361 .42252 L .43291 .42816 L p 0 .314 .945 r
F P
0 g
s
.41799 .44255 m .43291 .42816 L .44361 .42252 L p 0 .05 .1 r
F P
0 g
s
.44361 .42252 m .4286 .437 L .41799 .44255 L p 0 .05 .1 r
F P
0 g
s
.40479 .42764 m .41799 .44255 L .4286 .437 L p 0 .314 .946 r
F P
0 g
s
.41799 .44255 m .40479 .42764 L .41531 .42198 L p 0 .314 .946 r
F P
0 g
s
.4286 .437 m .41531 .42198 L .40479 .42764 L p 0 .314 .946 r
F P
0 g
s
.41531 .42198 m .40479 .42764 L .38975 .44208 L p 0 .05 .1 r
F P
0 g
s
.38975 .44208 m .40479 .42764 L .41531 .42198 L p 0 .05 .1 r
F P
0 g
s
.36322 .41214 m .3765 .42712 L .39158 .41271 L p 0 .349 .781 r
F P
0 g
s
.39158 .41271 m .37835 .39776 L .36322 .41214 L p 0 .349 .781 r
F P
0 g
s
.39158 .41271 m .40659 .39837 L .3934 .38344 L p 0 .349 .781 r
F P
0 g
s
.40659 .39837 m .39158 .41271 L .40479 .42764 L p 0 .349 .781 r
F P
0 g
s
.37835 .39776 m .39158 .41271 L .40201 .40693 L p 0 .314 .946 r
F P
0 g
s
.40201 .40693 m .39158 .41271 L .37835 .39776 L p 0 .314 .946 r
F P
0 g
s
.40258 .48579 m .41761 .47122 L .41356 .46895 L p 0 .275 .685 r
F P
0 g
s
.38792 .47154 m .39853 .4835 L .41356 .46895 L p 0 .349 .781 r
F P
0 g
s
.3651 .38278 m .37835 .39776 L .38869 .39186 L p 0 .314 .946 r
F P
0 g
s
.40201 .40693 m .38869 .39186 L .37835 .39776 L p 0 .314 .946 r
F P
0 g
s
.38869 .39186 m .37835 .39776 L .3651 .38278 L p 0 .314 .946 r
F P
0 g
s
.37835 .39776 m .38869 .39186 L .40201 .40693 L p 0 .314 .946 r
F P
0 g
s
.37464 .45658 m .38792 .47154 L .40299 .45701 L p 0 .349 .781 r
F P
0 g
s
.36135 .4416 m .37464 .45658 L .38975 .44208 L p 0 .349 .781 r
F P
0 g
s
.38975 .44208 m .3765 .42712 L .36135 .4416 L p 0 .349 .781 r
F P
0 g
s
.38975 .44208 m .40019 .43651 L .41531 .42198 L p 0 .05 .1 r
F P
0 g
s
.41531 .42198 m .40019 .43651 L .38975 .44208 L p 0 .05 .1 r
F P
0 g
s
.34803 .42659 m .36135 .4416 L .3765 .42712 L p 0 .349 .781 r
F P
0 g
s
.3765 .42712 m .36322 .41214 L .34803 .42659 L p 0 .349 .781 r
F P
0 g
s
.3347 .41157 m .34803 .42659 L .36322 .41214 L p 0 .349 .781 r
F P
0 g
s
.41351 .45156 m .39836 .46618 L .38792 .47154 L p 0 .05 .1 r
F P
0 g
s
.42682 .46659 m .41171 .48124 L .40258 .48579 L p 0 .05 .1 r
F P
0 g
s
.37464 .45658 m .38499 .4511 L .40019 .43651 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .38499 .4511 L .37464 .45658 L p 0 .05 .1 r
F P
0 g
s
.38499 .4511 m .37464 .45658 L .36135 .4416 L p 0 .312 .948 r
F P
0 g
s
.3716 .43601 m .36135 .4416 L .34803 .42659 L p 0 .312 .948 r
F P
0 g
s
.36135 .4416 m .3716 .43601 L .38499 .4511 L p 0 .312 .948 r
F P
0 g
s
.35819 .42089 m .34803 .42659 L .3347 .41157 L p 0 .312 .948 r
F P
0 g
s
.34803 .42659 m .35819 .42089 L .3716 .43601 L p 0 .312 .948 r
F P
0 g
s
.3347 .41157 m .34476 .40574 L .35819 .42089 L p 0 .312 .948 r
F P
0 g
s
.40019 .43651 m .41351 .45156 L .40299 .45701 L p 0 .313 .947 r
F P
0 g
s
.41351 .45156 m .40019 .43651 L .38499 .4511 L p 0 .349 .781 r
F P
0 g
s
.39836 .46618 m .41351 .45156 L .40299 .45701 L p 0 .05 .1 r
F P
0 g
s
.38499 .4511 m .39836 .46618 L .41351 .45156 L p 0 .349 .781 r
F P
0 g
s
.41531 .42198 m .4286 .437 L .41799 .44255 L p 0 .314 .946 r
F P
0 g
s
.4286 .437 m .41531 .42198 L .40019 .43651 L p 0 .349 .781 r
F P
0 g
s
.41351 .45156 m .4286 .437 L .41799 .44255 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .41351 .45156 L .4286 .437 L p 0 .349 .781 r
F P
0 g
s
.41351 .45156 m .40019 .43651 L .41531 .42198 L p 0 .349 .781 r
F P
0 g
s
.40019 .43651 m .41351 .45156 L .39836 .46618 L p 0 .349 .781 r
F P
0 g
s
.43258 .45672 m .42853 .45447 L p .4286 .437 L 0 .314 .946 r
F P
0 g
s
.4286 .437 m .44187 .45201 L .43258 .45672 L p 0 .314 .946 r
F P
0 g
s
.44187 .45201 m .4286 .437 L .41351 .45156 L p 0 .349 .781 r
F P
0 g
s
.41531 .42198 m .4286 .437 L .41351 .45156 L p 0 .349 .781 r
F P
0 g
s
.42682 .46659 m .41351 .45156 L .4286 .437 L p 0 .349 .781 r
F P
0 g
s
.4286 .437 m .41351 .45156 L .4242 .44602 L p 0 .05 .1 r
F P
0 g
s
.44748 .44229 m .44342 .44005 L p .44361 .42252 L 0 .314 .945 r
F P
0 g
s
.44361 .42252 m .45684 .4375 L .44748 .44229 L p 0 .314 .945 r
F P
0 g
s
.45684 .4375 m .44361 .42252 L .4286 .437 L p 0 .349 .781 r
F P
0 g
s
.44342 .44005 m .44748 .44229 L .45684 .4375 L p 0 .314 .945 r
F P
0 g
s
.44187 .45201 m .45684 .4375 L .44748 .44229 L p 0 .05 .1 r
F P
0 g
s
.4286 .437 m .44187 .45201 L .45684 .4375 L p 0 .349 .781 r
F P
0 g
s
.44187 .45201 m .4286 .437 L .44361 .42252 L p 0 .349 .781 r
F P
0 g
s
.42682 .46659 m .44187 .45201 L .43258 .45672 L p 0 .05 .1 r
F P
0 g
s
.4286 .437 m .44187 .45201 L .42682 .46659 L p 0 .349 .781 r
F P
0 g
s
.44361 .42252 m .45684 .4375 L .44187 .45201 L p 0 .349 .781 r
F P
0 g
s
.45684 .4375 m .44187 .45201 L .45273 .44649 L p 0 .05 .1 r
F P
0 g
s
.45684 .4375 m .46684 .44882 L .47034 .43917 L p 0 .349 .781 r
F P
0 g
s
.46684 .44882 m .45684 .4375 L .46779 .43188 L p 0 .314 .945 r
F P
0 g
s
.45684 .4375 m .46684 .44882 L .46624 .45047 L p 0 .349 .781 r
F P
0 g
s
.47034 .43917 m .46684 .44882 L .47785 .4433 L p 0 .082 .528 r
F P
0 g
s
.45684 .4375 m .46684 .44882 L .47785 .4433 L p 0 .314 .945 r
F P
0 g
s
.47785 .4433 m .46779 .43188 L .45684 .4375 L p 0 .314 .945 r
F P
0 g
s
.44187 .45201 m .45684 .4375 L .46779 .43188 L p 0 .05 .1 r
F P
0 g
s
.46779 .43188 m .45273 .44649 L .44187 .45201 L p 0 .05 .1 r
F P
0 g
s
.4286 .437 m .44187 .45201 L .45273 .44649 L p 0 .314 .946 r
F P
0 g
s
.44187 .45201 m .4286 .437 L .43937 .43137 L p 0 .314 .946 r
F P
0 g
s
.45273 .44649 m .43937 .43137 L .4286 .437 L p 0 .314 .946 r
F P
0 g
s
.41351 .45156 m .4286 .437 L .43937 .43137 L p 0 .05 .1 r
F P
0 g
s
.43937 .43137 m .4242 .44602 L .41351 .45156 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .41351 .45156 L .4242 .44602 L p 0 .313 .947 r
F P
0 g
s
.41351 .45156 m .40019 .43651 L .41078 .43085 L p 0 .313 .947 r
F P
0 g
s
.39836 .46618 m .38499 .4511 L .40019 .43651 L p 0 .349 .781 r
F P
0 g
s
.4242 .44602 m .41078 .43085 L .40019 .43651 L p 0 .313 .947 r
F P
0 g
s
.41078 .43085 m .40019 .43651 L .38499 .4511 L p 0 .05 .1 r
F P
0 g
s
.38499 .4511 m .40019 .43651 L .41078 .43085 L p 0 .05 .1 r
F P
0 g
s
.38499 .4511 m .39549 .44555 L .41078 .43085 L p 0 .05 .1 r
F P
0 g
s
.41078 .43085 m .39549 .44555 L .38499 .4511 L p 0 .05 .1 r
F P
0 g
s
.39549 .44555 m .38499 .4511 L .3716 .43601 L p 0 .312 .948 r
F P
0 g
s
.38201 .43033 m .3716 .43601 L .35819 .42089 L p 0 .312 .948 r
F P
0 g
s
.3716 .43601 m .38201 .43033 L .39549 .44555 L p 0 .312 .948 r
F P
0 g
s
.35819 .42089 m .3685 .41509 L .38201 .43033 L p 0 .312 .948 r
F P
0 g
s
.3685 .41509 m .35819 .42089 L .34476 .40574 L p 0 .312 .948 r
F P
0 g
s
.34476 .40574 m .35498 .39983 L .3685 .41509 L p 0 .312 .948 r
F P
0 g
s
.40838 .36919 m .3934 .38344 L .40659 .39837 L p 0 .349 .781 r
F P
0 g
s
.38869 .39186 m .37534 .37677 L .3651 .38278 L p 0 .314 .946 r
F P
0 g
s
.3651 .38278 m .37534 .37677 L .38869 .39186 L p 0 .314 .946 r
F P
0 g
s
.42153 .38409 m .40659 .39837 L .41976 .41327 L p 0 .349 .781 r
F P
0 g
s
.40479 .42764 m .41976 .41327 L .40659 .39837 L p 0 .349 .781 r
F P
0 g
s
.38869 .39186 m .40201 .40693 L .41259 .40106 L p 0 .314 .946 r
F P
0 g
s
.41259 .40106 m .40201 .40693 L .38869 .39186 L p 0 .314 .946 r
F P
0 g
s
.37534 .37677 m .38869 .39186 L .39918 .38587 L p 0 .314 .946 r
F P
0 g
s
.40659 .39837 m .42153 .38409 L .40838 .36919 L p 0 .349 .781 r
F P
0 g
s
.41259 .40106 m .39918 .38587 L .38869 .39186 L p 0 .314 .946 r
F P
0 g
s
.39918 .38587 m .38869 .39186 L .37534 .37677 L p 0 .314 .946 r
F P
0 g
s
.38869 .39186 m .39918 .38587 L .41259 .40106 L p 0 .314 .946 r
F P
0 g
s
.3704 .38521 m .38388 .40045 L .39918 .38587 L p 0 .349 .781 r
F P
0 g
s
.39918 .38587 m .38388 .40045 L .3704 .38521 L p 0 .349 .781 r
F P
0 g
s
.43291 .42816 m .41976 .41327 L .43037 .40752 L p 0 .314 .945 r
F P
0 g
s
.41976 .41327 m .43291 .42816 L .44361 .42252 L p 0 .314 .945 r
F P
0 g
s
.43037 .40752 m .44361 .42252 L .43291 .42816 L p 0 .314 .945 r
F P
0 g
s
.44361 .42252 m .43037 .40752 L .41976 .41327 L p 0 .314 .945 r
F P
0 g
s
.44361 .42252 m .43037 .40752 L .41531 .42198 L p 0 .349 .781 r
F P
0 g
s
.4286 .437 m .44361 .42252 L .43291 .42816 L p 0 .05 .1 r
F P
0 g
s
.41531 .42198 m .4286 .437 L .44361 .42252 L p 0 .349 .781 r
F P
0 g
s
.4286 .437 m .41531 .42198 L .43037 .40752 L p 0 .349 .781 r
F P
0 g
s
.44361 .42252 m .4286 .437 L .43937 .43137 L p 0 .05 .1 r
F P
0 g
s
.43037 .40752 m .44361 .42252 L .4286 .437 L p 0 .349 .781 r
F P
0 g
s
.47174 .42305 m .45855 .4081 L .44361 .42252 L p 0 .349 .781 r
F P
0 g
s
.45825 .42571 m .46231 .42793 L .47174 .42305 L p 0 .315 .944 r
F P
0 g
s
.45684 .4375 m .47174 .42305 L .46231 .42793 L p 0 .05 .1 r
F P
0 g
s
.44361 .42252 m .45684 .4375 L .47174 .42305 L p 0 .349 .781 r
F P
0 g
s
.45684 .4375 m .44361 .42252 L .45855 .4081 L p 0 .349 .781 r
F P
0 g
s
.45684 .4375 m .44361 .42252 L .45447 .41679 L p 0 .314 .945 r
F P
0 g
s
.4737 .42528 m .47174 .42305 L .45684 .4375 L p 0 .349 .781 r
F P
0 g
s
.45855 .4081 m .47174 .42305 L .45684 .4375 L p 0 .349 .781 r
F P
0 g
s
.45684 .4375 m .47174 .42305 L .48277 .41735 L p 0 .05 .1 r
F P
0 g
s
.47174 .42305 m .45684 .4375 L .46779 .43188 L p 0 .05 .1 r
F P
0 g
s
.48277 .41735 m .46779 .43188 L .45684 .4375 L p 0 .05 .1 r
F P
0 g
s
.44361 .42252 m .45684 .4375 L .46779 .43188 L p 0 .314 .945 r
F P
0 g
s
.46779 .43188 m .45447 .41679 L .44361 .42252 L p 0 .314 .945 r
F P
0 g
s
.4286 .437 m .44361 .42252 L .45447 .41679 L p 0 .05 .1 r
F P
0 g
s
.45447 .41679 m .43937 .43137 L .4286 .437 L p 0 .05 .1 r
F P
0 g
s
.41531 .42198 m .4286 .437 L .43937 .43137 L p 0 .314 .946 r
F P
0 g
s
.4286 .437 m .41531 .42198 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.43937 .43137 m .42599 .41623 L .41531 .42198 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .41531 .42198 L .40019 .43651 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .41531 .42198 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.40019 .43651 m .41078 .43085 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .41078 .43085 L .40019 .43651 L p 0 .05 .1 r
F P
0 g
s
.39549 .44555 m .41078 .43085 L p .40001 .43066 L 0 .349 .781 r
F P
0 g
s
.38201 .43033 m .39043 .43984 L p .40001 .43066 L 0 .349 .781 r
F P
0 g
s
.39043 .43984 m .39549 .44555 L p .40001 .43066 L 0 .349 .781 r
F P
0 g
s
.41976 .41327 m .40479 .42764 L .41531 .42198 L p 0 .05 .1 r
F P
0 g
s
.41531 .42198 m .43037 .40752 L .41976 .41327 L p 0 .05 .1 r
F P
0 g
s
.40479 .42764 m .41976 .41327 L .43037 .40752 L p 0 .05 .1 r
F P
0 g
s
.43037 .40752 m .41531 .42198 L .40479 .42764 L p 0 .05 .1 r
F P
0 g
s
.39158 .41271 m .40479 .42764 L .41531 .42198 L p 0 .314 .946 r
F P
0 g
s
.41531 .42198 m .40479 .42764 L .39158 .41271 L p 0 .314 .946 r
F P
0 g
s
.41078 .43085 m .39734 .41566 L .38201 .43033 L p 0 .349 .781 r
F P
0 g
s
.38201 .43033 m .39734 .41566 L .41078 .43085 L p 0 .349 .781 r
F P
0 g
s
.41078 .43085 m .39549 .44555 L .39043 .43984 L p 0 .349 .781 r
F P
0 g
s
.39043 .43984 m .38201 .43033 L p .40001 .43066 L 0 .349 .781 r
F P
0 g
s
.41078 .43085 m .39043 .43984 L .40001 .43066 L 0 .349 .781 r
F
.3685 .41509 m .38201 .43033 L .39734 .41566 L p F P
0 g
s
.41531 .42198 m .40201 .40693 L .39158 .41271 L p 0 .314 .946 r
F P
0 g
s
.39158 .41271 m .40201 .40693 L .41531 .42198 L p 0 .314 .946 r
F P
0 g
s
.39734 .41566 m .38388 .40045 L .3685 .41509 L p 0 .349 .781 r
F P
0 g
s
.3685 .41509 m .38388 .40045 L .39734 .41566 L p 0 .349 .781 r
F P
0 g
s
.39734 .41566 m .38201 .43033 L .3685 .41509 L p 0 .349 .781 r
F P
0 g
s
.35498 .39983 m .3685 .41509 L .38388 .40045 L p 0 .349 .781 r
F P
0 g
s
.38388 .40045 m .3704 .38521 L .35498 .39983 L p 0 .349 .781 r
F P
0 g
s
.35498 .39983 m .3704 .38521 L .38388 .40045 L p 0 .349 .781 r
F P
0 g
s
.38388 .40045 m .3685 .41509 L .35498 .39983 L p 0 .349 .781 r
F P
0 g
s
.38201 .43033 m .3685 .41509 L .37897 .40921 L p 0 .312 .948 r
F P
0 g
s
.36536 .39383 m .37897 .40921 L .3685 .41509 L p 0 .312 .948 r
F P
0 g
s
.3685 .41509 m .35498 .39983 L .36536 .39383 L p 0 .312 .948 r
F P
0 g
s
.3347 .41157 m .36966 .45096 L p .37273 .41986 L .539 0 0 r
F P
0 g
s
.35498 .39983 m .3347 .41157 L p .37273 .41986 L .539 0 0 r
F P
0 g
s
.35498 .39983 m .3347 .41157 L p .33953 .41091 L 0 .05 .1 r
F P
0 g
s
.3347 .41157 m .40449 .49021 L .39243 .50191 L .856 0 0 r
F
.3347 .41157 m .32245 .42316 L .39243 .50191 L p F P
0 g
s
.3347 .41157 m .39243 .50191 L .32245 .42316 L .856 0 0 r
F
.3347 .41157 m .32245 .42316 L p .33953 .41091 L 0 .05 .1 r
F P
0 g
s
.3209 .42334 m .32245 .42316 L .35751 .46261 L .1 0 0 r
F
.3209 .42334 m .35751 .46261 L .35668 .46264 L F
.3209 .42334 m .35668 .46264 L .35586 .46268 L F
.31605 .42162 m .33224 .47903 L .35049 .46038 L .883 0 0 r
F
.31605 .42162 m .29757 .4401 L .33224 .47903 L F
.29757 .4401 m .32428 .48991 L .33224 .47903 L .965 0 0 r
F
.29757 .4401 m .28931 .45069 L .32428 .48991 L F
.3209 .42334 m .35586 .46268 L .35751 .46261 L .1 0 0 r
F
.39243 .50191 m .32245 .42316 L .34259 .41157 L p .535 0 0 r
F P
0 g
s
.37897 .40921 m .36536 .39383 L .37589 .38773 L p 0 .312 .948 r
F P
0 g
s
.37589 .38773 m .35498 .39983 L p .37273 .41986 L .539 0 0 r
F P
0 g
s
.32245 .42316 m .35751 .46261 L p .36038 .43163 L .535 0 0 r
F P
0 g
s
.34259 .41157 m .32245 .42316 L p .36038 .43163 L .535 0 0 r
F P
0 g
s
.35586 .46268 m .32428 .48991 L .32897 .48995 L .1 0 0 r
F
.28931 .45069 m .32897 .48995 L .32428 .48991 L F
.28931 .45069 m .29371 .45038 L .32897 .48995 L F
.3209 .42334 m .35751 .46261 L .32245 .42316 L F
.35586 .46268 m .3523 .46759 L .35751 .46261 L F
.32897 .48995 m .35751 .46261 L .32245 .42316 L p .856 0 0 r
F P
0 g
s
.32245 .42316 m .35751 .46261 L .32897 .48995 L .856 0 0 r
F
.32245 .42316 m .29371 .45038 L .32897 .48995 L p F P
0 g
s
.32245 .42316 m .32897 .48995 L .29371 .45038 L .856 0 0 r
F
.32897 .48995 m .29371 .45038 L .3135 .43915 L p .526 0 0 r
F P
0 g
s
.3135 .43915 m .33391 .42758 L p .3314 .45927 L .526 0 0 r
F P
0 g
s
.32897 .48995 m .3135 .43915 L .3314 .45927 L .526 0 0 r
F
.24802 .49364 m .26725 .483 L .3135 .43915 L p 0 .05 .1 r
F P
0 g
s
.3135 .43915 m .34259 .41157 L p .30573 .44356 L 0 .05 .1 r
F P
0 g
s
.30573 .44356 m .24802 .49364 L .3135 .43915 L 0 .05 .1 r
F
.33968 .41325 m .24802 .49364 L .34259 .41157 L F
.32245 .42316 m .29371 .45038 L p .32929 .42236 L F P
0 g
s
.29371 .45038 m .24802 .49364 L p .29766 .4501 L 0 .05 .1 r
F P
0 g
s
.32929 .42236 m .29371 .45038 L .29766 .4501 L 0 .05 .1 r
F
.32977 .41368 m .29757 .4401 L .31605 .42162 L .1 0 0 r
F
.32359 .41986 m .28931 .45069 L .29757 .4401 L F
.32977 .41368 m .32359 .41986 L .29757 .4401 L F
.32359 .41986 m .3209 .42334 L .28931 .45069 L F
.3209 .42334 m .29371 .45038 L .28931 .45069 L F
.3209 .42334 m .32245 .42316 L .29371 .45038 L F
.31605 .42162 m .37185 .36885 L .38602 .36044 L p F P
0 g
s
.38602 .36044 m .32977 .41368 L .31605 .42162 L p .1 0 0 r
F P
0 g
s
.32977 .41368 m .38602 .36044 L .39218 .35677 L p .1 0 0 r
F P
0 g
s
.39218 .35677 m .33573 .41022 L .32977 .41368 L p .1 0 0 r
F P
0 g
s
.33573 .41022 m .32359 .41986 L .32977 .41368 L .1 0 0 r
F
.33485 .41111 m .3209 .42334 L .32359 .41986 L F
.33573 .41022 m .33485 .41111 L .32359 .41986 L F
.33447 .4116 m .32245 .42316 L .3209 .42334 L F
.33485 .41111 m .33447 .4116 L .3209 .42334 L F
.33447 .4116 m .3347 .41157 L .32245 .42316 L F
.21127 .45258 m .24802 .49364 L .3347 .41157 L p 0 .349 .781 r
F P
0 g
s
.3347 .41157 m .2986 .3709 L .21127 .45258 L p 0 .349 .781 r
F P
0 g
s
.33968 .41325 m .32245 .42316 L .32929 .42236 L 0 .05 .1 r
F
.29371 .45038 m .32245 .42316 L .34259 .41157 L p .1 0 0 r
F P
0 g
s
.36335 .39963 m .34259 .41157 L p .36038 .43163 L .535 0 0 r
F P
0 g
s
.36966 .45096 m .40449 .49021 L p .39043 .43984 L .539 0 0 r
F P
0 g
s
.39549 .44555 m .38201 .43033 L .39257 .42457 L p 0 .312 .948 r
F P
0 g
s
.37897 .40921 m .39257 .42457 L .38201 .43033 L p 0 .312 .948 r
F P
0 g
s
.43037 .40752 m .44361 .42252 L .45855 .4081 L p 0 .349 .781 r
F P
0 g
s
.44361 .42252 m .43037 .40752 L .44113 .40167 L p 0 .314 .945 r
F P
0 g
s
.45855 .4081 m .44361 .42252 L .45447 .41679 L p 0 .05 .1 r
F P
0 g
s
.45855 .4081 m .47174 .42305 L .48277 .41735 L p 0 .315 .944 r
F P
0 g
s
.48277 .41735 m .4695 .40228 L .45855 .4081 L p 0 .315 .944 r
F P
0 g
s
.44361 .42252 m .45855 .4081 L .4695 .40228 L p 0 .05 .1 r
F P
0 g
s
.4695 .40228 m .45447 .41679 L .44361 .42252 L p 0 .05 .1 r
F P
0 g
s
.43037 .40752 m .44361 .42252 L .45447 .41679 L p 0 .314 .945 r
F P
0 g
s
.45447 .41679 m .44113 .40167 L .43037 .40752 L p 0 .314 .945 r
F P
0 g
s
.43037 .40752 m .41531 .42198 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .44113 .40167 L .43037 .40752 L p 0 .05 .1 r
F P
0 g
s
.41531 .42198 m .43037 .40752 L .44113 .40167 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .42599 .41623 L .41531 .42198 L p 0 .05 .1 r
F P
0 g
s
.40201 .40693 m .41531 .42198 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .41531 .42198 L .40201 .40693 L p 0 .314 .946 r
F P
0 g
s
.41976 .41327 m .43466 .39898 L .42153 .38409 L p 0 .349 .781 r
F P
0 g
s
.42599 .41623 m .41259 .40106 L .40201 .40693 L p 0 .314 .946 r
F P
0 g
s
.40201 .40693 m .41259 .40106 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.38388 .40045 m .39734 .41566 L .41259 .40106 L p 0 .349 .781 r
F P
0 g
s
.41259 .40106 m .39734 .41566 L .38388 .40045 L p 0 .349 .781 r
F P
0 g
s
.39257 .42457 m .37897 .40921 L .38961 .40323 L p 0 .312 .948 r
F P
0 g
s
.41259 .40106 m .39918 .38587 L .38388 .40045 L p 0 .349 .781 r
F P
0 g
s
.38388 .40045 m .39918 .38587 L .41259 .40106 L p 0 .349 .781 r
F P
0 g
s
.37589 .38773 m .38961 .40323 L .37897 .40921 L p 0 .312 .948 r
F P
0 g
s
.39043 .43984 m .37589 .38773 L .36966 .45096 L .539 0 0 r
F
.34259 .41157 m .36335 .39963 L p .37814 .45164 L .535 0 0 r
F P
0 g
s
.37589 .38773 m .35498 .39983 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.38792 .47154 m .37464 .45658 L .38499 .4511 L p 0 .312 .948 r
F P
0 g
s
.39243 .50191 m .34259 .41157 L .37814 .45164 L .535 0 0 r
F
.26725 .483 m .28709 .47203 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.35498 .39983 m .34259 .41157 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.34259 .41157 m .26725 .483 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.28709 .47203 m .36335 .39963 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.36335 .39963 m .37589 .38773 L p .34552 .40989 L 0 .05 .1 r
F P
0 g
s
.34259 .41157 m .36335 .39963 L p .32808 .42533 L .1 0 0 r
F P
0 g
s
.29371 .45038 m .34259 .41157 L .32808 .42533 L .1 0 0 r
F
.36335 .39963 m .33391 .42758 L .3135 .43915 L p F P
0 g
s
.3135 .43915 m .29371 .45038 L p .32808 .42533 L .1 0 0 r
F P
0 g
s
.32808 .42533 m .36335 .39963 L .3135 .43915 L .1 0 0 r
F
.34259 .41157 m .35498 .39983 L p .33968 .41325 L 0 .05 .1 r
F P
0 g
s
.35498 .39983 m .32245 .42316 L .33968 .41325 L 0 .05 .1 r
F
.32245 .42316 m .3347 .41157 L .35498 .39983 L p .1 0 0 r
F P
0 g
s
.35498 .39983 m .37589 .38773 L p .34879 .4057 L .1 0 0 r
F P
0 g
s
.32245 .42316 m .35498 .39983 L .34879 .4057 L .1 0 0 r
F
.3349 .3875 m .3347 .41157 L .34993 .39714 L closepath p 0 .349 .781 r
F P
0 g
s
.36009 .39122 m .34993 .39714 L .3347 .41157 L p 0 .05 .1 r
F P
0 g
s
.2986 .3709 m .31667 .39125 L .3349 .3875 L p 0 .349 .781 r
F P
0 g
s
.3349 .3875 m .31667 .39125 L .3347 .41157 L closepath p 0 .349 .781 r
F P
0 g
s
.36009 .39122 m .34476 .40574 L .3347 .41157 L p 0 .05 .1 r
F P
0 g
s
.3347 .41157 m .34476 .40574 L .36009 .39122 L p 0 .05 .1 r
F P
0 g
s
.34476 .40574 m .36009 .39122 L .3704 .38521 L p 0 .05 .1 r
F P
0 g
s
.3704 .38521 m .36009 .39122 L .34476 .40574 L p 0 .05 .1 r
F P
0 g
s
.3704 .38521 m .35498 .39983 L .34476 .40574 L p 0 .05 .1 r
F P
0 g
s
.34476 .40574 m .35498 .39983 L .3704 .38521 L p 0 .05 .1 r
F P
0 g
s
.2986 .3709 m .3347 .41157 L .35498 .39983 L p 0 .312 .948 r
F P
0 g
s
.34476 .40574 m .3347 .41157 L .31667 .39125 L p 0 .312 .948 r
F P
0 g
s
.31667 .39125 m .32661 .38527 L .34476 .40574 L p 0 .312 .948 r
F P
0 g
s
.37589 .38773 m .36335 .39963 L .34259 .41157 L p .1 0 0 r
F P
0 g
s
.34259 .41157 m .32245 .42316 L p .34879 .4057 L .1 0 0 r
F P
0 g
s
.34879 .4057 m .37589 .38773 L .34259 .41157 L .1 0 0 r
F
.33736 .40567 m .22998 .44129 L .34259 .41157 L 0 .349 .781 r
F
.35498 .39983 m .34476 .40574 L .32661 .38527 L p 0 .312 .948 r
F P
0 g
s
.34259 .41157 m .35498 .39983 L p .33736 .40567 L 0 .349 .781 r
F P
0 g
s
.3135 .43915 m .34259 .41157 L p .29916 .42303 L 0 .349 .781 r
F P
0 g
s
.22998 .44129 m .26725 .483 L .3135 .43915 L p 0 .349 .781 r
F P
0 g
s
.29916 .42303 m .22998 .44129 L .3135 .43915 L 0 .349 .781 r
F
.26725 .483 m .22998 .44129 L p .33736 .40567 L F P
0 g
s
.35498 .39983 m .34259 .41157 L p .33736 .40567 L 0 .349 .781 r
F P
0 g
s
.34259 .41157 m .26725 .483 L p .33736 .40567 L 0 .349 .781 r
F P
0 g
s
.41351 .45156 m .42682 .46659 L .41761 .47122 L p 0 .313 .947 r
F P
0 g
s
.41171 .48124 m .42682 .46659 L .41761 .47122 L p 0 .05 .1 r
F P
0 g
s
.4376 .46117 m .45273 .44649 L .44187 .45201 L p 0 .05 .1 r
F P
0 g
s
.44187 .45201 m .42682 .46659 L .4376 .46117 L p 0 .05 .1 r
F P
0 g
s
.41351 .45156 m .42682 .46659 L .44187 .45201 L p 0 .349 .781 r
F P
0 g
s
.42682 .46659 m .44187 .45201 L .45273 .44649 L p 0 .05 .1 r
F P
0 g
s
.4242 .44602 m .43937 .43137 L .4286 .437 L p 0 .05 .1 r
F P
0 g
s
.41351 .45156 m .42682 .46659 L .41171 .48124 L p 0 .349 .781 r
F P
0 g
s
.4224 .47591 m .4376 .46117 L .42682 .46659 L p 0 .05 .1 r
F P
0 g
s
.4137 .48348 m .41171 .48124 L .42682 .46659 L p 0 .349 .781 r
F P
0 g
s
.42682 .46659 m .41171 .48124 L .4224 .47591 L p 0 .05 .1 r
F P
0 g
s
.45273 .44649 m .4376 .46117 L .42682 .46659 L p 0 .05 .1 r
F P
0 g
s
.41351 .45156 m .42682 .46659 L .4376 .46117 L p 0 .313 .947 r
F P
0 g
s
.42682 .46659 m .41351 .45156 L .39836 .46618 L p 0 .349 .781 r
F P
0 g
s
.39836 .46618 m .41171 .48124 L .42682 .46659 L p 0 .349 .781 r
F P
0 g
s
.41171 .48124 m .42682 .46659 L .4376 .46117 L p 0 .05 .1 r
F P
0 g
s
.4242 .44602 m .4376 .46117 L .42682 .46659 L p 0 .313 .947 r
F P
0 g
s
.42682 .46659 m .41351 .45156 L .4242 .44602 L p 0 .313 .947 r
F P
0 g
s
.41171 .48124 m .39836 .46618 L .41351 .45156 L p 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .4242 .44602 L .41351 .45156 L p 0 .313 .947 r
F P
0 g
s
.40895 .46074 m .4242 .44602 L .41351 .45156 L p 0 .05 .1 r
F P
0 g
s
.41351 .45156 m .39836 .46618 L .40895 .46074 L p 0 .05 .1 r
F P
0 g
s
.41078 .43085 m .4242 .44602 L .41351 .45156 L p 0 .313 .947 r
F P
0 g
s
.39836 .46618 m .41351 .45156 L .4242 .44602 L p 0 .05 .1 r
F P
0 g
s
.4376 .46117 m .4224 .47591 L .41171 .48124 L p 0 .05 .1 r
F P
0 g
s
.4242 .44602 m .40895 .46074 L .39836 .46618 L p 0 .05 .1 r
F P
0 g
s
.43937 .43137 m .45273 .44649 L .44187 .45201 L p 0 .314 .946 r
F P
0 g
s
.43937 .43137 m .45273 .44649 L .4376 .46117 L p 0 .349 .781 r
F P
0 g
s
.45273 .44649 m .4376 .46117 L .44854 .45566 L p 0 .05 .1 r
F P
0 g
s
.45273 .44649 m .43937 .43137 L .4242 .44602 L p 0 .349 .781 r
F P
0 g
s
.4242 .44602 m .4376 .46117 L .45273 .44649 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .47785 .4433 L .46684 .44882 L p 0 .314 .945 r
F P
0 g
s
.47785 .4433 m .46779 .43188 L .45273 .44649 L p 0 .349 .781 r
F P
0 g
s
.47725 .44496 m .47785 .4433 L .46684 .44882 L p 0 .082 .528 r
F P
0 g
s
.47725 .44496 m .47785 .4433 L p .45273 .44649 L 0 .349 .781 r
F P
0 g
s
.46684 .44882 m .46624 .45047 L .47725 .44496 L p 0 .082 .528 r
F P
0 g
s
.47222 .45418 m .47725 .44496 L .46624 .45047 L p 0 .05 .405 r
F P
0 g
s
.47222 .45418 m .47725 .44496 L p .45273 .44649 L 0 .349 .781 r
F P
0 g
s
.46607 .46159 m .45273 .44649 L .46779 .43188 L p 0 .349 .781 r
F P
0 g
s
.45273 .44649 m .46607 .46159 L .47222 .45418 L p 0 .349 .781 r
F P
0 g
s
.47725 .44496 m .47222 .45418 L p .46779 .43188 L 0 .349 .781 r
F P
0 g
s
.47725 .44496 m .47222 .45418 L .48337 .44864 L p 0 .05 .405 r
F P
0 g
s
.47222 .45418 m .46607 .46159 L p .46779 .43188 L 0 .349 .781 r
F P
0 g
s
.47222 .45418 m .46607 .46159 L .47719 .45611 L p 0 .05 .188 r
F P
0 g
s
.47719 .45611 m .48337 .44864 L .47222 .45418 L p 0 .05 .188 r
F P
0 g
s
.45273 .44649 m .46607 .46159 L .47719 .45611 L p 0 .314 .946 r
F P
0 g
s
.46607 .46159 m .45273 .44649 L .46376 .44089 L p 0 .314 .946 r
F P
0 g
s
.47719 .45611 m .46376 .44089 L .45273 .44649 L p 0 .314 .946 r
F P
0 g
s
.4376 .46117 m .45273 .44649 L .46376 .44089 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .43937 .43137 L .4286 .437 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .43937 .43137 L .4242 .44602 L p 0 .349 .781 r
F P
0 g
s
.4376 .46117 m .4242 .44602 L .43937 .43137 L p 0 .349 .781 r
F P
0 g
s
.43937 .43137 m .4242 .44602 L .43504 .4404 L p 0 .05 .1 r
F P
0 g
s
.43937 .43137 m .42599 .41623 L .41078 .43085 L p 0 .349 .781 r
F P
0 g
s
.41078 .43085 m .4242 .44602 L .43937 .43137 L p 0 .349 .781 r
F P
0 g
s
.45447 .41679 m .46779 .43188 L .45684 .4375 L p 0 .314 .945 r
F P
0 g
s
.46779 .43188 m .45447 .41679 L .43937 .43137 L p 0 .349 .781 r
F P
0 g
s
.45273 .44649 m .46779 .43188 L .45684 .4375 L p 0 .05 .1 r
F P
0 g
s
.43937 .43137 m .45273 .44649 L .46779 .43188 L p 0 .349 .781 r
F P
0 g
s
.45273 .44649 m .43937 .43137 L .45447 .41679 L p 0 .349 .781 r
F P
0 g
s
.45447 .41679 m .46779 .43188 L .45273 .44649 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .45273 .44649 L .46376 .44089 L p 0 .05 .1 r
F P
0 g
s
.46779 .43188 m .47785 .4433 L .48138 .43358 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .47785 .4433 L .47725 .44496 L p 0 .349 .781 r
F P
0 g
s
.47785 .4433 m .46779 .43188 L .4789 .42619 L p 0 .314 .945 r
F P
0 g
s
.48138 .43358 m .47785 .4433 L .48904 .43769 L p 0 .082 .528 r
F P
0 g
s
.46779 .43188 m .47785 .4433 L .48904 .43769 L p 0 .314 .945 r
F P
0 g
s
.48904 .43769 m .4789 .42619 L .46779 .43188 L p 0 .314 .945 r
F P
0 g
s
.45273 .44649 m .46779 .43188 L .4789 .42619 L p 0 .05 .1 r
F P
0 g
s
.4789 .42619 m .46376 .44089 L .45273 .44649 L p 0 .05 .1 r
F P
0 g
s
.43937 .43137 m .45273 .44649 L .46376 .44089 L p 0 .314 .946 r
F P
0 g
s
.45273 .44649 m .43937 .43137 L .4503 .42565 L p 0 .314 .946 r
F P
0 g
s
.46376 .44089 m .4503 .42565 L .43937 .43137 L p 0 .314 .946 r
F P
0 g
s
.4242 .44602 m .43937 .43137 L .4503 .42565 L p 0 .05 .1 r
F P
0 g
s
.39734 .41566 m .41078 .43085 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.42599 .41623 m .41259 .40106 L .39734 .41566 L p 0 .349 .781 r
F P
0 g
s
.4242 .44602 m .41078 .43085 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.42599 .41623 m .41078 .43085 L .42153 .42511 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .45447 .41679 L .44361 .42252 L p 0 .314 .945 r
F P
0 g
s
.45447 .41679 m .44113 .40167 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.43937 .43137 m .45447 .41679 L .44361 .42252 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .43937 .43137 L .45447 .41679 L p 0 .349 .781 r
F P
0 g
s
.43937 .43137 m .42599 .41623 L .44113 .40167 L p 0 .349 .781 r
F P
0 g
s
.44113 .40167 m .45447 .41679 L .43937 .43137 L p 0 .349 .781 r
F P
0 g
s
.45447 .41679 m .43937 .43137 L .4503 .42565 L p 0 .05 .1 r
F P
0 g
s
.48277 .41735 m .4695 .40228 L .45447 .41679 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .48277 .41735 L .47174 .42305 L p 0 .05 .1 r
F P
0 g
s
.45447 .41679 m .46779 .43188 L .48277 .41735 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .45447 .41679 L .4695 .40228 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .45447 .41679 L .46549 .41097 L p 0 .314 .945 r
F P
0 g
s
.48475 .41959 m .48277 .41735 L .46779 .43188 L p 0 .349 .781 r
F P
0 g
s
.4695 .40228 m .48277 .41735 L .46779 .43188 L p 0 .349 .781 r
F P
0 g
s
.46779 .43188 m .48277 .41735 L .49397 .41155 L p 0 .05 .1 r
F P
0 g
s
.48277 .41735 m .46779 .43188 L .4789 .42619 L p 0 .05 .1 r
F P
0 g
s
.49397 .41155 m .4789 .42619 L .46779 .43188 L p 0 .05 .1 r
F P
0 g
s
.45447 .41679 m .46779 .43188 L .4789 .42619 L p 0 .314 .945 r
F P
0 g
s
.4789 .42619 m .46549 .41097 L .45447 .41679 L p 0 .314 .945 r
F P
0 g
s
.43937 .43137 m .45447 .41679 L .46549 .41097 L p 0 .05 .1 r
F P
0 g
s
.46549 .41097 m .4503 .42565 L .43937 .43137 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .43937 .43137 L .4503 .42565 L p 0 .314 .946 r
F P
0 g
s
.43937 .43137 m .42599 .41623 L .43683 .41039 L p 0 .314 .946 r
F P
0 g
s
.4503 .42565 m .43683 .41039 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.42153 .42511 m .43683 .41039 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.41078 .43085 m .42599 .41623 L .43683 .41039 L p 0 .05 .1 r
F P
0 g
s
.39734 .41566 m .41259 .40106 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.42599 .41623 m .41078 .43085 L .39734 .41566 L p 0 .349 .781 r
F P
0 g
s
.4242 .44602 m .4376 .46117 L .4224 .47591 L p 0 .349 .781 r
F P
0 g
s
.4244 .47818 m .4224 .47591 L .4376 .46117 L p 0 .349 .781 r
F P
0 g
s
.43325 .47051 m .44854 .45566 L .4376 .46117 L p 0 .05 .1 r
F P
0 g
s
.4376 .46117 m .4224 .47591 L .43325 .47051 L p 0 .05 .1 r
F P
0 g
s
.46376 .44089 m .44854 .45566 L .4376 .46117 L p 0 .05 .1 r
F P
0 g
s
.4242 .44602 m .4376 .46117 L .44854 .45566 L p 0 .313 .947 r
F P
0 g
s
.4376 .46117 m .4242 .44602 L .40895 .46074 L p 0 .349 .781 r
F P
0 g
s
.40895 .46074 m .4224 .47591 L .4376 .46117 L p 0 .349 .781 r
F P
0 g
s
.4224 .47591 m .4376 .46117 L .44854 .45566 L p 0 .05 .1 r
F P
0 g
s
.43504 .4404 m .44854 .45566 L .4376 .46117 L p 0 .313 .947 r
F P
0 g
s
.4376 .46117 m .4242 .44602 L .43504 .4404 L p 0 .313 .947 r
F P
0 g
s
.41078 .43085 m .4242 .44602 L .40895 .46074 L p 0 .349 .781 r
F P
0 g
s
.4224 .47591 m .40895 .46074 L .4242 .44602 L p 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .43504 .4404 L .4242 .44602 L p 0 .313 .947 r
F P
0 g
s
.41971 .45522 m .43504 .4404 L .4242 .44602 L p 0 .05 .1 r
F P
0 g
s
.4242 .44602 m .40895 .46074 L .41971 .45522 L p 0 .05 .1 r
F P
0 g
s
.4503 .42565 m .43504 .4404 L .4242 .44602 L p 0 .05 .1 r
F P
0 g
s
.41078 .43085 m .4242 .44602 L .43504 .4404 L p 0 .313 .947 r
F P
0 g
s
.4242 .44602 m .41078 .43085 L .39549 .44555 L p 0 .349 .781 r
F P
0 g
s
.39549 .44555 m .40895 .46074 L .4242 .44602 L p 0 .349 .781 r
F P
0 g
s
.42153 .42511 m .43504 .4404 L .4242 .44602 L p 0 .313 .947 r
F P
0 g
s
.4242 .44602 m .41078 .43085 L .42153 .42511 L p 0 .313 .947 r
F P
0 g
s
.40895 .46074 m .4242 .44602 L .43504 .4404 L p 0 .05 .1 r
F P
0 g
s
.40895 .46074 m .39549 .44555 L .41078 .43085 L p 0 .349 .781 r
F P
0 g
s
.43504 .4404 m .42153 .42511 L .41078 .43085 L p 0 .313 .947 r
F P
0 g
s
.40615 .4399 m .42153 .42511 L .41078 .43085 L p 0 .05 .1 r
F P
0 g
s
.41078 .43085 m .39549 .44555 L .40615 .4399 L p 0 .05 .1 r
F P
0 g
s
.39549 .44555 m .41078 .43085 L .42153 .42511 L p 0 .05 .1 r
F P
0 g
s
.43683 .41039 m .42153 .42511 L .41078 .43085 L p 0 .05 .1 r
F P
0 g
s
.44854 .45566 m .43325 .47051 L .4224 .47591 L p 0 .05 .1 r
F P
0 g
s
.43504 .4404 m .41971 .45522 L .40895 .46074 L p 0 .05 .1 r
F P
0 g
s
.42153 .42511 m .40615 .4399 L .39549 .44555 L p 0 .05 .1 r
F P
0 g
s
.39257 .42457 m .40615 .4399 L .39549 .44555 L p 0 .312 .948 r
F P
0 g
s
.46376 .44089 m .47719 .45611 L .46607 .46159 L p 0 .314 .946 r
F P
0 g
s
.47719 .45611 m .46376 .44089 L .44854 .45566 L p 0 .349 .781 r
F P
0 g
s
.46963 .46205 m .47719 .45611 L .46607 .46159 L p 0 .05 .1 r
F P
0 g
s
.46963 .46205 m .47719 .45611 L p .44854 .45566 L 0 .349 .781 r
F P
0 g
s
.45874 .46721 m .44854 .45566 L .46376 .44089 L p 0 .349 .781 r
F P
0 g
s
.46607 .46159 m .45855 .46749 L .46963 .46205 L p 0 .05 .1 r
F P
0 g
s
.46039 .46669 m .46963 .46205 L .45855 .46749 L p 0 .05 .1 r
F P
0 g
s
.46039 .46669 m .46963 .46205 L p .44854 .45566 L 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .45874 .46721 L .46039 .46669 L p 0 .349 .781 r
F P
0 g
s
.46039 .46669 m .45874 .46721 L p .46376 .44089 L 0 .349 .781 r
F P
0 g
s
.46963 .46205 m .46039 .46669 L p .46376 .44089 L 0 .349 .781 r
F P
0 g
s
.45874 .46721 m .46277 .46523 L p .45323 .45882 L 0 .313 .947 r
F P
0 g
s
.44854 .45566 m .45191 .45948 L p .45323 .45882 L 0 .313 .947 r
F P
0 g
s
.45191 .45948 m .45874 .46721 L p .45323 .45882 L 0 .313 .947 r
F P
0 g
s
.4789 .42619 m .48904 .43769 L .47785 .4433 L p 0 .314 .945 r
F P
0 g
s
.4789 .42619 m .48867 .42118 L p .48879 .42666 L 0 .314 .945 r
F P
0 g
s
.48904 .43769 m .48225 .42999 L p .48879 .42666 L 0 .314 .945 r
F P
0 g
s
.48225 .42999 m .4789 .42619 L p .48879 .42666 L 0 .314 .945 r
F P
0 g
s
.49837 .42497 m .49313 .43564 L p .50382 .40646 L 0 .432 .873 r
F P
0 g
s
.50382 .40646 m .50468 .40933 L .49837 .42497 L p 0 .432 .873 r
F P
0 g
s
.51476 .40732 m .50784 .41087 L .4947 .42365 L p .1 0 0 r
F P
0 g
s
.48867 .42118 m .49313 .43564 L .48904 .43769 L p 0 .314 .945 r
F P
0 g
s
.4789 .42619 m .48904 .43769 L .49313 .43564 L p 0 .314 .945 r
F P
0 g
s
.48904 .43769 m .4789 .42619 L .46376 .44089 L p 0 .349 .781 r
F P
0 g
s
.54014 .50219 m .48587 .44063 L .49243 .43734 L p .56 0 0 r
F P
0 g
s
.48843 .43936 m .48904 .43769 L .47785 .4433 L p 0 .082 .528 r
F P
0 g
s
.48843 .43936 m .48904 .43769 L p .46376 .44089 L 0 .349 .781 r
F P
0 g
s
.4789 .42619 m .48904 .43769 L .48843 .43936 L p 0 .349 .781 r
F P
0 g
s
.47785 .4433 m .47725 .44496 L .48843 .43936 L p 0 .082 .528 r
F P
0 g
s
.48337 .44864 m .48843 .43936 L .47725 .44496 L p 0 .05 .405 r
F P
0 g
s
.48337 .44864 m .48843 .43936 L p .46376 .44089 L 0 .349 .781 r
F P
0 g
s
.48843 .43936 m .48337 .44864 L p .4789 .42619 L 0 .349 .781 r
F P
0 g
s
.49313 .43564 m .48867 .42118 L .4789 .42619 L p 0 .314 .945 r
F P
0 g
s
.47719 .45611 m .46376 .44089 L .4789 .42619 L p 0 .349 .781 r
F P
0 g
s
.48337 .44864 m .47719 .45611 L p .4789 .42619 L 0 .349 .781 r
F P
0 g
s
.46376 .44089 m .47719 .45611 L .48337 .44864 L p 0 .349 .781 r
F P
0 g
s
.48337 .44864 m .47719 .45611 L .47943 .455 L p 0 .05 .188 r
F P
0 g
s
.46376 .44089 m .47719 .45611 L .47943 .455 L p 0 .314 .946 r
F P
0 g
s
.46376 .44089 m .47719 .45611 L .46963 .46205 L p 0 .349 .781 r
F P
0 g
s
.46376 .44089 m .47345 .43597 L p .47439 .44103 L 0 .314 .946 r
F P
0 g
s
.47719 .45611 m .46712 .4447 L p .47439 .44103 L 0 .314 .946 r
F P
0 g
s
.46712 .4447 m .46376 .44089 L p .47439 .44103 L 0 .314 .946 r
F P
0 g
s
.48904 .43769 m .48843 .43936 L .49223 .43746 L p 0 .082 .528 r
F P
0 g
s
.49223 .43746 m .49313 .43564 L .48904 .43769 L p 0 .082 .528 r
F P
0 g
s
.48843 .43936 m .48337 .44864 L .486 .44734 L p 0 .05 .405 r
F P
0 g
s
.486 .44734 m .49223 .43746 L .48843 .43936 L p 0 .05 .405 r
F P
0 g
s
.49223 .43746 m .486 .44734 L p .48867 .42118 L 0 .432 .873 r
F P
0 g
s
.48867 .42118 m .49313 .43564 L .49223 .43746 L p 0 .432 .873 r
F P
0 g
s
.47943 .455 m .486 .44734 L .48337 .44864 L p 0 .05 .188 r
F P
0 g
s
.486 .44734 m .47943 .455 L p .48867 .42118 L 0 .432 .873 r
F P
0 g
s
.47943 .455 m .47345 .43597 L .48867 .42118 L p 0 .432 .873 r
F P
0 g
s
.4947 .42365 m .47947 .43847 L p .49949 .42121 L .1 0 0 r
F P
0 g
s
.47345 .43597 m .47943 .455 L .47719 .45611 L p 0 .314 .946 r
F P
0 g
s
.47943 .455 m .47345 .43597 L .46376 .44089 L p 0 .314 .946 r
F P
0 g
s
.47224 .46076 m .47943 .455 L .47719 .45611 L p 0 .05 .1 r
F P
0 g
s
.47719 .45611 m .46963 .46205 L .47224 .46076 L p 0 .05 .1 r
F P
0 g
s
.47345 .43597 m .47943 .455 L .47224 .46076 L p 0 .432 .873 r
F P
0 g
s
.46413 .46485 m .47224 .46076 L .46963 .46205 L p 0 .05 .1 r
F P
0 g
s
.46963 .46205 m .46039 .46669 L .46413 .46485 L p 0 .05 .1 r
F P
0 g
s
.47224 .46076 m .46413 .46485 L p .47345 .43597 L 0 .432 .873 r
F P
0 g
s
.46413 .46485 m .46277 .46523 L p .47345 .43597 L 0 .432 .873 r
F P
0 g
s
.46277 .46523 m .45815 .45083 L .47345 .43597 L p 0 .432 .873 r
F P
0 g
s
.47947 .43847 m .46416 .45336 L p .48184 .43727 L .1 0 0 r
F P
0 g
s
.48184 .43727 m .49949 .42121 L .47947 .43847 L .1 0 0 r
F
.49949 .42121 m .51476 .40732 L .4947 .42365 L F
.46277 .46523 m .45874 .46721 L p .45835 .45626 L 0 .313 .947 r
F P
0 g
s
.45815 .45083 m .45968 .4556 L p .45835 .45626 L 0 .313 .947 r
F P
0 g
s
.45968 .4556 m .46277 .46523 L p .45835 .45626 L 0 .313 .947 r
F P
0 g
s
.45874 .46721 m .44854 .45566 L .45815 .45083 L p 0 .313 .947 r
F P
0 g
s
.46277 .46523 m .45815 .45083 L .44854 .45566 L p 0 .313 .947 r
F P
0 g
s
.45815 .45083 m .46277 .46523 L .45476 .46743 L p 0 .432 .873 r
F P
0 g
s
.45476 .46743 m .44371 .4686 L p .45815 .45083 L 0 .432 .873 r
F P
0 g
s
.45084 .46632 m .45756 .463 L .47093 .44998 L p .1 0 0 r
F P
0 g
s
.47093 .44998 m .51476 .40732 L p .46573 .45258 L .1 0 0 r
F P
0 g
s
.45084 .46632 m .47093 .44998 L .46573 .45258 L .1 0 0 r
F
.46416 .45336 m .45084 .46632 L p .46573 .45258 L F P
0 g
s
.46573 .45258 m .51476 .40732 L .46416 .45336 L .1 0 0 r
F
.44278 .46576 m .45815 .45083 L .44854 .45566 L p 0 .05 .1 r
F P
0 g
s
.43527 .47279 m .43325 .47051 L .44854 .45566 L p 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .43325 .47051 L .44278 .46576 L p 0 .05 .1 r
F P
0 g
s
.44854 .45566 m .43504 .4404 L .41971 .45522 L p 0 .349 .781 r
F P
0 g
s
.41971 .45522 m .43325 .47051 L .44854 .45566 L p 0 .349 .781 r
F P
0 g
s
.43504 .4404 m .44854 .45566 L .43325 .47051 L p 0 .349 .781 r
F P
0 g
s
.43325 .47051 m .44854 .45566 L .45815 .45083 L p 0 .05 .1 r
F P
0 g
s
.43325 .47051 m .41971 .45522 L .43504 .4404 L p 0 .349 .781 r
F P
0 g
s
.41971 .45522 m .43063 .44961 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.43504 .4404 m .42176 .45324 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.42176 .45324 m .41971 .45522 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.45447 .41679 m .4695 .40228 L .45855 .4081 L p 0 .05 .1 r
F P
0 g
s
.41889 .36311 m .43213 .37813 L .44289 .37207 L p 0 .315 .944 r
F P
0 g
s
.44289 .37207 m .42956 .35694 L .41889 .36311 L p 0 .315 .944 r
F P
0 g
s
.4695 .40228 m .48277 .41735 L .49397 .41155 L p 0 .315 .944 r
F P
0 g
s
.4789 .42619 m .49397 .41155 L .48277 .41735 L p 0 .05 .1 r
F P
0 g
s
.4562 .38718 m .4695 .40228 L .45447 .41679 L p 0 .349 .781 r
F P
0 g
s
.4695 .40228 m .4562 .38718 L .44113 .40167 L p 0 .349 .781 r
F P
0 g
s
.44113 .40167 m .45447 .41679 L .4695 .40228 L p 0 .349 .781 r
F P
0 g
s
.49397 .41155 m .48061 .39637 L .4695 .40228 L p 0 .315 .944 r
F P
0 g
s
.45447 .41679 m .4695 .40228 L .48061 .39637 L p 0 .05 .1 r
F P
0 g
s
.4562 .38718 m .4695 .40228 L .48061 .39637 L p 0 .315 .944 r
F P
0 g
s
.4695 .40228 m .45447 .41679 L .46549 .41097 L p 0 .05 .1 r
F P
0 g
s
.46549 .41097 m .48061 .39637 L .4695 .40228 L p 0 .05 .1 r
F P
0 g
s
.45382 .36593 m .44289 .37207 L .4562 .38718 L p 0 .315 .944 r
F P
0 g
s
.4562 .38718 m .46722 .38116 L .45382 .36593 L p 0 .315 .944 r
F P
0 g
s
.45447 .41679 m .44113 .40167 L .4562 .38718 L p 0 .349 .781 r
F P
0 g
s
.48061 .39637 m .46722 .38116 L .4562 .38718 L p 0 .315 .944 r
F P
0 g
s
.46722 .38116 m .4562 .38718 L .44113 .40167 L p 0 .05 .1 r
F P
0 g
s
.44113 .40167 m .4562 .38718 L .46722 .38116 L p 0 .05 .1 r
F P
0 g
s
.44039 .35067 m .42956 .35694 L .44289 .37207 L p 0 .315 .944 r
F P
0 g
s
.44289 .37207 m .45382 .36593 L .44039 .35067 L p 0 .315 .944 r
F P
0 g
s
.40838 .36919 m .42153 .38409 L .43213 .37813 L p 0 .315 .944 r
F P
0 g
s
.43213 .37813 m .41889 .36311 L .40838 .36919 L p 0 .315 .944 r
F P
0 g
s
.42778 .38653 m .44289 .37207 L .42956 .35694 L p 0 .349 .781 r
F P
0 g
s
.44289 .37207 m .42778 .38653 L .44113 .40167 L p 0 .349 .781 r
F P
0 g
s
.42956 .35694 m .44289 .37207 L .42778 .38653 L p 0 .349 .781 r
F P
0 g
s
.44113 .40167 m .42778 .38653 L .44289 .37207 L p 0 .349 .781 r
F P
0 g
s
.46549 .41097 m .4789 .42619 L .46779 .43188 L p 0 .314 .945 r
F P
0 g
s
.46376 .44089 m .4789 .42619 L .46779 .43188 L p 0 .05 .1 r
F P
0 g
s
.42956 .35694 m .44039 .35067 L .42695 .3354 L p 0 .315 .944 r
F P
0 g
s
.4503 .42565 m .46549 .41097 L .45447 .41679 L p 0 .05 .1 r
F P
0 g
s
.45447 .41679 m .44113 .40167 L .45206 .39574 L p 0 .314 .945 r
F P
0 g
s
.48061 .39637 m .46549 .41097 L .45447 .41679 L p 0 .05 .1 r
F P
0 g
s
.45206 .39574 m .46549 .41097 L .45447 .41679 L p 0 .314 .945 r
F P
0 g
s
.44113 .40167 m .45447 .41679 L .46549 .41097 L p 0 .314 .945 r
F P
0 g
s
.44113 .40167 m .45206 .39574 L .46722 .38116 L p 0 .05 .1 r
F P
0 g
s
.46549 .41097 m .45206 .39574 L .44113 .40167 L p 0 .314 .945 r
F P
0 g
s
.45206 .39574 m .44113 .40167 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.46722 .38116 m .45206 .39574 L .44113 .40167 L p 0 .05 .1 r
F P
0 g
s
.42599 .41623 m .44113 .40167 L .45206 .39574 L p 0 .05 .1 r
F P
0 g
s
.44854 .45566 m .46376 .44089 L .45273 .44649 L p 0 .05 .1 r
F P
0 g
s
.4503 .42565 m .46376 .44089 L .45273 .44649 L p 0 .314 .946 r
F P
0 g
s
.43504 .4404 m .4503 .42565 L .43937 .43137 L p 0 .05 .1 r
F P
0 g
s
.43683 .41039 m .4503 .42565 L .43937 .43137 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .43683 .41039 L .45206 .39574 L p 0 .05 .1 r
F P
0 g
s
.45206 .39574 m .43683 .41039 L .42599 .41623 L p 0 .05 .1 r
F P
0 g
s
.49597 .41382 m .49397 .41155 L .4789 .42619 L p 0 .349 .781 r
F P
0 g
s
.48061 .39637 m .49397 .41155 L .50382 .40646 L p 0 .315 .944 r
F P
0 g
s
.49397 .41155 m .4789 .42619 L .48867 .42118 L p 0 .05 .1 r
F P
0 g
s
.48867 .42118 m .50382 .40646 L .49397 .41155 L p 0 .05 .1 r
F P
0 g
s
.4789 .42619 m .49397 .41155 L .50382 .40646 L p 0 .05 .1 r
F P
0 g
s
.49397 .41155 m .48061 .39637 L .46549 .41097 L p 0 .349 .781 r
F P
0 g
s
.46549 .41097 m .4789 .42619 L .49397 .41155 L p 0 .349 .781 r
F P
0 g
s
.48061 .39637 m .49397 .41155 L .4789 .42619 L p 0 .349 .781 r
F P
0 g
s
.48061 .39637 m .46722 .38116 L .45206 .39574 L p 0 .349 .781 r
F P
0 g
s
.45206 .39574 m .46549 .41097 L .48061 .39637 L p 0 .349 .781 r
F P
0 g
s
.46722 .38116 m .48061 .39637 L .46549 .41097 L p 0 .349 .781 r
F P
0 g
s
.4789 .42619 m .46549 .41097 L .48061 .39637 L p 0 .349 .781 r
F P
0 g
s
.49188 .39037 m .48061 .39637 L p .50382 .40646 L 0 .315 .944 r
F P
0 g
s
.46549 .41097 m .48061 .39637 L .49188 .39037 L p 0 .05 .1 r
F P
0 g
s
.46722 .38116 m .48061 .39637 L .49188 .39037 L p 0 .315 .944 r
F P
0 g
s
.48061 .39637 m .46549 .41097 L .47668 .40507 L p 0 .05 .1 r
F P
0 g
s
.49188 .39037 m .48061 .39637 L p .48009 .39752 L 0 .05 .1 r
F P
0 g
s
.47668 .40507 m .48986 .39232 L p .48009 .39752 L 0 .05 .1 r
F P
0 g
s
.48986 .39232 m .49188 .39037 L p .48009 .39752 L 0 .05 .1 r
F P
0 g
s
.46491 .35968 m .45382 .36593 L .46722 .38116 L p 0 .315 .944 r
F P
0 g
s
.46722 .38116 m .4784 .37504 L .46491 .35968 L p 0 .315 .944 r
F P
0 g
s
.49188 .39037 m .4784 .37504 L .46722 .38116 L p 0 .315 .944 r
F P
0 g
s
.46549 .41097 m .45206 .39574 L .46722 .38116 L p 0 .349 .781 r
F P
0 g
s
.4784 .37504 m .46722 .38116 L .4652 .3831 L p 0 .05 .1 r
F P
0 g
s
.4652 .3831 m .45206 .39574 L p .47488 .37781 L 0 .05 .1 r
F P
0 g
s
.47488 .37781 m .4784 .37504 L .4652 .3831 L 0 .05 .1 r
F
.47668 .40507 m .46549 .41097 L p .48835 .39313 L F P
0 g
s
.49188 .39037 m .48986 .39232 L p .48835 .39313 L 0 .05 .1 r
F P
0 g
s
.48986 .39232 m .47668 .40507 L p .48835 .39313 L 0 .05 .1 r
F P
0 g
s
.43785 .32892 m .5087 .4095 L .52077 .39776 L .858 0 0 r
F
.50901 .40946 m .52077 .39776 L .5087 .4095 L .1 0 0 r
F
.50901 .40946 m .52294 .3975 L .52077 .39776 L F
.50382 .40646 m .50265 .40261 L .49188 .39037 L p 0 .315 .944 r
F P
0 g
s
.50265 .40261 m .50382 .40646 L p .50164 .40791 L 0 .432 .873 r
F P
0 g
s
.48748 .41734 m .50063 .40457 L p .50164 .40791 L 0 .432 .873 r
F P
0 g
s
.50063 .40457 m .50265 .40261 L p .50164 .40791 L 0 .432 .873 r
F P
0 g
s
.43813 .32885 m .5087 .4095 L .43785 .32892 L .161 0 0 r
F
.43813 .32885 m .50901 .40946 L .5087 .4095 L F
.49188 .39037 m .50265 .40261 L .48748 .41734 L p 0 .35 .78 r
F P
0 g
s
.45139 .34431 m .44039 .35067 L .45382 .36593 L p 0 .315 .944 r
F P
0 g
s
.45382 .36593 m .46491 .35968 L .45139 .34431 L p 0 .315 .944 r
F P
0 g
s
.43785 .32892 m .42695 .3354 L .44039 .35067 L p 0 .315 .944 r
F P
0 g
s
.44039 .35067 m .45139 .34431 L .43785 .32892 L p 0 .315 .944 r
F P
0 g
s
.45206 .39574 m .46722 .38116 L .4784 .37504 L p 0 .05 .1 r
F P
0 g
s
.45206 .39574 m .46316 .38971 L .47638 .37699 L p 0 .05 .1 r
F P
0 g
s
.47638 .37699 m .4784 .37504 L p .47488 .37781 L 0 .05 .1 r
F P
0 g
s
.45206 .39574 m .47638 .37699 L .47488 .37781 L 0 .05 .1 r
F
.46316 .38971 m .45206 .39574 L p .47488 .37781 L F P
0 g
s
.4784 .37504 m .47638 .37699 L p .47488 .37781 L 0 .05 .1 r
F P
0 g
s
.47638 .37699 m .46316 .38971 L p .47488 .37781 L 0 .05 .1 r
F P
0 g
s
.46491 .35968 m .4784 .37504 L .47638 .37699 L p 0 .35 .78 r
F P
0 g
s
.46467 .36368 m .46491 .35968 L .47638 .37699 L 0 .35 .78 r
F
.45139 .34431 m .46491 .35968 L .44962 .37434 L p F P
0 g
s
.46316 .38971 m .44962 .37434 L .46491 .35968 L p 0 .35 .78 r
F P
0 g
s
.43785 .32892 m .45139 .34431 L .43606 .35894 L p 0 .35 .78 r
F P
0 g
s
.44962 .37434 m .43606 .35894 L .45139 .34431 L p 0 .35 .78 r
F P
0 g
s
.42695 .3354 m .41621 .34178 L .42956 .35694 L p 0 .315 .944 r
F P
0 g
s
.43606 .35894 m .42247 .34351 L .43785 .32892 L p 0 .35 .78 r
F P
0 g
s
.43778 .32932 m .50901 .40946 L .43813 .32885 L .977 0 0 r
F
.4784 .37504 m .49188 .39037 L .47668 .40507 L p 0 .35 .78 r
F P
0 g
s
.48748 .41734 m .47668 .40507 L .49188 .39037 L p 0 .35 .78 r
F P
0 g
s
.47668 .40507 m .46316 .38971 L .4784 .37504 L p 0 .35 .78 r
F P
0 g
s
.4369 .33021 m .50784 .41087 L .50869 .40997 L .888 0 0 r
F
.4369 .33021 m .4775 .37637 L p .47544 .37334 L .556 0 0 r
F P
0 g
s
.43778 .32932 m .50869 .40997 L .50901 .40946 L .977 0 0 r
F
.4369 .33021 m .50869 .40997 L .43778 .32932 L .888 0 0 r
F
.44353 .32627 m .43731 .32997 L p .47544 .37334 L .556 0 0 r
F P
0 g
s
.43731 .32997 m .4369 .33021 L p .47544 .37334 L .556 0 0 r
F P
0 g
s
.47638 .37699 m .46316 .38971 L p .46467 .36368 L 0 .35 .78 r
F P
0 g
s
.4775 .37637 m .491 .39172 L p .47919 .37545 L .556 0 0 r
F P
0 g
s
.47919 .37545 m .44353 .32627 L .4775 .37637 L .556 0 0 r
F
.50869 .40997 m .52294 .3975 L .50901 .40946 L .1 0 0 r
F
.50869 .40997 m .52075 .40099 L .52294 .3975 L F
.50784 .41087 m .52075 .40099 L .50869 .40997 L F
.50784 .41087 m .51476 .40732 L .52075 .40099 L F
.49976 .40168 m .51476 .40732 L .50784 .41087 L .556 0 0 r
F
.491 .39172 m .49816 .39642 L .49976 .40168 L F
.49816 .39642 m .51476 .40732 L .49976 .40168 L F
.4775 .37637 m .49403 .3901 L .491 .39172 L F
.49403 .3901 m .51476 .40732 L .491 .39172 L F
.4369 .33021 m .48138 .37425 L .4775 .37637 L F
.48138 .37425 m .51476 .40732 L .4775 .37637 L F
.491 .39172 m .50784 .41087 L p .49262 .39085 L F P
0 g
s
.49262 .39085 m .44353 .32627 L .491 .39172 L .556 0 0 r
F
.4789 .42619 m .46549 .41097 L .47668 .40507 L p 0 .314 .945 r
F P
0 g
s
.50382 .40646 m .48867 .42118 L .4789 .42619 L p 0 .05 .1 r
F P
0 g
s
.48867 .42118 m .4789 .42619 L p .47668 .40507 L 0 .314 .945 r
F P
0 g
s
.46549 .41097 m .4789 .42619 L .48867 .42118 L p 0 .314 .945 r
F P
0 g
s
.4789 .42619 m .46376 .44089 L .47345 .43597 L p 0 .05 .1 r
F P
0 g
s
.47345 .43597 m .48867 .42118 L .4789 .42619 L p 0 .05 .1 r
F P
0 g
s
.4789 .42619 m .46549 .41097 L .4503 .42565 L p 0 .349 .781 r
F P
0 g
s
.4503 .42565 m .46376 .44089 L .4789 .42619 L p 0 .349 .781 r
F P
0 g
s
.46549 .41097 m .4789 .42619 L .46376 .44089 L p 0 .349 .781 r
F P
0 g
s
.46376 .44089 m .4789 .42619 L .48867 .42118 L p 0 .05 .1 r
F P
0 g
s
.46549 .41097 m .45206 .39574 L .46316 .38971 L p 0 .314 .945 r
F P
0 g
s
.46316 .38971 m .47668 .40507 L .46549 .41097 L p 0 .314 .945 r
F P
0 g
s
.45206 .39574 m .46549 .41097 L .47668 .40507 L p 0 .314 .945 r
F P
0 g
s
.46376 .44089 m .4503 .42565 L .46549 .41097 L p 0 .349 .781 r
F P
0 g
s
.46549 .41097 m .4503 .42565 L .4614 .41984 L p 0 .05 .1 r
F P
0 g
s
.47668 .40507 m .46549 .41097 L p .48867 .42118 L 0 .314 .945 r
F P
0 g
s
.4614 .41984 m .47668 .40507 L .46549 .41097 L p 0 .05 .1 r
F P
0 g
s
.46549 .41097 m .45206 .39574 L .43683 .41039 L p 0 .349 .781 r
F P
0 g
s
.43683 .41039 m .4503 .42565 L .46549 .41097 L p 0 .349 .781 r
F P
0 g
s
.45206 .39574 m .46549 .41097 L .4503 .42565 L p 0 .349 .781 r
F P
0 g
s
.4503 .42565 m .46549 .41097 L .47668 .40507 L p 0 .05 .1 r
F P
0 g
s
.47668 .40507 m .46316 .38971 L .45206 .39574 L p 0 .314 .945 r
F P
0 g
s
.4503 .42565 m .43683 .41039 L .45206 .39574 L p 0 .349 .781 r
F P
0 g
s
.46316 .38971 m .45206 .39574 L .43683 .41039 L p 0 .05 .1 r
F P
0 g
s
.43683 .41039 m .45206 .39574 L .46316 .38971 L p 0 .05 .1 r
F P
0 g
s
.45815 .45083 m .47345 .43597 L .46376 .44089 L p 0 .05 .1 r
F P
0 g
s
.46376 .44089 m .44854 .45566 L .45815 .45083 L p 0 .05 .1 r
F P
0 g
s
.48867 .42118 m .47345 .43597 L .46376 .44089 L p 0 .05 .1 r
F P
0 g
s
.4503 .42565 m .46376 .44089 L .47345 .43597 L p 0 .314 .946 r
F P
0 g
s
.46376 .44089 m .4503 .42565 L .43504 .4404 L p 0 .349 .781 r
F P
0 g
s
.43504 .4404 m .44854 .45566 L .46376 .44089 L p 0 .349 .781 r
F P
0 g
s
.4503 .42565 m .46376 .44089 L .44854 .45566 L p 0 .349 .781 r
F P
0 g
s
.44854 .45566 m .46376 .44089 L .47345 .43597 L p 0 .05 .1 r
F P
0 g
s
.46376 .44089 m .4503 .42565 L .4614 .41984 L p 0 .314 .946 r
F P
0 g
s
.47345 .43597 m .46376 .44089 L p .4614 .41984 L 0 .314 .946 r
F P
0 g
s
.47668 .40507 m .4614 .41984 L .4503 .42565 L p 0 .05 .1 r
F P
0 g
s
.47224 .43213 m .4614 .41984 L .4503 .42565 L p 0 .314 .946 r
F P
0 g
s
.47345 .43597 m .47224 .43213 L p .4503 .42565 L 0 .314 .946 r
F P
0 g
s
.44854 .45566 m .43504 .4404 L .4503 .42565 L p 0 .349 .781 r
F P
0 g
s
.44605 .43469 m .4614 .41984 L .4503 .42565 L p 0 .05 .1 r
F P
0 g
s
.4503 .42565 m .43504 .4404 L .44605 .43469 L p 0 .05 .1 r
F P
0 g
s
.43683 .41039 m .4503 .42565 L .4614 .41984 L p 0 .314 .946 r
F P
0 g
s
.4503 .42565 m .43683 .41039 L .42153 .42511 L p 0 .349 .781 r
F P
0 g
s
.42153 .42511 m .43504 .4404 L .4503 .42565 L p 0 .349 .781 r
F P
0 g
s
.43683 .41039 m .4503 .42565 L .43504 .4404 L p 0 .349 .781 r
F P
0 g
s
.43504 .4404 m .4503 .42565 L .4614 .41984 L p 0 .05 .1 r
F P
0 g
s
.4503 .42565 m .43683 .41039 L .44784 .40446 L p 0 .314 .946 r
F P
0 g
s
.44784 .40446 m .4614 .41984 L .4503 .42565 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .44113 .40167 L .42778 .38653 L p 0 .349 .781 r
F P
0 g
s
.42778 .38653 m .44113 .40167 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.43683 .41039 m .44784 .40446 L .46316 .38971 L p 0 .05 .1 r
F P
0 g
s
.46316 .38971 m .44784 .40446 L .43683 .41039 L p 0 .05 .1 r
F P
0 g
s
.43683 .41039 m .44784 .40446 L .43425 .38906 L p 0 .314 .946 r
F P
0 g
s
.4614 .41984 m .44784 .40446 L .43683 .41039 L p 0 .314 .946 r
F P
0 g
s
.43504 .4404 m .42153 .42511 L .43683 .41039 L p 0 .349 .781 r
F P
0 g
s
.43244 .41928 m .44784 .40446 L .43683 .41039 L p 0 .05 .1 r
F P
0 g
s
.43425 .38906 m .44784 .40446 L .43683 .41039 L p 0 .314 .946 r
F P
0 g
s
.43683 .41039 m .42153 .42511 L .43244 .41928 L p 0 .05 .1 r
F P
0 g
s
.42153 .42511 m .43683 .41039 L .44784 .40446 L p 0 .05 .1 r
F P
0 g
s
.50382 .40646 m .48867 .42118 L .48748 .41734 L p 0 .432 .873 r
F P
0 g
s
.47345 .43597 m .45815 .45083 L .44854 .45566 L p 0 .05 .1 r
F P
0 g
s
.43504 .4404 m .44854 .45566 L .45815 .45083 L p 0 .313 .947 r
F P
0 g
s
.45693 .447 m .45815 .45083 L .44854 .45566 L p 0 .313 .947 r
F P
0 g
s
.44605 .43469 m .45693 .447 L p .44854 .45566 L 0 .313 .947 r
F P
0 g
s
.45693 .447 m .44605 .43469 L .43504 .4404 L p 0 .313 .947 r
F P
0 g
s
.45815 .45083 m .45693 .447 L p .43504 .4404 L 0 .313 .947 r
F P
0 g
s
.4614 .41984 m .44605 .43469 L .43504 .4404 L p 0 .05 .1 r
F P
0 g
s
.44784 .40446 m .43244 .41928 L .42153 .42511 L p 0 .05 .1 r
F P
0 g
s
.47668 .40507 m .48748 .41734 L .48867 .42118 L p 0 .314 .945 r
F P
0 g
s
.48867 .42118 m .48748 .41734 L .47668 .40507 L p 0 .314 .945 r
F P
0 g
s
.47224 .43213 m .48748 .41734 L .48867 .42118 L p 0 .432 .873 r
F P
0 g
s
.48867 .42118 m .47345 .43597 L .47224 .43213 L p 0 .432 .873 r
F P
0 g
s
.45815 .45083 m .44278 .46576 L .43325 .47051 L p 0 .05 .1 r
F P
0 g
s
.47668 .40507 m .48748 .41734 L .47224 .43213 L p 0 .35 .78 r
F P
0 g
s
.46316 .38971 m .47668 .40507 L .4614 .41984 L p 0 .35 .78 r
F P
0 g
s
.47224 .43213 m .4614 .41984 L .47668 .40507 L p 0 .35 .78 r
F P
0 g
s
.4614 .41984 m .47224 .43213 L .47345 .43597 L p 0 .314 .946 r
F P
0 g
s
.47345 .43597 m .45815 .45083 L .45693 .447 L p 0 .432 .873 r
F P
0 g
s
.45693 .447 m .47224 .43213 L .47345 .43597 L p 0 .432 .873 r
F P
0 g
s
.4614 .41984 m .44784 .40446 L .46316 .38971 L p 0 .35 .78 r
F P
0 g
s
.44962 .37434 m .46316 .38971 L .44784 .40446 L p 0 .35 .78 r
F P
0 g
s
.43606 .35894 m .44962 .37434 L .43425 .38906 L p 0 .35 .78 r
F P
0 g
s
.44784 .40446 m .43425 .38906 L .44962 .37434 L p 0 .35 .78 r
F P
0 g
s
.4614 .41984 m .47224 .43213 L .45693 .447 L p 0 .35 .78 r
F P
0 g
s
.44784 .40446 m .4614 .41984 L .44605 .43469 L p 0 .35 .78 r
F P
0 g
s
.45693 .447 m .44605 .43469 L .4614 .41984 L p 0 .35 .78 r
F P
0 g
s
.45815 .45083 m .44278 .46576 L .44154 .46194 L p 0 .432 .873 r
F P
0 g
s
.44854 .45566 m .43504 .4404 L .44605 .43469 L p 0 .313 .947 r
F P
0 g
s
.44154 .46194 m .45693 .447 L .45815 .45083 L p 0 .432 .873 r
F P
0 g
s
.44371 .4686 m .44278 .46576 L .45815 .45083 L p 0 .432 .873 r
F P
0 g
s
.42778 .38653 m .41259 .40106 L .42599 .41623 L p 0 .349 .781 r
F P
0 g
s
.42599 .41623 m .41259 .40106 L .42778 .38653 L p 0 .349 .781 r
F P
0 g
s
.42334 .3951 m .41259 .40106 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .43683 .41039 L .42334 .3951 L p 0 .314 .946 r
F P
0 g
s
.42334 .3951 m .43683 .41039 L .42599 .41623 L p 0 .314 .946 r
F P
0 g
s
.42599 .41623 m .41259 .40106 L .42334 .3951 L p 0 .314 .946 r
F P
0 g
s
.43425 .38906 m .42334 .3951 L .43683 .41039 L p 0 .314 .946 r
F P
0 g
s
.43683 .41039 m .42334 .3951 L .43425 .38906 L p 0 .314 .946 r
F P
0 g
s
.41881 .40385 m .43425 .38906 L .44784 .40446 L p 0 .35 .78 r
F P
0 g
s
.44784 .40446 m .43244 .41928 L .41881 .40385 L p 0 .35 .78 r
F P
0 g
s
.44605 .43469 m .43244 .41928 L .44784 .40446 L p 0 .35 .78 r
F P
0 g
s
.44605 .43469 m .45693 .447 L .44154 .46194 L p 0 .35 .78 r
F P
0 g
s
.45084 .46632 m .50784 .41087 L .4369 .33021 L p .858 0 0 r
F P
0 g
s
.3934 .38344 m .40838 .36919 L .39521 .35427 L p 0 .349 .781 r
F P
0 g
s
.39521 .35427 m .40838 .36919 L .41889 .36311 L p 0 .315 .944 r
F P
0 g
s
.39521 .35427 m .38019 .36849 L .3934 .38344 L p 0 .349 .781 r
F P
0 g
s
.41889 .36311 m .40564 .34807 L .39521 .35427 L p 0 .315 .944 r
F P
0 g
s
.40564 .34807 m .41889 .36311 L .42956 .35694 L p 0 .315 .944 r
F P
0 g
s
.42956 .35694 m .41621 .34178 L .40564 .34807 L p 0 .315 .944 r
F P
0 g
s
.39918 .38587 m .38574 .37067 L .37534 .37677 L p 0 .314 .946 r
F P
0 g
s
.37534 .37677 m .38574 .37067 L .39918 .38587 L p 0 .314 .946 r
F P
0 g
s
.41441 .37137 m .42956 .35694 L .41621 .34178 L p 0 .349 .781 r
F P
0 g
s
.42956 .35694 m .41441 .37137 L .42778 .38653 L p 0 .349 .781 r
F P
0 g
s
.41621 .34178 m .42956 .35694 L .41441 .37137 L p 0 .349 .781 r
F P
0 g
s
.42778 .38653 m .41441 .37137 L .42956 .35694 L p 0 .349 .781 r
F P
0 g
s
.41621 .34178 m .40102 .35619 L .41441 .37137 L p 0 .349 .781 r
F P
0 g
s
.41441 .37137 m .40102 .35619 L .41621 .34178 L p 0 .349 .781 r
F P
0 g
s
.41259 .40106 m .42778 .38653 L .41441 .37137 L p 0 .349 .781 r
F P
0 g
s
.41441 .37137 m .42778 .38653 L .41259 .40106 L p 0 .349 .781 r
F P
0 g
s
.39918 .38587 m .41441 .37137 L .40102 .35619 L p 0 .349 .781 r
F P
0 g
s
.41441 .37137 m .39918 .38587 L .41259 .40106 L p 0 .349 .781 r
F P
0 g
s
.40102 .35619 m .41441 .37137 L .39918 .38587 L p 0 .349 .781 r
F P
0 g
s
.41259 .40106 m .39918 .38587 L .41441 .37137 L p 0 .349 .781 r
F P
0 g
s
.40102 .35619 m .38574 .37067 L .39918 .38587 L p 0 .349 .781 r
F P
0 g
s
.39918 .38587 m .38574 .37067 L .40102 .35619 L p 0 .349 .781 r
F P
0 g
s
.40983 .3798 m .39918 .38587 L .41259 .40106 L p 0 .314 .946 r
F P
0 g
s
.41259 .40106 m .42334 .3951 L .40983 .3798 L p 0 .314 .946 r
F P
0 g
s
.40983 .3798 m .42334 .3951 L .41259 .40106 L p 0 .314 .946 r
F P
0 g
s
.41259 .40106 m .39918 .38587 L .40983 .3798 L p 0 .314 .946 r
F P
0 g
s
.39918 .38587 m .38574 .37067 L .3704 .38521 L p 0 .349 .781 r
F P
0 g
s
.3963 .36447 m .38574 .37067 L .39918 .38587 L p 0 .314 .946 r
F P
0 g
s
.39918 .38587 m .40983 .3798 L .3963 .36447 L p 0 .314 .946 r
F P
0 g
s
.3963 .36447 m .40983 .3798 L .39918 .38587 L p 0 .314 .946 r
F P
0 g
s
.39918 .38587 m .38574 .37067 L .3963 .36447 L p 0 .314 .946 r
F P
0 g
s
.3704 .38521 m .38574 .37067 L .39918 .38587 L p 0 .349 .781 r
F P
0 g
s
.42065 .37363 m .40983 .3798 L .42334 .3951 L p 0 .314 .946 r
F P
0 g
s
.42334 .3951 m .43425 .38906 L .42065 .37363 L p 0 .314 .946 r
F P
0 g
s
.42065 .37363 m .43425 .38906 L .42334 .3951 L p 0 .314 .946 r
F P
0 g
s
.42334 .3951 m .40983 .3798 L .42065 .37363 L p 0 .314 .946 r
F P
0 g
s
.40702 .35818 m .3963 .36447 L .40983 .3798 L p 0 .314 .946 r
F P
0 g
s
.40983 .3798 m .42065 .37363 L .40702 .35818 L p 0 .314 .946 r
F P
0 g
s
.40702 .35818 m .42065 .37363 L .40983 .3798 L p 0 .314 .946 r
F P
0 g
s
.40983 .3798 m .3963 .36447 L .40702 .35818 L p 0 .314 .946 r
F P
0 g
s
.44605 .43469 m .43504 .4404 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.43063 .44961 m .43269 .44762 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.43269 .44762 m .44605 .43469 L p .43122 .44837 L 0 .05 .1 r
F P
0 g
s
.42153 .42511 m .43504 .4404 L .44605 .43469 L p 0 .313 .947 r
F P
0 g
s
.43504 .4404 m .42153 .42511 L .40615 .4399 L p 0 .349 .781 r
F P
0 g
s
.40615 .4399 m .41971 .45522 L .43504 .4404 L p 0 .349 .781 r
F P
0 g
s
.42153 .42511 m .43504 .4404 L .41971 .45522 L p 0 .349 .781 r
F P
0 g
s
.41971 .45522 m .43504 .4404 L .44605 .43469 L p 0 .05 .1 r
F P
0 g
s
.43244 .41928 m .44605 .43469 L .43504 .4404 L p 0 .313 .947 r
F P
0 g
s
.43504 .4404 m .42153 .42511 L .43244 .41928 L p 0 .313 .947 r
F P
0 g
s
.44605 .43469 m .43244 .41928 L .42153 .42511 L p 0 .313 .947 r
F P
0 g
s
.41971 .45522 m .40615 .4399 L .42153 .42511 L p 0 .349 .781 r
F P
0 g
s
.43244 .41928 m .42153 .42511 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.41697 .43417 m .41904 .43218 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.41904 .43218 m .43244 .41928 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.40615 .4399 m .41697 .43417 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.42153 .42511 m .4082 .43793 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.4082 .43793 m .40615 .4399 L p .41759 .43295 L 0 .05 .1 r
F P
0 g
s
.40615 .4399 m .42153 .42511 L .43244 .41928 L p 0 .05 .1 r
F P
0 g
s
.43063 .44961 m .41971 .45522 L p .4232 .45249 L 0 .05 .1 r
F P
0 g
s
.44605 .43469 m .43269 .44762 L p .4232 .45249 L 0 .05 .1 r
F P
0 g
s
.43269 .44762 m .43063 .44961 L p .4232 .45249 L 0 .05 .1 r
F P
0 g
s
.43244 .41928 m .41697 .43417 L .40615 .4399 L p 0 .05 .1 r
F P
0 g
s
.42247 .34351 m .43606 .35894 L .42065 .37363 L p 0 .35 .78 r
F P
0 g
s
.43425 .38906 m .42065 .37363 L .43606 .35894 L p 0 .35 .78 r
F P
0 g
s
.42065 .37363 m .40702 .35818 L .42247 .34351 L p 0 .35 .78 r
F P
0 g
s
.40516 .3884 m .42065 .37363 L .43425 .38906 L p 0 .35 .78 r
F P
0 g
s
.43425 .38906 m .41881 .40385 L .40516 .3884 L p 0 .35 .78 r
F P
0 g
s
.3915 .37292 m .40702 .35818 L .42065 .37363 L p 0 .35 .78 r
F P
0 g
s
.42065 .37363 m .40516 .3884 L .3915 .37292 L p 0 .35 .78 r
F P
0 g
s
.43244 .41928 m .44605 .43469 L .43063 .44961 L p 0 .35 .78 r
F P
0 g
s
.44154 .46194 m .43063 .44961 L .44605 .43469 L p 0 .35 .78 r
F P
0 g
s
.4033 .41871 m .41881 .40385 L .43244 .41928 L p 0 .35 .78 r
F P
0 g
s
.43244 .41928 m .41697 .43417 L .4033 .41871 L p 0 .35 .78 r
F P
0 g
s
.43063 .44961 m .41697 .43417 L .43244 .41928 L p 0 .35 .78 r
F P
0 g
s
.38961 .40323 m .40516 .3884 L .41881 .40385 L p 0 .35 .78 r
F P
0 g
s
.41881 .40385 m .4033 .41871 L .38961 .40323 L p 0 .35 .78 r
F P
0 g
s
.37589 .38773 m .3915 .37292 L .40516 .3884 L p 0 .35 .78 r
F P
0 g
s
.40516 .3884 m .38961 .40323 L .37589 .38773 L p 0 .35 .78 r
F P
0 g
s
.4369 .33021 m .37904 .38514 L .45084 .46632 L p .858 0 0 r
F P
0 g
s
.43885 .44445 m .45084 .46632 L .4497 .4552 L .54 0 0 r
F
.42389 .42961 m .4359 .44597 L .43885 .44445 L F
.4359 .44597 m .45084 .46632 L .43885 .44445 L F
.4497 .4552 m .45084 .46632 L .45756 .463 L F
.37904 .38514 m .42013 .4316 L .42389 .42961 L F
.42013 .4316 m .45084 .46632 L .42389 .42961 L F
.43379 .44705 m .42013 .4316 L p .43537 .44624 L F P
0 g
s
.42013 .4316 m .37904 .38514 L p .42131 .43098 L .54 0 0 r
F P
0 g
s
.42013 .4316 m .42131 .43098 L .43537 .44624 L .54 0 0 r
F
.43537 .44624 m .37904 .38514 L .38546 .38142 L F
.45084 .46632 m .43379 .44705 L p .43537 .44624 L F P
0 g
s
.45756 .463 m .45084 .46632 L p .43537 .44624 L .54 0 0 r
F P
0 g
s
.38546 .38142 m .44044 .44363 L p .43537 .44624 L .54 0 0 r
F P
0 g
s
.44044 .44363 m .45756 .463 L p .43537 .44624 L .54 0 0 r
F P
0 g
s
.4033 .41871 m .41697 .43417 L .40615 .4399 L p 0 .312 .948 r
F P
0 g
s
.40615 .4399 m .39257 .42457 L .4033 .41871 L p 0 .312 .948 r
F P
0 g
s
.38961 .40323 m .4033 .41871 L .39257 .42457 L p 0 .312 .948 r
F P
0 g
s
.40449 .49021 m .44767 .46887 L .37589 .38773 L p .539 0 0 r
F P
0 g
s
.38499 .4511 m .39836 .46618 L .38792 .47154 L p 0 .312 .948 r
F P
0 g
s
.40258 .48579 m .39853 .4835 L .38792 .47154 L p 0 .312 .948 r
F P
0 g
s
.38792 .47154 m .39836 .46618 L p .40258 .48579 L 0 .312 .948 r
F P
0 g
s
.39836 .46618 m .41171 .48124 L .40258 .48579 L p 0 .312 .948 r
F P
0 g
s
.4056 .4875 m .40258 .48579 L .41171 .48124 L p 0 .312 .948 r
F P
0 g
s
.41171 .48124 m .4137 .48348 L .4056 .4875 L p 0 .312 .948 r
F P
0 g
s
.4224 .47591 m .4244 .47818 L .4137 .48348 L p 0 .312 .948 r
F P
0 g
s
.4137 .48348 m .41171 .48124 L .4224 .47591 L p 0 .312 .948 r
F P
0 g
s
.40895 .46074 m .4224 .47591 L .41171 .48124 L p 0 .312 .948 r
F P
0 g
s
.41171 .48124 m .39836 .46618 L .40895 .46074 L p 0 .312 .948 r
F P
0 g
s
.39549 .44555 m .40895 .46074 L .39836 .46618 L p 0 .312 .948 r
F P
0 g
s
.39836 .46618 m .38499 .4511 L .39549 .44555 L p 0 .312 .948 r
F P
0 g
s
.43325 .47051 m .43527 .47279 L .4244 .47818 L p 0 .312 .948 r
F P
0 g
s
.4244 .47818 m .4224 .47591 L .43325 .47051 L p 0 .312 .948 r
F P
0 g
s
.41971 .45522 m .43325 .47051 L .4224 .47591 L p 0 .312 .948 r
F P
0 g
s
.4224 .47591 m .40895 .46074 L .41971 .45522 L p 0 .312 .948 r
F P
0 g
s
.40615 .4399 m .41971 .45522 L .40895 .46074 L p 0 .312 .948 r
F P
0 g
s
.40895 .46074 m .39549 .44555 L .40615 .4399 L p 0 .312 .948 r
F P
0 g
s
.43532 .48089 m .39243 .50191 L p .37814 .45164 L .535 0 0 r
F P
0 g
s
.36335 .39963 m .39941 .44034 L p .37814 .45164 L .535 0 0 r
F P
0 g
s
.39941 .44034 m .43532 .48089 L p .37814 .45164 L .535 0 0 r
F P
0 g
s
.41971 .45522 m .40615 .4399 L .41697 .43417 L p 0 .312 .948 r
F P
0 g
s
.43532 .48089 m .36335 .39963 L .37589 .38773 L p .858 0 0 r
F P
0 g
s
.44278 .46576 m .44371 .4686 L .43527 .47279 L p 0 .312 .948 r
F P
0 g
s
.43527 .47279 m .43325 .47051 L .44278 .46576 L p 0 .312 .948 r
F P
0 g
s
.44154 .46194 m .44278 .46576 L .43325 .47051 L p 0 .312 .948 r
F P
0 g
s
.43063 .44961 m .44154 .46194 L p .43325 .47051 L 0 .312 .948 r
F P
0 g
s
.43325 .47051 m .41971 .45522 L .43063 .44961 L p 0 .312 .948 r
F P
0 g
s
.41697 .43417 m .43063 .44961 L .41971 .45522 L p 0 .312 .948 r
F P
0 g
s
.37589 .38773 m .44767 .46887 L .43532 .48089 L p .858 0 0 r
F P
0 g
s
.44767 .46887 m .43532 .48089 L .44113 .4771 L .1 0 0 r
F
.37589 .38773 m .43532 .48089 L .44767 .46887 L .858 0 0 r
F
.37589 .38773 m .36335 .39963 L .43532 .48089 L F
.36335 .39963 m .44113 .4771 L .43532 .48089 L .672 0 0 r
F
.36335 .39963 m .36902 .39564 L .44113 .4771 L F
.39941 .44034 m .38736 .45684 L .40378 .43801 L .1 0 0 r
F
.39941 .44034 m .40378 .43801 L .40515 .43645 L F
.37018 .46842 m .39941 .44034 L p .36373 .46546 L F P
0 g
s
.32897 .48995 m .34926 .47935 L p .36373 .46546 L .1 0 0 r
F P
0 g
s
.34926 .47935 m .37018 .46842 L p .36373 .46546 L .1 0 0 r
F P
0 g
s
.39941 .44034 m .37814 .45164 L p .36842 .46217 L .1 0 0 r
F P
0 g
s
.37814 .45164 m .35751 .46261 L p .36712 .46222 L .1 0 0 r
F P
0 g
s
.36842 .46217 m .37814 .45164 L .36712 .46222 L .1 0 0 r
F
.35751 .46261 m .32897 .48995 L p .36842 .46217 L F P
0 g
s
.45639 .30369 m .42832 .3303 L p .43934 .28427 L 0 .349 .781 r
F P
0 g
s
.42318 .32446 m .43934 .28427 L .42832 .3303 L 0 .349 .781 r
F
.4645 .22171 m .5 .26235 L .45639 .30369 L p F P
0 g
s
.43934 .28427 m .4645 .22171 L .45639 .30369 L 0 .349 .781 r
F
.54321 .31181 m .56641 .29869 L p .5261 .32828 L .1 0 0 r
F P
0 g
s
.56641 .29869 m .5317 .33216 L .50889 .34485 L p .1 0 0 r
F P
0 g
s
.52261 .24846 m .56641 .29869 L p .55417 .30561 L 0 .318 .939 r
F P
0 g
s
.52899 .2386 m .54665 .22184 L .53524 .22894 L p 0 .05 .1 r
F P
0 g
s
.74444 .52928 m .75707 .52453 L .73322 .5228 L p 0 .458 1 r
F P
0 g
s
.73322 .5228 m .72073 .52758 L .74444 .52928 L p 0 .458 1 r
F P
0 g
s
.74444 .52928 m .72073 .52758 L .71396 .54536 L p 0 .349 .781 r
F P
0 g
s
.71396 .54536 m .73098 .56481 L .74444 .52928 L p 0 .349 .781 r
F P
0 g
s
.74444 .52928 m .75707 .52453 L .77673 .52595 L p 0 .458 1 r
F P
0 g
s
.75707 .52453 m .74444 .52928 L .72073 .52758 L p 0 .458 1 r
F P
0 g
s
.58951 .50212 m
.6044 .51029 L
s
0 0 0 r
.67029 .49547 m
.67029 .49547 L
s
.67029 .49547 m
.67029 .49547 L
s
.61449 .596 m .60456 .54006 L .58118 .55824 L .778 0 0 r
F
.61449 .596 m .63793 .57797 L .60456 .54006 L F
.61547 .60434 m .63793 .57797 L .61449 .596 L .257 0 0 r
F
.59149 .61732 m .61449 .596 L .58118 .55824 L .831 0 0 r
F
.60772 .61152 m .61449 .596 L .59149 .61732 L .257 0 0 r
F
.60772 .61152 m .61547 .60434 L .61449 .596 L F
.72073 .52758 m .73322 .5228 L .70925 .52107 L p 0 .458 1 r
F P
0 g
s
.70925 .52107 m .69689 .52586 L .72073 .52758 L p 0 .458 1 r
F P
0 g
s
.72073 .52758 m .73322 .5228 L .75707 .52453 L p 0 .458 1 r
F P
0 g
s
.73322 .5228 m .72073 .52758 L .69689 .52586 L p 0 .458 1 r
F P
0 g
s
.71396 .54536 m .72073 .52758 L .69689 .52586 L closepath p 0 .349 .781 r
F P
0 g
s
.55406 .66632 m .60772 .61152 L .59149 .61732 L p .257 0 0 r
F P
0 g
s
.59149 .61732 m .53823 .67161 L .55406 .66632 L p .257 0 0 r
F P
0 g
s
.53823 .67161 m .59149 .61732 L .5581 .57955 L p .855 0 0 r
F P
0 g
s
.59149 .61732 m .58118 .55824 L .5581 .57955 L .831 0 0 r
F
.5581 .57955 m .59149 .61732 L .60772 .61152 L p .556 0 0 r
F P
0 g
s
.60184 .60773 m
.61449 .596 L
s
.60772 .61152 m .59149 .61732 L .5581 .57955 L .556 0 0 r
F
.73098 .56481 m .74356 .56031 L .77673 .52595 L p 0 .05 .248 r
F P
0 g
s
.74356 .56031 m .73098 .56481 L .71396 .54536 L p 0 .318 .939 r
F P
0 g
s
.73098 .56481 m .69689 .52586 L .61787 .60663 L p 0 .349 .781 r
F P
0 g
s
.61787 .60663 m .65255 .64594 L .73098 .56481 L p 0 .349 .781 r
F P
0 g
s
.77673 .52595 m .74356 .56031 L .75632 .55573 L p 0 .05 .248 r
F P
0 g
s
.69689 .52586 m .70925 .52107 L .73322 .5228 L p 0 .458 1 r
F P
0 g
s
.70925 .52107 m .73322 .5228 L .7459 .51796 L p 0 .458 1 r
F P
0 g
s
.73322 .5228 m .70925 .52107 L .72178 .5162 L p 0 .458 1 r
F P
0 g
s
.7459 .51796 m .72178 .5162 L .70925 .52107 L p 0 .458 1 r
F P
0 g
s
.73098 .56481 m .75632 .55573 L .72178 .5162 L p 0 .318 .939 r
F P
0 g
s
.72178 .5162 m .69689 .52586 L .73098 .56481 L p 0 .318 .939 r
F P
0 g
s
.73098 .56481 m .65255 .64594 L .67707 .63793 L p 0 .05 .248 r
F P
0 g
s
.67707 .63793 m .75632 .55573 L .73098 .56481 L p 0 .05 .248 r
F P
0 g
s
.58451 .56307 m .58118 .55824 L .60456 .54006 L .221 0 0 r
F
.5818 .56618 m .58451 .56307 L .58966 .56008 L F
.58451 .56307 m .60456 .54006 L .58966 .56008 L F
.62335 .59829 m .65576 .56791 L .63793 .57797 L .257 0 0 r
F
.61547 .60434 m .62335 .59829 L .63793 .57797 L F
.62335 .59829 m .62929 .59496 L .65576 .56791 L F
.62335 .59829 m .62929 .59496 L .59553 .55666 L .682 0 0 r
F
.63793 .57797 m .62219 .52972 L .60456 .54006 L .684 0 0 r
F
.58966 .56008 m .60456 .54006 L .62219 .52972 L .221 0 0 r
F
.58966 .56008 m .59171 .55817 L .59553 .55666 L F
.59171 .55817 m .62219 .52972 L .59553 .55666 L F
.72642 .5407 m .71396 .54536 L .69689 .52586 L p 0 .318 .939 r
F P
0 g
s
.69689 .52586 m .70925 .52107 L .72642 .5407 L p 0 .318 .939 r
F P
0 g
s
.72642 .5407 m .70925 .52107 L .72178 .5162 L p 0 .318 .939 r
F P
0 g
s
.71396 .54536 m .72642 .5407 L .74356 .56031 L p 0 .318 .939 r
F P
0 g
s
.73907 .53598 m .75632 .55573 L .74356 .56031 L p 0 .318 .939 r
F P
0 g
s
.74356 .56031 m .72642 .5407 L .73907 .53598 L p 0 .318 .939 r
F P
0 g
s
.72178 .5162 m .73907 .53598 L .72642 .5407 L p 0 .318 .939 r
F P
0 g
s
.69689 .52586 m .72178 .5162 L .68021 .55879 L p 0 .05 .212 r
F P
0 g
s
.68021 .55879 m .65576 .56791 L p .66686 .57247 L .257 0 0 r
F P
0 g
s
.65847 .59191 m .68326 .56227 L .69683 .57773 L 0 .349 .781 r
F
.65346 .58621 m .68021 .55879 L .65847 .59191 L F
.68021 .55879 m .72178 .5162 L .68326 .56227 L F
.68021 .55879 m .68326 .56227 L .65847 .59191 L F
.67062 .56237 m .69689 .52586 L .68021 .55879 L 0 .05 .212 r
F
.68326 .56227 m .72178 .5162 L .69683 .57773 L 0 .349 .781 r
F
.65576 .56791 m .62929 .59496 L .65346 .58621 L p .257 0 0 r
F P
0 g
s
.72178 .5162 m .65346 .58621 L p .65346 .58621 L 0 .349 .781 r
F P
0 g
s
.75632 .55573 m .72178 .5162 L p .65346 .58621 L 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .65847 .59191 L .65346 .58621 L 0 .349 .781 r
F
.65847 .59191 m .75632 .55573 L .65346 .58621 L F
.63793 .57797 m .65576 .56791 L .62219 .52972 L .684 0 0 r
F
.62929 .59496 m .62219 .52972 L .65576 .56791 L .856 0 0 r
F
.62929 .59496 m .65576 .56791 L .62219 .52972 L p F P
0 g
s
.62929 .59496 m .59553 .55666 L .62219 .52972 L .856 0 0 r
F
.62219 .52972 m .59553 .55666 L .62929 .59496 L p F P
0 g
s
.62929 .59496 m .59553 .55666 L p .63637 .56678 L .559 0 0 r
F P
0 g
s
.65576 .56791 m .65346 .58621 L .66686 .57247 L .257 0 0 r
F
.64996 .58747 m .66848 .56317 L .65346 .58621 L 0 .05 .212 r
F
.66848 .56317 m .69689 .52586 L .67062 .56237 L F
.66848 .56317 m .67062 .56237 L .65346 .58621 L F
.62929 .59496 m .65576 .56791 L p .64613 .58886 L F P
0 g
s
.64996 .58747 m .65576 .56791 L .66848 .56317 L 0 .05 .212 r
F
.65576 .56791 m .69689 .52586 L p .66848 .56317 L F P
0 g
s
.62219 .52972 m .65576 .56791 L .68021 .55879 L p .567 0 0 r
F P
0 g
s
.62219 .52972 m .68021 .55879 L .66322 .53943 L .567 0 0 r
F
.59553 .55666 m .62219 .52972 L p .63275 .53364 L .221 0 0 r
F P
0 g
s
.64367 .5377 m .61925 .54732 L p .63275 .53364 L .221 0 0 r
F P
0 g
s
.61925 .54732 m .59553 .55666 L p .63275 .53364 L .221 0 0 r
F P
0 g
s
.56165 .51822 m .59553 .55666 L p .61925 .54732 L .559 0 0 r
F P
0 g
s
.59553 .55666 m .62929 .59496 L p .61925 .54732 L .559 0 0 r
F P
0 g
s
.59259 .55837 m .59553 .55666 L .56165 .51822 L .682 0 0 r
F
.62335 .59829 m .59553 .55666 L .59259 .55837 L F
.58966 .56008 m .56165 .51822 L .55585 .52173 L F
.62335 .59829 m .59259 .55837 L .58966 .56008 L F
.59259 .55837 m .56165 .51822 L .58966 .56008 L F
.5818 .56618 m .58169 .56472 L .58451 .56307 L .221 0 0 r
F
.58169 .56472 m .58118 .55824 L .58451 .56307 L F
.57403 .57336 m .57488 .57156 L .5818 .56618 L F
.57488 .57156 m .58118 .55824 L .5818 .56618 L F
.57403 .57336 m .5581 .57955 L .58118 .55824 L F
.5818 .56618 m .55585 .52173 L .54801 .52789 L .778 0 0 r
F
.61547 .60434 m .58573 .56313 L .5818 .56618 L F
.58573 .56313 m .55585 .52173 L .5818 .56618 L F
.61547 .60434 m .58966 .56008 L .62335 .59829 L F
.61547 .60434 m .5818 .56618 L .58966 .56008 L F
.61547 .60434 m .62335 .59829 L .55585 .52173 L F
.6159 .60797 m .62335 .59829 L .61547 .60434 L .257 0 0 r
F
.62335 .59829 m .59553 .55666 L .62929 .59496 L .682 0 0 r
F
.62335 .59829 m .58966 .56008 L .59553 .55666 L F
.61703 .6071 m .62929 .59496 L .62335 .59829 L .257 0 0 r
F
.6159 .60797 m .61703 .6071 L .62335 .59829 L F
.61703 .6071 m .61787 .60663 L .62929 .59496 L F
.61787 .60663 m .62929 .59496 L .56165 .51822 L p .856 0 0 r
F P
0 g
s
.61787 .60663 m .56165 .51822 L .62929 .59496 L .856 0 0 r
F
.65346 .58621 m .72178 .5162 L .72178 .5162 L p 0 .349 .781 r
F P
0 g
s
.64613 .58886 m .65576 .56791 L .64996 .58747 L 0 .05 .212 r
F
.66322 .53943 m .66322 .53943 L .6462 .52003 L .567 0 0 r
F
.72178 .5162 m .72178 .5162 L p .65346 .58621 L 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .72178 .5162 L .64192 .59803 L 0 .349 .781 r
F
.6462 .52003 m .62219 .52972 L p .66322 .53943 L .567 0 0 r
F P
0 g
s
.65346 .58621 m .65346 .58621 L p .66686 .57247 L .257 0 0 r
F P
0 g
s
.68021 .55879 m .65346 .58621 L p .67062 .56237 L 0 .05 .212 r
F P
0 g
s
.66686 .57247 m .67835 .57719 L .68021 .55879 L .257 0 0 r
F
.72178 .5162 m .75632 .55573 L p .69683 .57773 L 0 .349 .781 r
F P
0 g
s
.72178 .5162 m .7459 .51796 L .73322 .5228 L p 0 .458 1 r
F P
0 g
s
.73322 .5228 m .75707 .52453 L .76989 .51971 L p 0 .458 1 r
F P
0 g
s
.75707 .52453 m .73322 .5228 L .7459 .51796 L p 0 .458 1 r
F P
0 g
s
.76989 .51971 m .7459 .51796 L .73322 .5228 L p 0 .458 1 r
F P
0 g
s
.73907 .53598 m .72178 .5162 L .7459 .51796 L closepath p 0 .349 .781 r
F P
0 g
s
.72178 .5162 m .7459 .51796 L .75876 .51304 L p 0 .458 1 r
F P
0 g
s
.7459 .51796 m .72178 .5162 L .73907 .53598 L closepath p 0 .349 .781 r
F P
0 g
s
.7459 .51796 m .72178 .5162 L .7345 .51126 L p 0 .458 1 r
F P
0 g
s
.7345 .51126 m .75876 .51304 L .7459 .51796 L p 0 .458 1 r
F P
0 g
s
.75632 .55573 m .78966 .52115 L .77673 .52595 L p 0 .05 .248 r
F P
0 g
s
.75707 .52453 m .77673 .52595 L .78966 .52115 L p 0 .458 1 r
F P
0 g
s
.77673 .52595 m .75707 .52453 L .76989 .51971 L p 0 .458 1 r
F P
0 g
s
.76989 .51971 m .78966 .52115 L .77673 .52595 L p 0 .458 1 r
F P
0 g
s
.78966 .52115 m .76989 .51971 L .75707 .52453 L p 0 .458 1 r
F P
0 g
s
.76989 .51971 m .78966 .52115 L .75632 .55573 L closepath p 0 .349 .781 r
F P
0 g
s
.76927 .55109 m .80278 .51629 L .78966 .52115 L p 0 .05 .248 r
F P
0 g
s
.78966 .52115 m .75632 .55573 L .76927 .55109 L p 0 .05 .248 r
F P
0 g
s
.75632 .55573 m .78966 .52115 L .76989 .51971 L closepath p 0 .349 .781 r
F P
0 g
s
.76989 .51971 m .75632 .55573 L .73907 .53598 L p 0 .349 .781 r
F P
0 g
s
.7459 .51796 m .76989 .51971 L .75707 .52453 L p 0 .458 1 r
F P
0 g
s
.73907 .53598 m .7459 .51796 L .76989 .51971 L p 0 .349 .781 r
F P
0 g
s
.75632 .55573 m .76989 .51971 L .7459 .51796 L p 0 .349 .781 r
F P
0 g
s
.7459 .51796 m .73907 .53598 L .75632 .55573 L p 0 .349 .781 r
F P
0 g
s
.8161 .51135 m .80278 .51629 L .76927 .55109 L p 0 .05 .248 r
F P
0 g
s
.76927 .55109 m .78241 .54638 L .8161 .51135 L p 0 .05 .248 r
F P
0 g
s
.72178 .5162 m .75632 .55573 L .78241 .54638 L p 0 .318 .939 r
F P
0 g
s
.75876 .51304 m .7345 .51126 L .72178 .5162 L p 0 .458 1 r
F P
0 g
s
.7345 .51126 m .7519 .53119 L .73907 .53598 L p 0 .318 .939 r
F P
0 g
s
.73907 .53598 m .72178 .5162 L .7345 .51126 L p 0 .318 .939 r
F P
0 g
s
.7459 .51796 m .76989 .51971 L .78289 .51482 L p 0 .458 1 r
F P
0 g
s
.76989 .51971 m .7459 .51796 L .75876 .51304 L p 0 .458 1 r
F P
0 g
s
.78289 .51482 m .75876 .51304 L .7459 .51796 L p 0 .458 1 r
F P
0 g
s
.74741 .50624 m .7345 .51126 L .75876 .51304 L p 0 .458 1 r
F P
0 g
s
.77181 .50806 m .75876 .51304 L .7345 .51126 L p 0 .458 1 r
F P
0 g
s
.7345 .51126 m .74741 .50624 L .77181 .50806 L p 0 .458 1 r
F P
0 g
s
.78241 .54638 m .74741 .50624 L .72178 .5162 L p 0 .318 .939 r
F P
0 g
s
.76493 .52633 m .7519 .53119 L .7345 .51126 L p 0 .318 .939 r
F P
0 g
s
.7345 .51126 m .74741 .50624 L .76493 .52633 L p 0 .318 .939 r
F P
0 g
s
.72178 .5162 m .74741 .50624 L p .69211 .55436 L 0 .05 .212 r
F P
0 g
s
.68021 .55879 m .72178 .5162 L p .69211 .55436 L 0 .05 .212 r
F P
0 g
s
.75632 .55573 m .67707 .63793 L .64192 .59803 L p 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .65346 .58621 L .65847 .59191 L 0 .349 .781 r
F
.64192 .59803 m .66605 .62543 L .75632 .55573 L p F P
0 g
s
.65346 .58621 m .67835 .57719 L p .66686 .57247 L .257 0 0 r
F P
0 g
s
.67835 .57719 m .70539 .54941 L .68021 .55879 L p .257 0 0 r
F P
0 g
s
.66719 .57604 m .69211 .55436 L .67835 .57719 L 0 .05 .212 r
F
.64769 .59211 m .66669 .58917 L .65346 .58621 L .257 0 0 r
F
.64769 .59211 m .64192 .59803 L .64894 .59192 L F
.64192 .59803 m .66669 .58917 L p .64894 .59192 L F P
0 g
s
.65697 .58494 m .68021 .55879 L .69211 .55436 L 0 .05 .212 r
F
.65346 .58621 m .68021 .55879 L p .65697 .58494 L F P
0 g
s
.61925 .54732 m .67835 .57719 L .58491 .50829 L .559 0 0 r
F
.64192 .59803 m .66669 .58917 L .64192 .59803 L .556 0 0 r
F
.66669 .58917 m .67835 .57719 L .65346 .58621 L p .257 0 0 r
F P
0 g
s
.64192 .59803 m .65346 .58621 L p .65697 .58494 L 0 .05 .212 r
F P
0 g
s
.65697 .58494 m .66719 .57604 L .67835 .57719 L 0 .05 .212 r
F
.66669 .58917 m .64192 .59803 L p .65697 .58494 L F P
0 g
s
.67835 .57719 m .66669 .58917 L p .65697 .58494 L 0 .05 .212 r
F P
0 g
s
.69211 .55436 m .69836 .54892 L .70539 .54941 L 0 .05 .212 r
F
.74741 .50624 m .70539 .54941 L p .69836 .54892 L F P
0 g
s
.70539 .54941 m .67871 .51026 L .67092 .51004 L .204 0 0 r
F
.66322 .53943 m .70539 .54941 L .6462 .52003 L .567 0 0 r
F
.70539 .54941 m .67092 .51004 L .6462 .52003 L p F P
0 g
s
.66322 .53943 m .6462 .52003 L .6462 .52003 L .567 0 0 r
F
.66322 .53943 m .66322 .53943 L .6462 .52003 L F
.66322 .53943 m .6462 .52003 L .6462 .52003 L F
.62219 .52972 m .67092 .51004 L .64367 .5377 L p .221 0 0 r
F P
0 g
s
.60886 .49807 m .58491 .50829 L p .63137 .54255 L .559 0 0 r
F P
0 g
s
.67835 .57719 m .64367 .5377 L p .63137 .54255 L .559 0 0 r
F P
0 g
s
.64367 .5377 m .60886 .49807 L p .63137 .54255 L .559 0 0 r
F P
0 g
s
.58491 .50829 m .56165 .51822 L p .61925 .54732 L .559 0 0 r
F P
0 g
s
.66686 .57247 m .65346 .58621 L .66686 .57247 L .257 0 0 r
F
.65346 .58621 m .67835 .57719 L p .61925 .54732 L .559 0 0 r
F P
0 g
s
.61925 .54732 m .65346 .58621 L .61925 .54732 L .559 0 0 r
F
.64367 .5377 m .67835 .57719 L p .63637 .56678 L F P
0 g
s
.59553 .55666 m .61925 .54732 L p .63637 .56678 L .559 0 0 r
F P
0 g
s
.61925 .54732 m .64367 .5377 L p .63637 .56678 L .559 0 0 r
F P
0 g
s
.65346 .58621 m .62929 .59496 L p .63637 .56678 L .559 0 0 r
F P
0 g
s
.63637 .56678 m .67835 .57719 L .65344 .58618 L .559 0 0 r
F
.67835 .57719 m .65346 .58621 L p .65344 .58618 L F P
0 g
s
.63637 .56678 m .63637 .56678 L .65344 .58618 L .559 0 0 r
F
.61925 .54732 m .65346 .58621 L .61925 .54732 L F
.62929 .59496 m .65346 .58621 L p .61925 .54732 L F P
0 g
s
.59702 .50994 m .66669 .58917 L p .60762 .55909 L .556 0 0 r
F P
0 g
s
.62929 .59496 m .64192 .59803 L .64769 .59211 L .257 0 0 r
F
.65346 .58621 m .62929 .59496 L p .64769 .59211 L F P
0 g
s
.64192 .59803 m .64613 .58886 L .64996 .58747 L 0 .05 .212 r
F
.64192 .59803 m .62929 .59496 L .64613 .58886 L F
.60762 .55909 m .60762 .55909 L .64192 .59803 L .556 0 0 r
F
.65346 .58621 m .64192 .59803 L p .64996 .58747 L 0 .05 .212 r
F P
0 g
s
.60762 .55909 m .66669 .58917 L .64192 .59803 L .556 0 0 r
F
.64311 .45947 m .67076 .49107 L .62208 .51128 L p .569 0 0 r
F P
0 g
s
.70539 .54941 m .67835 .57719 L p .69211 .55436 L 0 .05 .212 r
F P
0 g
s
.68021 .55879 m .70539 .54941 L p .66322 .53943 L .567 0 0 r
F P
0 g
s
.68021 .55879 m .68021 .55879 L p .66322 .53943 L .567 0 0 r
F P
0 g
s
.66322 .53943 m .68021 .55879 L .66322 .53943 L .567 0 0 r
F
.66322 .53943 m .68021 .55879 L .66322 .53943 L F
.67835 .57719 m .70539 .54941 L .67092 .51004 L .858 0 0 r
F
.67092 .51004 m .70539 .54941 L .67835 .57719 L p F P
0 g
s
.67835 .57719 m .67092 .51004 L .64367 .5377 L .858 0 0 r
F
.67835 .57719 m .64367 .5377 L .67092 .51004 L p F P
0 g
s
.6478 .53447 m .67092 .51004 L .67871 .51026 L .221 0 0 r
F
.64367 .5377 m .64868 .53262 L .6478 .53447 L F
.64868 .53262 m .67092 .51004 L .6478 .53447 L F
.64367 .5377 m .67871 .51026 L .64619 .53785 L F
.64367 .5377 m .61128 .4981 L .60886 .49807 L .175 0 0 r
F
.67835 .57719 m .64493 .53778 L .64367 .5377 L F
.64493 .53778 m .61128 .4981 L .64367 .5377 L F
.64619 .53785 m .67343 .52168 L .64964 .53806 L .221 0 0 r
F
.7519 .53119 m .76927 .55109 L .75632 .55573 L p 0 .318 .939 r
F P
0 g
s
.75632 .55573 m .73907 .53598 L .7519 .53119 L p 0 .318 .939 r
F P
0 g
s
.78241 .54638 m .75632 .55573 L .67707 .63793 L p 0 .05 .248 r
F P
0 g
s
.78241 .54638 m .76927 .55109 L .7519 .53119 L p 0 .318 .939 r
F P
0 g
s
.7519 .53119 m .76493 .52633 L .78241 .54638 L p 0 .318 .939 r
F P
0 g
s
.66669 .58917 m .74741 .50624 L .78241 .54638 L p 0 .35 .78 r
F P
0 g
s
.67835 .57719 m .71347 .54997 L .70539 .54941 L .257 0 0 r
F
.60886 .49807 m .67835 .57719 L .66669 .58917 L p .858 0 0 r
F P
0 g
s
.67835 .57719 m .68096 .57746 L .71347 .54997 L .257 0 0 r
F
.67835 .57719 m .68096 .57746 L .61128 .4981 L .175 0 0 r
F
.66669 .58917 m .67835 .57719 L .60886 .49807 L .858 0 0 r
F
.67835 .57719 m .64619 .53785 L .68096 .57746 L .175 0 0 r
F
.67835 .57719 m .64367 .5377 L .64619 .53785 L F
.68096 .57746 m .64527 .53978 L .64619 .53785 L .978 0 0 r
F
.66669 .58917 m .68096 .57746 L .67835 .57719 L .257 0 0 r
F
.66669 .58917 m .59702 .50994 L .60886 .49807 L p .858 0 0 r
F P
0 g
s
.67707 .63793 m .70232 .62969 L .78241 .54638 L p 0 .05 .248 r
F P
0 g
s
.78241 .54638 m .70232 .62969 L .66669 .58917 L p 0 .35 .78 r
F P
0 g
s
.66669 .58917 m .66706 .58921 L .68096 .57746 L .257 0 0 r
F
.66669 .58917 m .60886 .49807 L .59702 .50994 L .858 0 0 r
F
.66706 .58921 m .67923 .58141 L .68096 .57746 L .257 0 0 r
F
.68096 .57746 m .67923 .58141 L .64435 .54171 L .978 0 0 r
F
.64527 .53978 m .64435 .54171 L .60934 .50186 L F
.68096 .57746 m .64435 .54171 L .64527 .53978 L F
.68096 .57746 m .64435 .54171 L .67923 .58141 L F
.68096 .57746 m .64619 .53785 L .64435 .54171 L F
.67923 .58141 m .64435 .54171 L .63863 .54825 L .888 0 0 r
F
.67923 .58141 m .60355 .50834 L .60934 .50186 L F
.64192 .59803 m .66669 .58917 L .70232 .62969 L p 0 .315 .944 r
F P
0 g
s
.67192 .61376 m .68452 .60945 L .66669 .58917 L p 0 .315 .944 r
F P
0 g
s
.66669 .58917 m .65421 .59363 L .67192 .61376 L p 0 .315 .944 r
F P
0 g
s
.70232 .62969 m .67707 .63793 L .64192 .59803 L p 0 .315 .944 r
F P
0 g
s
.65951 .618 m .67192 .61376 L .65421 .59363 L p 0 .315 .944 r
F P
0 g
s
.66669 .58917 m .68452 .60945 L .66689 .61372 L closepath p 0 .35 .78 r
F P
0 g
s
.66706 .58921 m .6668 .58978 L .67923 .58141 L .257 0 0 r
F
.6668 .58978 m .67358 .58802 L .67923 .58141 L F
.67923 .58141 m .67358 .58802 L .60355 .50834 L .888 0 0 r
F
.64435 .54171 m .65625 .54141 L .64183 .54701 L .221 0 0 r
F
.64435 .54171 m .64183 .54701 L .63863 .54825 L F
.64619 .53785 m .64964 .53806 L .64435 .54171 L F
.64619 .53785 m .60934 .50186 L .61128 .4981 L .978 0 0 r
F
.64527 .53978 m .60934 .50186 L .64619 .53785 L F
.56165 .51822 m .55007 .52978 L .61787 .60663 L p .856 0 0 r
F P
0 g
s
.61787 .60663 m .55007 .52978 L .56165 .51822 L .856 0 0 r
F
.55007 .52978 m .5732 .52001 L p .60762 .55909 L .556 0 0 r
F P
0 g
s
.5732 .52001 m .59702 .50994 L p .60762 .55909 L .556 0 0 r
F P
0 g
s
.62929 .59496 m .61787 .60663 L .64192 .59803 L p .257 0 0 r
F P
0 g
s
.66669 .58917 m .64192 .59803 L p .64192 .59803 L .556 0 0 r
F P
0 g
s
.61787 .60663 m .55007 .52978 L p .60762 .55909 L .556 0 0 r
F P
0 g
s
.5921 .57742 m .60386 .57293 L .59087 .55819 L p 0 .315 .944 r
F P
0 g
s
.59087 .55819 m .57919 .56279 L .5921 .57742 L p 0 .315 .944 r
F P
0 g
s
.60271 .55352 m .59087 .55819 L .60386 .57293 L p 0 .315 .944 r
F P
0 g
s
.60271 .55352 m .58811 .56828 L p .59851 .56832 L 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .61787 .60663 L .62929 .59496 L p 0 .05 .212 r
F P
0 g
s
.64192 .59803 m .61787 .60663 L p .60762 .55909 L .556 0 0 r
F P
0 g
s
.60386 .57293 m .6158 .56838 L .60271 .55352 L p 0 .315 .944 r
F P
0 g
s
.6158 .56838 m .60762 .55909 L p .59851 .56832 L 0 .349 .781 r
F P
0 g
s
.60762 .55909 m .60271 .55352 L p .59851 .56832 L 0 .349 .781 r
F P
0 g
s
.5603 .57752 m
.56136 .57654 L
s
.56136 .57654 m
.57766 .56149 L
s
.5581 .57955 m .50446 .63361 L .53823 .67161 L p .855 0 0 r
F P
0 g
s
.60772 .61152 m .57403 .57336 L .5581 .57955 L p .556 0 0 r
F P
0 g
s
.55406 .66632 m .50446 .63361 L .53823 .67161 L .54 0 0 r
F
.54836 .67288 m .53823 .67161 L .52115 .69119 L .257 0 0 r
F
.54836 .67288 m .55406 .66632 L .53823 .67161 L F
.55406 .66632 m .53823 .67161 L .50446 .63361 L p .54 0 0 r
F P
0 g
s
.55406 .66632 m .51998 .62792 L .50446 .63361 L .54 0 0 r
F
.50446 .63361 m .51998 .62792 L .55406 .66632 L p F P
0 g
s
.54631 .677 m .54836 .67288 L .52115 .69119 L .257 0 0 r
F
.54631 .677 m .54836 .67288 L .5142 .63443 L .968 0 0 r
F
.51711 .62897 m .50446 .63361 L .52648 .61142 L p .221 0 0 r
F P
0 g
s
.5142 .63443 m .50446 .63361 L .51998 .62792 L .221 0 0 r
F
.52115 .69119 m .53823 .67161 L .50446 .63361 L .883 0 0 r
F
.52115 .69119 m .50446 .63361 L .48717 .65303 L F
.5142 .63443 m .48717 .65303 L .50446 .63361 L .221 0 0 r
F
.51206 .63845 m .48717 .65303 L .50923 .63785 L F
.51206 .63845 m .50923 .63785 L .5142 .63443 L F
.54631 .677 m .5142 .63443 L .51313 .63644 L .968 0 0 r
F
.54631 .677 m .5142 .63443 L .54836 .67288 L F
.55985 .66554 m .54836 .67288 L .54631 .677 L .257 0 0 r
F
.54631 .677 m .51206 .63845 L .5142 .63443 L .968 0 0 r
F
.51206 .63845 m .47992 .59584 L .47768 .59976 L F
.54631 .677 m .51313 .63644 L .51206 .63845 L F
.51313 .63644 m .47992 .59584 L .51206 .63845 L F
.56016 .66562 m .54631 .677 L .54849 .67755 L .257 0 0 r
F
.56016 .66562 m .55985 .66554 L .54631 .677 L F
.54849 .67755 m .54631 .677 L .51206 .63845 L .1 0 0 r
F
.54849 .67755 m .51206 .63845 L .5131 .63867 L F
.54849 .67755 m .51206 .63845 L .54631 .677 L F
.54849 .67755 m .51414 .63889 L .51206 .63845 L F
.54849 .67755 m .47768 .59976 L .47967 .60009 L F
.51414 .63889 m .51015 .64201 L .51206 .63845 L .221 0 0 r
F
.51479 .70367 m .52115 .69119 L .48717 .65303 L .965 0 0 r
F
.51479 .70367 m .48717 .65303 L .48052 .66523 L F
.51015 .64201 m .48052 .66523 L .51206 .63845 L .221 0 0 r
F
.5131 .63867 m .51206 .63845 L .47768 .59976 L .1 0 0 r
F
.51313 .63644 m .5142 .63443 L .47992 .59584 L .968 0 0 r
F
.51998 .62792 m .51711 .62897 L p .5581 .57955 L .221 0 0 r
F P
0 g
s
.52648 .61142 m .5581 .57955 L p .51711 .62897 L .221 0 0 r
F P
0 g
s
.60772 .61152 m .5581 .57955 L .57403 .57336 L .556 0 0 r
F
.5581 .57955 m .57403 .57336 L .51998 .62792 L p .221 0 0 r
F P
0 g
s
.5581 .57955 m
.5603 .57752 L
s
.56272 .58478 m
.59149 .61732 L
s
0 0 0 r
.69483 .48534 m
.69483 .48534 L
s
.68265 .49037 m
.69483 .48534 L
s
.67029 .49547 m
.68265 .49037 L
s
.67029 .49547 m
.67029 .49547 L
s
0 g
.57765 .49812 m
.5946 .48121 L
s
0 0 0 r
.5052 .30685 m
.5052 .30685 L
s
.5052 .30685 m
.5052 .30685 L
s
.5129 .24283 m .52399 .23594 L .48899 .19578 L p 0 .319 .936 r
F P
0 g
s
.48899 .19578 m .47813 .20298 L .5129 .24283 L p 0 .319 .936 r
F P
0 g
s
.51767 .2456 m .53524 .22894 L .52399 .23594 L p 0 .05 .1 r
F P
0 g
s
.52399 .23594 m .50651 .25249 L .51767 .2456 L p 0 .05 .1 r
F P
0 g
s
.5 .26235 m .51767 .2456 L .50651 .25249 L p 0 .05 .1 r
F P
0 g
s
.5129 .24283 m .53524 .22894 L .5 .26235 L p 0 .05 .1 r
F P
0 g
s
.53524 .22894 m .51767 .2456 L .52899 .2386 L p 0 .05 .1 r
F P
0 g
s
.51122 .25546 m .52899 .2386 L .51767 .2456 L p 0 .05 .1 r
F P
0 g
s
.51767 .2456 m .5 .26235 L .51122 .25546 L p 0 .05 .1 r
F P
0 g
s
.55824 .21464 m .54665 .22184 L .52899 .2386 L p 0 .05 .1 r
F P
0 g
s
.5 .26235 m .53524 .22894 L .55824 .21464 L p 0 .05 .1 r
F P
0 g
s
.48899 .19578 m .52399 .23594 L .53524 .22894 L p 0 .319 .936 r
F P
0 g
s
.5 .21005 m .53524 .22894 L .51767 .2456 L p 0 .349 .781 r
F P
0 g
s
.5 .23617 m .51767 .2456 L .53524 .22894 L p 0 .349 .781 r
F P
0 g
s
.53524 .22894 m .5 .21005 L .5 .23617 L p 0 .349 .781 r
F P
0 g
s
.51767 .2456 m .5 .23617 L .5 .21005 L p 0 .349 .781 r
F P
0 g
s
.51767 .2456 m .5 .26235 L .5 .23617 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .23617 m .5 .26235 L .51767 .2456 L closepath p 0 .349 .781 r
F P
0 g
s
.52899 .2386 m .54047 .2315 L .55824 .21464 L p 0 .05 .1 r
F P
0 g
s
.54047 .2315 m .52899 .2386 L .51122 .25546 L p 0 .05 .1 r
F P
0 g
s
.51122 .25546 m .52261 .24846 L .54047 .2315 L p 0 .05 .1 r
F P
0 g
s
.55824 .21464 m .52261 .24846 L .5 .26235 L p 0 .05 .1 r
F P
0 g
s
.5 .23617 m .5 .26235 L .51122 .25546 L p 0 .181 .719 r
F P
0 g
s
.48897 .21721 m .48896 .24314 L .5 .23617 L p 0 .181 .719 r
F P
0 g
s
.5 .26235 m .5 .23617 L .48896 .24314 L p 0 .181 .719 r
F P
0 g
s
.5 .21005 m .5 .23617 L .48896 .24314 L p 0 .181 .719 r
F P
0 g
s
.47811 .22426 m .48897 .21721 L .48896 .24314 L p 0 .181 .719 r
F P
0 g
s
.5 .23617 m .5 .21005 L .48897 .21721 L p 0 .181 .719 r
F P
0 g
s
.48896 .24314 m .48897 .21721 L .5 .21005 L p 0 .181 .719 r
F P
0 g
s
.48227 .24205 m .5 .23617 L .5 .21005 L p 0 .349 .781 r
F P
0 g
s
.5 .23617 m .48227 .24205 L .4645 .22171 L p 0 .349 .781 r
F P
0 g
s
.5 .23617 m .5 .26235 L .48227 .24205 L closepath p 0 .349 .781 r
F P
0 g
s
.48227 .24205 m .5 .26235 L .5 .23617 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .26235 m .5 .23617 L .5112 .22909 L p 0 .181 .719 r
F P
0 g
s
.5112 .22909 m .51122 .25546 L .5 .26235 L p 0 .181 .719 r
F P
0 g
s
.49336 .235 m .51122 .25546 L .5 .26235 L p 0 .318 .939 r
F P
0 g
s
.51122 .25546 m .5112 .22909 L .5 .23617 L p 0 .181 .719 r
F P
0 g
s
.49243 .43734 m
.49257 .43721 L
s
.49257 .43721 m
.49569 .43417 L
s
.49569 .43417 m
.49623 .43364 L
s
.53823 .67161 m
.54077 .67076 L
s
.54517 .66929 m
.55114 .66729 L
s
.50989 .63972 m
.51018 .64005 L
s
.5112 .6412 m
.53823 .67161 L
s
.53583 .67435 m
.53823 .67161 L
s
.76989 .51971 m .78966 .52115 L .80278 .51629 L p 0 .458 1 r
F P
0 g
s
.78966 .52115 m .76989 .51971 L .78289 .51482 L p 0 .458 1 r
F P
0 g
s
.78289 .51482 m .80278 .51629 L .78966 .52115 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.6956 .53503 m
.70925 .52107 L
s
.70925 .52107 m
.70925 .52107 L
s
.70925 .52107 m
.70925 .52107 L
s
.68254 .49053 m
.70925 .52107 L
s
.67726 .48449 m
.68254 .49053 L
s
0 g
.60732 .49447 m
.6105 .49809 L
s
.60772 .61152 m .5818 .56618 L .61547 .60434 L .831 0 0 r
F
.60772 .61152 m .61547 .60434 L .54801 .52789 L F
0 g
.5581 .57955 m
.57109 .5745 L
s
.61479 .609 m .61547 .60434 L .60772 .61152 L .257 0 0 r
F
.61479 .609 m .6159 .60797 L .61547 .60434 L F
0 g
.60994 .60947 m
.61547 .60434 L
s
.61547 .60434 m
.6157 .60416 L
s
.48899 .19578 m .47813 .20298 L .47811 .22426 L p 0 .181 .719 r
F P
0 g
s
.47813 .20298 m .48899 .19578 L .48897 .21721 L p 0 .181 .719 r
F P
0 g
s
.48897 .21721 m .47811 .22426 L .47813 .20298 L p 0 .181 .719 r
F P
0 g
s
.47813 .20298 m .48899 .19578 L .45368 .22882 L p 0 .05 .1 r
F P
0 g
s
.45368 .22882 m .44303 .23581 L .47813 .20298 L p 0 .05 .1 r
F P
0 g
s
.57403 .57336 m .60772 .61152 L .55406 .66632 L p .856 0 0 r
F P
0 g
s
.60772 .61152 m .57403 .57336 L .5818 .56618 L .831 0 0 r
F
.56095 .66402 m .61479 .609 L .60772 .61152 L p .257 0 0 r
F P
0 g
s
.60772 .61152 m .55406 .66632 L .56095 .66402 L p .257 0 0 r
F P
0 g
s
.55406 .66632 m .60772 .61152 L .54021 .53506 L p .856 0 0 r
F P
0 g
s
.60772 .61152 m .54801 .52789 L .54021 .53506 L .831 0 0 r
F
.54021 .53506 m .60772 .61152 L .61479 .609 L p .556 0 0 r
F P
0 g
s
.61479 .609 m .60772 .61152 L .54021 .53506 L .556 0 0 r
F
0 g
.50446 .63361 m
.50695 .6327 L
s
.50204 .63634 m
.50446 .63361 L
s
.37409 .36683 m
.39201 .35063 L
s
0 0 0 r
.51767 .2456 m
.51767 .2456 L
s
.47811 .22426 m .48897 .21721 L .48899 .19578 L p 0 .181 .719 r
F P
0 g
s
.80278 .51629 m .78289 .51482 L .76989 .51971 L p 0 .458 1 r
F P
0 g
s
.75876 .51304 m .78289 .51482 L .76989 .51971 L p 0 .458 1 r
F P
0 g
s
.51753 .32757 m
.52068 .32454 L
s
.50145 .34302 m
.51753 .32757 L
s
.5818 .56618 m
.58203 .566 L
s
.57652 .57106 m
.5818 .56618 L
s
.39394 .35327 m .38602 .36044 L .37185 .36885 L .1 0 0 r
F
0 g
.37185 .36885 m
.38602 .36044 L
s
.37185 .36885 m
.37409 .36683 L
s
.55406 .66632 m .51998 .62792 L .57403 .57336 L p .856 0 0 r
F P
0 g
s
.57403 .57336 m
.60772 .61152 L
s
.54692 .49918 m .54797 .50939 L .54014 .50219 L .56 0 0 r
F
0 0 0 r
.52752 .29385 m
.52752 .29385 L
s
.5052 .30685 m
.52752 .29385 L
s
.5052 .30685 m
.5052 .30685 L
s
.69483 .48534 m
.69483 .48534 L
s
.75424 .44017 m
.75424 .44017 L
s
.75424 .44017 m
.75424 .44017 L
s
.69483 .48534 m
.69483 .48534 L
s
.54805 .50022 m .55583 .51375 L .54797 .50939 L .56 0 0 r
F
.54692 .49918 m .54805 .50022 L .54797 .50939 L F
0 g
.54014 .50219 m
.54797 .50939 L
s
.54692 .49918 m
.54995 .49618 L
s
.54014 .50219 m
.54692 .49918 L
s
.62405 .67542 m .65255 .64594 L .61816 .6544 L p 0 .349 .781 r
F P
0 g
s
.65255 .64594 m .66472 .64196 L .64728 .62218 L p 0 .315 .944 r
F P
0 g
s
.64728 .62218 m .63523 .6263 L .65255 .64594 L p 0 .315 .944 r
F P
0 g
s
.66472 .64196 m .65255 .64594 L .62405 .67542 L p 0 .05 .248 r
F P
0 g
s
.65255 .64594 m .63523 .6263 L .61801 .63049 L p 0 .349 .781 r
F P
0 g
s
.61801 .63049 m .61816 .6544 L .65255 .64594 L p 0 .349 .781 r
F P
0 g
s
.65255 .64594 m .61787 .60663 L .64192 .59803 L p 0 .315 .944 r
F P
0 g
s
.64192 .59803 m .67707 .63793 L .65255 .64594 L p 0 .315 .944 r
F P
0 g
s
0 0 0 r
.66472 .64196 m
.66472 .64196 L
s
.66472 .64196 m
.66472 .64196 L
s
.54812 .53117 m .54801 .52789 L .55585 .52173 L .183 0 0 r
F
.547 .5322 m .54801 .52789 L .54812 .53117 L F
.547 .5322 m .54021 .53506 L .54801 .52789 L F
.54021 .53506 m .48577 .58939 L .55406 .66632 L p .856 0 0 r
F P
0 g
s
.6159 .60797 m .54924 .53028 L .61703 .6071 L .777 0 0 r
F
.61703 .6071 m .55007 .52978 L .61787 .60663 L .681 0 0 r
F
.61703 .6071 m .54924 .53028 L .55007 .52978 L F
.61479 .609 m .57611 .56518 L p .57216 .56674 L .556 0 0 r
F P
0 g
s
.59087 .55819 m .57785 .54342 L .56626 .54813 L p 0 .315 .944 r
F P
0 g
s
.56626 .54813 m .57785 .54342 L p .57436 .546 L 0 .05 .154 r
F P
0 g
s
.57611 .56518 m .56013 .55177 L .56318 .55053 L .556 0 0 r
F
.57216 .56674 m .54021 .53506 L .57611 .56518 L F
.547 .5322 m .54021 .53506 L p .55796 .55266 L F P
0 g
s
.55796 .55266 m .57216 .56674 L .561 .55142 L .556 0 0 r
F
.55796 .55266 m .561 .55142 L .547 .5322 L F
.56626 .54813 m .57919 .56279 L .59087 .55819 L p 0 .315 .944 r
F P
0 g
s
.57611 .56518 m .56318 .55053 L p .57216 .56674 L .556 0 0 r
F P
0 g
s
.56318 .55053 m .547 .5322 L p .561 .55142 L .556 0 0 r
F P
0 g
s
.57216 .56674 m .56318 .55053 L .561 .55142 L .556 0 0 r
F
.6159 .60797 m .54812 .53117 L .54924 .53028 L .777 0 0 r
F
.61479 .609 m .54812 .53117 L .6159 .60797 L .831 0 0 r
F
.56318 .55053 m .54021 .53506 L .547 .5322 L .556 0 0 r
F
.56013 .55177 m .54021 .53506 L .56318 .55053 L F
.61479 .609 m .57216 .56674 L .57611 .56518 L F
.547 .5322 m .61479 .609 L .56095 .66402 L p .856 0 0 r
F P
0 g
s
.61479 .609 m .547 .5322 L .54812 .53117 L .831 0 0 r
F
.57919 .56279 m .56626 .54813 L .55177 .56268 L p 0 .349 .781 r
F P
0 g
s
.56587 .54944 m .55177 .56268 L .56328 .55806 L 0 .05 .154 r
F
.56626 .54813 m .56433 .55007 L p .56587 .54944 L F P
0 g
s
.56433 .55007 m .55177 .56268 L p .56587 .54944 L 0 .05 .154 r
F P
0 g
s
.57785 .54342 m .56626 .54813 L p .56587 .54944 L 0 .05 .154 r
F P
0 g
s
.56328 .55806 m .57591 .54537 L p .56587 .54944 L 0 .05 .154 r
F P
0 g
s
.57591 .54537 m .57785 .54342 L p .56587 .54944 L 0 .05 .154 r
F P
0 g
s
.55177 .56268 m .56433 .55007 L p .57436 .546 L 0 .05 .154 r
F P
0 g
s
.56433 .55007 m .56626 .54813 L p .57436 .546 L 0 .05 .154 r
F P
0 g
s
.5921 .57742 m .57919 .56279 L .56474 .57736 L p 0 .349 .781 r
F P
0 g
s
.56474 .57736 m .57634 .57285 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.57919 .56279 m .57727 .56473 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.57727 .56473 m .56474 .57736 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.59087 .55819 m .57919 .56279 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.57634 .57285 m .58893 .56014 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.58893 .56014 m .59087 .55819 L p .57881 .56412 L 0 .05 .17 r
F P
0 g
s
.52766 .54759 m .54021 .53506 L p .52922 .54694 L .183 0 0 r
F P
0 g
s
.54021 .53506 m .547 .5322 L .5344 .54477 L p .183 0 0 r
F P
0 g
s
.56095 .66402 m .49237 .58674 L .547 .5322 L p .856 0 0 r
F P
0 g
s
.55177 .56268 m .54138 .55092 L .5268 .56552 L p 0 .349 .781 r
F P
0 g
s
.5268 .56552 m .54138 .55092 L .5403 .54735 L p 0 .433 .873 r
F P
0 g
s
.5344 .54477 m .51981 .55935 L p .52922 .54694 L .183 0 0 r
F P
0 g
s
.52922 .54694 m .51981 .55935 L .51645 .56073 L .183 0 0 r
F
.54021 .53506 m .5344 .54477 L .52922 .54694 L F
.53722 .57729 m .5268 .56552 L .51214 .58018 L p 0 .349 .781 r
F P
0 g
s
.51214 .58018 m .5268 .56552 L .52569 .56196 L p 0 .433 .873 r
F P
0 g
s
.49849 .57669 m .51311 .56211 L p .50205 .57525 L .183 0 0 r
F P
0 g
s
.51544 .56115 m .50312 .57481 L .51311 .56211 L .183 0 0 r
F
.50312 .57481 m .49237 .58674 L .50205 .57525 L F
.50312 .57481 m .50205 .57525 L .51311 .56211 L F
.51981 .55935 m .50514 .57399 L p .51645 .56073 L F P
0 g
s
.50514 .57399 m .49237 .58674 L p .50359 .57462 L .183 0 0 r
F P
0 g
s
.51645 .56073 m .50514 .57399 L .50359 .57462 L .183 0 0 r
F
.52922 .54694 m .51645 .56073 L .52766 .54759 L F
.51645 .56073 m .49237 .58674 L .51544 .56115 L F
.51645 .56073 m .51544 .56115 L .52766 .54759 L F
.51311 .56211 m .52766 .54759 L p .51544 .56115 L F P
0 g
s
.52013 .54404 m .52569 .56196 L .5403 .54735 L p 0 .433 .873 r
F P
0 g
s
.53247 .55518 m .53168 .55446 L .52569 .56196 L 0 .314 .946 r
F
.5403 .54735 m .52569 .56196 L .5268 .56552 L p 0 .433 .873 r
F P
0 g
s
.56626 .54813 m .5559 .53639 L .54138 .55092 L p 0 .349 .781 r
F P
0 g
s
.54138 .55092 m .5559 .53639 L .55484 .53282 L p 0 .433 .873 r
F P
0 g
s
.55484 .53282 m .5403 .54735 L .54138 .55092 L p 0 .433 .873 r
F P
0 g
s
.54138 .55092 m .55177 .56268 L .56626 .54813 L p 0 .349 .781 r
F P
0 g
s
.5403 .54735 m .5502 .54325 L p .55177 .56268 L 0 .314 .945 r
F P
0 g
s
.55177 .56268 m .54138 .55092 L .5403 .54735 L p 0 .314 .945 r
F P
0 g
s
.57785 .54342 m .56328 .55806 L .55177 .56268 L p 0 .05 .154 r
F P
0 g
s
.55177 .56268 m .56328 .55806 L p .5403 .54735 L 0 .314 .945 r
F P
0 g
s
.5403 .54735 m .54138 .55092 L .55177 .56268 L p 0 .314 .945 r
F P
0 g
s
.56328 .55806 m .5502 .54325 L .5403 .54735 L p 0 .314 .945 r
F P
0 g
s
.52569 .56196 m .5403 .54735 L .5502 .54325 L p 0 .05 .139 r
F P
0 g
s
.5403 .54735 m .52569 .56196 L .53553 .55794 L p 0 .05 .139 r
F P
0 g
s
.5502 .54325 m .53553 .55794 L .52569 .56196 L p 0 .05 .139 r
F P
0 g
s
.52569 .56196 m .53553 .55794 L p .53247 .55518 L 0 .314 .946 r
F P
0 g
s
.52013 .54404 m .52431 .5575 L p .53168 .55446 L 0 .314 .946 r
F P
0 g
s
.52431 .5575 m .52569 .56196 L p .53168 .55446 L 0 .314 .946 r
F P
0 g
s
.50674 .56311 m .51102 .57663 L .52569 .56196 L p 0 .433 .873 r
F P
0 g
s
.52569 .56196 m .51102 .57663 L .51214 .58018 L p 0 .433 .873 r
F P
0 g
s
.5268 .56552 m .53722 .57729 L .55177 .56268 L p 0 .349 .781 r
F P
0 g
s
.52569 .56196 m .53553 .55794 L p .53722 .57729 L 0 .314 .946 r
F P
0 g
s
.53722 .57729 m .5268 .56552 L .52569 .56196 L p 0 .314 .946 r
F P
0 g
s
.56474 .57736 m .55177 .56268 L .53722 .57729 L p 0 .349 .781 r
F P
0 g
s
.55177 .56268 m .56474 .57736 L .57919 .56279 L p 0 .349 .781 r
F P
0 g
s
.56474 .57736 m .55177 .56268 L .56328 .55806 L p 0 .314 .945 r
F P
0 g
s
.57634 .57285 m .56474 .57736 L .57919 .56279 L p 0 .05 .17 r
F P
0 g
s
.55177 .56268 m .56474 .57736 L .57634 .57285 L p 0 .314 .945 r
F P
0 g
s
.57634 .57285 m .56328 .55806 L .55177 .56268 L p 0 .314 .945 r
F P
0 g
s
.53722 .57729 m .55177 .56268 L .56328 .55806 L p 0 .05 .154 r
F P
0 g
s
.55177 .56268 m .53722 .57729 L .54865 .57278 L p 0 .05 .154 r
F P
0 g
s
.56328 .55806 m .54865 .57278 L .53722 .57729 L p 0 .05 .154 r
F P
0 g
s
.52569 .56196 m .5268 .56552 L p .54865 .57278 L 0 .314 .946 r
F P
0 g
s
.54865 .57278 m .53553 .55794 L .52569 .56196 L p 0 .314 .946 r
F P
0 g
s
.51102 .57663 m .52569 .56196 L .53553 .55794 L p 0 .05 .139 r
F P
0 g
s
.52569 .56196 m .51102 .57663 L .52078 .5727 L p 0 .05 .139 r
F P
0 g
s
.5268 .56552 m .53722 .57729 L .54865 .57278 L p 0 .314 .946 r
F P
0 g
s
.53553 .55794 m .52078 .5727 L .51102 .57663 L p 0 .05 .139 r
F P
0 g
s
.52078 .5727 m .51102 .57663 L p .51095 .57164 L 0 .313 .947 r
F P
0 g
s
.50762 .56133 m .50674 .56311 L p .52569 .56196 L 0 .433 .873 r
F P
0 g
s
.51372 .55162 m .50762 .56133 L p .52569 .56196 L 0 .433 .873 r
F P
0 g
s
.51081 .56143 m .51749 .56898 L p .51095 .57164 L 0 .313 .947 r
F P
0 g
s
.51749 .56898 m .52078 .5727 L p .51095 .57164 L 0 .313 .947 r
F P
0 g
s
.51083 .56286 m .51095 .57164 L .50674 .56311 L 0 .313 .947 r
F
.50674 .56311 m .51081 .56143 L p .51083 .56286 L F P
0 g
s
.51102 .57663 m .50961 .57218 L p .51095 .57164 L 0 .313 .947 r
F P
0 g
s
.50961 .57218 m .50674 .56311 L p .51095 .57164 L 0 .313 .947 r
F P
0 g
s
.51102 .57663 m .52078 .5727 L p .51614 .56953 L 0 .313 .947 r
F P
0 g
s
.50674 .56311 m .50961 .57218 L p .51614 .56953 L 0 .313 .947 r
F P
0 g
s
.50961 .57218 m .51102 .57663 L p .51614 .56953 L 0 .313 .947 r
F P
0 g
s
.49237 .58674 m .48577 .58939 L .49849 .57669 L p .183 0 0 r
F P
0 g
s
.50205 .57525 m .49237 .58674 L .49849 .57669 L .183 0 0 r
F
.52709 .5383 m .52013 .54404 L p .5403 .54735 L 0 .433 .873 r
F P
0 g
s
.52013 .54404 m .52239 .54308 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.52569 .56196 m .52431 .5575 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.52431 .5575 m .52013 .54404 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.53553 .55794 m .52569 .56196 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.52239 .54308 m .53225 .55423 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.53225 .55423 m .53553 .55794 L p .52487 .55726 L 0 .314 .946 r
F P
0 g
s
.56626 .54813 m .57785 .54342 L p .55484 .53282 L 0 .315 .944 r
F P
0 g
s
.55484 .53282 m .5559 .53639 L .56626 .54813 L p 0 .315 .944 r
F P
0 g
s
.57785 .54342 m .56481 .52863 L .55484 .53282 L p 0 .315 .944 r
F P
0 g
s
.5403 .54735 m .55484 .53282 L .56481 .52863 L p 0 .05 .139 r
F P
0 g
s
.53616 .53378 m .5403 .54735 L .55484 .53282 L p 0 .433 .873 r
F P
0 g
s
.55484 .53282 m .5403 .54735 L .5502 .54325 L p 0 .05 .139 r
F P
0 g
s
.56481 .52863 m .5502 .54325 L .5403 .54735 L p 0 .05 .139 r
F P
0 g
s
.5502 .54325 m .5403 .54735 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.54374 .53149 m .53616 .53378 L p .55484 .53282 L 0 .433 .873 r
F P
0 g
s
.53616 .53378 m .54374 .53149 L .5496 .52901 L p 0 .462 .885 r
F P
0 g
s
.5496 .52901 m .54029 .53203 L .53616 .53378 L p 0 .462 .885 r
F P
0 g
s
.54029 .53203 m .54693 .53955 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.54693 .53955 m .5502 .54325 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.53616 .53378 m .54029 .53203 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.5403 .54735 m .53894 .54288 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.53894 .54288 m .53616 .53378 L p .5403 .54232 L 0 .314 .945 r
F P
0 g
s
.54405 .53152 m
.5444 .53121 L
s
.54526 .53041 m
.54801 .52789 L
s
0 0 0 r
.72705 .40888 m
.72705 .40888 L
s
.72705 .40888 m
.72705 .40888 L
s
.54631 .677 m .52115 .69119 L .51479 .70367 L .257 0 0 r
F
0 g
.52115 .69119 m
.53583 .67435 L
s
.61801 .63049 m .63523 .6263 L .61787 .60663 L closepath p 0 .349 .781 r
F P
0 g
s
.62981 .60236 m .61787 .60663 L .63523 .6263 L p 0 .315 .944 r
F P
0 g
s
.63523 .6263 m .64728 .62218 L .62981 .60236 L p 0 .315 .944 r
F P
0 g
s
.54917 .50084 m .56164 .51409 L .55583 .51375 L .56 0 0 r
F
.54805 .50022 m .54917 .50084 L .55583 .51375 L F
0 g
.54797 .50939 m
.55583 .51375 L
s
.54924 .53028 m .55585 .52173 L .56165 .51822 L .183 0 0 r
F
.54812 .53117 m .55585 .52173 L .54924 .53028 L F
0 g
.54801 .52789 m
.55585 .52173 L
s
.6159 .60797 m
.61703 .6071 L
s
.61479 .609 m
.6159 .60797 L
s
0 0 0 r
.37741 .33409 m
.37741 .33409 L
s
.61801 .63049 m .61787 .60663 L .60355 .62127 L closepath p 0 .349 .781 r
F P
0 g
s
.61787 .60663 m .62981 .60236 L .6154 .6171 L p 0 .05 .212 r
F P
0 g
s
.6154 .6171 m .60355 .62127 L .61787 .60663 L p 0 .05 .212 r
F P
0 g
s
.61787 .60663 m .605 .59204 L .59063 .60666 L p 0 .349 .781 r
F P
0 g
s
.6127 .60663 m
.61479 .609 L
s
.59063 .60666 m .60355 .62127 L .61787 .60663 L p 0 .349 .781 r
F P
0 g
s
.61787 .60663 m .62981 .60236 L .61685 .58766 L p 0 .315 .944 r
F P
0 g
s
.61685 .58766 m .605 .59204 L .61787 .60663 L p 0 .315 .944 r
F P
0 g
s
.61787 .60663 m .60355 .62127 L .6154 .6171 L p 0 .05 .212 r
F P
0 g
s
.6154 .6171 m .62981 .60236 L .61787 .60663 L p 0 .05 .212 r
F P
0 g
s
0 0 0 r
.62981 .60236 m
.62981 .60236 L
s
0 g
.55645 .53701 m
.56626 .54813 L
s
.49225 .43744 m
.49243 .43734 L
s
.44303 .23581 m .4645 .22171 L .38008 .30075 L p 0 .05 .1 r
F P
0 g
s
.38008 .30075 m .35957 .31387 L .44303 .23581 L p 0 .05 .1 r
F P
0 g
s
.605 .59204 m .5921 .57742 L .5777 .59202 L p 0 .349 .781 r
F P
0 g
s
.5869 .57741 m
.58936 .5802 L
s
.59981 .59203 m
.60227 .59482 L
s
.5777 .59202 m .59063 .60666 L .605 .59204 L p 0 .349 .781 r
F P
0 g
s
.605 .59204 m .61685 .58766 L .60386 .57293 L p 0 .315 .944 r
F P
0 g
s
.60386 .57293 m .5921 .57742 L .605 .59204 L p 0 .315 .944 r
F P
0 g
s
.51206 .63845 m .48052 .66523 L .48717 .65303 L .221 0 0 r
F
0 g
.48717 .65303 m
.50204 .63634 L
s
.61816 .6544 m .61801 .63049 L .60355 .62127 L p 0 .349 .781 r
F P
0 g
s
.56474 .57736 m .5777 .59202 L .5921 .57742 L p 0 .349 .781 r
F P
0 g
s
.79608 .50986 m .78289 .51482 L .80278 .51629 L p 0 .458 1 r
F P
0 g
s
.80278 .51629 m .8161 .51135 L .78135 .47137 L p 0 .319 .936 r
F P
0 g
s
.80278 .51629 m .8161 .51135 L .79608 .50986 L p 0 .458 1 r
F P
0 g
s
.8161 .51135 m .80278 .51629 L .78289 .51482 L p 0 .458 1 r
F P
0 g
s
.54692 .49918 m
.54805 .50022 L
s
.59688 .4802 m .60884 .49382 L .56164 .51409 L p .56 0 0 r
F P
0 g
s
.56164 .51409 m .55 .50088 L .59688 .4802 L p .56 0 0 r
F P
0 g
s
.54917 .50084 m .55 .50088 L .56164 .51409 L .56 0 0 r
F
0 g
.55 .50088 m
.55301 .49789 L
s
.55583 .51375 m
.56164 .51409 L
s
.54805 .50022 m
.54917 .50084 L
s
0 0 0 r
.49433 .2753 m
.53186 .31822 L
s
.55007 .52978 m .56165 .51822 L p .57029 .5162 L .183 0 0 r
F P
0 g
s
.56155 .52493 m .55007 .52978 L p .57029 .5162 L .183 0 0 r
F P
0 g
s
.54924 .53028 m .56165 .51822 L .55007 .52978 L .183 0 0 r
F
.55484 .53282 m .55404 .53014 L .54374 .53149 L p 0 .433 .873 r
F P
0 g
s
.54374 .53149 m .55404 .53014 L .56287 .52642 L p 0 .483 1 r
F P
0 g
s
.56481 .52863 m .56287 .52642 L .55404 .53014 L p 0 .315 .944 r
F P
0 g
s
.56287 .52642 m .5496 .52901 L .54374 .53149 L p 0 .483 1 r
F P
0 g
s
.5496 .52901 m .54029 .53203 L p .55673 .52975 L 0 .349 .781 r
F P
0 g
s
.56481 .52863 m .55767 .52881 L .55673 .52975 L 0 .349 .781 r
F
.55767 .52881 m .5496 .52901 L .55673 .52975 L F
.57029 .5162 m .57906 .51415 L .56155 .52493 L .183 0 0 r
F
.5732 .52001 m .56155 .52493 L p .57906 .51415 L F P
0 g
s
.57648 .52374 m .57452 .52151 L .56287 .52642 L p 0 .315 .944 r
F P
0 g
s
.5496 .52901 m .56287 .52642 L .57452 .52151 L p 0 .483 1 r
F P
0 g
s
.57452 .52151 m .56118 .52411 L .5496 .52901 L p 0 .483 1 r
F P
0 g
s
.54029 .53203 m .5496 .52901 L .56118 .52411 L p 0 .462 .885 r
F P
0 g
s
.56118 .52411 m .55181 .52714 L .54029 .53203 L p 0 .462 .885 r
F P
0 g
s
.56118 .52411 m .55181 .52714 L p .56835 .52486 L 0 .349 .781 r
F P
0 g
s
.57648 .52374 m .5693 .52391 L .56835 .52486 L 0 .349 .781 r
F
.5693 .52391 m .56118 .52411 L .56835 .52486 L F
.57906 .51415 m .58797 .51206 L .5732 .52001 L .183 0 0 r
F
.58502 .51501 m .5732 .52001 L p .58797 .51206 L F P
0 g
s
.58833 .51877 m .58635 .51653 L .57452 .52151 L p 0 .315 .944 r
F P
0 g
s
.56118 .52411 m .57452 .52151 L .58635 .51653 L p 0 .483 1 r
F P
0 g
s
.58635 .51653 m .57293 .51913 L .56118 .52411 L p 0 .483 1 r
F P
0 g
s
.55181 .52714 m .56118 .52411 L .57293 .51913 L p 0 .462 .885 r
F P
0 g
s
.57293 .51913 m .56351 .52219 L .55181 .52714 L p 0 .462 .885 r
F P
0 g
s
.57293 .51913 m .56351 .52219 L p .58015 .5199 L 0 .349 .781 r
F P
0 g
s
.58833 .51877 m .5811 .51894 L .58015 .5199 L 0 .349 .781 r
F
.5811 .51894 m .57293 .51913 L .58015 .5199 L F
.59702 .50994 m .58502 .51501 L p .58797 .51206 L .183 0 0 r
F P
0 g
s
.55 .50088 m
.56164 .51409 L
s
.56165 .51822 m .60886 .49807 L .59702 .50994 L p .183 0 0 r
F P
0 g
s
.55585 .52173 m
.56165 .51822 L
s
.55339 .52648 m
.56165 .51822 L
s
.54917 .50084 m
.55 .50088 L
s
.57919 .56279 m .59087 .55819 L .57634 .57285 L p 0 .05 .17 r
F P
0 g
s
.5695 .55181 m
.57919 .56279 L
s
.60355 .62127 m .58915 .63599 L .61816 .6544 L p 0 .349 .781 r
F P
0 g
s
.58915 .63599 m .60355 .62127 L .6154 .6171 L p 0 .05 .212 r
F P
0 g
s
.60355 .62127 m .59063 .60666 L .5762 .62134 L p 0 .349 .781 r
F P
0 g
s
.5762 .62134 m .58915 .63599 L .60355 .62127 L p 0 .349 .781 r
F P
0 g
s
.6154 .6171 m .60093 .63191 L .58915 .63599 L p 0 .05 .212 r
F P
0 g
s
.60355 .62127 m .58915 .63599 L .60093 .63191 L p 0 .05 .212 r
F P
0 g
s
.60093 .63191 m .6154 .6171 L .60355 .62127 L p 0 .05 .212 r
F P
0 g
s
.48899 .19578 m .48897 .21721 L .5 .21005 L p 0 .181 .719 r
F P
0 g
s
.53524 .22894 m .5 .18847 L .48899 .19578 L p 0 .319 .936 r
F P
0 g
s
.5 .21005 m .5 .18847 L .48899 .19578 L p 0 .181 .719 r
F P
0 g
s
.48897 .21721 m .48899 .19578 L .5 .18847 L p 0 .181 .719 r
F P
0 g
s
.45368 .22882 m .48899 .19578 L .5 .18847 L p 0 .05 .1 r
F P
0 g
s
.61816 .6544 m .61824 .66886 L .62405 .67542 L p 0 .349 .781 r
F P
0 g
s
.61824 .66886 m .61816 .6544 L .58915 .63599 L closepath p 0 .349 .781 r
F P
0 g
s
.55474 .49701 m .55395 .49842 L .56276 .49453 L p 0 .05 .118 r
F P
0 g
s
.62405 .67542 m .63606 .67165 L .66472 .64196 L p 0 .05 .248 r
F P
0 g
s
.62405 .67542 m .61824 .66886 L .63022 .66503 L p 0 .314 .946 r
F P
0 g
s
.63022 .66503 m .63606 .67165 L .62405 .67542 L p 0 .314 .946 r
F P
0 g
s
.63606 .67165 m .62405 .67542 L .59527 .70518 L p 0 .05 .248 r
F P
0 g
s
.61824 .66886 m .62405 .67542 L .63606 .67165 L p 0 .314 .946 r
F P
0 g
s
.59527 .70518 m .62405 .67542 L .61824 .66886 L p 0 .349 .781 r
F P
0 g
s
.59063 .60666 m .5777 .59202 L .56322 .60668 L p 0 .349 .781 r
F P
0 g
s
.56322 .60668 m .5762 .62134 L .59063 .60666 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.72009 .47492 m
.72009 .47492 L
s
.69483 .48534 m
.72009 .47492 L
s
.69483 .48534 m
.69483 .48534 L
s
.41545 .26161 m
.41545 .26161 L
s
.41545 .26161 m
.41545 .26161 L
s
.63022 .66503 m .61824 .66886 L .58915 .63599 L p 0 .314 .946 r
F P
0 g
s
.58915 .63599 m .60484 .66811 L .61824 .66886 L closepath p 0 .349 .781 r
F P
0 g
s
.61824 .66886 m .60484 .66811 L .59527 .70518 L p 0 .349 .781 r
F P
0 g
s
.61824 .66886 m .63022 .66503 L .60093 .63191 L p 0 .314 .946 r
F P
0 g
s
.60093 .63191 m .58915 .63599 L .61824 .66886 L p 0 .314 .946 r
F P
0 g
s
.63606 .67165 m .63022 .66503 L .61824 .66886 L p 0 .314 .946 r
F P
0 g
s
.51126 .63112 m
.51711 .62897 L
s
0 0 0 r
.68723 .38345 m
.68723 .38345 L
s
.5 .18847 m .5 .21005 L .48897 .21721 L p 0 .181 .719 r
F P
0 g
s
.77181 .50806 m .75876 .51304 L .78289 .51482 L p 0 .458 1 r
F P
0 g
s
.78289 .51482 m .79608 .50986 L .77181 .50806 L p 0 .458 1 r
F P
0 g
s
.78289 .51482 m .79608 .50986 L .8161 .51135 L p 0 .458 1 r
F P
0 g
s
.79608 .50986 m .78289 .51482 L .75876 .51304 L p 0 .458 1 r
F P
0 g
s
.55395 .49842 m .54366 .49266 L .5495 .49004 L p 0 .408 1 r
F P
0 g
s
.5495 .49004 m .56276 .49453 L .55395 .49842 L p 0 .408 1 r
F P
0 g
s
.5777 .59202 m .56474 .57736 L .55023 .592 L p 0 .349 .781 r
F P
0 g
s
.55023 .592 m .56322 .60668 L .5777 .59202 L p 0 .349 .781 r
F P
0 g
s
.54836 .67288 m .51998 .62792 L .55406 .66632 L .884 0 0 r
F
.56095 .66402 m .48577 .58939 L .55406 .66632 L .54 0 0 r
F
.54836 .67288 m .55406 .66632 L .48577 .58939 L .884 0 0 r
F
.56013 .66496 m .55406 .66632 L .54836 .67288 L .257 0 0 r
F
.56013 .66496 m .56095 .66402 L .55406 .66632 L F
.56095 .66402 m .55406 .66632 L .48577 .58939 L p .54 0 0 r
F P
0 g
s
0 0 0 r
.75595 .57391 m
.75595 .57391 L
s
.75595 .57391 m
.75595 .57391 L
s
.56328 .55806 m .57634 .57285 L .56474 .57736 L p 0 .314 .945 r
F P
0 g
s
.56174 .58759 m .57634 .57285 L .56474 .57736 L p 0 .05 .17 r
F P
0 g
s
.56474 .57736 m .55023 .592 L .56174 .58759 L p 0 .05 .17 r
F P
0 g
s
.53722 .57729 m .55023 .592 L .56474 .57736 L p 0 .349 .781 r
F P
0 g
s
.56474 .57736 m .57634 .57285 L .56174 .58759 L p 0 .05 .17 r
F P
0 g
s
.56174 .58759 m .55023 .592 L .56474 .57736 L p 0 .05 .17 r
F P
0 g
s
.5502 .54325 m .56481 .52863 L .55484 .53282 L p 0 .05 .139 r
F P
0 g
s
.55404 .53014 m .55484 .53282 L .56481 .52863 L p 0 .315 .944 r
F P
0 g
s
.49235 .43723 m
.49243 .43734 L
s
0 0 0 r
.69269 .4435 m
.69269 .4435 L
s
.60484 .66811 m .58256 .66687 L .57773 .68542 L p 0 .349 .781 r
F P
0 g
s
.57773 .68542 m .59527 .70518 L .60484 .66811 L p 0 .349 .781 r
F P
0 g
s
.58256 .66687 m .60484 .66811 L .58915 .63599 L p 0 .349 .781 r
F P
0 g
s
.58915 .63599 m .60093 .63191 L .63022 .66503 L p 0 .314 .946 r
F P
0 g
s
.58915 .63599 m .57469 .65077 L .58256 .66687 L p 0 .349 .781 r
F P
0 g
s
.57469 .65077 m .58915 .63599 L .60093 .63191 L p 0 .05 .212 r
F P
0 g
s
.57469 .65077 m .58915 .63599 L .5762 .62134 L p 0 .349 .781 r
F P
0 g
s
.60093 .63191 m .58915 .63599 L .57469 .65077 L p 0 .05 .212 r
F P
0 g
s
.58915 .63599 m .60093 .63191 L .58789 .61716 L p 0 .314 .946 r
F P
0 g
s
.58789 .61716 m .5762 .62134 L .58915 .63599 L p 0 .314 .946 r
F P
0 g
s
.58915 .63599 m .5762 .62134 L .58789 .61716 L p 0 .314 .946 r
F P
0 g
s
.58789 .61716 m .60093 .63191 L .58915 .63599 L p 0 .314 .946 r
F P
0 g
s
0 0 0 r
.61354 .27827 m
.61354 .27827 L
s
.61354 .27827 m
.61354 .27827 L
s
.41545 .26161 m
.41545 .26161 L
s
.5502 .54325 m .56328 .55806 L .55177 .56268 L p 0 .314 .945 r
F P
0 g
s
.54865 .57278 m .56328 .55806 L .55177 .56268 L p 0 .05 .154 r
F P
0 g
s
.5762 .62134 m .56169 .6361 L .57469 .65077 L p 0 .349 .781 r
F P
0 g
s
.56169 .6361 m .5762 .62134 L .56322 .60668 L p 0 .349 .781 r
F P
0 g
s
.5762 .62134 m .58789 .61716 L .57482 .60239 L p 0 .314 .946 r
F P
0 g
s
.57482 .60239 m .56322 .60668 L .5762 .62134 L p 0 .314 .946 r
F P
0 g
s
.5762 .62134 m .56322 .60668 L .57482 .60239 L p 0 .314 .946 r
F P
0 g
s
.57482 .60239 m .58789 .61716 L .5762 .62134 L p 0 .314 .946 r
F P
0 g
s
0 0 0 r
.62981 .60236 m
.62981 .60236 L
s
.66472 .64196 m
.66472 .64196 L
s
.64728 .62218 m .66472 .64196 L .67707 .63793 L p 0 .315 .944 r
F P
0 g
s
.67707 .63793 m .66472 .64196 L .63606 .67165 L p 0 .05 .248 r
F P
0 g
s
.41107 .33925 m
.41266 .33775 L
s
.54836 .67288 m .5142 .63443 L .51998 .62792 L .884 0 0 r
F
.54836 .67288 m .48577 .58939 L .47992 .59584 L F
.55985 .66554 m .56013 .66496 L .54836 .67288 L .257 0 0 r
F
0 g
.51998 .62792 m
.55406 .66632 L
s
.54836 .67288 m
.55406 .66632 L
s
.5142 .63443 m
.51998 .62792 L
s
0 0 0 r
.72074 .53364 m
.72074 .53364 L
s
.7 .54149 m
.72074 .53364 L
s
.42841 .6497 m .40485 .62775 L .36995 .66235 L .831 0 0 r
F
.47571 .59985 m .47003 .59929 L .43525 .63397 L .58 0 0 r
F
.42761 .63308 m .40817 .63084 L .42841 .6497 L .523 0 0 r
F
.42841 .6497 m .36995 .66235 L .3936 .68445 L .831 0 0 r
F
.43653 .63627 m .42841 .6497 L .45171 .66363 L .523 0 0 r
F
.43525 .63397 m .43379 .63732 L .43653 .63627 L F
.43379 .63732 m .42841 .6497 L .43653 .63627 L F
.45171 .66363 m .42841 .6497 L .3936 .68445 L .765 0 0 r
F
.44087 .63461 m .45171 .66363 L .46868 .6658 L .523 0 0 r
F
.51214 .58018 m .52259 .59198 L .53722 .57729 L p 0 .349 .781 r
F P
0 g
s
.51214 .58018 m .51102 .57663 L p .49923 .59248 L 0 .433 .873 r
F P
0 g
s
.50125 .59874 m .49237 .58674 L .50409 .60758 L .54 0 0 r
F
.52183 .61993 m .50875 .60519 L .51797 .62136 L F
.50024 .5956 m .49565 .59043 L .50125 .59874 L F
.49565 .59043 m .49237 .58674 L .49523 .5906 L F
.49565 .59043 m .49523 .5906 L .50125 .59874 L F
.51102 .57663 m .49824 .5894 L p .49923 .59248 L 0 .433 .873 r
F P
0 g
s
.51214 .58018 m .51102 .57663 L .52078 .5727 L p 0 .313 .947 r
F P
0 g
s
.55023 .592 m .53722 .57729 L .52259 .59198 L p 0 .349 .781 r
F P
0 g
s
.55023 .592 m .53722 .57729 L .54865 .57278 L p 0 .314 .946 r
F P
0 g
s
.53722 .57729 m .55023 .592 L .56174 .58759 L p 0 .314 .946 r
F P
0 g
s
.56174 .58759 m .54865 .57278 L .53722 .57729 L p 0 .314 .946 r
F P
0 g
s
.52259 .59198 m .53722 .57729 L .54865 .57278 L p 0 .05 .154 r
F P
0 g
s
.53722 .57729 m .52259 .59198 L .53394 .58756 L p 0 .05 .154 r
F P
0 g
s
.54865 .57278 m .53394 .58756 L .52259 .59198 L p 0 .05 .154 r
F P
0 g
s
.51102 .57663 m .51214 .58018 L p .53394 .58756 L 0 .313 .947 r
F P
0 g
s
.53394 .58756 m .52078 .5727 L .51102 .57663 L p 0 .313 .947 r
F P
0 g
s
.51102 .57663 m .52078 .5727 L p .49953 .58889 L 0 .05 .139 r
F P
0 g
s
.50875 .60519 m .52183 .61993 L p .50577 .60633 L .54 0 0 r
F P
0 g
s
.50875 .60519 m .50662 .60601 L .51797 .62136 L .54 0 0 r
F
.49565 .59043 m .50024 .5956 L p .49178 .59197 L F P
0 g
s
.50024 .5956 m .50875 .60519 L p .50178 .6004 L .54 0 0 r
F P
0 g
s
.48577 .58939 m .50024 .5956 L .50178 .6004 L .54 0 0 r
F
.48577 .58939 m .50875 .60519 L .50577 .60633 L F
.52183 .61993 m .56095 .66402 L p .51797 .62136 L F P
0 g
s
.48577 .58939 m .52183 .61993 L .51797 .62136 L .54 0 0 r
F
.50875 .60519 m .50024 .5956 L .50662 .60601 L F
.50024 .5956 m .50125 .59874 L .50662 .60601 L F
.56095 .66402 m .52183 .61993 L .51797 .62136 L F
.56013 .66496 m .49561 .59048 L .56095 .66402 L .884 0 0 r
F
.48577 .58939 m .49237 .58674 L .49565 .59043 L p .54 0 0 r
F P
0 g
s
.48577 .58939 m .49565 .59043 L .49178 .59197 L .54 0 0 r
F
.49561 .59048 m .49237 .58674 L .49565 .59043 L .884 0 0 r
F
.49561 .59048 m .49565 .59043 L .56095 .66402 L F
.50409 .60758 m .49237 .58674 L .48577 .58939 L .54 0 0 r
F
.56013 .66496 m .49154 .58766 L .49237 .58674 L .884 0 0 r
F
.49858 .59046 m .49627 .59137 L p .49923 .59248 L 0 .433 .873 r
F P
0 g
s
.49851 .59023 m .49824 .5894 L .49627 .59137 L 0 .433 .873 r
F
.49938 .59295 m .51214 .58018 L p .49923 .59248 L F P
0 g
s
.55985 .66554 m .49154 .58766 L .56013 .66496 L .969 0 0 r
F
.51797 .62136 m .50125 .59874 L .50409 .60758 L .54 0 0 r
F
.55985 .66554 m .49122 .58822 L .49154 .58766 L .969 0 0 r
F
.52259 .59198 m .51214 .58018 L .49742 .59492 L p 0 .349 .781 r
F P
0 g
s
.49627 .59137 m .50597 .58753 L p .50664 .58606 L 0 .05 .139 r
F P
0 g
s
.51102 .57663 m .49824 .5894 L p .50664 .58606 L 0 .05 .139 r
F P
0 g
s
.49824 .5894 m .49627 .59137 L p .50664 .58606 L 0 .05 .139 r
F P
0 g
s
.49542 .58872 m .49627 .59137 L .49824 .5894 L p 0 .433 .873 r
F P
0 g
s
.49824 .5894 m .51102 .57663 L p .4975 .58711 L 0 .433 .873 r
F P
0 g
s
.4975 .58711 m .49542 .58872 L .49824 .5894 L 0 .433 .873 r
F
.53565 .60671 m .52259 .59198 L .5079 .60673 L p 0 .349 .781 r
F P
0 g
s
.5079 .60673 m .51917 .60241 L p .51963 .60101 L 0 .05 .154 r
F P
0 g
s
.52259 .59198 m .50987 .60476 L p .51963 .60101 L 0 .05 .154 r
F P
0 g
s
.50987 .60476 m .5079 .60673 L p .51963 .60101 L 0 .05 .154 r
F P
0 g
s
.53565 .60671 m .52099 .62148 L .53407 .63622 L p 0 .349 .781 r
F P
0 g
s
.52099 .62148 m .53235 .61728 L p .53279 .61586 L 0 .05 .17 r
F P
0 g
s
.53565 .60671 m .52295 .61951 L p .53279 .61586 L 0 .05 .17 r
F P
0 g
s
.52295 .61951 m .52099 .62148 L p .53279 .61586 L 0 .05 .17 r
F P
0 g
s
.49627 .59137 m .49824 .5894 L p .49953 .58889 L 0 .05 .139 r
F P
0 g
s
.49824 .5894 m .51102 .57663 L p .49953 .58889 L 0 .05 .139 r
F P
0 g
s
.49627 .59137 m .49742 .59492 L p .49923 .59248 L 0 .433 .873 r
F P
0 g
s
.52259 .59198 m .53565 .60671 L .55023 .592 L p 0 .349 .781 r
F P
0 g
s
.55023 .592 m .53565 .60671 L .54868 .62141 L p 0 .349 .781 r
F P
0 g
s
.55023 .592 m .53565 .60671 L .54708 .6024 L p 0 .05 .17 r
F P
0 g
s
.54868 .62141 m .56322 .60668 L .55023 .592 L p 0 .349 .781 r
F P
0 g
s
.56174 .58759 m .55023 .592 L .56322 .60668 L p 0 .314 .946 r
F P
0 g
s
.56322 .60668 m .55023 .592 L .56174 .58759 L p 0 .314 .946 r
F P
0 g
s
.54708 .6024 m .56174 .58759 L .55023 .592 L p 0 .05 .17 r
F P
0 g
s
.53565 .60671 m .55023 .592 L .56174 .58759 L p 0 .05 .17 r
F P
0 g
s
.56174 .58759 m .54708 .6024 L .53565 .60671 L p 0 .05 .17 r
F P
0 g
s
.52259 .59198 m .53565 .60671 L .54708 .6024 L p 0 .313 .947 r
F P
0 g
s
.53565 .60671 m .52259 .59198 L .53394 .58756 L p 0 .313 .947 r
F P
0 g
s
.54708 .6024 m .53394 .58756 L .52259 .59198 L p 0 .313 .947 r
F P
0 g
s
.52259 .59198 m .53394 .58756 L p .51136 .60419 L 0 .05 .154 r
F P
0 g
s
.5079 .60673 m .50987 .60476 L p .51136 .60419 L 0 .05 .154 r
F P
0 g
s
.50987 .60476 m .52259 .59198 L p .51136 .60419 L 0 .05 .154 r
F P
0 g
s
.49742 .59492 m .49938 .59295 L p .49923 .59248 L 0 .433 .873 r
F P
0 g
s
.53407 .63622 m .54868 .62141 L .53565 .60671 L p 0 .349 .781 r
F P
0 g
s
.53235 .61728 m .54708 .6024 L .53565 .60671 L p 0 .05 .17 r
F P
0 g
s
.53565 .60671 m .54708 .6024 L p .52446 .61895 L 0 .05 .17 r
F P
0 g
s
.52099 .62148 m .52295 .61951 L p .52446 .61895 L 0 .05 .17 r
F P
0 g
s
.52295 .61951 m .53565 .60671 L p .52446 .61895 L 0 .05 .17 r
F P
0 g
s
.56016 .66562 m .49122 .58822 L .55985 .66554 L .1 0 0 r
F
.49122 .58822 m .47768 .59976 L .47992 .59584 L .183 0 0 r
F
.56016 .66562 m .49151 .58826 L .49122 .58822 L .1 0 0 r
F
.54849 .67755 m .56016 .66562 L .49151 .58826 L p .856 0 0 r
F P
0 g
s
.56322 .60668 m .54868 .62141 L .56169 .6361 L p 0 .349 .781 r
F P
0 g
s
.57469 .65077 m .56016 .66562 L .58256 .66687 L closepath p 0 .349 .781 r
F P
0 g
s
.60093 .63191 m .58639 .64679 L .57469 .65077 L p 0 .05 .212 r
F P
0 g
s
.57469 .65077 m .58639 .64679 L .57178 .66175 L p 0 .05 .212 r
F P
0 g
s
.57178 .66175 m .56016 .66562 L .57469 .65077 L p 0 .05 .212 r
F P
0 g
s
.56016 .66562 m .57469 .65077 L .56169 .6361 L p 0 .349 .781 r
F P
0 g
s
.58639 .64679 m .57469 .65077 L .56016 .66562 L p 0 .05 .212 r
F P
0 g
s
.57469 .65077 m .58639 .64679 L .60093 .63191 L p 0 .05 .212 r
F P
0 g
s
.56169 .6361 m .54712 .65093 L .56016 .66562 L p 0 .349 .781 r
F P
0 g
s
.54712 .65093 m .56169 .6361 L .54868 .62141 L p 0 .349 .781 r
F P
0 g
s
.54868 .62141 m .53407 .63622 L .54712 .65093 L p 0 .349 .781 r
F P
0 g
s
.5079 .60673 m .52099 .62148 L .53565 .60671 L p 0 .349 .781 r
F P
0 g
s
.56016 .66562 m .54712 .65093 L .55866 .64694 L p 0 .312 .948 r
F P
0 g
s
.56016 .66562 m .57178 .66175 L .58639 .64679 L p 0 .05 .212 r
F P
0 g
s
.55866 .64694 m .57178 .66175 L .56016 .66562 L p 0 .312 .948 r
F P
0 g
s
.49742 .59492 m .5079 .60673 L .52259 .59198 L p 0 .349 .781 r
F P
0 g
s
.54712 .65093 m .53407 .63622 L .54551 .63212 L p 0 .312 .948 r
F P
0 g
s
.54551 .63212 m .55866 .64694 L .54712 .65093 L p 0 .312 .948 r
F P
0 g
s
.53407 .63622 m .52099 .62148 L .53235 .61728 L p 0 .312 .948 r
F P
0 g
s
.53235 .61728 m .54551 .63212 L .53407 .63622 L p 0 .312 .948 r
F P
0 g
s
.54708 .6024 m .53235 .61728 L .52099 .62148 L p 0 .05 .17 r
F P
0 g
s
.52099 .62148 m .5079 .60673 L .51917 .60241 L p 0 .312 .948 r
F P
0 g
s
.51917 .60241 m .53235 .61728 L .52099 .62148 L p 0 .312 .948 r
F P
0 g
s
.59826 .64276 m .58639 .64679 L .60093 .63191 L p 0 .05 .212 r
F P
0 g
s
.64237 .66115 m .63022 .66503 L .60093 .63191 L p 0 .314 .946 r
F P
0 g
s
.61289 .62778 m .60093 .63191 L .63022 .66503 L p 0 .314 .946 r
F P
0 g
s
.60093 .63191 m .61289 .62778 L .64237 .66115 L p 0 .314 .946 r
F P
0 g
s
.60093 .63191 m .61289 .62778 L .59826 .64276 L p 0 .05 .212 r
F P
0 g
s
.61289 .62778 m .60093 .63191 L .58639 .64679 L p 0 .05 .212 r
F P
0 g
s
.53394 .58756 m .51917 .60241 L .5079 .60673 L p 0 .05 .154 r
F P
0 g
s
.5079 .60673 m .49742 .59492 L p .50597 .58753 L 0 .312 .948 r
F P
0 g
s
.50597 .58753 m .51917 .60241 L .5079 .60673 L p 0 .312 .948 r
F P
0 g
s
.49742 .59492 m .49627 .59137 L .50597 .58753 L p 0 .312 .948 r
F P
0 g
s
.51214 .58018 m .52259 .59198 L .53394 .58756 L p 0 .313 .947 r
F P
0 g
s
.52259 .59198 m .51214 .58018 L p .52078 .5727 L 0 .313 .947 r
F P
0 g
s
.52078 .5727 m .50597 .58753 L .49627 .59137 L p 0 .05 .139 r
F P
0 g
s
.49627 .59137 m .49542 .58872 L .50399 .5853 L p 0 .312 .948 r
F P
0 g
s
.50399 .5853 m .50597 .58753 L .49627 .59137 L p 0 .312 .948 r
F P
0 g
s
.58639 .64679 m .59826 .64276 L .58357 .65782 L p 0 .05 .212 r
F P
0 g
s
.58357 .65782 m .57178 .66175 L .58639 .64679 L p 0 .05 .212 r
F P
0 g
s
.59826 .64276 m .58639 .64679 L .57178 .66175 L p 0 .05 .212 r
F P
0 g
s
.58639 .64679 m .59826 .64276 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.53394 .58756 m .54708 .6024 L .53565 .60671 L p 0 .313 .947 r
F P
0 g
s
.53394 .58756 m .54708 .6024 L .53235 .61728 L p 0 .349 .781 r
F P
0 g
s
.54708 .6024 m .53235 .61728 L .54387 .61301 L p 0 .05 .17 r
F P
0 g
s
.51917 .60241 m .53235 .61728 L .54708 .6024 L p 0 .349 .781 r
F P
0 g
s
.54387 .61301 m .55869 .59803 L .54708 .6024 L p 0 .05 .17 r
F P
0 g
s
.53235 .61728 m .54708 .6024 L .55869 .59803 L p 0 .05 .17 r
F P
0 g
s
.57178 .66175 m .55866 .64694 L .57036 .6429 L p 0 .312 .948 r
F P
0 g
s
.57178 .66175 m .58357 .65782 L .59826 .64276 L p 0 .05 .212 r
F P
0 g
s
.57036 .6429 m .58357 .65782 L .57178 .66175 L p 0 .312 .948 r
F P
0 g
s
.53235 .61728 m .51917 .60241 L .53394 .58756 L p 0 .349 .781 r
F P
0 g
s
.55866 .64694 m .54551 .63212 L .55712 .62796 L p 0 .312 .948 r
F P
0 g
s
.55712 .62796 m .57036 .6429 L .55866 .64694 L p 0 .312 .948 r
F P
0 g
s
.54551 .63212 m .53235 .61728 L .54387 .61301 L p 0 .312 .948 r
F P
0 g
s
.54387 .61301 m .55712 .62796 L .54551 .63212 L p 0 .312 .948 r
F P
0 g
s
.54708 .6024 m .53394 .58756 L .51917 .60241 L p 0 .349 .781 r
F P
0 g
s
.53235 .61728 m .51917 .60241 L .5306 .59803 L p 0 .312 .948 r
F P
0 g
s
.55869 .59803 m .54387 .61301 L .53235 .61728 L p 0 .05 .17 r
F P
0 g
s
.5306 .59803 m .54387 .61301 L .53235 .61728 L p 0 .312 .948 r
F P
0 g
s
.63022 .66503 m .64237 .66115 L .61289 .62778 L p 0 .314 .946 r
F P
0 g
s
.59826 .64276 m .60625 .6591 L .62881 .66038 L p 0 .349 .781 r
F P
0 g
s
.60625 .6591 m .59826 .64276 L .61289 .62778 L p 0 .349 .781 r
F P
0 g
s
.59826 .64276 m .58357 .65782 L .60625 .6591 L closepath p 0 .349 .781 r
F P
0 g
s
.60625 .6591 m .58357 .65782 L .59826 .64276 L closepath p 0 .349 .781 r
F P
0 g
s
.59554 .65383 m .58357 .65782 L .59826 .64276 L p 0 .05 .212 r
F P
0 g
s
.62881 .66038 m .61289 .62778 L .59826 .64276 L p 0 .349 .781 r
F P
0 g
s
.59826 .64276 m .61032 .63867 L .59554 .65383 L p 0 .05 .212 r
F P
0 g
s
.59554 .65383 m .61032 .63867 L .59826 .64276 L p 0 .05 .212 r
F P
0 g
s
.59826 .64276 m .58357 .65782 L .59554 .65383 L p 0 .05 .212 r
F P
0 g
s
.58357 .65782 m .59826 .64276 L .58509 .62787 L p 0 .349 .781 r
F P
0 g
s
.58509 .62787 m .59826 .64276 L .58357 .65782 L p 0 .349 .781 r
F P
0 g
s
.57036 .6429 m .58509 .62787 L .5719 .61296 L p 0 .349 .781 r
F P
0 g
s
.58509 .62787 m .57036 .6429 L .58357 .65782 L p 0 .349 .781 r
F P
0 g
s
.58357 .65782 m .57036 .6429 L .58509 .62787 L p 0 .349 .781 r
F P
0 g
s
.5719 .61296 m .58509 .62787 L .57036 .6429 L p 0 .349 .781 r
F P
0 g
s
.5719 .61296 m .55712 .62796 L .57036 .6429 L p 0 .349 .781 r
F P
0 g
s
.56322 .60668 m .57482 .60239 L .56174 .58759 L p 0 .314 .946 r
F P
0 g
s
.56174 .58759 m .57482 .60239 L .56322 .60668 L p 0 .314 .946 r
F P
0 g
s
.55712 .62796 m .5719 .61296 L .56364 .60363 L p 0 .349 .781 r
F P
0 g
s
.56364 .60363 m .55869 .59803 L p .5581 .60924 L 0 .349 .781 r
F P
0 g
s
.5581 .60924 m .55712 .62796 L .56364 .60363 L 0 .349 .781 r
F
.57036 .6429 m .55712 .62796 L .5719 .61296 L p F P
0 g
s
.55869 .59803 m .5719 .61296 L .55712 .62796 L p 0 .349 .781 r
F P
0 g
s
.55869 .59803 m .54387 .61301 L .55712 .62796 L p 0 .349 .781 r
F P
0 g
s
.55712 .62796 m .54387 .61301 L .55869 .59803 L p 0 .349 .781 r
F P
0 g
s
.59554 .65383 m .58357 .65782 L .57036 .6429 L p 0 .312 .948 r
F P
0 g
s
.57036 .6429 m .58224 .6388 L .59554 .65383 L p 0 .312 .948 r
F P
0 g
s
.58224 .6388 m .57036 .6429 L .55712 .62796 L p 0 .312 .948 r
F P
0 g
s
.55712 .62796 m .56891 .62375 L .58224 .6388 L p 0 .312 .948 r
F P
0 g
s
.56891 .62375 m .55712 .62796 L .54387 .61301 L p 0 .312 .948 r
F P
0 g
s
.6077 .64978 m .59554 .65383 L .61032 .63867 L p 0 .05 .212 r
F P
0 g
s
.61032 .63867 m .59554 .65383 L .6077 .64978 L p 0 .05 .212 r
F P
0 g
s
.6077 .64978 m .59554 .65383 L .58224 .6388 L p 0 .312 .948 r
F P
0 g
s
.61032 .63867 m .59826 .64276 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.61289 .62778 m .59826 .64276 L .61032 .63867 L p 0 .05 .212 r
F P
0 g
s
.61289 .62778 m .60093 .63191 L .6154 .6171 L p 0 .05 .212 r
F P
0 g
s
.6154 .6171 m .60093 .63191 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.60093 .63191 m .61289 .62778 L .59975 .61292 L p 0 .314 .946 r
F P
0 g
s
.59975 .61292 m .58789 .61716 L .60093 .63191 L p 0 .314 .946 r
F P
0 g
s
.60093 .63191 m .58789 .61716 L .59975 .61292 L p 0 .314 .946 r
F P
0 g
s
.59975 .61292 m .61289 .62778 L .60093 .63191 L p 0 .314 .946 r
F P
0 g
s
.59826 .64276 m .61289 .62778 L .59975 .61292 L p 0 .349 .781 r
F P
0 g
s
.59975 .61292 m .61289 .62778 L .59826 .64276 L p 0 .349 .781 r
F P
0 g
s
.59975 .61292 m .58509 .62787 L .59826 .64276 L p 0 .349 .781 r
F P
0 g
s
.59826 .64276 m .58509 .62787 L .59975 .61292 L p 0 .349 .781 r
F P
0 g
s
.58224 .6388 m .5943 .63463 L .6077 .64978 L p 0 .312 .948 r
F P
0 g
s
.5943 .63463 m .58224 .6388 L .56891 .62375 L p 0 .312 .948 r
F P
0 g
s
.56016 .66562 m .6077 .64978 L p .54884 .61862 L .539 0 0 r
F P
0 g
s
.49151 .58826 m .5259 .62701 L p .54884 .61862 L .539 0 0 r
F P
0 g
s
.5259 .62701 m .56016 .66562 L p .54884 .61862 L .539 0 0 r
F P
0 g
s
.56016 .66562 m .47967 .60009 L .49151 .58826 L .856 0 0 r
F
.56016 .66562 m .54849 .67755 L .47967 .60009 L F
.56016 .66562 m .57773 .68542 L .58256 .66687 L closepath p 0 .349 .781 r
F P
0 g
s
.51326 .79001 m .59527 .70518 L .56016 .66562 L p 0 .349 .781 r
F P
0 g
s
.59527 .70518 m .60713 .70161 L .63606 .67165 L p 0 .05 .248 r
F P
0 g
s
.64825 .66782 m .63606 .67165 L .60713 .70161 L p 0 .05 .248 r
F P
0 g
s
.60713 .70161 m .61917 .69798 L .64825 .66782 L p 0 .05 .248 r
F P
0 g
s
.59527 .70518 m .61917 .69798 L .58357 .65782 L p 0 .312 .948 r
F P
0 g
s
.58357 .65782 m .56016 .66562 L .59527 .70518 L p 0 .312 .948 r
F P
0 g
s
.58947 .6817 m .57773 .68542 L .56016 .66562 L p 0 .312 .948 r
F P
0 g
s
.56016 .66562 m .57178 .66175 L .58947 .6817 L p 0 .312 .948 r
F P
0 g
s
.56016 .66562 m .47752 .75008 L .51326 .79001 L p 0 .349 .781 r
F P
0 g
s
.60139 .67792 m .58947 .6817 L .57178 .66175 L p 0 .312 .948 r
F P
0 g
s
.57178 .66175 m .58357 .65782 L .60139 .67792 L p 0 .312 .948 r
F P
0 g
s
.60625 .6591 m .58357 .65782 L .60139 .67792 L closepath p 0 .349 .781 r
F P
0 g
s
.60139 .67792 m .58357 .65782 L .60625 .6591 L closepath p 0 .349 .781 r
F P
0 g
s
.60139 .67792 m .61917 .69798 L .62881 .66038 L p 0 .349 .781 r
F P
0 g
s
.62881 .66038 m .60625 .6591 L .60139 .67792 L p 0 .349 .781 r
F P
0 g
s
.60625 .6591 m .62881 .66038 L .61917 .69798 L p 0 .349 .781 r
F P
0 g
s
.61917 .69798 m .60139 .67792 L .60625 .6591 L p 0 .349 .781 r
F P
0 g
s
.58357 .65782 m .59554 .65383 L .61348 .67409 L p 0 .312 .948 r
F P
0 g
s
.66063 .66393 m .64825 .66782 L .61917 .69798 L p 0 .05 .248 r
F P
0 g
s
.63606 .67165 m .64825 .66782 L .67707 .63793 L p 0 .05 .248 r
F P
0 g
s
.64825 .66782 m .63606 .67165 L .63022 .66503 L p 0 .314 .946 r
F P
0 g
s
.64237 .66115 m .63022 .66503 L .63606 .67165 L p 0 .314 .946 r
F P
0 g
s
.63606 .67165 m .64825 .66782 L .64237 .66115 L p 0 .314 .946 r
F P
0 g
s
.63022 .66503 m .64237 .66115 L .64825 .66782 L p 0 .314 .946 r
F P
0 g
s
.62881 .66038 m .61917 .69798 L .64825 .66782 L p 0 .349 .781 r
F P
0 g
s
.64237 .66115 m .64825 .66782 L .61917 .69798 L p 0 .349 .781 r
F P
0 g
s
.61917 .69798 m .62881 .66038 L .64237 .66115 L p 0 .349 .781 r
F P
0 g
s
.61289 .62778 m .62881 .66038 L .60625 .6591 L p 0 .349 .781 r
F P
0 g
s
.61917 .69798 m .63138 .69431 L .66063 .66393 L p 0 .05 .248 r
F P
0 g
s
.67319 .65998 m .66063 .66393 L .63138 .69431 L p 0 .05 .248 r
F P
0 g
s
.63138 .69431 m .64378 .69057 L .67319 .65998 L p 0 .05 .248 r
F P
0 g
s
.64378 .69057 m .6077 .64978 L .58357 .65782 L p 0 .312 .948 r
F P
0 g
s
.62576 .67019 m .61348 .67409 L .59554 .65383 L p 0 .312 .948 r
F P
0 g
s
.59554 .65383 m .6077 .64978 L .62576 .67019 L p 0 .312 .948 r
F P
0 g
s
.62881 .66038 m .64237 .66115 L .61289 .62778 L closepath p 0 .349 .781 r
F P
0 g
s
.61289 .62778 m .64237 .66115 L .62881 .66038 L closepath p 0 .349 .781 r
F P
0 g
s
.63065 .65111 m .62576 .67019 L .6077 .64978 L closepath p 0 .35 .78 r
F P
0 g
s
.61289 .62778 m .64237 .66115 L .64226 .64649 L closepath p 0 .349 .781 r
F P
0 g
s
.64226 .64649 m .64237 .66115 L .61289 .62778 L closepath p 0 .349 .781 r
F P
0 g
s
.67707 .63793 m .64226 .64649 L .64237 .66115 L p 0 .349 .781 r
F P
0 g
s
.64237 .66115 m .64825 .66782 L .67707 .63793 L p 0 .349 .781 r
F P
0 g
s
.64226 .64649 m .67707 .63793 L .64825 .66782 L p 0 .349 .781 r
F P
0 g
s
.64825 .66782 m .64237 .66115 L .64226 .64649 L p 0 .349 .781 r
F P
0 g
s
.6547 .65722 m .64237 .66115 L .61289 .62778 L p 0 .314 .946 r
F P
0 g
s
.64209 .62223 m .62744 .61287 L .61289 .62778 L p 0 .349 .781 r
F P
0 g
s
.61289 .62778 m .64226 .64649 L .64209 .62223 L p 0 .349 .781 r
F P
0 g
s
.64226 .64649 m .61289 .62778 L .62744 .61287 L p 0 .349 .781 r
F P
0 g
s
.62502 .62359 m .61289 .62778 L .64237 .66115 L p 0 .314 .946 r
F P
0 g
s
.64209 .62223 m .64226 .64649 L .67707 .63793 L p 0 .349 .781 r
F P
0 g
s
.67707 .63793 m .65951 .618 L .64728 .62218 L p 0 .315 .944 r
F P
0 g
s
.65951 .618 m .67707 .63793 L .64226 .64649 L p 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .62981 .60236 L .64728 .62218 L p 0 .315 .944 r
F P
0 g
s
.64728 .62218 m .65951 .618 L .64192 .59803 L p 0 .315 .944 r
F P
0 g
s
.64226 .64649 m .64209 .62223 L .65951 .618 L p 0 .349 .781 r
F P
0 g
s
.62744 .61287 m .64209 .62223 L .64226 .64649 L p 0 .349 .781 r
F P
0 g
s
.61289 .62778 m .62502 .62359 L .6547 .65722 L p 0 .314 .946 r
F P
0 g
s
.63065 .65111 m .6077 .64978 L .62255 .63452 L closepath p 0 .35 .78 r
F P
0 g
s
.61917 .69798 m .59527 .70518 L .51326 .79001 L p 0 .05 .248 r
F P
0 g
s
.60713 .70161 m .59527 .70518 L .57773 .68542 L p 0 .312 .948 r
F P
0 g
s
.57773 .68542 m .58947 .6817 L .60713 .70161 L p 0 .312 .948 r
F P
0 g
s
.60713 .70161 m .58947 .6817 L .60139 .67792 L p 0 .312 .948 r
F P
0 g
s
.60139 .67792 m .61917 .69798 L .60713 .70161 L p 0 .312 .948 r
F P
0 g
s
.51326 .79001 m .53623 .784 L .61917 .69798 L p 0 .05 .248 r
F P
0 g
s
.58357 .65782 m .61917 .69798 L .60745 .71013 L p 0 .349 .781 r
F P
0 g
s
.60745 .71013 m .53623 .784 L p .57688 .67567 L 0 .349 .781 r
F P
0 g
s
.58357 .65782 m .60745 .71013 L .57688 .67567 L 0 .349 .781 r
F
.58357 .65782 m .56016 .66562 L p .57768 .66386 L .257 0 0 r
F P
0 g
s
.56016 .66562 m .54849 .67755 L .57177 .66991 L p .257 0 0 r
F P
0 g
s
.61917 .69798 m .58357 .65782 L p .57688 .67567 L 0 .349 .781 r
F P
0 g
s
.53623 .784 m .60745 .71013 L p .57688 .67567 L 0 .349 .781 r
F P
0 g
s
.60745 .71013 m .61917 .69798 L p .57688 .67567 L 0 .349 .781 r
F P
0 g
s
.49151 .58826 m .47967 .60009 L .54849 .67755 L p .856 0 0 r
F P
0 g
s
.54849 .67755 m .47967 .60009 L p .53695 .63066 L .535 0 0 r
F P
0 g
s
.58357 .65782 m .61917 .69798 L .64378 .69057 L p 0 .312 .948 r
F P
0 g
s
.61348 .67409 m .60139 .67792 L .58357 .65782 L p 0 .312 .948 r
F P
0 g
s
.54849 .67755 m .51479 .70367 L .52108 .70556 L .257 0 0 r
F
.54849 .67755 m .54631 .677 L .51479 .70367 L F
.52108 .70556 m .54849 .67755 L .51414 .63889 L p .856 0 0 r
F P
0 g
s
.54849 .67755 m .52108 .70556 L .48653 .66678 L .856 0 0 r
F
.51414 .63889 m .48653 .66678 L .52108 .70556 L p F P
0 g
s
.52108 .70556 m .48653 .66678 L p .52656 .67864 L .526 0 0 r
F P
0 g
s
.57177 .66991 m .55803 .71402 L .54406 .69831 L 0 .349 .781 r
F
.57688 .67567 m .56117 .71754 L .57177 .66991 L F
.56117 .71754 m .53623 .784 L .55803 .71402 L F
.56117 .71754 m .55803 .71402 L .57177 .66991 L F
.5 .74345 m .57177 .66991 L p .57177 .66991 L F P
0 g
s
.53623 .784 m .5 .74345 L p .54406 .69831 L 0 .349 .781 r
F P
0 g
s
.5 .74345 m .5 .74345 L p .57177 .66991 L 0 .349 .781 r
F P
0 g
s
.55438 .6503 m .55438 .6503 L .53695 .63066 L .535 0 0 r
F
.58357 .65782 m .57688 .67567 L .57177 .66991 L 0 .349 .781 r
F
.56016 .66562 m .57177 .66991 L .57768 .66386 L .257 0 0 r
F
.56241 .66487 m .58357 .65782 L p .5684 .67102 L 0 .05 .212 r
F P
0 g
s
.59576 .66204 m .6077 .64978 L .58357 .65782 L p .257 0 0 r
F P
0 g
s
.58357 .65782 m .5 .74345 L .53623 .784 L p 0 .349 .781 r
F P
0 g
s
.57768 .66386 m .59576 .66204 L .58357 .65782 L .257 0 0 r
F
.54849 .67755 m .52108 .70556 L .54406 .69831 L p F P
0 g
s
.54849 .67755 m .54406 .69831 L .55794 .68408 L .257 0 0 r
F
.57177 .66991 m .54849 .67755 L p .55794 .68408 L F P
0 g
s
.5684 .67102 m .54202 .69895 L .53303 .70179 L 0 .05 .212 r
F
.57177 .66991 m .54406 .69831 L p .5684 .67102 L F P
0 g
s
.54406 .69831 m .5 .74345 L p .54202 .69895 L 0 .05 .212 r
F P
0 g
s
.54406 .69831 m .54202 .69895 L .5684 .67102 L 0 .05 .212 r
F
.54406 .69831 m .56773 .69084 L p .55794 .68408 L .257 0 0 r
F P
0 g
s
.5684 .67102 m .53303 .70179 L .54849 .67755 L 0 .05 .212 r
F
.47752 .75008 m .52108 .70556 L p .53303 .70179 L F P
0 g
s
.5 .74345 m .47752 .75008 L p .53303 .70179 L 0 .05 .212 r
F P
0 g
s
.44087 .63461 m .43525 .63397 L .45171 .66363 L .523 0 0 r
F
.45171 .66363 m .3936 .68445 L .41686 .69863 L .765 0 0 r
F
.46868 .6658 m .45171 .66363 L .41686 .69863 L .587 0 0 r
F
.46868 .6658 m .41686 .69863 L .43366 .70107 L F
.47752 .75008 m .5 .74345 L .46638 .70583 L p 0 .308 .954 r
F P
0 g
s
.43366 .70107 m .46868 .6658 L .44087 .63461 L p .856 0 0 r
F P
0 g
s
.46868 .6658 m .43366 .70107 L .45553 .69369 L p .212 0 0 r
F P
0 g
s
.45553 .69369 m .47806 .68607 L p .47329 .67575 L .212 0 0 r
F P
0 g
s
.46868 .6658 m .45553 .69369 L .47329 .67575 L .212 0 0 r
F
.45095 .70359 m .47752 .75008 L .46638 .70583 L 0 .308 .954 r
F
.44087 .63461 m .46868 .6658 L .43366 .70107 L .856 0 0 r
F
.43525 .63397 m .42743 .62933 L .42761 .63308 L .523 0 0 r
F
.43525 .63397 m .42761 .63308 L .42841 .6497 L F
.44087 .63461 m .40008 .66903 L .40565 .66977 L .58 0 0 r
F
.43806 .63429 m .40008 .66903 L .44087 .63461 L F
.43806 .63429 m .43525 .63397 L .40008 .66903 L F
.42751 .63092 m .40485 .62775 L .40817 .63084 L .523 0 0 r
F
.42751 .63092 m .40817 .63084 L .42761 .63308 L F
.42743 .62933 m .426 .62923 L .42751 .63092 L F
.426 .62923 m .41125 .6282 L .42751 .63092 L F
.41125 .6282 m .40485 .62775 L .41042 .62853 L F
.41125 .6282 m .41042 .62853 L .42751 .63092 L F
.42743 .62933 m .4195 .62194 L .40485 .62775 L F
.4622 .59473 m .40674 .63898 L .39228 .6643 L .831 0 0 r
F
.40674 .63898 m .38431 .65687 L .38659 .65899 L F
.40674 .63898 m .38659 .65899 L .39228 .6643 L F
.44087 .63461 m .40565 .66977 L .43366 .70107 L p .856 0 0 r
F P
0 g
s
.51414 .63889 m .48653 .66678 L .48052 .66523 L .221 0 0 r
F
.54849 .67755 m .48653 .66678 L .51414 .63889 L .856 0 0 r
F
.58357 .65782 m .57177 .66991 L p .5684 .67102 L 0 .05 .212 r
F P
0 g
s
.56016 .66562 m .56241 .66487 L p .5684 .67102 L 0 .05 .212 r
F P
0 g
s
.54849 .67755 m .56016 .66562 L p .5684 .67102 L 0 .05 .212 r
F P
0 g
s
.51414 .63889 m .54849 .67755 L .57177 .66991 L p .535 0 0 r
F P
0 g
s
.53221 .65085 m .48653 .66678 L .51414 .63889 L p .221 0 0 r
F P
0 g
s
.46868 .6658 m .51391 .6498 L p .47203 .64109 L .523 0 0 r
F P
0 g
s
.44087 .63461 m .46217 .6585 L p .47203 .64109 L .523 0 0 r
F P
0 g
s
.46217 .6585 m .46868 .6658 L p .47203 .64109 L .523 0 0 r
F P
0 g
s
.49151 .58826 m .47768 .59976 L .49122 .58822 L .183 0 0 r
F
.49151 .58826 m .47967 .60009 L .47768 .59976 L F
.54865 .57278 m .56174 .58759 L .55023 .592 L p 0 .314 .946 r
F P
0 g
s
.53553 .55794 m .54865 .57278 L .53722 .57729 L p 0 .314 .946 r
F P
0 g
s
.53394 .58756 m .54865 .57278 L .53722 .57729 L p 0 .05 .154 r
F P
0 g
s
.51917 .60241 m .53394 .58756 L .52259 .59198 L p 0 .05 .154 r
F P
0 g
s
.52078 .5727 m .53394 .58756 L .52259 .59198 L p 0 .313 .947 r
F P
0 g
s
.51102 .57663 m .5066 .57518 L .49542 .58872 L 0 .433 .873 r
F
.50159 .57354 m .49704 .58473 L p .5066 .57518 L F P
0 g
s
.49704 .58473 m .49542 .58872 L p .5066 .57518 L 0 .433 .873 r
F P
0 g
s
.50597 .58753 m .52078 .5727 L .51102 .57663 L p 0 .05 .139 r
F P
0 g
s
.54865 .57278 m .56174 .58759 L .54708 .6024 L p 0 .349 .781 r
F P
0 g
s
.56174 .58759 m .54708 .6024 L .55869 .59803 L p 0 .05 .17 r
F P
0 g
s
.57343 .58312 m .56174 .58759 L .57482 .60239 L p 0 .314 .946 r
F P
0 g
s
.57482 .60239 m .56174 .58759 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.55869 .59803 m .57343 .58312 L .56174 .58759 L p 0 .05 .17 r
F P
0 g
s
.53394 .58756 m .54708 .6024 L .56174 .58759 L p 0 .349 .781 r
F P
0 g
s
.56174 .58759 m .54865 .57278 L .53394 .58756 L p 0 .349 .781 r
F P
0 g
s
.54708 .6024 m .56174 .58759 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.51102 .57663 m .50674 .56311 L .50159 .57354 L p 0 .433 .873 r
F P
0 g
s
.49542 .58872 m .50159 .57354 L .50733 .57121 L p 0 .129 .614 r
F P
0 g
s
.50733 .57121 m .50399 .5853 L .49542 .58872 L p 0 .129 .614 r
F P
0 g
s
.54708 .6024 m .53394 .58756 L .54865 .57278 L p 0 .349 .781 r
F P
0 g
s
.54865 .57278 m .56174 .58759 L .57634 .57285 L p 0 .349 .781 r
F P
0 g
s
.57634 .57285 m .56328 .55806 L .54865 .57278 L p 0 .349 .781 r
F P
0 g
s
.56174 .58759 m .54865 .57278 L .56328 .55806 L p 0 .349 .781 r
F P
0 g
s
.56174 .58759 m .54865 .57278 L .56024 .56819 L p 0 .314 .946 r
F P
0 g
s
.56328 .55806 m .57634 .57285 L .56174 .58759 L p 0 .349 .781 r
F P
0 g
s
.57634 .57285 m .56174 .58759 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.57343 .58312 m .56174 .58759 L .57634 .57285 L p 0 .05 .17 r
F P
0 g
s
.54865 .57278 m .56174 .58759 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.57343 .58312 m .56024 .56819 L .54865 .57278 L p 0 .314 .946 r
F P
0 g
s
.53394 .58756 m .54865 .57278 L .56024 .56819 L p 0 .05 .154 r
F P
0 g
s
.53553 .55794 m .54865 .57278 L .53394 .58756 L p 0 .349 .781 r
F P
0 g
s
.54865 .57278 m .53394 .58756 L .54546 .58307 L p 0 .05 .154 r
F P
0 g
s
.54546 .58307 m .56024 .56819 L .54865 .57278 L p 0 .05 .154 r
F P
0 g
s
.52078 .5727 m .53394 .58756 L .54865 .57278 L p 0 .349 .781 r
F P
0 g
s
.54865 .57278 m .53553 .55794 L .52078 .5727 L p 0 .349 .781 r
F P
0 g
s
.53394 .58756 m .52078 .5727 L .53553 .55794 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .55869 .59803 L .54708 .6024 L p 0 .05 .17 r
F P
0 g
s
.53394 .58756 m .54708 .6024 L .55869 .59803 L p 0 .313 .947 r
F P
0 g
s
.54708 .6024 m .53394 .58756 L .54546 .58307 L p 0 .313 .947 r
F P
0 g
s
.54546 .58307 m .55869 .59803 L .54708 .6024 L p 0 .313 .947 r
F P
0 g
s
.55869 .59803 m .54546 .58307 L .53394 .58756 L p 0 .313 .947 r
F P
0 g
s
.51917 .60241 m .53394 .58756 L .54546 .58307 L p 0 .05 .154 r
F P
0 g
s
.52078 .5727 m .53394 .58756 L .51917 .60241 L p 0 .349 .781 r
F P
0 g
s
.53394 .58756 m .51917 .60241 L .5306 .59803 L p 0 .05 .154 r
F P
0 g
s
.5306 .59803 m .54546 .58307 L .53394 .58756 L p 0 .05 .154 r
F P
0 g
s
.56024 .56819 m .54546 .58307 L .53394 .58756 L p 0 .05 .154 r
F P
0 g
s
.52078 .5727 m .53394 .58756 L .54546 .58307 L p 0 .313 .947 r
F P
0 g
s
.50597 .58753 m .51917 .60241 L .53394 .58756 L p 0 .349 .781 r
F P
0 g
s
.53394 .58756 m .52078 .5727 L .50597 .58753 L p 0 .349 .781 r
F P
0 g
s
.53394 .58756 m .52078 .5727 L .53221 .5681 L p 0 .313 .947 r
F P
0 g
s
.53221 .5681 m .54546 .58307 L .53394 .58756 L p 0 .313 .947 r
F P
0 g
s
.54546 .58307 m .53221 .5681 L .52078 .5727 L p 0 .313 .947 r
F P
0 g
s
.51917 .60241 m .50597 .58753 L .52078 .5727 L p 0 .349 .781 r
F P
0 g
s
.50597 .58753 m .52078 .5727 L .53221 .5681 L p 0 .05 .139 r
F P
0 g
s
.52078 .5727 m .50597 .58753 L p .50757 .5789 L 0 .349 .781 r
F P
0 g
s
.52078 .5727 m .51081 .56143 L .50674 .56311 L p 0 .313 .947 r
F P
0 g
s
.51081 .56143 m .51749 .56898 L p .50757 .5789 L 0 .349 .781 r
F P
0 g
s
.51749 .56898 m .52078 .5727 L p .50757 .5789 L 0 .349 .781 r
F P
0 g
s
.52078 .5727 m .50597 .58753 L .51731 .58303 L p 0 .05 .139 r
F P
0 g
s
.51731 .58303 m .53221 .5681 L .52078 .5727 L p 0 .05 .139 r
F P
0 g
s
.50399 .5853 m .50597 .58753 L .52078 .5727 L p 0 .349 .781 r
F P
0 g
s
.52078 .5727 m .51447 .572 L .50399 .5853 L 0 .349 .781 r
F
.50733 .57121 m .50487 .58159 L p .51447 .572 L F P
0 g
s
.50487 .58159 m .50399 .5853 L p .51447 .572 L 0 .349 .781 r
F P
0 g
s
.50733 .57121 m .51081 .56143 L p .50597 .58753 L 0 .349 .781 r
F P
0 g
s
.50597 .58753 m .50399 .5853 L .50733 .57121 L p 0 .349 .781 r
F P
0 g
s
.52569 .56196 m .52013 .54404 L .51372 .55162 L p 0 .433 .873 r
F P
0 g
s
.52078 .5727 m .53553 .55794 L .52569 .56196 L p 0 .05 .139 r
F P
0 g
s
.51081 .56143 m .52078 .5727 L .53553 .55794 L p 0 .349 .781 r
F P
0 g
s
.5114 .55977 m .51636 .55052 L p .52078 .5727 L 0 .349 .781 r
F P
0 g
s
.53553 .55794 m .54865 .57278 L .56328 .55806 L p 0 .349 .781 r
F P
0 g
s
.56328 .55806 m .5502 .54325 L .53553 .55794 L p 0 .349 .781 r
F P
0 g
s
.54865 .57278 m .53553 .55794 L .5502 .54325 L p 0 .349 .781 r
F P
0 g
s
.54865 .57278 m .53553 .55794 L .54704 .55324 L p 0 .314 .946 r
F P
0 g
s
.56328 .55806 m .57634 .57285 L .59087 .55819 L p 0 .349 .781 r
F P
0 g
s
.59087 .55819 m .57785 .54342 L .56328 .55806 L p 0 .349 .781 r
F P
0 g
s
.57634 .57285 m .56328 .55806 L .57785 .54342 L p 0 .349 .781 r
F P
0 g
s
.57634 .57285 m .56328 .55806 L .57496 .55338 L p 0 .314 .945 r
F P
0 g
s
.57785 .54342 m .59087 .55819 L .57634 .57285 L p 0 .349 .781 r
F P
0 g
s
.59087 .55819 m .57634 .57285 L .58811 .56828 L p 0 .05 .17 r
F P
0 g
s
.58811 .56828 m .57634 .57285 L .59087 .55819 L p 0 .05 .17 r
F P
0 g
s
.56328 .55806 m .57634 .57285 L .58811 .56828 L p 0 .314 .945 r
F P
0 g
s
.58811 .56828 m .57496 .55338 L .56328 .55806 L p 0 .314 .945 r
F P
0 g
s
.54865 .57278 m .56328 .55806 L .57496 .55338 L p 0 .05 .154 r
F P
0 g
s
.5502 .54325 m .56328 .55806 L .54865 .57278 L p 0 .349 .781 r
F P
0 g
s
.56328 .55806 m .54865 .57278 L .56024 .56819 L p 0 .05 .154 r
F P
0 g
s
.57496 .55338 m .56024 .56819 L .54865 .57278 L p 0 .05 .154 r
F P
0 g
s
.53553 .55794 m .54865 .57278 L .56024 .56819 L p 0 .314 .946 r
F P
0 g
s
.56024 .56819 m .54704 .55324 L .53553 .55794 L p 0 .314 .946 r
F P
0 g
s
.52078 .5727 m .53553 .55794 L .54704 .55324 L p 0 .05 .139 r
F P
0 g
s
.53553 .55794 m .52239 .54308 L .52013 .54404 L p 0 .314 .946 r
F P
0 g
s
.52239 .54308 m .53553 .55794 L .52078 .5727 L p 0 .349 .781 r
F P
0 g
s
.53553 .55794 m .52078 .5727 L .53221 .5681 L p 0 .05 .139 r
F P
0 g
s
.51636 .55052 m .52239 .54308 L p .52078 .5727 L 0 .349 .781 r
F P
0 g
s
.54704 .55324 m .53221 .5681 L .52078 .5727 L p 0 .05 .139 r
F P
0 g
s
.52078 .5727 m .51081 .56143 L .5114 .55977 L p 0 .349 .781 r
F P
0 g
s
.51081 .56143 m .52078 .5727 L .53221 .5681 L p 0 .313 .947 r
F P
0 g
s
.52078 .5727 m .51081 .56143 L .50733 .57121 L p 0 .349 .781 r
F P
0 g
s
.5114 .55977 m .51081 .56143 L p .53553 .55794 L 0 .349 .781 r
F P
0 g
s
.51636 .55052 m .5114 .55977 L p .53553 .55794 L 0 .349 .781 r
F P
0 g
s
.52078 .5727 m .51081 .56143 L .52216 .55675 L p 0 .313 .947 r
F P
0 g
s
.50399 .5853 m .50733 .57121 L .51867 .56659 L p 0 .129 .614 r
F P
0 g
s
.54546 .58307 m .5306 .59803 L .51917 .60241 L p 0 .05 .154 r
F P
0 g
s
.51917 .60241 m .50597 .58753 L .51731 .58303 L p 0 .312 .948 r
F P
0 g
s
.51731 .58303 m .5306 .59803 L .51917 .60241 L p 0 .312 .948 r
F P
0 g
s
.58789 .61716 m .59975 .61292 L .5866 .59803 L p 0 .314 .946 r
F P
0 g
s
.5866 .59803 m .57482 .60239 L .58789 .61716 L p 0 .314 .946 r
F P
0 g
s
.58789 .61716 m .57482 .60239 L .5866 .59803 L p 0 .314 .946 r
F P
0 g
s
.5866 .59803 m .59975 .61292 L .58789 .61716 L p 0 .314 .946 r
F P
0 g
s
.58509 .62787 m .59975 .61292 L .5866 .59803 L p 0 .349 .781 r
F P
0 g
s
.5866 .59803 m .59975 .61292 L .58509 .62787 L p 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .51731 .58303 L .50597 .58753 L p 0 .05 .139 r
F P
0 g
s
.50597 .58753 m .50399 .5853 L .51532 .58079 L p 0 .312 .948 r
F P
0 g
s
.51532 .58079 m .51731 .58303 L .50597 .58753 L p 0 .312 .948 r
F P
0 g
s
.51867 .56659 m .51532 .58079 L .50399 .5853 L p 0 .129 .614 r
F P
0 g
s
.5866 .59803 m .5719 .61296 L .58509 .62787 L p 0 .349 .781 r
F P
0 g
s
.57482 .60239 m .5866 .59803 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.57343 .58312 m .5866 .59803 L .57482 .60239 L p 0 .314 .946 r
F P
0 g
s
.5719 .61296 m .5866 .59803 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .5866 .59803 L .5719 .61296 L p 0 .349 .781 r
F P
0 g
s
.58509 .62787 m .5719 .61296 L .5866 .59803 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .55869 .59803 L .5719 .61296 L p 0 .349 .781 r
F P
0 g
s
.5719 .61296 m .55869 .59803 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .55869 .59803 L .57047 .59359 L p 0 .05 .17 r
F P
0 g
s
.57047 .59359 m .55869 .59803 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.56024 .56819 m .57343 .58312 L .56174 .58759 L p 0 .314 .946 r
F P
0 g
s
.56024 .56819 m .57343 .58312 L .55869 .59803 L p 0 .349 .781 r
F P
0 g
s
.54546 .58307 m .55869 .59803 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .56024 .56819 L .54546 .58307 L p 0 .349 .781 r
F P
0 g
s
.55869 .59803 m .54546 .58307 L .56024 .56819 L p 0 .349 .781 r
F P
0 g
s
.54704 .55324 m .56024 .56819 L .54865 .57278 L p 0 .314 .946 r
F P
0 g
s
.54704 .55324 m .56024 .56819 L .54546 .58307 L p 0 .349 .781 r
F P
0 g
s
.57496 .55338 m .58811 .56828 L .57634 .57285 L p 0 .314 .945 r
F P
0 g
s
.57343 .58312 m .58811 .56828 L .57634 .57285 L p 0 .05 .17 r
F P
0 g
s
.57634 .57285 m .58811 .56828 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.56024 .56819 m .57343 .58312 L .58811 .56828 L p 0 .349 .781 r
F P
0 g
s
.58811 .56828 m .57496 .55338 L .56024 .56819 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .56024 .56819 L .57496 .55338 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .56024 .56819 L .57201 .56354 L p 0 .314 .946 r
F P
0 g
s
.60124 .58317 m .58811 .56828 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.57343 .58312 m .58811 .56828 L .60124 .58317 L p 0 .349 .781 r
F P
0 g
s
.6158 .56838 m .60386 .57293 L .61685 .58766 L p 0 .315 .944 r
F P
0 g
s
.58811 .56828 m .60124 .58317 L .6158 .56838 L p 0 .349 .781 r
F P
0 g
s
.6158 .56838 m .60124 .58317 L .58811 .56828 L p 0 .349 .781 r
F P
0 g
s
.58811 .56828 m .60271 .55352 L .6158 .56838 L p 0 .349 .781 r
F P
0 g
s
.58529 .57858 m .60005 .56365 L .58811 .56828 L p 0 .05 .17 r
F P
0 g
s
.58811 .56828 m .57343 .58312 L .58529 .57858 L p 0 .05 .17 r
F P
0 g
s
.57343 .58312 m .58811 .56828 L .60005 .56365 L p 0 .05 .17 r
F P
0 g
s
.57496 .55338 m .58811 .56828 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.60005 .56365 m .58529 .57858 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.56024 .56819 m .57343 .58312 L .58529 .57858 L p 0 .314 .946 r
F P
0 g
s
.58529 .57858 m .57201 .56354 L .56024 .56819 L p 0 .314 .946 r
F P
0 g
s
.54546 .58307 m .56024 .56819 L .57201 .56354 L p 0 .05 .154 r
F P
0 g
s
.56024 .56819 m .54546 .58307 L .55714 .57852 L p 0 .05 .154 r
F P
0 g
s
.53221 .5681 m .54546 .58307 L .56024 .56819 L p 0 .349 .781 r
F P
0 g
s
.54546 .58307 m .53221 .5681 L .54704 .55324 L p 0 .349 .781 r
F P
0 g
s
.55869 .59803 m .54387 .61301 L .55557 .60867 L p 0 .05 .17 r
F P
0 g
s
.55557 .60867 m .54387 .61301 L .55869 .59803 L p 0 .05 .17 r
F P
0 g
s
.55557 .60867 m .57047 .59359 L .55869 .59803 L p 0 .05 .17 r
F P
0 g
s
.55869 .59803 m .57047 .59359 L .55557 .60867 L p 0 .05 .17 r
F P
0 g
s
.54546 .58307 m .55869 .59803 L .54387 .61301 L p 0 .349 .781 r
F P
0 g
s
.54546 .58307 m .55869 .59803 L .57047 .59359 L p 0 .313 .947 r
F P
0 g
s
.5306 .59803 m .54387 .61301 L .55869 .59803 L p 0 .349 .781 r
F P
0 g
s
.55869 .59803 m .54546 .58307 L .5306 .59803 L p 0 .349 .781 r
F P
0 g
s
.55869 .59803 m .54546 .58307 L .55714 .57852 L p 0 .313 .947 r
F P
0 g
s
.55714 .57852 m .57047 .59359 L .55869 .59803 L p 0 .313 .947 r
F P
0 g
s
.54387 .61301 m .5306 .59803 L .54546 .58307 L p 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .54546 .58307 L .5306 .59803 L p 0 .349 .781 r
F P
0 g
s
.57047 .59359 m .55714 .57852 L .54546 .58307 L p 0 .313 .947 r
F P
0 g
s
.5306 .59803 m .54546 .58307 L .55714 .57852 L p 0 .05 .154 r
F P
0 g
s
.54546 .58307 m .5306 .59803 L .5422 .59358 L p 0 .05 .154 r
F P
0 g
s
.5422 .59358 m .55714 .57852 L .54546 .58307 L p 0 .05 .154 r
F P
0 g
s
.57201 .56354 m .55714 .57852 L .54546 .58307 L p 0 .05 .154 r
F P
0 g
s
.53221 .5681 m .54546 .58307 L .55714 .57852 L p 0 .313 .947 r
F P
0 g
s
.51731 .58303 m .5306 .59803 L .54546 .58307 L p 0 .349 .781 r
F P
0 g
s
.54546 .58307 m .53221 .5681 L .51731 .58303 L p 0 .349 .781 r
F P
0 g
s
.56024 .56819 m .54704 .55324 L .53221 .5681 L p 0 .349 .781 r
F P
0 g
s
.54546 .58307 m .53221 .5681 L .5438 .56343 L p 0 .313 .947 r
F P
0 g
s
.5438 .56343 m .55714 .57852 L .54546 .58307 L p 0 .313 .947 r
F P
0 g
s
.5306 .59803 m .51731 .58303 L .53221 .5681 L p 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .51731 .58303 L p .51891 .57434 L 0 .349 .781 r
F P
0 g
s
.52216 .55675 m .53221 .5681 L .52078 .5727 L p 0 .313 .947 r
F P
0 g
s
.53221 .5681 m .52216 .55675 L .51081 .56143 L p 0 .313 .947 r
F P
0 g
s
.52216 .55675 m .52889 .56435 L p .51891 .57434 L 0 .349 .781 r
F P
0 g
s
.52889 .56435 m .53221 .5681 L p .51891 .57434 L 0 .349 .781 r
F P
0 g
s
.55714 .57852 m .5438 .56343 L .53221 .5681 L p 0 .313 .947 r
F P
0 g
s
.51731 .58303 m .53221 .5681 L .5438 .56343 L p 0 .05 .139 r
F P
0 g
s
.53221 .5681 m .51731 .58303 L .52882 .57846 L p 0 .05 .139 r
F P
0 g
s
.52882 .57846 m .5438 .56343 L .53221 .5681 L p 0 .05 .139 r
F P
0 g
s
.51532 .58079 m .51731 .58303 L .53221 .5681 L p 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .52585 .56739 L .51532 .58079 L 0 .349 .781 r
F
.51867 .56659 m .5162 .57705 L p .52585 .56739 L F P
0 g
s
.5162 .57705 m .51532 .58079 L p .52585 .56739 L 0 .349 .781 r
F P
0 g
s
.51867 .56659 m .52216 .55675 L p .51731 .58303 L 0 .349 .781 r
F P
0 g
s
.54387 .61301 m .55557 .60867 L .56891 .62375 L p 0 .312 .948 r
F P
0 g
s
.54387 .61301 m .5306 .59803 L .5422 .59358 L p 0 .312 .948 r
F P
0 g
s
.5422 .59358 m .55557 .60867 L .54387 .61301 L p 0 .312 .948 r
F P
0 g
s
.51731 .58303 m .51532 .58079 L .51867 .56659 L p 0 .349 .781 r
F P
0 g
s
.53553 .55794 m .5502 .54325 L .5403 .54735 L p 0 .05 .139 r
F P
0 g
s
.5502 .54325 m .56328 .55806 L .57785 .54342 L p 0 .349 .781 r
F P
0 g
s
.57785 .54342 m .56481 .52863 L .5502 .54325 L p 0 .349 .781 r
F P
0 g
s
.56328 .55806 m .5502 .54325 L .56481 .52863 L p 0 .349 .781 r
F P
0 g
s
.56328 .55806 m .5502 .54325 L .56179 .53846 L p 0 .314 .945 r
F P
0 g
s
.57785 .54342 m .59087 .55819 L .60271 .55352 L p 0 .315 .944 r
F P
0 g
s
.60271 .55352 m .58961 .53864 L .57785 .54342 L p 0 .315 .944 r
F P
0 g
s
.56328 .55806 m .57785 .54342 L .58961 .53864 L p 0 .05 .154 r
F P
0 g
s
.56481 .52863 m .57785 .54342 L .56328 .55806 L p 0 .349 .781 r
F P
0 g
s
.57785 .54342 m .56328 .55806 L .57496 .55338 L p 0 .05 .154 r
F P
0 g
s
.58961 .53864 m .57496 .55338 L .56328 .55806 L p 0 .05 .154 r
F P
0 g
s
.5502 .54325 m .56328 .55806 L .57496 .55338 L p 0 .314 .945 r
F P
0 g
s
.57496 .55338 m .56179 .53846 L .5502 .54325 L p 0 .314 .945 r
F P
0 g
s
.53553 .55794 m .5502 .54325 L .56179 .53846 L p 0 .05 .139 r
F P
0 g
s
.53487 .53417 m .52709 .5383 L p .5403 .54735 L 0 .433 .873 r
F P
0 g
s
.5403 .54735 m .53616 .53378 L .53487 .53417 L p 0 .433 .873 r
F P
0 g
s
.53616 .53378 m .5403 .54735 L .5502 .54325 L p 0 .314 .945 r
F P
0 g
s
.5502 .54325 m .54029 .53203 L .53616 .53378 L p 0 .314 .945 r
F P
0 g
s
.54029 .53203 m .5502 .54325 L .53553 .55794 L p 0 .349 .781 r
F P
0 g
s
.5502 .54325 m .53553 .55794 L .54704 .55324 L p 0 .05 .139 r
F P
0 g
s
.52239 .54308 m .53553 .55794 L .5502 .54325 L p 0 .349 .781 r
F P
0 g
s
.53487 .53417 m .53616 .53378 L .54029 .53203 L p 0 .462 .885 r
F P
0 g
s
.54029 .53203 m .5387 .53254 L .53487 .53417 L p 0 .462 .885 r
F P
0 g
s
.5387 .53254 m .54029 .53203 L p .53553 .55794 L 0 .349 .781 r
F P
0 g
s
.52975 .53717 m .5387 .53254 L p .53553 .55794 L 0 .349 .781 r
F P
0 g
s
.53553 .55794 m .52239 .54308 L .52975 .53717 L p 0 .349 .781 r
F P
0 g
s
.56179 .53846 m .54704 .55324 L .53553 .55794 L p 0 .05 .139 r
F P
0 g
s
.52975 .53717 m .52239 .54308 L p .5502 .54325 L 0 .349 .781 r
F P
0 g
s
.5387 .53254 m .52975 .53717 L p .5502 .54325 L 0 .349 .781 r
F P
0 g
s
.53381 .53827 m .54704 .55324 L .53553 .55794 L p 0 .314 .946 r
F P
0 g
s
.53553 .55794 m .52239 .54308 L .53381 .53827 L p 0 .314 .946 r
F P
0 g
s
.53221 .5681 m .54704 .55324 L .53553 .55794 L p 0 .05 .139 r
F P
0 g
s
.52239 .54308 m .53553 .55794 L .54704 .55324 L p 0 .314 .946 r
F P
0 g
s
.53553 .55794 m .52239 .54308 L .51636 .55052 L p 0 .349 .781 r
F P
0 g
s
.52216 .55675 m .53221 .5681 L .54704 .55324 L p 0 .349 .781 r
F P
0 g
s
.52276 .55507 m .52774 .54575 L p .53221 .5681 L 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .52216 .55675 L .52276 .55507 L p 0 .349 .781 r
F P
0 g
s
.54704 .55324 m .53381 .53827 L .52239 .54308 L p 0 .314 .946 r
F P
0 g
s
.53381 .53827 m .54704 .55324 L .53221 .5681 L p 0 .349 .781 r
F P
0 g
s
.56179 .53846 m .57496 .55338 L .56328 .55806 L p 0 .314 .945 r
F P
0 g
s
.56024 .56819 m .57496 .55338 L .56328 .55806 L p 0 .05 .154 r
F P
0 g
s
.54704 .55324 m .56024 .56819 L .57496 .55338 L p 0 .349 .781 r
F P
0 g
s
.57496 .55338 m .56179 .53846 L .54704 .55324 L p 0 .349 .781 r
F P
0 g
s
.56024 .56819 m .54704 .55324 L .56179 .53846 L p 0 .349 .781 r
F P
0 g
s
.56024 .56819 m .54704 .55324 L .55872 .54847 L p 0 .314 .946 r
F P
0 g
s
.56179 .53846 m .57496 .55338 L .56024 .56819 L p 0 .349 .781 r
F P
0 g
s
.58811 .56828 m .60271 .55352 L .59087 .55819 L p 0 .05 .17 r
F P
0 g
s
.59087 .55819 m .60271 .55352 L .58811 .56828 L p 0 .05 .17 r
F P
0 g
s
.57496 .55338 m .58811 .56828 L .60271 .55352 L p 0 .349 .781 r
F P
0 g
s
.60271 .55352 m .58961 .53864 L .57496 .55338 L p 0 .349 .781 r
F P
0 g
s
.58811 .56828 m .57496 .55338 L .58961 .53864 L p 0 .349 .781 r
F P
0 g
s
.58811 .56828 m .57496 .55338 L .58681 .54863 L p 0 .314 .945 r
F P
0 g
s
.60271 .55352 m .6158 .56838 L .62791 .56375 L p 0 .315 .944 r
F P
0 g
s
.62791 .56375 m .61474 .54878 L .60271 .55352 L p 0 .315 .944 r
F P
0 g
s
.60005 .56365 m .61474 .54878 L .60271 .55352 L p 0 .05 .17 r
F P
0 g
s
.60271 .55352 m .58811 .56828 L .60005 .56365 L p 0 .05 .17 r
F P
0 g
s
.58811 .56828 m .60271 .55352 L .61474 .54878 L p 0 .05 .17 r
F P
0 g
s
.58961 .53864 m .60271 .55352 L .58811 .56828 L p 0 .349 .781 r
F P
0 g
s
.61474 .54878 m .60005 .56365 L .58811 .56828 L p 0 .05 .17 r
F P
0 g
s
.57496 .55338 m .58811 .56828 L .60005 .56365 L p 0 .314 .945 r
F P
0 g
s
.60005 .56365 m .58681 .54863 L .57496 .55338 L p 0 .314 .945 r
F P
0 g
s
.56024 .56819 m .57496 .55338 L .58681 .54863 L p 0 .05 .154 r
F P
0 g
s
.57496 .55338 m .56024 .56819 L .57201 .56354 L p 0 .05 .154 r
F P
0 g
s
.58681 .54863 m .57201 .56354 L .56024 .56819 L p 0 .05 .154 r
F P
0 g
s
.54704 .55324 m .56024 .56819 L .57201 .56354 L p 0 .314 .946 r
F P
0 g
s
.57201 .56354 m .55872 .54847 L .54704 .55324 L p 0 .314 .946 r
F P
0 g
s
.53221 .5681 m .54704 .55324 L .55872 .54847 L p 0 .05 .139 r
F P
0 g
s
.54704 .55324 m .53221 .5681 L .5438 .56343 L p 0 .05 .139 r
F P
0 g
s
.52774 .54575 m .53381 .53827 L p .53221 .5681 L 0 .349 .781 r
F P
0 g
s
.55872 .54847 m .5438 .56343 L .53221 .5681 L p 0 .05 .139 r
F P
0 g
s
.52216 .55675 m .53221 .5681 L .5438 .56343 L p 0 .313 .947 r
F P
0 g
s
.53221 .5681 m .52216 .55675 L .51867 .56659 L p 0 .349 .781 r
F P
0 g
s
.52276 .55507 m .52216 .55675 L p .54704 .55324 L 0 .349 .781 r
F P
0 g
s
.52774 .54575 m .52276 .55507 L p .54704 .55324 L 0 .349 .781 r
F P
0 g
s
.53221 .5681 m .52216 .55675 L .53369 .55199 L p 0 .313 .947 r
F P
0 g
s
.51532 .58079 m .51867 .56659 L .53018 .5619 L p 0 .129 .614 r
F P
0 g
s
.55714 .57852 m .5422 .59358 L .5306 .59803 L p 0 .05 .154 r
F P
0 g
s
.5306 .59803 m .51731 .58303 L .52882 .57846 L p 0 .312 .948 r
F P
0 g
s
.52882 .57846 m .5422 .59358 L .5306 .59803 L p 0 .312 .948 r
F P
0 g
s
.5438 .56343 m .52882 .57846 L .51731 .58303 L p 0 .05 .139 r
F P
0 g
s
.51731 .58303 m .51532 .58079 L .52682 .5762 L p 0 .312 .948 r
F P
0 g
s
.52682 .5762 m .52882 .57846 L .51731 .58303 L p 0 .312 .948 r
F P
0 g
s
.53018 .5619 m .52682 .5762 L .51532 .58079 L p 0 .129 .614 r
F P
0 g
s
.55557 .60867 m .56744 .60427 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.57047 .59359 m .55756 .60666 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.55756 .60666 m .55557 .60867 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.61289 .62778 m .62502 .62359 L .61032 .63867 L p 0 .05 .212 r
F P
0 g
s
.61032 .63867 m .62502 .62359 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.64237 .66115 m .6547 .65722 L .62502 .62359 L p 0 .314 .946 r
F P
0 g
s
.6896 .63384 m .67707 .63793 L .64825 .66782 L p 0 .05 .248 r
F P
0 g
s
.64825 .66782 m .66063 .66393 L .6896 .63384 L p 0 .05 .248 r
F P
0 g
s
.66722 .65322 m .6547 .65722 L .62502 .62359 L p 0 .314 .946 r
F P
0 g
s
.63733 .61933 m .62502 .62359 L .6547 .65722 L p 0 .314 .946 r
F P
0 g
s
.62502 .62359 m .63733 .61933 L .66722 .65322 L p 0 .314 .946 r
F P
0 g
s
.61032 .63867 m .62502 .62359 L .63733 .61933 L p 0 .05 .212 r
F P
0 g
s
.63733 .61933 m .62255 .63452 L .61032 .63867 L p 0 .05 .212 r
F P
0 g
s
.62502 .62359 m .61032 .63867 L .62255 .63452 L p 0 .05 .212 r
F P
0 g
s
.61032 .63867 m .62255 .63452 L .6077 .64978 L p 0 .05 .212 r
F P
0 g
s
.6077 .64978 m .62255 .63452 L .61032 .63867 L p 0 .05 .212 r
F P
0 g
s
.65421 .59363 m .64192 .59803 L .65951 .618 L p 0 .315 .944 r
F P
0 g
s
.65951 .618 m .64192 .59803 L .64209 .62223 L closepath p 0 .349 .781 r
F P
0 g
s
.64209 .62223 m .64192 .59803 L .65951 .618 L closepath p 0 .349 .781 r
F P
0 g
s
.64209 .62223 m .64192 .59803 L .62744 .61287 L closepath p 0 .349 .781 r
F P
0 g
s
.62744 .61287 m .64192 .59803 L .64209 .62223 L closepath p 0 .349 .781 r
F P
0 g
s
.6547 .65722 m .66722 .65322 L .63733 .61933 L p 0 .314 .946 r
F P
0 g
s
.65205 .60421 m .66669 .58917 L .66689 .61372 L closepath p 0 .35 .78 r
F P
0 g
s
.65951 .618 m .67707 .63793 L .6896 .63384 L p 0 .315 .944 r
F P
0 g
s
.67707 .63793 m .65951 .618 L .64209 .62223 L p 0 .349 .781 r
F P
0 g
s
.6896 .63384 m .67192 .61376 L .65951 .618 L p 0 .315 .944 r
F P
0 g
s
.66689 .61372 m .6671 .63834 L .63733 .61933 L p 0 .35 .78 r
F P
0 g
s
.63733 .61933 m .65205 .60421 L .66689 .61372 L p 0 .35 .78 r
F P
0 g
s
.63733 .61933 m .6671 .63834 L .66722 .65322 L closepath p 0 .35 .78 r
F P
0 g
s
.66722 .65322 m .65349 .65243 L .63733 .61933 L closepath p 0 .35 .78 r
F P
0 g
s
.62255 .63452 m .63733 .61933 L .65349 .65243 L p 0 .35 .78 r
F P
0 g
s
.65349 .65243 m .63065 .65111 L .62255 .63452 L p 0 .35 .78 r
F P
0 g
s
.666 .59072 m .61091 .64733 L .61831 .64486 L p .257 0 0 r
F P
0 g
s
.62981 .60236 m .64192 .59803 L .62744 .61287 L p 0 .05 .212 r
F P
0 g
s
.62744 .61287 m .6154 .6171 L .62981 .60236 L p 0 .05 .212 r
F P
0 g
s
.62981 .60236 m .64192 .59803 L .62887 .58321 L p 0 .315 .944 r
F P
0 g
s
.62887 .58321 m .61685 .58766 L .62981 .60236 L p 0 .315 .944 r
F P
0 g
s
.62981 .60236 m .6154 .6171 L .62744 .61287 L p 0 .05 .212 r
F P
0 g
s
.62744 .61287 m .64192 .59803 L .62981 .60236 L p 0 .05 .212 r
F P
0 g
s
.61685 .58766 m .62887 .58321 L .6158 .56838 L p 0 .315 .944 r
F P
0 g
s
.6154 .6171 m .62744 .61287 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.61289 .62778 m .62744 .61287 L .6154 .6171 L p 0 .05 .212 r
F P
0 g
s
.63965 .60857 m .62744 .61287 L .64192 .59803 L p 0 .05 .212 r
F P
0 g
s
.64192 .59803 m .65421 .59363 L .63965 .60857 L p 0 .05 .212 r
F P
0 g
s
.62887 .58321 m .64192 .59803 L .65421 .59363 L p 0 .315 .944 r
F P
0 g
s
.65421 .59363 m .64192 .59803 L .62744 .61287 L p 0 .05 .212 r
F P
0 g
s
.64192 .59803 m .62887 .58321 L .61435 .59803 L p 0 .349 .781 r
F P
0 g
s
.61435 .59803 m .62744 .61287 L .64192 .59803 L p 0 .349 .781 r
F P
0 g
s
.64192 .59803 m .62744 .61287 L .61435 .59803 L p 0 .349 .781 r
F P
0 g
s
.61435 .59803 m .62887 .58321 L .64192 .59803 L p 0 .349 .781 r
F P
0 g
s
.65421 .59363 m .64107 .5787 L .62887 .58321 L p 0 .315 .944 r
F P
0 g
s
.6158 .56838 m .62887 .58321 L .64107 .5787 L p 0 .315 .944 r
F P
0 g
s
.62887 .58321 m .6158 .56838 L .60124 .58317 L p 0 .349 .781 r
F P
0 g
s
.60124 .58317 m .61435 .59803 L .62887 .58321 L p 0 .349 .781 r
F P
0 g
s
.62887 .58321 m .61435 .59803 L .60124 .58317 L p 0 .349 .781 r
F P
0 g
s
.60124 .58317 m .6158 .56838 L .62887 .58321 L p 0 .349 .781 r
F P
0 g
s
.64107 .5787 m .62791 .56375 L .6158 .56838 L p 0 .315 .944 r
F P
0 g
s
.58961 .53864 m .60271 .55352 L .61474 .54878 L p 0 .315 .944 r
F P
0 g
s
.62744 .61287 m .63965 .60857 L .62502 .62359 L p 0 .05 .212 r
F P
0 g
s
.62502 .62359 m .61289 .62778 L .62744 .61287 L p 0 .05 .212 r
F P
0 g
s
.62744 .61287 m .63965 .60857 L .65421 .59363 L p 0 .05 .212 r
F P
0 g
s
.63965 .60857 m .62744 .61287 L .61289 .62778 L p 0 .05 .212 r
F P
0 g
s
.62744 .61287 m .61435 .59803 L .59975 .61292 L p 0 .349 .781 r
F P
0 g
s
.59975 .61292 m .61289 .62778 L .62744 .61287 L p 0 .349 .781 r
F P
0 g
s
.62744 .61287 m .61289 .62778 L .59975 .61292 L p 0 .349 .781 r
F P
0 g
s
.59975 .61292 m .61435 .59803 L .62744 .61287 L p 0 .349 .781 r
F P
0 g
s
.61474 .54878 m .60154 .53379 L .58961 .53864 L p 0 .315 .944 r
F P
0 g
s
.57496 .55338 m .58961 .53864 L .60154 .53379 L p 0 .05 .154 r
F P
0 g
s
.58681 .54863 m .60154 .53379 L .58961 .53864 L p 0 .05 .154 r
F P
0 g
s
.57648 .52374 m .58961 .53864 L .60154 .53379 L p 0 .315 .944 r
F P
0 g
s
.61435 .59803 m .60124 .58317 L .5866 .59803 L p 0 .349 .781 r
F P
0 g
s
.5866 .59803 m .59975 .61292 L .61435 .59803 L p 0 .349 .781 r
F P
0 g
s
.61435 .59803 m .59975 .61292 L .5866 .59803 L p 0 .349 .781 r
F P
0 g
s
.5866 .59803 m .60124 .58317 L .61435 .59803 L p 0 .349 .781 r
F P
0 g
s
.60154 .53379 m .58833 .51877 L .57648 .52374 L p 0 .315 .944 r
F P
0 g
s
.61289 .62778 m .62502 .62359 L .63965 .60857 L p 0 .05 .212 r
F P
0 g
s
.59975 .61292 m .61289 .62778 L .62502 .62359 L p 0 .314 .946 r
F P
0 g
s
.62502 .62359 m .61289 .62778 L .59975 .61292 L p 0 .314 .946 r
F P
0 g
s
.60154 .53379 m .58681 .54863 L .57496 .55338 L p 0 .05 .154 r
F P
0 g
s
.62502 .62359 m .6118 .60861 L .59975 .61292 L p 0 .314 .946 r
F P
0 g
s
.5866 .59803 m .59975 .61292 L .6118 .60861 L p 0 .314 .946 r
F P
0 g
s
.6118 .60861 m .59975 .61292 L .5866 .59803 L p 0 .314 .946 r
F P
0 g
s
.59975 .61292 m .6118 .60861 L .62502 .62359 L p 0 .314 .946 r
F P
0 g
s
.6118 .60861 m .59855 .59361 L .5866 .59803 L p 0 .314 .946 r
F P
0 g
s
.5866 .59803 m .59855 .59361 L .6118 .60861 L p 0 .314 .946 r
F P
0 g
s
.65205 .60421 m .63965 .60857 L .65421 .59363 L p 0 .05 .212 r
F P
0 g
s
.65421 .59363 m .66669 .58917 L .65205 .60421 L p 0 .05 .212 r
F P
0 g
s
.64107 .5787 m .65421 .59363 L .66669 .58917 L p 0 .315 .944 r
F P
0 g
s
.66669 .58917 m .65421 .59363 L .63965 .60857 L p 0 .05 .212 r
F P
0 g
s
.66669 .58917 m .65346 .57413 L .64107 .5787 L p 0 .315 .944 r
F P
0 g
s
.62791 .56375 m .64107 .5787 L .65346 .57413 L p 0 .315 .944 r
F P
0 g
s
.65346 .57413 m .64021 .55906 L .62791 .56375 L p 0 .315 .944 r
F P
0 g
s
.61474 .54878 m .62791 .56375 L .64021 .55906 L p 0 .315 .944 r
F P
0 g
s
.64021 .55906 m .62694 .54397 L .61474 .54878 L p 0 .315 .944 r
F P
0 g
s
.62694 .54397 m .61474 .54878 L p .6144 .55012 L 0 .05 .17 r
F P
0 g
s
.61218 .55894 m .62498 .54596 L p .6144 .55012 L 0 .05 .17 r
F P
0 g
s
.62498 .54596 m .62694 .54397 L p .6144 .55012 L 0 .05 .17 r
F P
0 g
s
.60302 .51676 m .59874 .5144 L .58833 .51877 L p 0 .315 .944 r
F P
0 g
s
.61366 .52886 m .60302 .51676 L p .58833 .51877 L 0 .315 .944 r
F P
0 g
s
.66669 .58917 m .59736 .50995 L .66706 .58921 L .161 0 0 r
F
.66669 .58917 m .59702 .50994 L .59736 .50995 L F
.60154 .53379 m .61474 .54878 L .62694 .54397 L p 0 .315 .944 r
F P
0 g
s
.61474 .54878 m .60005 .56365 L .61218 .55894 L p 0 .05 .17 r
F P
0 g
s
.61474 .54878 m .62694 .54397 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.60005 .56365 m .61278 .55076 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.61278 .55076 m .61474 .54878 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.63965 .60857 m .65205 .60421 L .66474 .59117 L p 0 .05 .212 r
F P
0 g
s
.66474 .59117 m .66669 .58917 L p .66307 .59177 L 0 .05 .212 r
F P
0 g
s
.63965 .60857 m .66474 .59117 L .66307 .59177 L 0 .05 .212 r
F
.66669 .58917 m .65205 .60421 L .63878 .58914 L p 0 .35 .78 r
F P
0 g
s
.63878 .58914 m .65346 .57413 L .66669 .58917 L p 0 .35 .78 r
F P
0 g
s
.62694 .54397 m .61366 .52886 L .60154 .53379 L p 0 .315 .944 r
F P
0 g
s
.58833 .51877 m .60154 .53379 L .61366 .52886 L p 0 .315 .944 r
F P
0 g
s
.61474 .54878 m .60154 .53379 L .58681 .54863 L p 0 .349 .781 r
F P
0 g
s
.60154 .53379 m .61474 .54878 L .60005 .56365 L p 0 .349 .781 r
F P
0 g
s
.60005 .56365 m .58681 .54863 L .60154 .53379 L p 0 .349 .781 r
F P
0 g
s
.61366 .52886 m .60154 .53379 L p .60119 .53511 L 0 .05 .154 r
F P
0 g
s
.59885 .5438 m .61169 .53085 L p .60119 .53511 L 0 .05 .154 r
F P
0 g
s
.61169 .53085 m .61366 .52886 L p .60119 .53511 L 0 .05 .154 r
F P
0 g
s
.58681 .54863 m .60154 .53379 L .61366 .52886 L p 0 .05 .154 r
F P
0 g
s
.61218 .55894 m .60005 .56365 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.62694 .54397 m .62498 .54596 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.62498 .54596 m .61218 .55894 L p .62334 .5466 L 0 .05 .17 r
F P
0 g
s
.59885 .5438 m .58681 .54863 L p .61006 .53151 L 0 .05 .154 r
F P
0 g
s
.61366 .52886 m .61169 .53085 L p .61006 .53151 L 0 .05 .154 r
F P
0 g
s
.61169 .53085 m .59885 .5438 L p .61006 .53151 L 0 .05 .154 r
F P
0 g
s
.61218 .55894 m .62694 .54397 L .64021 .55906 L p 0 .35 .78 r
F P
0 g
s
.58681 .54863 m .60005 .56365 L .61474 .54878 L p 0 .349 .781 r
F P
0 g
s
.61366 .52886 m .62694 .54397 L .61218 .55894 L p 0 .35 .78 r
F P
0 g
s
.62317 .54131 m .61419 .53133 L .62621 .54548 L .888 0 0 r
F
.59874 .5144 m .60302 .51676 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.56481 .52863 m .57785 .54342 L .58961 .53864 L p 0 .315 .944 r
F P
0 g
s
.58961 .53864 m .57648 .52374 L .56481 .52863 L p 0 .315 .944 r
F P
0 g
s
.57496 .55338 m .58961 .53864 L .57785 .54342 L p 0 .05 .154 r
F P
0 g
s
.57648 .52374 m .58961 .53864 L .57496 .55338 L p 0 .349 .781 r
F P
0 g
s
.58961 .53864 m .57648 .52374 L .56179 .53846 L p 0 .349 .781 r
F P
0 g
s
.57496 .55338 m .56179 .53846 L .57648 .52374 L p 0 .349 .781 r
F P
0 g
s
.60154 .53379 m .58833 .51877 L .57356 .53359 L p 0 .349 .781 r
F P
0 g
s
.58961 .53864 m .57496 .55338 L .58681 .54863 L p 0 .05 .154 r
F P
0 g
s
.56179 .53846 m .57496 .55338 L .58961 .53864 L p 0 .349 .781 r
F P
0 g
s
.58833 .51877 m .60154 .53379 L .58681 .54863 L p 0 .349 .781 r
F P
0 g
s
.58681 .54863 m .57356 .53359 L .58833 .51877 L p 0 .349 .781 r
F P
0 g
s
.5839 .52931 m .59676 .51639 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.59676 .51639 m .59874 .5144 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.61218 .55894 m .59885 .5438 L .61366 .52886 L p 0 .35 .78 r
F P
0 g
s
.60154 .53379 m .58681 .54863 L .59885 .5438 L p 0 .05 .154 r
F P
0 g
s
.57356 .53359 m .58681 .54863 L .60154 .53379 L p 0 .349 .781 r
F P
0 g
s
.60302 .51676 m .61366 .52886 L .59885 .5438 L p 0 .35 .78 r
F P
0 g
s
.58817 .53168 m .5839 .52931 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.60302 .51676 m .60104 .51874 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.60104 .51874 m .58817 .53168 L p .60047 .51843 L 0 .275 .686 r
F P
0 g
s
.59885 .5438 m .58817 .53168 L .60302 .51676 L p 0 .35 .78 r
F P
0 g
s
.61138 .52821 m .59626 .51142 L .61291 .53035 L .888 0 0 r
F
.61138 .52821 m .61291 .53035 L .62621 .54548 L F
.61419 .53133 m .61138 .52821 L .62621 .54548 L F
.65346 .57413 m .63878 .58914 L .62548 .57405 L p 0 .35 .78 r
F P
0 g
s
.62548 .57405 m .64021 .55906 L .65346 .57413 L p 0 .35 .78 r
F P
0 g
s
.64021 .55906 m .62548 .57405 L .61218 .55894 L p 0 .35 .78 r
F P
0 g
s
.66706 .58921 m .59708 .51049 L .6668 .58978 L .977 0 0 r
F
.66706 .58921 m .59736 .50995 L .59708 .51049 L F
.6668 .58978 m .59708 .51049 L .59626 .51142 L .888 0 0 r
F
.60691 .52197 m .61291 .53035 L .61465 .52964 L .556 0 0 r
F
.59626 .51142 m .60425 .52051 L p .60691 .52197 L F P
0 g
s
.60425 .52051 m .61291 .53035 L p .60691 .52197 L .556 0 0 r
F P
0 g
s
.61291 .53035 m .60425 .52051 L .61524 .52941 L .556 0 0 r
F
.60425 .52051 m .59626 .51142 L .60806 .52261 L F
.60425 .52051 m .60806 .52261 L .61524 .52941 L F
.62317 .54131 m .62621 .54548 L .666 .59072 L .888 0 0 r
F
.6668 .58978 m .62317 .54131 L .666 .59072 L F
.62621 .54548 m .61291 .53035 L .63044 .54381 L .556 0 0 r
F
.61291 .53035 m .61524 .52941 L .63044 .54381 L F
.61465 .52964 m .62621 .54548 L .62938 .54423 L F
.61291 .53035 m .62621 .54548 L p .61465 .52964 L F P
0 g
s
.6668 .58978 m .666 .59072 L .67358 .58802 L .257 0 0 r
F
.666 .59072 m .66646 .59056 L p .6608 .58413 L .556 0 0 r
F P
0 g
s
.62938 .54423 m .6608 .58413 L .67358 .58802 L .556 0 0 r
F
.66646 .59056 m .67358 .58802 L p .6608 .58413 L F P
0 g
s
.62621 .54548 m .666 .59072 L p .62938 .54423 L .556 0 0 r
F P
0 g
s
.63044 .54381 m .59626 .51142 L .60355 .50834 L .556 0 0 r
F
.666 .59072 m .62621 .54548 L .63044 .54381 L F
.62502 .62359 m .63965 .60857 L .65205 .60421 L p 0 .05 .212 r
F P
0 g
s
.65205 .60421 m .63965 .60857 L .62502 .62359 L p 0 .05 .212 r
F P
0 g
s
.5839 .52931 m .59874 .5144 L .58833 .51877 L p 0 .05 .139 r
F P
0 g
s
.57356 .53359 m .58833 .51877 L .59874 .5144 L p 0 .05 .139 r
F P
0 g
s
.58635 .51653 m .58833 .51877 L .59874 .5144 L p 0 .315 .944 r
F P
0 g
s
.59874 .5144 m .59555 .51265 L .58635 .51653 L p 0 .315 .944 r
F P
0 g
s
.59885 .5438 m .61218 .55894 L .60005 .56365 L p 0 .314 .945 r
F P
0 g
s
.58681 .54863 m .60005 .56365 L .61218 .55894 L p 0 .314 .945 r
F P
0 g
s
.59734 .57398 m .61218 .55894 L .60005 .56365 L p 0 .05 .17 r
F P
0 g
s
.60005 .56365 m .58529 .57858 L .59734 .57398 L p 0 .05 .17 r
F P
0 g
s
.58529 .57858 m .60005 .56365 L .61218 .55894 L p 0 .05 .17 r
F P
0 g
s
.65205 .60421 m .63733 .61933 L .62502 .62359 L p 0 .05 .212 r
F P
0 g
s
.62255 .63452 m .63733 .61933 L .62502 .62359 L p 0 .05 .212 r
F P
0 g
s
.62502 .62359 m .63733 .61933 L .65205 .60421 L p 0 .05 .212 r
F P
0 g
s
.6118 .60861 m .62502 .62359 L .63733 .61933 L p 0 .314 .946 r
F P
0 g
s
.63733 .61933 m .62502 .62359 L .6118 .60861 L p 0 .314 .946 r
F P
0 g
s
.61218 .55894 m .59885 .5438 L .58681 .54863 L p 0 .314 .945 r
F P
0 g
s
.63733 .61933 m .62402 .60423 L .6118 .60861 L p 0 .314 .946 r
F P
0 g
s
.59855 .59361 m .6118 .60861 L .62402 .60423 L p 0 .314 .946 r
F P
0 g
s
.62402 .60423 m .6118 .60861 L .59855 .59361 L p 0 .314 .946 r
F P
0 g
s
.6118 .60861 m .62402 .60423 L .63733 .61933 L p 0 .314 .946 r
F P
0 g
s
.59874 .5144 m .5839 .52931 L .57356 .53359 L p 0 .05 .139 r
F P
0 g
s
.57343 .58312 m .5866 .59803 L .60124 .58317 L p 0 .349 .781 r
F P
0 g
s
.60124 .58317 m .5866 .59803 L .57343 .58312 L p 0 .349 .781 r
F P
0 g
s
.58529 .57858 m .59855 .59361 L .61069 .58911 L p 0 .314 .946 r
F P
0 g
s
.62402 .60423 m .61069 .58911 L .59855 .59361 L p 0 .314 .946 r
F P
0 g
s
.61069 .58911 m .59855 .59361 L .58529 .57858 L p 0 .314 .946 r
F P
0 g
s
.59855 .59361 m .61069 .58911 L .62402 .60423 L p 0 .314 .946 r
F P
0 g
s
.61069 .58911 m .59734 .57398 L .58529 .57858 L p 0 .314 .946 r
F P
0 g
s
.58529 .57858 m .59734 .57398 L .61069 .58911 L p 0 .314 .946 r
F P
0 g
s
.61218 .55894 m .59734 .57398 L .58529 .57858 L p 0 .05 .17 r
F P
0 g
s
.59555 .51265 m .59874 .5144 L .5839 .52931 L p 0 .275 .686 r
F P
0 g
s
.65205 .60421 m .63733 .61933 L .62402 .60423 L p 0 .35 .78 r
F P
0 g
s
.62402 .60423 m .63878 .58914 L .65205 .60421 L p 0 .35 .78 r
F P
0 g
s
.63878 .58914 m .62402 .60423 L .61069 .58911 L p 0 .35 .78 r
F P
0 g
s
.61069 .58911 m .62548 .57405 L .63878 .58914 L p 0 .35 .78 r
F P
0 g
s
.62548 .57405 m .61069 .58911 L .59734 .57398 L p 0 .35 .78 r
F P
0 g
s
.59734 .57398 m .61218 .55894 L .62548 .57405 L p 0 .35 .78 r
F P
0 g
s
.58681 .54863 m .60005 .56365 L .58811 .56828 L p 0 .314 .945 r
F P
0 g
s
.60005 .56365 m .58681 .54863 L .59885 .5438 L p 0 .314 .945 r
F P
0 g
s
.57201 .56354 m .58529 .57858 L .60005 .56365 L p 0 .349 .781 r
F P
0 g
s
.60005 .56365 m .58681 .54863 L .57201 .56354 L p 0 .349 .781 r
F P
0 g
s
.58681 .54863 m .60005 .56365 L .58529 .57858 L p 0 .349 .781 r
F P
0 g
s
.59885 .5438 m .61218 .55894 L .59734 .57398 L p 0 .35 .78 r
F P
0 g
s
.62402 .60423 m .63733 .61933 L .62255 .63452 L p 0 .35 .78 r
F P
0 g
s
.62255 .63452 m .60919 .6194 L .62402 .60423 L p 0 .35 .78 r
F P
0 g
s
.61069 .58911 m .62402 .60423 L .60919 .6194 L p 0 .35 .78 r
F P
0 g
s
.60919 .6194 m .59582 .60425 L .61069 .58911 L p 0 .35 .78 r
F P
0 g
s
.57343 .58312 m .5866 .59803 L .59855 .59361 L p 0 .314 .946 r
F P
0 g
s
.59855 .59361 m .5866 .59803 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.59855 .59361 m .58529 .57858 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.57343 .58312 m .58529 .57858 L .59855 .59361 L p 0 .314 .946 r
F P
0 g
s
.59734 .57398 m .61069 .58911 L .59582 .60425 L p 0 .35 .78 r
F P
0 g
s
.60919 .6194 m .62255 .63452 L .6077 .64978 L p 0 .35 .78 r
F P
0 g
s
.6077 .64978 m .5943 .63463 L .60919 .6194 L p 0 .35 .78 r
F P
0 g
s
.59582 .60425 m .60919 .6194 L .5943 .63463 L p 0 .35 .78 r
F P
0 g
s
.61091 .64733 m .666 .59072 L .59626 .51142 L p .858 0 0 r
F P
0 g
s
.55756 .60666 m .57047 .59359 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.57356 .53359 m .58681 .54863 L .57496 .55338 L p 0 .314 .945 r
F P
0 g
s
.57496 .55338 m .56179 .53846 L .57356 .53359 L p 0 .314 .945 r
F P
0 g
s
.57201 .56354 m .58681 .54863 L .57496 .55338 L p 0 .05 .154 r
F P
0 g
s
.56179 .53846 m .57496 .55338 L .58681 .54863 L p 0 .314 .945 r
F P
0 g
s
.58681 .54863 m .57356 .53359 L .56179 .53846 L p 0 .314 .945 r
F P
0 g
s
.57047 .59359 m .58529 .57858 L .57343 .58312 L p 0 .05 .17 r
F P
0 g
s
.57343 .58312 m .58529 .57858 L .57047 .59359 L p 0 .05 .17 r
F P
0 g
s
.57201 .56354 m .58529 .57858 L .57343 .58312 L p 0 .314 .946 r
F P
0 g
s
.55872 .54847 m .57201 .56354 L .56024 .56819 L p 0 .314 .946 r
F P
0 g
s
.55714 .57852 m .57201 .56354 L .56024 .56819 L p 0 .05 .154 r
F P
0 g
s
.58833 .51877 m .57356 .53359 L .5839 .52931 L p 0 .05 .139 r
F P
0 g
s
.57293 .51913 m .58635 .51653 L .59555 .51265 L p 0 .483 1 r
F P
0 g
s
.58817 .53168 m .59885 .5438 L .58681 .54863 L p 0 .314 .945 r
F P
0 g
s
.5839 .52931 m .58817 .53168 L p .58681 .54863 L 0 .314 .945 r
F P
0 g
s
.58681 .54863 m .57356 .53359 L .5839 .52931 L p 0 .314 .945 r
F P
0 g
s
.58529 .57858 m .57201 .56354 L .58681 .54863 L p 0 .349 .781 r
F P
0 g
s
.58681 .54863 m .57201 .56354 L .58396 .55881 L p 0 .05 .154 r
F P
0 g
s
.57356 .53359 m .58681 .54863 L .59885 .5438 L p 0 .314 .945 r
F P
0 g
s
.55872 .54847 m .57201 .56354 L .58681 .54863 L p 0 .349 .781 r
F P
0 g
s
.58681 .54863 m .57356 .53359 L .55872 .54847 L p 0 .349 .781 r
F P
0 g
s
.57356 .53359 m .58681 .54863 L .57201 .56354 L p 0 .349 .781 r
F P
0 g
s
.57201 .56354 m .58681 .54863 L .59885 .5438 L p 0 .05 .154 r
F P
0 g
s
.59555 .51265 m .57901 .51656 L .57293 .51913 L p 0 .483 1 r
F P
0 g
s
.56179 .53846 m .57648 .52374 L .56481 .52863 L p 0 .05 .139 r
F P
0 g
s
.56287 .52642 m .56481 .52863 L .57648 .52374 L p 0 .315 .944 r
F P
0 g
s
.5502 .54325 m .56481 .52863 L .57648 .52374 L p 0 .05 .139 r
F P
0 g
s
.57648 .52374 m .56179 .53846 L .5502 .54325 L p 0 .05 .139 r
F P
0 g
s
.57452 .52151 m .57648 .52374 L .56179 .53846 L p 0 .349 .781 r
F P
0 g
s
.56179 .53846 m .57648 .52374 L .58833 .51877 L p 0 .05 .139 r
F P
0 g
s
.57356 .53359 m .58833 .51877 L .57648 .52374 L p 0 .05 .139 r
F P
0 g
s
.57648 .52374 m .56179 .53846 L .57356 .53359 L p 0 .05 .139 r
F P
0 g
s
.56287 .52642 m .56481 .52863 L .5502 .54325 L p 0 .349 .781 r
F P
0 g
s
.56481 .52863 m .5502 .54325 L .56179 .53846 L p 0 .05 .139 r
F P
0 g
s
.54029 .53203 m .5502 .54325 L .56481 .52863 L p 0 .349 .781 r
F P
0 g
s
.56481 .52863 m .56287 .52642 L .5496 .52901 L p 0 .349 .781 r
F P
0 g
s
.5496 .52901 m .56287 .52642 L p .5502 .54325 L 0 .349 .781 r
F P
0 g
s
.55181 .52714 m .56179 .53846 L .57648 .52374 L p 0 .349 .781 r
F P
0 g
s
.57648 .52374 m .57452 .52151 L .56118 .52411 L p 0 .349 .781 r
F P
0 g
s
.56118 .52411 m .57452 .52151 L p .56179 .53846 L 0 .349 .781 r
F P
0 g
s
.58833 .51877 m .57356 .53359 L .56179 .53846 L p 0 .05 .139 r
F P
0 g
s
.57452 .52151 m .57648 .52374 L .58833 .51877 L p 0 .315 .944 r
F P
0 g
s
.56351 .52219 m .57356 .53359 L .58833 .51877 L p 0 .349 .781 r
F P
0 g
s
.58635 .51653 m .58833 .51877 L .57356 .53359 L p 0 .349 .781 r
F P
0 g
s
.57293 .51913 m .58635 .51653 L p .57356 .53359 L 0 .349 .781 r
F P
0 g
s
.57356 .53359 m .56351 .52219 L .57293 .51913 L p 0 .349 .781 r
F P
0 g
s
.56351 .52219 m .57293 .51913 L .57901 .51656 L p 0 .462 .885 r
F P
0 g
s
.57901 .51656 m .56779 .52037 L .56351 .52219 L p 0 .462 .885 r
F P
0 g
s
.5839 .52931 m .57356 .53359 L p .57166 .52923 L 0 .314 .945 r
F P
0 g
s
.56779 .52037 m .57857 .52635 L p .57166 .52923 L 0 .314 .945 r
F P
0 g
s
.57857 .52635 m .5839 .52931 L p .57166 .52923 L 0 .314 .945 r
F P
0 g
s
.57201 .56354 m .55872 .54847 L .57356 .53359 L p 0 .349 .781 r
F P
0 g
s
.58817 .53168 m .5839 .52931 L .57356 .53359 L p 0 .314 .945 r
F P
0 g
s
.59885 .5438 m .58817 .53168 L p .57356 .53359 L 0 .314 .945 r
F P
0 g
s
.55872 .54847 m .57356 .53359 L .5839 .52931 L p 0 .05 .139 r
F P
0 g
s
.56898 .54428 m .5839 .52931 L .57356 .53359 L p 0 .05 .139 r
F P
0 g
s
.57356 .53359 m .55872 .54847 L .56898 .54428 L p 0 .05 .139 r
F P
0 g
s
.57356 .53359 m .5839 .52931 L p .57714 .52695 L 0 .314 .945 r
F P
0 g
s
.56351 .52219 m .57024 .52982 L p .57714 .52695 L 0 .314 .945 r
F P
0 g
s
.57024 .52982 m .57356 .53359 L p .57714 .52695 L 0 .314 .945 r
F P
0 g
s
.5839 .52931 m .56779 .52037 L .56351 .52219 L p 0 .314 .945 r
F P
0 g
s
.58529 .57858 m .57047 .59359 L .58242 .58909 L p 0 .05 .17 r
F P
0 g
s
.58242 .58909 m .57047 .59359 L .58529 .57858 L p 0 .05 .17 r
F P
0 g
s
.58529 .57858 m .57201 .56354 L .58396 .55881 L p 0 .314 .946 r
F P
0 g
s
.57201 .56354 m .58529 .57858 L .59734 .57398 L p 0 .314 .946 r
F P
0 g
s
.55714 .57852 m .57047 .59359 L .58529 .57858 L p 0 .349 .781 r
F P
0 g
s
.58529 .57858 m .57201 .56354 L .55714 .57852 L p 0 .349 .781 r
F P
0 g
s
.57201 .56354 m .58529 .57858 L .57047 .59359 L p 0 .349 .781 r
F P
0 g
s
.59885 .5438 m .58396 .55881 L .57201 .56354 L p 0 .05 .154 r
F P
0 g
s
.57325 .54667 m .58396 .55881 L .57201 .56354 L p 0 .314 .946 r
F P
0 g
s
.56898 .54428 m .57325 .54667 L p .57201 .56354 L 0 .314 .946 r
F P
0 g
s
.57201 .56354 m .55872 .54847 L .56898 .54428 L p 0 .314 .946 r
F P
0 g
s
.59734 .57398 m .58396 .55881 L .57201 .56354 L p 0 .314 .946 r
F P
0 g
s
.57047 .59359 m .55714 .57852 L .57201 .56354 L p 0 .349 .781 r
F P
0 g
s
.55714 .57852 m .57201 .56354 L .58396 .55881 L p 0 .05 .154 r
F P
0 g
s
.57201 .56354 m .55714 .57852 L .56901 .5739 L p 0 .05 .154 r
F P
0 g
s
.56901 .5739 m .58396 .55881 L .57201 .56354 L p 0 .05 .154 r
F P
0 g
s
.55872 .54847 m .57201 .56354 L .58396 .55881 L p 0 .314 .946 r
F P
0 g
s
.5438 .56343 m .55714 .57852 L .57201 .56354 L p 0 .349 .781 r
F P
0 g
s
.57201 .56354 m .55872 .54847 L .5438 .56343 L p 0 .349 .781 r
F P
0 g
s
.55872 .54847 m .57201 .56354 L .55714 .57852 L p 0 .349 .781 r
F P
0 g
s
.5839 .52931 m .56898 .54428 L .55872 .54847 L p 0 .05 .139 r
F P
0 g
s
.54704 .55324 m .56179 .53846 L .57356 .53359 L p 0 .05 .139 r
F P
0 g
s
.55872 .54847 m .57356 .53359 L .56179 .53846 L p 0 .05 .139 r
F P
0 g
s
.56179 .53846 m .54704 .55324 L .55872 .54847 L p 0 .05 .139 r
F P
0 g
s
.57356 .53359 m .55872 .54847 L .54704 .55324 L p 0 .05 .139 r
F P
0 g
s
.5502 .54325 m .54029 .53203 L .5496 .52901 L p 0 .349 .781 r
F P
0 g
s
.55181 .52714 m .56179 .53846 L .5502 .54325 L p 0 .314 .945 r
F P
0 g
s
.5502 .54325 m .54029 .53203 L .55181 .52714 L p 0 .314 .945 r
F P
0 g
s
.54704 .55324 m .56179 .53846 L .5502 .54325 L p 0 .05 .139 r
F P
0 g
s
.54029 .53203 m .5502 .54325 L .56179 .53846 L p 0 .314 .945 r
F P
0 g
s
.56179 .53846 m .55181 .52714 L .54029 .53203 L p 0 .314 .945 r
F P
0 g
s
.56179 .53846 m .55181 .52714 L .56118 .52411 L p 0 .349 .781 r
F P
0 g
s
.5502 .54325 m .54029 .53203 L .5387 .53254 L p 0 .349 .781 r
F P
0 g
s
.55181 .52714 m .56179 .53846 L .54704 .55324 L p 0 .349 .781 r
F P
0 g
s
.56351 .52219 m .57356 .53359 L .56179 .53846 L p 0 .314 .945 r
F P
0 g
s
.56179 .53846 m .55181 .52714 L .56351 .52219 L p 0 .314 .945 r
F P
0 g
s
.55181 .52714 m .56179 .53846 L .57356 .53359 L p 0 .314 .945 r
F P
0 g
s
.53381 .53827 m .54704 .55324 L .56179 .53846 L p 0 .349 .781 r
F P
0 g
s
.54121 .53232 m .53381 .53827 L p .56179 .53846 L 0 .349 .781 r
F P
0 g
s
.5387 .53254 m .54029 .53203 L .55181 .52714 L p 0 .462 .885 r
F P
0 g
s
.55181 .52714 m .55021 .52766 L .5387 .53254 L p 0 .462 .885 r
F P
0 g
s
.55021 .52766 m .54121 .53232 L p .56179 .53846 L 0 .349 .781 r
F P
0 g
s
.56179 .53846 m .55181 .52714 L .55021 .52766 L p 0 .349 .781 r
F P
0 g
s
.55021 .52766 m .55181 .52714 L p .54704 .55324 L 0 .349 .781 r
F P
0 g
s
.54121 .53232 m .55021 .52766 L p .54704 .55324 L 0 .349 .781 r
F P
0 g
s
.5454 .53339 m .55872 .54847 L .57356 .53359 L p 0 .349 .781 r
F P
0 g
s
.57356 .53359 m .56351 .52219 L .55181 .52714 L p 0 .314 .945 r
F P
0 g
s
.56351 .52219 m .57356 .53359 L .55872 .54847 L p 0 .349 .781 r
F P
0 g
s
.55021 .52766 m .55181 .52714 L .56351 .52219 L p 0 .462 .885 r
F P
0 g
s
.56351 .52219 m .5619 .52271 L .55021 .52766 L p 0 .462 .885 r
F P
0 g
s
.5619 .52271 m .56351 .52219 L p .55872 .54847 L 0 .349 .781 r
F P
0 g
s
.55284 .5274 m .5619 .52271 L p .55872 .54847 L 0 .349 .781 r
F P
0 g
s
.55872 .54847 m .5454 .53339 L .55284 .5274 L p 0 .349 .781 r
F P
0 g
s
.56898 .54428 m .55872 .54847 L p .55598 .54446 L 0 .314 .946 r
F P
0 g
s
.55284 .5274 m .5454 .53339 L p .57356 .53359 L 0 .349 .781 r
F P
0 g
s
.54774 .5324 m .56365 .5413 L p .55598 .54446 L 0 .314 .946 r
F P
0 g
s
.56365 .5413 m .56898 .54428 L p .55598 .54446 L 0 .314 .946 r
F P
0 g
s
.56898 .54428 m .55872 .54847 L p .58396 .55881 L 0 .314 .946 r
F P
0 g
s
.55714 .57852 m .5438 .56343 L .55872 .54847 L p 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .55872 .54847 L .56898 .54428 L p 0 .05 .139 r
F P
0 g
s
.55872 .54847 m .5438 .56343 L .554 .55933 L p 0 .05 .139 r
F P
0 g
s
.554 .55933 m .56898 .54428 L .55872 .54847 L p 0 .05 .139 r
F P
0 g
s
.55872 .54847 m .56898 .54428 L p .56306 .54154 L 0 .314 .946 r
F P
0 g
s
.5454 .53339 m .55539 .5447 L p .56306 .54154 L 0 .314 .946 r
F P
0 g
s
.55539 .5447 m .55872 .54847 L p .56306 .54154 L 0 .314 .946 r
F P
0 g
s
.56898 .54428 m .54774 .5324 L .5454 .53339 L p 0 .314 .946 r
F P
0 g
s
.58833 .51877 m .58635 .51653 L .57293 .51913 L p 0 .349 .781 r
F P
0 g
s
.57901 .51656 m .59555 .51265 L p .5839 .52931 L 0 .275 .686 r
F P
0 g
s
.5839 .52931 m .56779 .52037 L .57901 .51656 L p 0 .275 .686 r
F P
0 g
s
.57356 .53359 m .56351 .52219 L .56779 .52037 L p 0 .314 .945 r
F P
0 g
s
.5619 .52271 m .55284 .5274 L p .57356 .53359 L 0 .349 .781 r
F P
0 g
s
.57356 .53359 m .56351 .52219 L .5619 .52271 L p 0 .349 .781 r
F P
0 g
s
.56779 .52037 m .5839 .52931 L .56898 .54428 L p 0 .275 .686 r
F P
0 g
s
.5619 .52271 m .56351 .52219 L .56779 .52037 L p 0 .462 .885 r
F P
0 g
s
.56779 .52037 m .56587 .52102 L .5619 .52271 L p 0 .462 .885 r
F P
0 g
s
.56587 .52102 m .56779 .52037 L p .56898 .54428 L 0 .275 .686 r
F P
0 g
s
.55558 .52623 m .56587 .52102 L p .56898 .54428 L 0 .275 .686 r
F P
0 g
s
.58242 .58909 m .57047 .59359 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.56744 .60427 m .56944 .60224 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.56944 .60224 m .58242 .58909 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.59582 .60425 m .58242 .58909 L .59734 .57398 L p 0 .35 .78 r
F P
0 g
s
.5943 .63463 m .58088 .61946 L .59582 .60425 L p 0 .35 .78 r
F P
0 g
s
.58242 .58909 m .59582 .60425 L .58088 .61946 L p 0 .35 .78 r
F P
0 g
s
.58088 .61946 m .56744 .60427 L .58242 .58909 L p 0 .35 .78 r
F P
0 g
s
.57064 .6018 m .61091 .64733 L p .60252 .56949 L .858 0 0 r
F P
0 g
s
.61091 .64733 m .61831 .64486 L .57787 .59911 L .54 0 0 r
F
.57047 .59359 m .58242 .58909 L .56944 .60224 L p 0 .05 .17 r
F P
0 g
s
.56944 .60224 m .56744 .60427 L p .56785 .60283 L 0 .05 .17 r
F P
0 g
s
.57047 .59359 m .56944 .60224 L .56785 .60283 L 0 .05 .17 r
F
.55714 .57852 m .57047 .59359 L .58242 .58909 L p 0 .313 .947 r
F P
0 g
s
.5422 .59358 m .55557 .60867 L .57047 .59359 L p 0 .349 .781 r
F P
0 g
s
.57047 .59359 m .55714 .57852 L .5422 .59358 L p 0 .349 .781 r
F P
0 g
s
.55714 .57852 m .57047 .59359 L .55557 .60867 L p 0 .349 .781 r
F P
0 g
s
.57047 .59359 m .55714 .57852 L .56901 .5739 L p 0 .313 .947 r
F P
0 g
s
.56901 .5739 m .58242 .58909 L .57047 .59359 L p 0 .313 .947 r
F P
0 g
s
.56898 .54428 m .54774 .5324 L .55558 .52623 L p 0 .275 .686 r
F P
0 g
s
.58242 .58909 m .56901 .5739 L .55714 .57852 L p 0 .313 .947 r
F P
0 g
s
.55557 .60867 m .5422 .59358 L .55714 .57852 L p 0 .349 .781 r
F P
0 g
s
.5422 .59358 m .55714 .57852 L .56901 .5739 L p 0 .05 .154 r
F P
0 g
s
.5422 .59358 m .55398 .58906 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.55714 .57852 m .5442 .59157 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.5442 .59157 m .5422 .59358 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.56901 .5739 m .55714 .57852 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.55398 .58906 m .55599 .58703 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.55599 .58703 m .56901 .5739 L p .55441 .58764 L 0 .05 .154 r
F P
0 g
s
.58396 .55881 m .56901 .5739 L .55714 .57852 L p 0 .05 .154 r
F P
0 g
s
.5438 .56343 m .55714 .57852 L .56901 .5739 L p 0 .313 .947 r
F P
0 g
s
.52882 .57846 m .5422 .59358 L .55714 .57852 L p 0 .349 .781 r
F P
0 g
s
.55714 .57852 m .5438 .56343 L .52882 .57846 L p 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .55714 .57852 L .5422 .59358 L p 0 .349 .781 r
F P
0 g
s
.55714 .57852 m .5438 .56343 L .554 .55933 L p 0 .313 .947 r
F P
0 g
s
.56901 .5739 m .55714 .57852 L p .554 .55933 L 0 .313 .947 r
F P
0 g
s
.5454 .53339 m .55872 .54847 L .54704 .55324 L p 0 .314 .946 r
F P
0 g
s
.5438 .56343 m .55872 .54847 L .54704 .55324 L p 0 .05 .139 r
F P
0 g
s
.54704 .55324 m .53381 .53827 L .54121 .53232 L p 0 .349 .781 r
F P
0 g
s
.53381 .53827 m .54704 .55324 L .55872 .54847 L p 0 .314 .946 r
F P
0 g
s
.55872 .54847 m .5454 .53339 L .53381 .53827 L p 0 .314 .946 r
F P
0 g
s
.55872 .54847 m .5454 .53339 L .54774 .5324 L p 0 .314 .946 r
F P
0 g
s
.54704 .55324 m .53381 .53827 L .5454 .53339 L p 0 .314 .946 r
F P
0 g
s
.54704 .55324 m .53381 .53827 L .52774 .54575 L p 0 .349 .781 r
F P
0 g
s
.53369 .55199 m .5438 .56343 L .55872 .54847 L p 0 .349 .781 r
F P
0 g
s
.53429 .5503 m .53369 .55199 L p .55872 .54847 L 0 .349 .781 r
F P
0 g
s
.5393 .54092 m .53429 .5503 L p .55872 .54847 L 0 .349 .781 r
F P
0 g
s
.55872 .54847 m .5454 .53339 L .5393 .54092 L p 0 .349 .781 r
F P
0 g
s
.5454 .53339 m .55872 .54847 L .5438 .56343 L p 0 .349 .781 r
F P
0 g
s
.56898 .54428 m .554 .55933 L .5438 .56343 L p 0 .05 .139 r
F P
0 g
s
.54774 .5324 m .56898 .54428 L .554 .55933 L p 0 .275 .686 r
F P
0 g
s
.5393 .54092 m .5454 .53339 L p .5438 .56343 L 0 .349 .781 r
F P
0 g
s
.54202 .53978 m .54774 .5324 L p .554 .55933 L 0 .275 .686 r
F P
0 g
s
.554 .55933 m .5438 .56343 L p .56901 .5739 L 0 .313 .947 r
F P
0 g
s
.5422 .59358 m .52882 .57846 L .5438 .56343 L p 0 .349 .781 r
F P
0 g
s
.52882 .57846 m .5438 .56343 L .554 .55933 L p 0 .05 .139 r
F P
0 g
s
.5438 .56343 m .52882 .57846 L .53894 .57445 L p 0 .05 .139 r
F P
0 g
s
.53894 .57445 m .554 .55933 L .5438 .56343 L p 0 .05 .139 r
F P
0 g
s
.5438 .56343 m .554 .55933 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.53429 .5503 m .5393 .54092 L p .5438 .56343 L 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .53369 .55199 L .53429 .5503 L p 0 .349 .781 r
F P
0 g
s
.53369 .55199 m .54047 .55965 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.54047 .55965 m .5438 .56343 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.554 .55933 m .5438 .56343 L p .54186 .55909 L 0 .313 .947 r
F P
0 g
s
.53791 .55025 m .54867 .55632 L p .54186 .55909 L 0 .313 .947 r
F P
0 g
s
.54867 .55632 m .554 .55933 L p .54186 .55909 L 0 .313 .947 r
F P
0 g
s
.53791 .55025 m .53369 .55199 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.554 .55933 m .54867 .55632 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.54867 .55632 m .53791 .55025 L p .54726 .55689 L 0 .313 .947 r
F P
0 g
s
.53821 .54868 m .54202 .53978 L p .554 .55933 L 0 .275 .686 r
F P
0 g
s
.55398 .58906 m .5422 .59358 L p .54576 .59096 L 0 .05 .154 r
F P
0 g
s
.56901 .5739 m .55599 .58703 L p .54576 .59096 L 0 .05 .154 r
F P
0 g
s
.55599 .58703 m .55398 .58906 L p .54576 .59096 L 0 .05 .154 r
F P
0 g
s
.56898 .54428 m .5839 .52931 L .58817 .53168 L p 0 .275 .686 r
F P
0 g
s
.58396 .55881 m .59885 .5438 L .58681 .54863 L p 0 .05 .154 r
F P
0 g
s
.58817 .53168 m .59885 .5438 L .58396 .55881 L p 0 .35 .78 r
F P
0 g
s
.58817 .53168 m .57325 .54667 L .56898 .54428 L p 0 .275 .686 r
F P
0 g
s
.58396 .55881 m .57325 .54667 L .58817 .53168 L p 0 .35 .78 r
F P
0 g
s
.58396 .55881 m .57325 .54667 L .56898 .54428 L p 0 .314 .946 r
F P
0 g
s
.58242 .58909 m .56901 .5739 L .58396 .55881 L p 0 .35 .78 r
F P
0 g
s
.57325 .54667 m .58396 .55881 L .56901 .5739 L p 0 .35 .78 r
F P
0 g
s
.56901 .5739 m .55826 .56173 L .57325 .54667 L p 0 .35 .78 r
F P
0 g
s
.56785 .60283 m .56744 .60427 L .55756 .60666 L 0 .05 .17 r
F
.56901 .5739 m .58242 .58909 L .56744 .60427 L p 0 .35 .78 r
F P
0 g
s
.56901 .5739 m .55826 .56173 L .554 .55933 L p 0 .313 .947 r
F P
0 g
s
.554 .55933 m .55826 .56173 L .56901 .5739 L p 0 .313 .947 r
F P
0 g
s
.56744 .60427 m .55398 .58906 L .56901 .5739 L p 0 .35 .78 r
F P
0 g
s
.55826 .56173 m .56901 .5739 L .55398 .58906 L p 0 .35 .78 r
F P
0 g
s
.59626 .51142 m .55718 .58658 L .57064 .6018 L .858 0 0 r
F
.554 .55933 m .53894 .57445 L .52882 .57846 L p 0 .05 .139 r
F P
0 g
s
.554 .55933 m .53791 .55025 L .53821 .54868 L p 0 .275 .686 r
F P
0 g
s
.53369 .55199 m .5438 .56343 L .53221 .5681 L p 0 .313 .947 r
F P
0 g
s
.5438 .56343 m .53369 .55199 L .52216 .55675 L p 0 .313 .947 r
F P
0 g
s
.52682 .5762 m .52882 .57846 L .5438 .56343 L p 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .53741 .56271 L .52682 .5762 L 0 .349 .781 r
F
.53018 .5619 m .52771 .57244 L p .53741 .56271 L F P
0 g
s
.52771 .57244 m .52682 .5762 L p .53741 .56271 L 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .53369 .55199 L .53018 .5619 L p 0 .349 .781 r
F P
0 g
s
.5438 .56343 m .52882 .57846 L p .53043 .56971 L 0 .349 .781 r
F P
0 g
s
.53369 .55199 m .54047 .55965 L p .53043 .56971 L 0 .349 .781 r
F P
0 g
s
.54047 .55965 m .5438 .56343 L p .53043 .56971 L 0 .349 .781 r
F P
0 g
s
.56744 .60427 m .55557 .60867 L .55756 .60666 L p 0 .05 .17 r
F P
0 g
s
.56891 .62375 m .58088 .61946 L .5943 .63463 L p 0 .312 .948 r
F P
0 g
s
.58088 .61946 m .56891 .62375 L .55557 .60867 L p 0 .312 .948 r
F P
0 g
s
.55557 .60867 m .56744 .60427 L .58088 .61946 L p 0 .312 .948 r
F P
0 g
s
.55557 .60867 m .5422 .59358 L .55398 .58906 L p 0 .312 .948 r
F P
0 g
s
.55398 .58906 m .56744 .60427 L .55557 .60867 L p 0 .312 .948 r
F P
0 g
s
.5422 .59358 m .52882 .57846 L .53894 .57445 L p 0 .312 .948 r
F P
0 g
s
.55398 .58906 m .5422 .59358 L p .53894 .57445 L 0 .312 .948 r
F P
0 g
s
.53894 .57445 m .5432 .57687 L .55398 .58906 L p 0 .312 .948 r
F P
0 g
s
.6077 .64978 m .5432 .57687 L p .49151 .58826 L .539 0 0 r
F P
0 g
s
.5438 .56343 m .53369 .55199 L .53791 .55025 L p 0 .313 .947 r
F P
0 g
s
.53791 .55025 m .554 .55933 L .53894 .57445 L p 0 .275 .686 r
F P
0 g
s
.53018 .5619 m .53369 .55199 L p .53043 .56971 L 0 .349 .781 r
F P
0 g
s
.52882 .57846 m .52946 .57068 L .53043 .56971 L 0 .349 .781 r
F
.52946 .57068 m .53018 .5619 L .53043 .56971 L F
.52882 .57846 m .52682 .5762 L .53018 .5619 L p F P
0 g
s
.53614 .55948 m .53576 .57264 L .52682 .5762 L p 0 .129 .614 r
F P
0 g
s
.52682 .5762 m .53018 .5619 L .53614 .55948 L p 0 .129 .614 r
F P
0 g
s
.53362 .57142 m .49151 .58826 L p .50282 .58577 L .539 0 0 r
F P
0 g
s
.52882 .57846 m .52682 .5762 L .53576 .57264 L p 0 .312 .948 r
F P
0 g
s
.53576 .57264 m .53894 .57445 L .52882 .57846 L p 0 .312 .948 r
F P
0 g
s
.50282 .58577 m .5432 .57687 L .53576 .57264 L .539 0 0 r
F
.50282 .58577 m .53576 .57264 L .53362 .57142 L F
.51199 .58127 m .52447 .57568 L .508 .58526 L .183 0 0 r
F
.53894 .57445 m .53576 .57264 L .53586 .56917 L p 0 .275 .686 r
F P
0 g
s
.53586 .56917 m .53614 .55948 L p .53762 .5674 L 0 .275 .686 r
F P
0 g
s
.53894 .57445 m .53586 .56917 L .53762 .5674 L 0 .275 .686 r
F
.52447 .57568 m .53331 .57172 L .52246 .57769 L .183 0 0 r
F
.53331 .57172 m .53713 .57001 L .53271 .57233 L F
.53331 .57172 m .53271 .57233 L .52246 .57769 L F
.53378 .57151 m .53713 .57001 L .53362 .57142 L p .539 0 0 r
F P
0 g
s
.53614 .55948 m .53791 .55025 L p .53894 .57445 L 0 .275 .686 r
F P
0 g
s
.53894 .57445 m .554 .55933 L .55826 .56173 L p 0 .275 .686 r
F P
0 g
s
.5432 .57687 m .53894 .57445 L p .54152 .57275 L 0 .275 .686 r
F P
0 g
s
.55826 .56173 m .54522 .57485 L p .54152 .57275 L 0 .275 .686 r
F P
0 g
s
.54522 .57485 m .5432 .57687 L p .54152 .57275 L 0 .275 .686 r
F P
0 g
s
.554 .55933 m .56898 .54428 L .57325 .54667 L p 0 .275 .686 r
F P
0 g
s
.57325 .54667 m .55826 .56173 L .554 .55933 L p 0 .275 .686 r
F P
0 g
s
.55398 .58906 m .5432 .57687 L .55826 .56173 L p 0 .35 .78 r
F P
0 g
s
.59626 .51142 m .54033 .56752 L .55718 .58658 L p .858 0 0 r
F P
0 g
s
.55718 .58658 m .54842 .57667 L p .55888 .58592 L .54 0 0 r
F P
0 g
s
.54842 .57667 m .54033 .56752 L p .55107 .57818 L .54 0 0 r
F P
0 g
s
.55107 .57818 m .55888 .58592 L .54842 .57667 L .54 0 0 r
F
.53713 .57001 m .53401 .57164 L p .5432 .57687 L .539 0 0 r
F P
0 g
s
.52447 .57568 m .52246 .57769 L .508 .58526 L .183 0 0 r
F
.51644 .58373 m .53713 .57001 L .52502 .58216 L F
.508 .58526 m .52246 .57769 L .51644 .58373 L F
.52246 .57769 m .53713 .57001 L .51644 .58373 L F
.51398 .57927 m .52547 .57468 L p .51199 .58127 L F P
0 g
s
.52547 .57468 m .53713 .57001 L p .52447 .57568 L .183 0 0 r
F P
0 g
s
.52547 .57468 m .52447 .57568 L .51199 .58127 L .183 0 0 r
F
.58242 .58909 m .59734 .57398 L .58529 .57858 L p 0 .05 .17 r
F P
0 g
s
.58529 .57858 m .59734 .57398 L .58242 .58909 L p 0 .05 .17 r
F P
0 g
s
.58396 .55881 m .59734 .57398 L .58529 .57858 L p 0 .314 .946 r
F P
0 g
s
.59734 .57398 m .58396 .55881 L .59885 .5438 L p 0 .35 .78 r
F P
0 g
s
.58396 .55881 m .59734 .57398 L .58242 .58909 L p 0 .35 .78 r
F P
0 g
s
.59626 .51142 m .57064 .6018 L .60252 .56949 L .858 0 0 r
F
.57064 .6018 m .55718 .58658 L p .57373 .60065 L .54 0 0 r
F P
0 g
s
.55888 .58592 m .57373 .60065 L .55718 .58658 L .54 0 0 r
F
.59061 .52133 m .56055 .5515 L p .58504 .52365 L .183 0 0 r
F P
0 g
s
.56055 .5515 m .54743 .56467 L p .55888 .55218 L .183 0 0 r
F P
0 g
s
.58504 .52365 m .56055 .5515 L .55888 .55218 L .183 0 0 r
F
.57092 .53831 m .55838 .55238 L .56842 .53934 L F
.55838 .55238 m .54743 .56467 L .55722 .55285 L F
.55838 .55238 m .55722 .55285 L .56842 .53934 L F
.54743 .56467 m .54033 .56752 L p .5534 .5544 L F P
0 g
s
.56842 .53934 m .55722 .55285 L .5534 .5544 L .183 0 0 r
F
.55722 .55285 m .54743 .56467 L .5534 .5544 L F
.57207 .59676 m .56264 .58448 L .57064 .6018 L .54 0 0 r
F
.57476 .60027 m .57207 .59676 L .57064 .6018 L F
.56264 .58448 m .54743 .56467 L .56036 .58535 L F
.56264 .58448 m .56036 .58535 L .57064 .6018 L F
.55718 .58658 m .54743 .56467 L .54033 .56752 L F
.57064 .6018 m .56036 .58535 L .55718 .58658 L F
.56036 .58535 m .54743 .56467 L .55718 .58658 L F
.57207 .59676 m .57297 .59357 L .54743 .56467 L F
.57476 .60027 m .57297 .59357 L .57207 .59676 L F
.57476 .60027 m .57787 .59911 L .57297 .59357 L F
.61091 .64733 m .57787 .59911 L .57476 .60027 L F
.58504 .52365 m .57201 .53786 L .58336 .52435 L .183 0 0 r
F
.57201 .53786 m .54743 .56467 L .57092 .53831 L F
.57201 .53786 m .57092 .53831 L .58336 .52435 L F
.58336 .52435 m .57092 .53831 L .56842 .53934 L F
.67358 .58802 m .60355 .50834 L .59626 .51142 L p .556 0 0 r
F P
0 g
s
.59626 .51142 m .60355 .50834 L .59061 .52133 L p .183 0 0 r
F P
0 g
s
.59626 .51142 m .59061 .52133 L .58504 .52365 L .183 0 0 r
F
.58336 .52435 m .59626 .51142 L p .58504 .52365 L F P
0 g
s
.61091 .64733 m .57476 .60027 L .57064 .6018 L .54 0 0 r
F
.61831 .64486 m .61091 .64733 L .57064 .6018 L p F P
0 g
s
.57373 .60065 m .61831 .64486 L .57064 .6018 L .54 0 0 r
F
.50266 .5838 m .51398 .57927 L .49969 .58678 L .183 0 0 r
F
.51398 .57927 m .51199 .58127 L .49969 .58678 L F
.49969 .58678 m .51199 .58127 L .508 .58526 L F
.49151 .58826 m .50266 .5838 L p .49969 .58678 L F P
0 g
s
.49395 .58782 m .49969 .58678 L .48297 .59878 L .183 0 0 r
F
.52502 .58216 m .49075 .59571 L p .49969 .58678 L F P
0 g
s
.49075 .59571 m .48297 .59878 L p .49969 .58678 L .183 0 0 r
F P
0 g
s
.49151 .58826 m .49395 .58782 L .4927 .58889 L .183 0 0 r
F
.49151 .58826 m .4927 .58889 L .47967 .60009 L F
.48297 .59878 m .47967 .60009 L p .49395 .58782 L F P
0 g
s
.58357 .65782 m .6077 .64978 L .59576 .66204 L p 0 .05 .212 r
F P
0 g
s
.6077 .64978 m .56647 .61607 L .59576 .66204 L .858 0 0 r
F
.56647 .61607 m .52502 .58216 L .56046 .62218 L F
.56647 .61607 m .56046 .62218 L .59576 .66204 L F
.52502 .58216 m .53713 .57001 L p .56647 .61607 L F P
0 g
s
.59576 .66204 m .56046 .62218 L p .56647 .61607 L .858 0 0 r
F P
0 g
s
.56046 .62218 m .52502 .58216 L p .56647 .61607 L .858 0 0 r
F P
0 g
s
.56046 .62218 m .59576 .66204 L p .53695 .63066 L .535 0 0 r
F P
0 g
s
.57177 .66991 m .59576 .66204 L p .57768 .66386 L .257 0 0 r
F P
0 g
s
.58357 .65782 m .59576 .66204 L .57515 .6688 L 0 .05 .212 r
F
.52317 .73662 m .5 .74345 L .54406 .69831 L p F P
0 g
s
.48531 .61764 m .4601 .62727 L p .47607 .63395 L .523 0 0 r
F P
0 g
s
.45449 .63745 m .49808 .64651 L .4601 .62727 L .523 0 0 r
F
.49808 .64651 m .51391 .6498 L .49682 .64264 L F
.49808 .64651 m .49682 .64264 L .4601 .62727 L F
.47967 .60009 m .52502 .58216 L .56046 .62218 L p .535 0 0 r
F P
0 g
s
.47967 .60009 m .56046 .62218 L .53695 .63066 L .535 0 0 r
F
.52096 .5819 m .51833 .58295 L p .51434 .58695 L .18 0 0 r
F P
0 g
s
.51833 .58295 m .47571 .59985 L p .51434 .58695 L .18 0 0 r
F P
0 g
s
.47571 .59985 m .46276 .62625 L .51434 .58695 L .18 0 0 r
F
.48531 .61764 m .52096 .5819 L p .46276 .62625 L F P
0 g
s
.49154 .58766 m .48577 .58939 L .49237 .58674 L .183 0 0 r
F
.49154 .58766 m .47992 .59584 L .48577 .58939 L F
.49122 .58822 m .47992 .59584 L .49154 .58766 L F
.46386 .58651 m .47571 .59985 L .47901 .59854 L p .535 0 0 r
F P
0 g
s
.47901 .59854 m .52096 .5819 L p .46803 .58617 L .535 0 0 r
F P
0 g
s
.46386 .58651 m .47901 .59854 L .46803 .58617 L .535 0 0 r
F
.4622 .59473 m .4543 .58739 L .38431 .65687 L .831 0 0 r
F
.46193 .58578 m .4543 .58739 L .4622 .59473 L .535 0 0 r
F
.47003 .59929 m .4622 .59473 L .39228 .6643 L .764 0 0 r
F
.46305 .58643 m .4622 .59473 L .47003 .59929 L .535 0 0 r
F
.46305 .58643 m .46193 .58578 L .4622 .59473 L F
.46386 .58651 m .46305 .58643 L .47003 .59929 L F
.47571 .59985 m .43806 .63429 L .44087 .63461 L .58 0 0 r
F
.47571 .59985 m .43525 .63397 L .43806 .63429 L F
.47003 .59929 m .39228 .6643 L .40008 .66903 L .764 0 0 r
F
.46386 .58651 m .47003 .59929 L .47571 .59985 L .535 0 0 r
F
.43525 .63397 m .39228 .6643 L .42743 .62933 L .764 0 0 r
F
.43525 .63397 m .40008 .66903 L .39228 .6643 L F
.44087 .63461 m .40008 .66903 L .43525 .63397 L .58 0 0 r
F
.44087 .63461 m .40565 .66977 L .40008 .66903 L F
.40565 .66977 m .47571 .59985 L .46386 .58651 L p .856 0 0 r
F P
0 g
s
.4601 .62727 m .44087 .63461 L p .45449 .63745 L .523 0 0 r
F P
0 g
s
.44087 .63461 m .43366 .70107 L .40565 .66977 L .856 0 0 r
F
.44087 .63461 m .40565 .66977 L p .46276 .62625 L .18 0 0 r
F P
0 g
s
.40565 .66977 m .42401 .66304 L p .42097 .65809 L .18 0 0 r
F P
0 g
s
.42401 .66304 m .40565 .66977 L .43016 .67303 L 0 .308 .954 r
F
.40565 .66977 m .47752 .75008 L p .43016 .67303 L F P
0 g
s
.44771 .70158 m .47752 .75008 L .44904 .70024 L 0 .308 .954 r
F
.44771 .70158 m .44904 .70024 L .42712 .6619 L F
.42401 .66304 m .44771 .70158 L .42712 .6619 L F
.45553 .69369 m .42712 .6619 L p .44695 .69659 L F P
0 g
s
.44695 .69659 m .45095 .70359 L .45553 .69369 L 0 .308 .954 r
F
.40008 .66903 m .3936 .68445 L .39228 .6643 L .511 0 0 r
F
.40008 .66903 m .41686 .69863 L .3936 .68445 L F
.42743 .62933 m .39228 .6643 L .38431 .65687 L .831 0 0 r
F
.40565 .66977 m .41686 .69863 L .40008 .66903 L .511 0 0 r
F
.40565 .66977 m .43366 .70107 L .41686 .69863 L F
.39282 .65622 m .40008 .66903 L .39228 .6643 L F
.39361 .65632 m .40008 .66903 L .39301 .65655 L F
.39361 .65632 m .39301 .65655 L .39282 .65622 L F
.39361 .65632 m .40565 .66977 L .40008 .66903 L F
.44143 .78697 m .47752 .75008 L .39361 .65632 L p 0 .349 .781 r
F P
0 g
s
.42743 .62933 m .38431 .65687 L .4195 .62194 L .831 0 0 r
F
.46386 .58651 m .39361 .65632 L .40565 .66977 L p .856 0 0 r
F P
0 g
s
.46386 .58651 m .40565 .66977 L .39361 .65632 L .856 0 0 r
F
.41491 .64824 m .39361 .65632 L .40565 .66977 L p 0 .308 .954 r
F P
0 g
s
.39228 .6643 m .36995 .66235 L .38431 .65687 L .511 0 0 r
F
.39228 .6643 m .3936 .68445 L .36995 .66235 L F
.3917 .65555 m .39228 .6643 L .38431 .65687 L F
.39282 .65622 m .39228 .6643 L .3917 .65555 L F
.46386 .58651 m .47571 .59985 L .40565 .66977 L .856 0 0 r
F
.42401 .66304 m .42712 .6619 L p .42097 .65809 L .18 0 0 r
F P
0 g
s
.42097 .65809 m .42712 .6619 L .43271 .6563 L .18 0 0 r
F
.46276 .62625 m .42097 .65809 L .43271 .6563 L F
.46276 .62625 m .43271 .6563 L .44925 .65378 L F
.46638 .70583 m .45553 .69369 L p .45095 .70359 L 0 .308 .954 r
F P
0 g
s
.51326 .79001 m .47752 .75008 L .5 .74345 L p 0 .308 .954 r
F P
0 g
s
.49541 .77006 m .50669 .76693 L .48868 .74679 L p 0 .308 .954 r
F P
0 g
s
.48868 .74679 m .47752 .75008 L .49541 .77006 L p 0 .308 .954 r
F P
0 g
s
.47752 .75008 m .47749 .77723 L .49541 .77006 L closepath p 0 .349 .781 r
F P
0 g
s
.48868 .74679 m .47752 .75008 L .47749 .77723 L p 0 .181 .719 r
F P
0 g
s
.45953 .76847 m .47749 .77723 L .47752 .75008 L closepath p 0 .349 .781 r
F P
0 g
s
.51326 .79001 m .49541 .77006 L .47749 .77723 L p 0 .349 .781 r
F P
0 g
s
.47752 .75008 m .48868 .74679 L .48866 .77414 L p 0 .181 .719 r
F P
0 g
s
.48866 .77414 m .47749 .77723 L .47752 .75008 L p 0 .181 .719 r
F P
0 g
s
.47749 .77723 m .48866 .77414 L .48868 .74679 L p 0 .181 .719 r
F P
0 g
s
.47746 .80445 m .47749 .77723 L .45953 .76847 L p 0 .349 .781 r
F P
0 g
s
.45953 .76847 m .44143 .78697 L .47746 .80445 L p 0 .349 .781 r
F P
0 g
s
.48868 .74679 m .50669 .76693 L .51813 .76375 L p 0 .308 .954 r
F P
0 g
s
.50669 .76693 m .49541 .77006 L .51326 .79001 L p 0 .308 .954 r
F P
0 g
s
.51813 .76375 m .5 .74345 L .48868 .74679 L p 0 .308 .954 r
F P
0 g
s
.5 .77101 m .5 .74345 L .48868 .74679 L p 0 .181 .719 r
F P
0 g
s
.48868 .74679 m .48866 .77414 L .5 .77101 L p 0 .181 .719 r
F P
0 g
s
.48866 .77414 m .48868 .74679 L .5 .74345 L p 0 .181 .719 r
F P
0 g
s
.5 .74345 m .47752 .75008 L .44143 .78697 L p 0 .05 .212 r
F P
0 g
s
.47752 .75008 m .48868 .74679 L .47058 .76531 L p 0 .05 .212 r
F P
0 g
s
.47058 .76531 m .45953 .76847 L .47752 .75008 L p 0 .05 .212 r
F P
0 g
s
.43366 .70107 m .40565 .66977 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.40565 .66977 m .44087 .63461 L p .44499 .64403 L .18 0 0 r
F P
0 g
s
.42712 .6619 m .44925 .65378 L p .43271 .6563 L .18 0 0 r
F P
0 g
s
.44925 .65378 m .42712 .6619 L p .44499 .64403 L .18 0 0 r
F P
0 g
s
.42712 .6619 m .42712 .6619 L p .44499 .64403 L .18 0 0 r
F P
0 g
s
.41491 .64824 m .42712 .6619 L p .41492 .64824 L 0 .308 .954 r
F P
0 g
s
.54202 .69895 m .5 .74345 L .53303 .70179 L 0 .05 .212 r
F
.52317 .73662 m .43687 .63991 L .41491 .64824 L p 0 .308 .954 r
F P
0 g
s
.42712 .6619 m .45553 .69369 L p .42712 .6619 L 0 .308 .954 r
F P
0 g
s
.45553 .69369 m .45553 .69369 L .42712 .6619 L 0 .308 .954 r
F
.5 .74345 m .52317 .73662 L p .41492 .64824 L F P
0 g
s
.47806 .68607 m .45553 .69369 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.45553 .69369 m .43366 .70107 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.5 .74345 m .42712 .6619 L p .42712 .6619 L 0 .349 .781 r
F P
0 g
s
.45953 .76847 m .47058 .76531 L .45238 .78394 L p 0 .05 .212 r
F P
0 g
s
.5 .74345 m .5 .74345 L p .42712 .6619 L 0 .349 .781 r
F P
0 g
s
.44925 .65378 m .47806 .68607 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.40565 .66977 m .42712 .6619 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.42712 .6619 m .44925 .65378 L p .44133 .6778 L .511 0 0 r
F P
0 g
s
.41491 .64824 m .40565 .66977 L .42401 .66304 L 0 .308 .954 r
F
.42712 .6619 m .41491 .64824 L p .42401 .66304 L F P
0 g
s
.40565 .66977 m .39361 .65632 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.42712 .6619 m .40565 .66977 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.42712 .6619 m .42712 .6619 L .41492 .64824 L 0 .308 .954 r
F
.43687 .63991 m .44925 .65378 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.39361 .65632 m .41491 .64824 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.41491 .64824 m .43687 .63991 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.45238 .78394 m .44143 .78697 L .45953 .76847 L p 0 .05 .212 r
F P
0 g
s
.39361 .65632 m .35688 .69284 L .44143 .78697 L p 0 .349 .781 r
F P
0 g
s
.44143 .78697 m .46349 .78087 L .5 .74345 L p 0 .05 .212 r
F P
0 g
s
.45238 .78394 m .47058 .76531 L .4818 .76211 L p 0 .05 .212 r
F P
0 g
s
.4818 .76211 m .46349 .78087 L .45238 .78394 L p 0 .05 .212 r
F P
0 g
s
.46349 .78087 m .37774 .68527 L .41491 .64824 L p 0 .349 .781 r
F P
0 g
s
.42712 .6619 m .41491 .64824 L p .42185 .66717 L 0 .349 .781 r
F P
0 g
s
.47058 .76531 m .48868 .74679 L .5 .74345 L p 0 .05 .212 r
F P
0 g
s
.5 .74345 m .4818 .76211 L .47058 .76531 L p 0 .05 .212 r
F P
0 g
s
.46349 .78087 m .5 .74345 L p .42712 .6619 L 0 .349 .781 r
F P
0 g
s
.42185 .66717 m .46349 .78087 L .42712 .6619 L 0 .349 .781 r
F
.41491 .64824 m .42712 .6619 L p .42185 .66717 L F P
0 g
s
.44925 .65378 m .42712 .6619 L p .42102 .65507 L .511 0 0 r
F P
0 g
s
.40418 .65231 m .39361 .65632 L .3753 .67453 L p 0 .05 .118 r
F P
0 g
s
.38576 .67065 m .3753 .67453 L .35688 .69284 L p 0 .05 .118 r
F P
0 g
s
.3753 .67453 m .38576 .67065 L .40418 .65231 L p 0 .05 .118 r
F P
0 g
s
.41491 .64824 m .40418 .65231 L .38576 .67065 L p 0 .05 .118 r
F P
0 g
s
.35688 .69284 m .39361 .65632 L .41491 .64824 L p 0 .05 .118 r
F P
0 g
s
.42185 .66717 m .45553 .69369 L .43803 .71135 L 0 .349 .781 r
F
.42712 .6619 m .45553 .69369 L p .42185 .66717 L F P
0 g
s
.42893 .62122 m .46386 .58651 L p .45065 .61265 L .166 0 0 r
F P
0 g
s
.46386 .58651 m .39282 .65622 L .46305 .58643 L .577 0 0 r
F
.47571 .59985 m .44087 .63461 L p .46276 .62625 L .18 0 0 r
F P
0 g
s
.50159 .57354 m .50674 .56311 L .51081 .56143 L p 0 .099 .551 r
F P
0 g
s
.51081 .56143 m .50733 .57121 L .50159 .57354 L p 0 .099 .551 r
F P
0 g
s
.50733 .57121 m .51081 .56143 L .52216 .55675 L p 0 .099 .551 r
F P
0 g
s
.52216 .55675 m .51867 .56659 L .50733 .57121 L p 0 .099 .551 r
F P
0 g
s
.48598 .57746 m .47484 .58202 L p .48999 .58198 L .535 0 0 r
F P
0 g
s
.46193 .58578 m .46079 .58473 L .4543 .58739 L .535 0 0 r
F
.46079 .58473 m .4503 .59462 L .4543 .58739 L .164 0 0 r
F
.46079 .58473 m .4543 .58739 L p .43894 .60357 L F P
0 g
s
.50531 .56956 m .49729 .57284 L p .51383 .57917 L .535 0 0 r
F P
0 g
s
.49253 .55939 m .48898 .54896 L .47773 .55376 L p 0 .243 .835 r
F P
0 g
s
.47773 .55376 m .48125 .56412 L .49253 .55939 L p 0 .243 .835 r
F P
0 g
s
.49729 .57284 m .48598 .57746 L p .50334 .57967 L .535 0 0 r
F P
0 g
s
.52096 .5819 m .50877 .56814 L .50531 .56956 L p .535 0 0 r
F P
0 g
s
.51383 .57917 m .52096 .5819 L .50531 .56956 L .535 0 0 r
F
.50334 .57967 m .52096 .5819 L .49729 .57284 L F
.48999 .58198 m .52096 .5819 L .48598 .57746 L F
.47484 .58202 m .46386 .58651 L p .47782 .58538 L F P
0 g
s
.47782 .58538 m .52096 .5819 L .47484 .58202 L .535 0 0 r
F
.46386 .58651 m .50877 .56814 L .4918 .58508 L p .166 0 0 r
F P
0 g
s
.49593 .57419 m .49253 .55939 L .48125 .56412 L p 0 .224 .802 r
F P
0 g
s
.48898 .54896 m .48214 .55575 L p .49229 .5672 L 0 .349 .781 r
F P
0 g
s
.48898 .54896 m .49253 .55939 L .49836 .55695 L p 0 .243 .835 r
F P
0 g
s
.48125 .56412 m .48463 .57881 L .49593 .57419 L p 0 .224 .802 r
F P
0 g
s
.49392 .5762 m .49593 .57419 L .48463 .57881 L p 0 .05 .118 r
F P
0 g
s
.49253 .55939 m .48898 .54896 L p .49392 .5762 L 0 .349 .781 r
F P
0 g
s
.48125 .56412 m .47773 .55376 L .46665 .55849 L p 0 .243 .835 r
F P
0 g
s
.45284 .59262 m .46079 .58473 L p .43894 .60357 L .164 0 0 r
F P
0 g
s
.39903 .52523 m .4543 .58739 L .46079 .58473 L p .535 0 0 r
F P
0 g
s
.40529 .52228 m .39903 .52523 L p .44644 .5709 L .535 0 0 r
F P
0 g
s
.46079 .58473 m .44794 .57026 L p .44644 .5709 L .535 0 0 r
F P
0 g
s
.44794 .57026 m .40529 .52228 L p .44644 .5709 L .535 0 0 r
F P
0 g
s
.43894 .60357 m .42723 .61589 L .44421 .6012 L .164 0 0 r
F
.39056 .65448 m .43088 .61443 L p .42723 .61589 L F P
0 g
s
.43088 .61443 m .44421 .6012 L p .42723 .61589 L .164 0 0 r
F P
0 g
s
.44727 .60299 m .43394 .61624 L .44475 .61195 L p 0 .05 .118 r
F P
0 g
s
.43394 .61624 m .44475 .61195 L .44275 .6097 L p 0 .31 .951 r
F P
0 g
s
.44421 .6012 m .45284 .59262 L p .43956 .60308 L .164 0 0 r
F P
0 g
s
.43894 .60357 m .44421 .6012 L .43956 .60308 L .164 0 0 r
F
.43956 .60308 m .42582 .61645 L .43446 .60709 L F
.42582 .61645 m .42449 .61698 L .43446 .60709 L F
.44267 .60182 m .42814 .61553 L .43956 .60308 L F
.42814 .61553 m .38431 .65687 L .42582 .61645 L F
.42814 .61553 m .42582 .61645 L .43956 .60308 L F
.46193 .58578 m .3917 .65555 L .39056 .65448 L .831 0 0 r
F
.46305 .58643 m .3917 .65555 L .46193 .58578 L .764 0 0 r
F
.46305 .58643 m .39282 .65622 L .3917 .65555 L F
.46386 .58651 m .39361 .65632 L .39282 .65622 L .577 0 0 r
F
.4503 .59462 m .44267 .60182 L .43956 .60308 L .164 0 0 r
F
.4503 .59462 m .43446 .60709 L .4543 .58739 L F
.4543 .58739 m .39903 .52523 L p .3917 .59078 L .856 0 0 r
F P
0 g
s
.4195 .62194 m .4543 .58739 L p .3917 .59078 L .856 0 0 r
F P
0 g
s
.4393 .60318 m .42563 .61653 L .42723 .61589 L .164 0 0 r
F
.43778 .6038 m .38431 .65687 L p .4393 .60318 L F P
0 g
s
.4543 .58739 m .43778 .6038 L p .4393 .60318 L .164 0 0 r
F P
0 g
s
.4503 .59462 m .44342 .60151 L .44267 .60182 L .164 0 0 r
F
.46079 .58473 m .45284 .59262 L .4503 .59462 L F
.45284 .59262 m .44421 .6012 L .4503 .59462 L F
.44421 .6012 m .39056 .65448 L .44342 .60151 L F
.44421 .6012 m .44342 .60151 L .4503 .59462 L F
.44267 .60182 m .39056 .65448 L .38431 .65687 L F
.44342 .60151 m .39056 .65448 L .44267 .60182 L F
.40529 .52228 m .46079 .58473 L .43088 .61443 L p .856 0 0 r
F P
0 g
s
.46193 .58578 m .39056 .65448 L .46079 .58473 L .831 0 0 r
F
.44713 .57248 m .44304 .57572 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.46002 .58698 m .44713 .57248 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.46269 .56019 m .44713 .57248 L .46002 .58698 L p 0 .346 .852 r
F P
0 g
s
.44304 .57572 m .45592 .5902 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.45592 .5902 m .4579 .59243 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.462 .5892 m .4579 .59243 L .44727 .60299 L p 0 .05 .118 r
F P
0 g
s
.44727 .60299 m .4579 .59243 L .44304 .57572 L p 0 .349 .781 r
F P
0 g
s
.46386 .58651 m .4918 .58508 L .45763 .59882 L .166 0 0 r
F
.44727 .60299 m .45816 .59861 L p .462 .5892 L 0 .05 .118 r
F P
0 g
s
.46002 .58698 m .462 .5892 L p .46209 .58534 L 0 .346 .852 r
F P
0 g
s
.46209 .58534 m .46269 .56019 L .46002 .58698 L 0 .346 .852 r
F
.462 .5892 m .44713 .57248 L .45655 .5685 L p 0 .311 .95 r
F P
0 g
s
.462 .5892 m .46506 .58679 L .46492 .58268 L p 0 .346 .852 r
F P
0 g
s
.46492 .58268 m .46453 .57113 L p .46319 .58072 L 0 .346 .852 r
F P
0 g
s
.462 .5892 m .46492 .58268 L .46319 .58072 L 0 .346 .852 r
F
.46506 .58679 m .462 .5892 L .47151 .58533 L p 0 .05 .118 r
F P
0 g
s
.46453 .57113 m .46269 .56019 L p .462 .5892 L 0 .346 .852 r
F P
0 g
s
.46453 .57113 m .46506 .58679 L .47349 .58335 L p 0 .224 .802 r
F P
0 g
s
.47151 .58533 m .47349 .58335 L .46506 .58679 L p 0 .05 .118 r
F P
0 g
s
.44713 .57248 m .462 .5892 L .47151 .58533 L p 0 .311 .95 r
F P
0 g
s
.44304 .57572 m .43238 .58626 L .44727 .60299 L p 0 .349 .781 r
F P
0 g
s
.462 .5892 m .46002 .58698 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.4579 .59243 m .462 .5892 L p .45947 .58741 L 0 .346 .852 r
F P
0 g
s
.45816 .59861 m .47151 .58533 L .462 .5892 L p 0 .05 .118 r
F P
0 g
s
.45655 .5685 m .47151 .58533 L .462 .5892 L p 0 .311 .95 r
F P
0 g
s
.47151 .58533 m .45816 .59861 L .44316 .58175 L p 0 .349 .781 r
F P
0 g
s
.47151 .58533 m .45655 .5685 L .44713 .57248 L p 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .45655 .5685 L .47151 .58533 L p 0 .349 .781 r
F P
0 g
s
.45655 .5685 m .44316 .58175 L .45816 .59861 L p 0 .349 .781 r
F P
0 g
s
.44316 .58175 m .4541 .57718 L p .45762 .59578 L 0 .311 .95 r
F P
0 g
s
.45816 .59861 m .45616 .59637 L p .45762 .59578 L 0 .311 .95 r
F P
0 g
s
.45616 .59637 m .44316 .58175 L p .45762 .59578 L 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .43238 .58626 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.45816 .59861 m .45616 .59637 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.45616 .59637 m .44316 .58175 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.40529 .52228 m .43088 .61443 L .39901 .57868 L .856 0 0 r
F
.43238 .58626 m .41901 .59948 L .43394 .61624 L p 0 .349 .781 r
F P
0 g
s
.42971 .59507 m .41901 .59948 L .43195 .61401 L p 0 .31 .951 r
F P
0 g
s
.42971 .59507 m .43195 .61401 L .43338 .61344 L 0 .31 .951 r
F
.42594 .59662 m .42971 .59507 L p .43314 .6122 L F P
0 g
s
.43338 .61344 m .42594 .59662 L .43314 .6122 L 0 .31 .951 r
F
.41901 .59948 m .42594 .59662 L p .43338 .61344 L F P
0 g
s
.43195 .61401 m .43394 .61624 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.43394 .61624 m .43195 .61401 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.43195 .61401 m .41901 .59948 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.38431 .65687 m .39056 .65448 L p .42723 .61589 L .164 0 0 r
F P
0 g
s
.42563 .61653 m .38431 .65687 L .42723 .61589 L .164 0 0 r
F
.44727 .60299 m .45816 .59861 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.43238 .58626 m .44529 .60076 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.44529 .60076 m .44727 .60299 L p .4547 .59696 L 0 .311 .95 r
F P
0 g
s
.43394 .61624 m .44727 .60299 L .43238 .58626 L p 0 .349 .781 r
F P
0 g
s
.43338 .61344 m .43394 .61624 L .44275 .6097 L 0 .31 .951 r
F
.44475 .61195 m .43394 .61624 L p .43338 .61344 L F P
0 g
s
.44275 .6097 m .42971 .59507 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.42971 .59507 m .44275 .6097 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.44275 .6097 m .44475 .61195 L p .43338 .61344 L 0 .31 .951 r
F P
0 g
s
.42582 .61645 m .38431 .65687 L .42449 .61698 L .164 0 0 r
F
.43238 .58626 m .44316 .58175 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.44727 .60299 m .44529 .60076 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.44529 .60076 m .43238 .58626 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.4195 .62194 m .36995 .66235 L .40485 .62775 L .164 0 0 r
F
.38431 .65687 m .4195 .62194 L .40485 .62775 L p F P
0 g
s
.40485 .62775 m .36995 .66235 L .38431 .65687 L p .164 0 0 r
F P
0 g
s
.36995 .66235 m .40485 .62775 L .3497 .56601 L p .855 0 0 r
F P
0 g
s
.3497 .56601 m .40485 .62775 L .41161 .62507 L p .523 0 0 r
F P
0 g
s
.41161 .62507 m .4195 .62194 L p .39503 .60233 L .523 0 0 r
F P
0 g
s
.3497 .56601 m .41161 .62507 L .39503 .60233 L .523 0 0 r
F
.3497 .56601 m .31439 .60037 L .36995 .66235 L p .855 0 0 r
F P
0 g
s
.32822 .59422 m .31439 .60037 L .3497 .56601 L p .1 0 0 r
F P
0 g
s
.39903 .52523 m .3608 .5554 L .36382 .55954 L .881 0 0 r
F
.36382 .55954 m .3497 .56601 L p .35981 .57411 L .523 0 0 r
F P
0 g
s
.35981 .57411 m .3822 .59205 L .36528 .56212 L .523 0 0 r
F
.35981 .57411 m .36528 .56212 L .36382 .55954 L F
.3497 .56601 m .29619 .57576 L .31439 .60037 L .88 0 0 r
F
.3497 .56601 m .33171 .54142 L .29619 .57576 L F
.35096 .55402 m .33171 .54142 L .34717 .56255 L .523 0 0 r
F
.36 .55738 m .35157 .55263 L .36121 .56073 L F
.35157 .55263 m .33171 .54142 L .35096 .55402 L F
.35157 .55263 m .35096 .55402 L .36121 .56073 L F
.39064 .50997 m .39241 .50611 L .35695 .54051 L .937 0 0 r
F
.34469 .54632 m .32401 .52055 L .33171 .54142 L .523 0 0 r
F
.35779 .55127 m .34973 .54394 L .34469 .54632 L F
.34973 .54394 m .32401 .52055 L .34469 .54632 L F
.36 .55738 m .35779 .55127 L .33171 .54142 L F
.3822 .59205 m .41459 .618 L .37526 .57271 L F
.3822 .59205 m .37526 .57271 L .36382 .55954 L F
.40837 .60947 m .37505 .57212 L p .41459 .618 L F P
0 g
s
.37505 .57212 m .36382 .55954 L p .37526 .57271 L .523 0 0 r
F P
0 g
s
.41459 .618 m .37505 .57212 L .37526 .57271 L .523 0 0 r
F
.4195 .62194 m .38431 .65687 L .36995 .66235 L .164 0 0 r
F
.39903 .52523 m .32822 .59422 L .38431 .65687 L p .856 0 0 r
F P
0 g
s
.3497 .56601 m .36382 .55954 L .32822 .59422 L p .1 0 0 r
F P
0 g
s
.36382 .55954 m .3497 .56601 L .31439 .60037 L .1 0 0 r
F
.36382 .55954 m .31439 .60037 L .32822 .59422 L F
.36382 .55954 m .32211 .58594 L .32822 .59422 L .881 0 0 r
F
.36382 .55954 m .32822 .59422 L .32211 .58594 L F
.34388 .57896 m .33304 .58952 L .33299 .58937 L .941 0 0 r
F
.4195 .62194 m .40837 .60947 L p .41459 .618 L .523 0 0 r
F P
0 g
s
.36382 .55954 m .4195 .62194 L .38431 .65687 L p .856 0 0 r
F P
0 g
s
.38431 .65687 m .32822 .59422 L .36382 .55954 L p .856 0 0 r
F P
0 g
s
.3917 .59078 m .38524 .64854 L .397 .59672 L .856 0 0 r
F
.38524 .64854 m .38431 .65687 L .397 .59672 L F
.38431 .65687 m .4195 .62194 L p .397 .59672 L F P
0 g
s
.39056 .65448 m .33423 .59155 L .40529 .52228 L p .856 0 0 r
F P
0 g
s
.40252 .55272 m .38907 .56589 L .40405 .5827 L p 0 .349 .781 r
F P
0 g
s
.40252 .55272 m .38907 .56589 L .39956 .56122 L p 0 .05 .1 r
F P
0 g
s
.37896 .54479 m .39903 .52523 L p .38341 .54122 L .1 0 0 r
F P
0 g
s
.36887 .55461 m .37896 .54479 L p .3701 .55405 L .1 0 0 r
F P
0 g
s
.3701 .55405 m .33423 .59155 L .36887 .55461 L .1 0 0 r
F
.38341 .54122 m .3715 .5534 L .37896 .54479 L F
.3715 .5534 m .33423 .59155 L .3701 .55405 L F
.3715 .5534 m .3701 .55405 L .37896 .54479 L F
.40529 .52228 m .39903 .52523 L .37896 .54479 L F
.41325 .54222 m .42815 .55898 L .43225 .55573 L p 0 .346 .852 r
F P
0 g
s
.41746 .5695 m .42815 .55898 L .41325 .54222 L p 0 .349 .781 r
F P
0 g
s
.43284 .52657 m .41733 .53896 L .43225 .55573 L p 0 .346 .852 r
F P
0 g
s
.43225 .55573 m .41733 .53896 L .41325 .54222 L p 0 .346 .852 r
F P
0 g
s
.45277 .53943 m .43225 .55573 L .44713 .57248 L p 0 .346 .852 r
F P
0 g
s
.43474 .52719 m .43284 .52657 L p .43225 .55573 L 0 .346 .852 r
F P
0 g
s
.44496 .53262 m .43474 .52719 L p .43225 .55573 L 0 .346 .852 r
F P
0 g
s
.43225 .55573 m .45277 .53943 L .44496 .53262 L p 0 .346 .852 r
F P
0 g
s
.45277 .53943 m .43225 .55573 L .44157 .55163 L p 0 .05 .1 r
F P
0 g
s
.4585 .54788 m .45277 .53943 L p .44713 .57248 L 0 .346 .852 r
F P
0 g
s
.45277 .53943 m .4585 .54788 L .46106 .54677 L p 0 .296 .924 r
F P
0 g
s
.46106 .54677 m .45495 .53846 L .45277 .53943 L p 0 .296 .924 r
F P
0 g
s
.45495 .53846 m .44157 .55163 L .43225 .55573 L p 0 .05 .1 r
F P
0 g
s
.43225 .55573 m .45277 .53943 L .45495 .53846 L p 0 .05 .1 r
F P
0 g
s
.41733 .53896 m .43225 .55573 L .44157 .55163 L p 0 .311 .95 r
F P
0 g
s
.43225 .55573 m .41733 .53896 L .42657 .53475 L p 0 .311 .95 r
F P
0 g
s
.41325 .54222 m .40252 .55272 L .41746 .5695 L p 0 .349 .781 r
F P
0 g
s
.44157 .55163 m .42657 .53475 L .41733 .53896 L p 0 .311 .95 r
F P
0 g
s
.40252 .55272 m .41325 .54222 L p .42657 .53475 L 0 .05 .1 r
F P
0 g
s
.41325 .54222 m .40252 .55272 L .41309 .54795 L p 0 .05 .1 r
F P
0 g
s
.40529 .52228 m .37896 .54479 L .39472 .53215 L .1 0 0 r
F
.38703 .53932 m .37896 .54479 L .36887 .55461 L F
.37238 .553 m .36887 .55461 L .32822 .59422 L F
.38703 .53932 m .36887 .55461 L .37238 .553 L F
.39472 .53215 m .38403 .54072 L .38703 .53932 L F
.38403 .54072 m .37896 .54479 L .38703 .53932 L F
.39903 .52523 m .40529 .52228 L .40194 .52555 L p F P
0 g
s
.40194 .52555 m .38852 .53863 L p .39599 .52835 L .1 0 0 r
F P
0 g
s
.39599 .52835 m .38852 .53863 L .38378 .54084 L .1 0 0 r
F
.38852 .53863 m .33423 .59155 L p .38378 .54084 L F P
0 g
s
.39903 .52523 m .40194 .52555 L .39599 .52835 L .1 0 0 r
F
.40529 .52228 m .39307 .51697 L .39903 .52523 L .535 0 0 r
F
.40529 .52228 m .40444 .5211 L .39307 .51697 L F
.40444 .5211 m .37417 .55059 L .37402 .55017 L .941 0 0 r
F
.39903 .52523 m .39893 .5251 L .39779 .52621 L .881 0 0 r
F
.39893 .5251 m .39307 .51697 L .39779 .52621 L F
.36074 .5578 m .35779 .55127 L .36 .55738 L .523 0 0 r
F
.3621 .55718 m .35779 .55127 L .36074 .5578 L F
.36121 .56073 m .35096 .55402 L .3497 .56601 L F
.35096 .55402 m .34717 .56255 L .3497 .56601 L F
.39779 .52621 m .39307 .51697 L .32211 .58594 L .881 0 0 r
F
.40444 .5211 m .39064 .50997 L .39307 .51697 L .535 0 0 r
F
.40409 .5201 m .39241 .50611 L .39064 .50997 L F
.40444 .5211 m .40409 .5201 L .39064 .50997 L F
.40409 .5201 m .40435 .51955 L .39241 .50611 L F
.40409 .5201 m .36886 .55427 L .40435 .51955 L .932 0 0 r
F
.36886 .55427 m .36898 .554 L .40435 .51955 L F
.40444 .5211 m .36892 .55504 L .40409 .5201 L .941 0 0 r
F
.33423 .59155 m .32822 .59422 L .36887 .55461 L p .1 0 0 r
F P
0 g
s
.36892 .55504 m .36874 .55454 L .40409 .5201 L .941 0 0 r
F
.40194 .52555 m .38727 .53921 L .38852 .53863 L .1 0 0 r
F
.40164 .52569 m .32822 .59422 L .40194 .52555 L F
.40529 .52228 m .38831 .53835 L .40444 .5211 L .881 0 0 r
F
.38727 .53921 m .32822 .59422 L .38852 .53863 L .1 0 0 r
F
.38831 .53835 m .36953 .55613 L .38786 .53773 L .881 0 0 r
F
.38831 .53835 m .38786 .53773 L .40444 .5211 L F
.36953 .55613 m .36909 .55554 L .40444 .5211 L F
.38852 .53863 m .32822 .59422 L .33423 .59155 L .1 0 0 r
F
.40529 .52228 m .40164 .52569 L .40194 .52555 L F
.40529 .52228 m .33423 .59155 L .33336 .59036 L .881 0 0 r
F
.36382 .55954 m .3621 .55718 L .36074 .5578 L .523 0 0 r
F
.36382 .55954 m .36 .55738 L .36121 .56073 L F
.3608 .5554 m .32211 .58594 L .36382 .55954 L .881 0 0 r
F
.36382 .55954 m .32211 .58594 L .35779 .55127 L F
.40409 .5201 m .33299 .58937 L .33322 .58884 L .932 0 0 r
F
.36892 .55504 m .33304 .58952 L .34388 .57896 L .941 0 0 r
F
.36892 .55504 m .33336 .59036 L .33304 .58952 L F
.36909 .55554 m .33336 .59036 L .36892 .55504 L F
.36892 .55504 m .33299 .58937 L .36874 .55454 L F
.36886 .55427 m .33322 .58884 L .36898 .554 L .932 0 0 r
F
.36953 .55613 m .33336 .59036 L .36909 .55554 L .881 0 0 r
F
.36198 .59241 m .34689 .57553 L .33322 .58884 L p 0 .349 .781 r
F P
0 g
s
.34689 .57553 m .36198 .59241 L .37555 .57912 L p 0 .349 .781 r
F P
0 g
s
.37555 .57912 m .3605 .56226 L .34689 .57553 L p 0 .349 .781 r
F P
0 g
s
.33322 .58884 m .34689 .57553 L .35712 .5709 L p 0 .05 .1 r
F P
0 g
s
.35712 .5709 m .34337 .58431 L .33322 .58884 L p 0 .05 .1 r
F P
0 g
s
.33322 .58884 m .33418 .58842 L p .33588 .58675 L .1 0 0 r
F P
0 g
s
.3605 .56226 m .37555 .57912 L .38907 .56589 L p 0 .349 .781 r
F P
0 g
s
.34337 .58431 m .35712 .5709 L .3675 .5662 L p 0 .05 .1 r
F P
0 g
s
.3675 .5662 m .35367 .5797 L .34337 .58431 L p 0 .05 .1 r
F P
0 g
s
.43088 .61443 m .39056 .65448 L p .39901 .57868 L .856 0 0 r
F P
0 g
s
.37555 .57912 m .39058 .59596 L .40405 .5827 L p 0 .349 .781 r
F P
0 g
s
.40405 .5827 m .38907 .56589 L .37555 .57912 L p 0 .349 .781 r
F P
0 g
s
.41746 .5695 m .40405 .5827 L .41901 .59948 L p 0 .349 .781 r
F P
0 g
s
.41746 .5695 m .40405 .5827 L .41465 .57816 L p 0 .05 .1 r
F P
0 g
s
.40405 .5827 m .41746 .5695 L .40252 .55272 L p 0 .349 .781 r
F P
0 g
s
.42815 .55898 m .41746 .5695 L .43238 .58626 L p 0 .349 .781 r
F P
0 g
s
.44713 .57248 m .44304 .57572 L .43238 .58626 L p 0 .05 .1 r
F P
0 g
s
.43238 .58626 m .44304 .57572 L .44713 .57248 L p 0 .05 .1 r
F P
0 g
s
.43238 .58626 m .44304 .57572 L .42815 .55898 L p 0 .349 .781 r
F P
0 g
s
.43238 .58626 m .44316 .58175 L p .44713 .57248 L 0 .05 .1 r
F P
0 g
s
.44713 .57248 m .45655 .5685 L p .43238 .58626 L 0 .05 .1 r
F P
0 g
s
.45655 .5685 m .44316 .58175 L .43238 .58626 L p 0 .05 .1 r
F P
0 g
s
.41746 .5695 m .43238 .58626 L .44316 .58175 L p 0 .311 .95 r
F P
0 g
s
.41901 .59948 m .43238 .58626 L .41746 .5695 L p 0 .349 .781 r
F P
0 g
s
.43238 .58626 m .41746 .5695 L .42814 .56487 L p 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .42814 .56487 L .41746 .5695 L p 0 .311 .95 r
F P
0 g
s
.40405 .5827 m .41746 .5695 L .42814 .56487 L p 0 .05 .1 r
F P
0 g
s
.42814 .56487 m .41465 .57816 L .40405 .5827 L p 0 .05 .1 r
F P
0 g
s
.38907 .56589 m .40405 .5827 L .41465 .57816 L p 0 .31 .951 r
F P
0 g
s
.41465 .57816 m .39956 .56122 L .38907 .56589 L p 0 .31 .951 r
F P
0 g
s
.40405 .5827 m .38907 .56589 L .39956 .56122 L p 0 .31 .951 r
F P
0 g
s
.3675 .5662 m .38281 .58335 L .39654 .56988 L p 0 .349 .781 r
F P
0 g
s
.39654 .56988 m .38281 .58335 L .3675 .5662 L p 0 .349 .781 r
F P
0 g
s
.39058 .59596 m .37555 .57912 L .36198 .59241 L p 0 .349 .781 r
F P
0 g
s
.38281 .58335 m .3675 .5662 L .35367 .5797 L p 0 .349 .781 r
F P
0 g
s
.35367 .5797 m .3675 .5662 L .38281 .58335 L p 0 .349 .781 r
F P
0 g
s
.36413 .57503 m .35367 .5797 L .3675 .5662 L p 0 .05 .1 r
F P
0 g
s
.37402 .55017 m .36909 .55554 L .36892 .55504 L .941 0 0 r
F
.37417 .55059 m .36909 .55554 L .37402 .55017 L F
.38907 .56589 m .37406 .54906 L .3605 .56226 L p 0 .349 .781 r
F P
0 g
s
.38907 .56589 m .40252 .55272 L .38756 .53591 L p 0 .349 .781 r
F P
0 g
s
.41746 .5695 m .40252 .55272 L .41309 .54795 L p 0 .311 .95 r
F P
0 g
s
.42815 .55898 m .41746 .5695 L .42814 .56487 L p 0 .05 .1 r
F P
0 g
s
.42815 .55898 m .44304 .57572 L .44713 .57248 L p 0 .346 .852 r
F P
0 g
s
.44713 .57248 m .43225 .55573 L .42815 .55898 L p 0 .346 .852 r
F P
0 g
s
.41746 .5695 m .42815 .55898 L .43225 .55573 L p 0 .05 .1 r
F P
0 g
s
.45655 .5685 m .44713 .57248 L p .45356 .56788 L 0 .05 .1 r
F P
0 g
s
.46269 .56019 m .46453 .57113 L .47015 .56877 L p 0 .243 .835 r
F P
0 g
s
.47015 .56877 m .46665 .55849 L .46269 .56019 L p 0 .243 .835 r
F P
0 g
s
.46665 .55849 m .45989 .56519 L p .45356 .56788 L 0 .05 .1 r
F P
0 g
s
.45989 .56519 m .45655 .5685 L p .45356 .56788 L 0 .05 .1 r
F P
0 g
s
.46237 .55832 m .4585 .54788 L p .44713 .57248 L 0 .346 .852 r
F P
0 g
s
.44713 .57248 m .46269 .56019 L .46237 .55832 L p 0 .346 .852 r
F P
0 g
s
.44713 .57248 m .46269 .56019 L .46665 .55849 L p 0 .05 .1 r
F P
0 g
s
.46269 .56019 m .44713 .57248 L .45655 .5685 L p 0 .05 .1 r
F P
0 g
s
.43225 .55573 m .44713 .57248 L .45655 .5685 L p 0 .311 .95 r
F P
0 g
s
.44713 .57248 m .43225 .55573 L .44157 .55163 L p 0 .311 .95 r
F P
0 g
s
.45655 .5685 m .44157 .55163 L .43225 .55573 L p 0 .311 .95 r
F P
0 g
s
.43225 .55573 m .44157 .55163 L p .41746 .5695 L 0 .05 .1 r
F P
0 g
s
.44157 .55163 m .42814 .56487 L .41746 .5695 L p 0 .05 .1 r
F P
0 g
s
.40252 .55272 m .41746 .5695 L .42814 .56487 L p 0 .311 .95 r
F P
0 g
s
.42814 .56487 m .41309 .54795 L .40252 .55272 L p 0 .311 .95 r
F P
0 g
s
.38907 .56589 m .40252 .55272 L .41309 .54795 L p 0 .05 .1 r
F P
0 g
s
.38756 .53591 m .37406 .54906 L .38907 .56589 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .39956 .56122 L .38907 .56589 L p 0 .05 .1 r
F P
0 g
s
.39956 .56122 m .38647 .54652 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.38907 .56589 m .39956 .56122 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.37606 .5513 m .38907 .56589 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.38907 .56589 m .37606 .5513 L p .38507 .54716 L 0 .31 .951 r
F P
0 g
s
.38647 .54652 m .38445 .54425 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.38445 .54425 m .39956 .56122 L .38907 .56589 L p 0 .31 .951 r
F P
0 g
s
.39654 .56988 m .38128 .55276 L .3675 .5662 L p 0 .349 .781 r
F P
0 g
s
.3675 .5662 m .38128 .55276 L .39654 .56988 L p 0 .349 .781 r
F P
0 g
s
.3675 .5662 m .37805 .56143 L .36413 .57503 L p 0 .05 .1 r
F P
0 g
s
.33588 .58675 m .35367 .5797 L .35455 .57884 L .1 0 0 r
F
.37081 .55755 m .35712 .5709 L .34689 .57553 L p 0 .05 .1 r
F P
0 g
s
.39832 .52543 m .38756 .53591 L .40252 .55272 L p 0 .349 .781 r
F P
0 g
s
.40252 .55272 m .38955 .53815 L p .39863 .53393 L 0 .311 .95 r
F P
0 g
s
.40252 .55272 m .40805 .5473 L p .40156 .54646 L 0 .349 .781 r
F P
0 g
s
.40805 .5473 m .41325 .54222 L p .40156 .54646 L 0 .349 .781 r
F P
0 g
s
.41325 .54222 m .39832 .52543 L p .40156 .54646 L 0 .349 .781 r
F P
0 g
s
.42657 .53475 m .41309 .54795 L .40252 .55272 L p 0 .05 .1 r
F P
0 g
s
.40252 .55272 m .41309 .54795 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.38955 .53815 m .40252 .55272 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.39956 .56122 m .41309 .54795 L .40252 .55272 L p 0 .05 .1 r
F P
0 g
s
.39803 .53101 m .41309 .54795 L .40252 .55272 L p 0 .311 .95 r
F P
0 g
s
.41309 .54795 m .39956 .56122 L .38445 .54425 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .40004 .53327 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.40004 .53327 m .39803 .53101 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.38756 .53591 m .39803 .53101 L p .39863 .53393 L 0 .311 .95 r
F P
0 g
s
.38955 .53815 m .38756 .53591 L p .39863 .53393 L 0 .311 .95 r
F P
0 g
s
.38445 .54425 m .39803 .53101 L .41309 .54795 L p 0 .349 .781 r
F P
0 g
s
.39803 .53101 m .38445 .54425 L .39956 .56122 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .42814 .56487 L .41746 .5695 L p 0 .311 .95 r
F P
0 g
s
.39956 .56122 m .41309 .54795 L .42814 .56487 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .39956 .56122 L .41465 .57816 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .39956 .56122 L .41021 .55647 L p 0 .05 .1 r
F P
0 g
s
.39956 .56122 m .41309 .54795 L .39803 .53101 L p 0 .349 .781 r
F P
0 g
s
.43225 .55573 m .42815 .55898 L p .42814 .56487 L 0 .05 .1 r
F P
0 g
s
.42814 .56487 m .44157 .55163 L .43225 .55573 L p 0 .05 .1 r
F P
0 g
s
.42657 .53475 m .44157 .55163 L .43225 .55573 L p 0 .311 .95 r
F P
0 g
s
.44157 .55163 m .42814 .56487 L .41309 .54795 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .42657 .53475 L .44157 .55163 L p 0 .349 .781 r
F P
0 g
s
.42657 .53475 m .41309 .54795 L .42814 .56487 L p 0 .349 .781 r
F P
0 g
s
.42814 .56487 m .41309 .54795 L .42383 .54312 L p 0 .311 .95 r
F P
0 g
s
.44157 .55163 m .45655 .5685 L .44713 .57248 L p 0 .311 .95 r
F P
0 g
s
.42814 .56487 m .44157 .55163 L .45655 .5685 L p 0 .349 .781 r
F P
0 g
s
.44157 .55163 m .42814 .56487 L .44316 .58175 L p 0 .349 .781 r
F P
0 g
s
.44157 .55163 m .42814 .56487 L .43898 .56016 L p 0 .05 .1 r
F P
0 g
s
.42814 .56487 m .44157 .55163 L .42657 .53475 L p 0 .349 .781 r
F P
0 g
s
.4585 .54788 m .46237 .55832 L .46606 .55674 L p 0 .267 .876 r
F P
0 g
s
.46665 .55849 m .46606 .55674 L .46237 .55832 L p 0 .243 .835 r
F P
0 g
s
.46606 .55674 m .46665 .55849 L p .44157 .55163 L 0 .349 .781 r
F P
0 g
s
.46606 .55674 m .46106 .54677 L .4585 .54788 L p 0 .267 .876 r
F P
0 g
s
.46106 .54677 m .46606 .55674 L p .44157 .55163 L 0 .349 .781 r
F P
0 g
s
.46237 .55832 m .46269 .56019 L .46665 .55849 L p 0 .243 .835 r
F P
0 g
s
.45655 .5685 m .46665 .55849 L .46269 .56019 L p 0 .05 .1 r
F P
0 g
s
.46665 .55849 m .45655 .5685 L .44157 .55163 L p 0 .349 .781 r
F P
0 g
s
.44157 .55163 m .45495 .53846 L .46106 .54677 L p 0 .349 .781 r
F P
0 g
s
.45495 .53846 m .44157 .55163 L .45655 .5685 L p 0 .349 .781 r
F P
0 g
s
.47349 .58335 m .47015 .56877 L .46453 .57113 L p 0 .224 .802 r
F P
0 g
s
.46665 .55849 m .45989 .56519 L p .4699 .57646 L 0 .349 .781 r
F P
0 g
s
.45989 .56519 m .45655 .5685 L p .4699 .57646 L 0 .349 .781 r
F P
0 g
s
.46606 .55674 m .46106 .54677 L p .45655 .5685 L 0 .349 .781 r
F P
0 g
s
.45655 .5685 m .46665 .55849 L .46606 .55674 L p 0 .349 .781 r
F P
0 g
s
.45655 .5685 m .46665 .55849 L .47015 .56877 L p 0 .349 .781 r
F P
0 g
s
.47015 .56877 m .46665 .55849 L p .47151 .58533 L 0 .349 .781 r
F P
0 g
s
.46665 .55849 m .47015 .56877 L .48125 .56412 L p 0 .243 .835 r
F P
0 g
s
.45655 .5685 m .46665 .55849 L .47773 .55376 L p 0 .05 .1 r
F P
0 g
s
.46665 .55849 m .45655 .5685 L .46757 .56383 L p 0 .05 .1 r
F P
0 g
s
.46106 .54677 m .45495 .53846 L p .45655 .5685 L 0 .349 .781 r
F P
0 g
s
.47773 .55376 m .46757 .56383 L .45655 .5685 L p 0 .05 .1 r
F P
0 g
s
.44157 .55163 m .45655 .5685 L .46757 .56383 L p 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .45655 .5685 L .44713 .57248 L p 0 .05 .1 r
F P
0 g
s
.44316 .58175 m .45655 .5685 L .44157 .55163 L p 0 .349 .781 r
F P
0 g
s
.45655 .5685 m .44157 .55163 L .45249 .54684 L p 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .45249 .54684 L .44157 .55163 L p 0 .311 .95 r
F P
0 g
s
.42814 .56487 m .44157 .55163 L .45249 .54684 L p 0 .05 .1 r
F P
0 g
s
.45249 .54684 m .43898 .56016 L .42814 .56487 L p 0 .05 .1 r
F P
0 g
s
.41309 .54795 m .42814 .56487 L .43898 .56016 L p 0 .311 .95 r
F P
0 g
s
.41465 .57816 m .42814 .56487 L .41746 .5695 L p 0 .05 .1 r
F P
0 g
s
.41465 .57816 m .42814 .56487 L .41309 .54795 L p 0 .349 .781 r
F P
0 g
s
.43898 .56016 m .42383 .54312 L .41309 .54795 L p 0 .311 .95 r
F P
0 g
s
.39956 .56122 m .41309 .54795 L .42383 .54312 L p 0 .05 .1 r
F P
0 g
s
.42383 .54312 m .41021 .55647 L .39956 .56122 L p 0 .05 .1 r
F P
0 g
s
.38445 .54425 m .39956 .56122 L .41021 .55647 L p 0 .31 .951 r
F P
0 g
s
.41021 .55647 m .395 .53937 L .38445 .54425 L p 0 .31 .951 r
F P
0 g
s
.39956 .56122 m .38445 .54425 L .395 .53937 L p 0 .31 .951 r
F P
0 g
s
.35712 .5709 m .37081 .55755 L .38128 .55276 L p 0 .05 .1 r
F P
0 g
s
.38445 .54425 m .37406 .54906 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.37406 .54906 m .38445 .54425 L p .38507 .54716 L 0 .31 .951 r
F P
0 g
s
.37406 .54906 m .37606 .5513 L p .37744 .55067 L 0 .31 .951 r
F P
0 g
s
.37606 .5513 m .37406 .54906 L p .38507 .54716 L 0 .31 .951 r
F P
0 g
s
.395 .53937 m .38128 .55276 L .37081 .55755 L p 0 .05 .1 r
F P
0 g
s
.38128 .55276 m .3675 .5662 L .35712 .5709 L p 0 .05 .1 r
F P
0 g
s
.39956 .56122 m .41465 .57816 L .40405 .5827 L p 0 .31 .951 r
F P
0 g
s
.42814 .56487 m .41465 .57816 L .39956 .56122 L p 0 .349 .781 r
F P
0 g
s
.42814 .56487 m .44316 .58175 L .43238 .58626 L p 0 .311 .95 r
F P
0 g
s
.41465 .57816 m .42814 .56487 L .44316 .58175 L p 0 .349 .781 r
F P
0 g
s
.41901 .59948 m .43238 .58626 L .44316 .58175 L p 0 .05 .1 r
F P
0 g
s
.43238 .58626 m .41901 .59948 L .42971 .59507 L p 0 .05 .1 r
F P
0 g
s
.44316 .58175 m .42971 .59507 L .41901 .59948 L p 0 .05 .1 r
F P
0 g
s
.42814 .56487 m .41465 .57816 L .42971 .59507 L p 0 .349 .781 r
F P
0 g
s
.42814 .56487 m .41465 .57816 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.45655 .5685 m .44316 .58175 L .42814 .56487 L p 0 .349 .781 r
F P
0 g
s
.45655 .5685 m .47151 .58533 L p .4699 .57646 L 0 .349 .781 r
F P
0 g
s
.47015 .56877 m .47349 .58335 L p .45655 .5685 L 0 .349 .781 r
F P
0 g
s
.47349 .58335 m .47151 .58533 L .45655 .5685 L p 0 .349 .781 r
F P
0 g
s
.47151 .58533 m .45655 .5685 L .46757 .56383 L p 0 .311 .95 r
F P
0 g
s
.45816 .59861 m .47151 .58533 L .45655 .5685 L p 0 .349 .781 r
F P
0 g
s
.47151 .58533 m .47349 .58335 L .47015 .56877 L p 0 .349 .781 r
F P
0 g
s
.47015 .56877 m .47349 .58335 L .48463 .57881 L p 0 .224 .802 r
F P
0 g
s
.48263 .5808 m .48463 .57881 L .47349 .58335 L p 0 .05 .118 r
F P
0 g
s
.47349 .58335 m .47151 .58533 L .48263 .5808 L p 0 .05 .118 r
F P
0 g
s
.45655 .5685 m .47151 .58533 L .48263 .5808 L p 0 .311 .95 r
F P
0 g
s
.48463 .57881 m .48125 .56412 L .47015 .56877 L p 0 .224 .802 r
F P
0 g
s
.48263 .5808 m .46757 .56383 L .45655 .5685 L p 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .45655 .5685 L .46757 .56383 L p 0 .05 .1 r
F P
0 g
s
.45655 .5685 m .44316 .58175 L .4541 .57718 L p 0 .05 .1 r
F P
0 g
s
.46757 .56383 m .4541 .57718 L .44316 .58175 L p 0 .05 .1 r
F P
0 g
s
.42814 .56487 m .44316 .58175 L .4541 .57718 L p 0 .311 .95 r
F P
0 g
s
.42971 .59507 m .44316 .58175 L .43238 .58626 L p 0 .05 .1 r
F P
0 g
s
.42971 .59507 m .44316 .58175 L .42814 .56487 L p 0 .349 .781 r
F P
0 g
s
.44316 .58175 m .42814 .56487 L .43898 .56016 L p 0 .311 .95 r
F P
0 g
s
.4541 .57718 m .43898 .56016 L .42814 .56487 L p 0 .311 .95 r
F P
0 g
s
.41465 .57816 m .42814 .56487 L .43898 .56016 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .42541 .57354 L .41465 .57816 L p 0 .05 .1 r
F P
0 g
s
.39956 .56122 m .41465 .57816 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.42541 .57354 m .41021 .55647 L .39956 .56122 L p 0 .31 .951 r
F P
0 g
s
.41465 .57816 m .39956 .56122 L .41021 .55647 L p 0 .31 .951 r
F P
0 g
s
.395 .53937 m .41021 .55647 L .39956 .56122 L p 0 .31 .951 r
F P
0 g
s
.38128 .55276 m .39654 .56988 L .41021 .55647 L p 0 .349 .781 r
F P
0 g
s
.41021 .55647 m .395 .53937 L .38128 .55276 L p 0 .349 .781 r
F P
0 g
s
.38128 .55276 m .395 .53937 L .41021 .55647 L p 0 .349 .781 r
F P
0 g
s
.41021 .55647 m .39654 .56988 L .38128 .55276 L p 0 .349 .781 r
F P
0 g
s
.3919 .5479 m .38128 .55276 L .395 .53937 L p 0 .05 .1 r
F P
0 g
s
.37805 .56143 m .3675 .5662 L .38128 .55276 L p 0 .05 .1 r
F P
0 g
s
.38128 .55276 m .3919 .5479 L .37805 .56143 L p 0 .05 .1 r
F P
0 g
s
.38986 .54439 m .33588 .58675 L .35455 .57884 L .1 0 0 r
F
.38875 .55659 m .37805 .56143 L .3919 .5479 L p 0 .05 .1 r
F P
0 g
s
.37475 .57028 m .36413 .57503 L .37805 .56143 L p 0 .05 .1 r
F P
0 g
s
.37805 .56143 m .38875 .55659 L .37475 .57028 L p 0 .05 .1 r
F P
0 g
s
.38986 .54439 m .35455 .57884 L .37475 .57028 L .1 0 0 r
F
.35367 .5797 m .37475 .57028 L p .35455 .57884 L F P
0 g
s
.3605 .56226 m .37406 .54906 L .38445 .54425 L p 0 .05 .1 r
F P
0 g
s
.34689 .57553 m .3605 .56226 L .37081 .55755 L p 0 .05 .1 r
F P
0 g
s
.38445 .54425 m .37081 .55755 L .3605 .56226 L p 0 .05 .1 r
F P
0 g
s
.37081 .55755 m .38445 .54425 L .395 .53937 L p 0 .05 .1 r
F P
0 g
s
.36898 .554 m .33322 .58884 L p .38986 .54439 L .1 0 0 r
F P
0 g
s
.35779 .55127 m .35527 .5443 L .32401 .52055 L .523 0 0 r
F
.35653 .54779 m .35527 .5443 L .3195 .57902 L .941 0 0 r
F
.35527 .5443 m .32881 .50895 L .32401 .52055 L .523 0 0 r
F
.35527 .5443 m .35695 .54051 L .32881 .50895 L F
.35611 .54241 m .35695 .54051 L .32109 .5753 L .937 0 0 r
F
.38431 .65687 m .36995 .66235 L .31439 .60037 L p .511 0 0 r
F P
0 g
s
.31439 .60037 m .32822 .59422 L .38431 .65687 L p .511 0 0 r
F P
0 g
s
.32822 .59422 m .31439 .60037 L .29619 .57576 L .511 0 0 r
F
.32822 .59422 m .29619 .57576 L .32211 .58594 L F
.39056 .65448 m .38431 .65687 L .32822 .59422 L p F P
0 g
s
.32822 .59422 m .33423 .59155 L .39056 .65448 L p .511 0 0 r
F P
0 g
s
.33423 .59155 m .32822 .59422 L .32211 .58594 L .511 0 0 r
F
.35779 .55127 m .3195 .57902 L .32211 .58594 L .941 0 0 r
F
.35779 .55127 m .32211 .58594 L .3195 .57902 L F
.33336 .59036 m .32211 .58594 L .3195 .57902 L .511 0 0 r
F
.33423 .59155 m .32211 .58594 L .33336 .59036 L F
.33322 .58884 m .34835 .60575 L .36198 .59241 L p 0 .349 .781 r
F P
0 g
s
.35527 .5443 m .32109 .5753 L .3195 .57902 L .937 0 0 r
F
.39307 .51697 m .39064 .50997 L .35527 .5443 L .941 0 0 r
F
.39307 .51697 m .35527 .5443 L .35653 .54779 L F
.39064 .50997 m .35695 .54051 L .35611 .54241 L .937 0 0 r
F
.39064 .50997 m .35611 .54241 L .35527 .5443 L F
.35611 .54241 m .32109 .5753 L .35527 .5443 L F
.39307 .51697 m .35653 .54779 L .35779 .55127 L .941 0 0 r
F
.35653 .54779 m .3195 .57902 L .35779 .55127 L F
.35779 .55127 m .3195 .57902 L .35527 .5443 L F
.35527 .5443 m .32109 .5753 L .35695 .54051 L .937 0 0 r
F
.35527 .5443 m .3195 .57902 L .32109 .5753 L F
.40435 .51955 m .32109 .5753 L .39241 .50611 L .856 0 0 r
F
.39241 .50611 m .32109 .5753 L .33322 .58884 L p F P
0 g
s
.32109 .5753 m .35695 .54051 L p .35956 .54826 L .1 0 0 r
F P
0 g
s
.40435 .51955 m .33322 .58884 L .32109 .5753 L .856 0 0 r
F
.34137 .56594 m .32109 .5753 L p .35956 .54826 L .1 0 0 r
F P
0 g
s
.33171 .54142 m .28821 .55499 L .29619 .57576 L .939 0 0 r
F
.33171 .54142 m .32401 .52055 L .28821 .55499 L F
.32401 .52055 m .29274 .54362 L .28821 .55499 L .946 0 0 r
F
.35695 .54051 m .32109 .5753 L .29274 .54362 L .856 0 0 r
F
.32401 .52055 m .32881 .50895 L .29274 .54362 L .946 0 0 r
F
.35695 .54051 m .29274 .54362 L .32881 .50895 L .856 0 0 r
F
.32109 .5753 m .35695 .54051 L .32881 .50895 L p F P
0 g
s
.32881 .50895 m .29274 .54362 L .32109 .5753 L p .856 0 0 r
F P
0 g
s
.29274 .54362 m .32881 .50895 L p .33092 .51615 L .1 0 0 r
F P
0 g
s
.31262 .53377 m .29274 .54362 L p .33092 .51615 L .1 0 0 r
F P
0 g
s
.24802 .49364 m .29274 .54362 L p .29682 .53339 L 0 .308 .954 r
F P
0 g
s
.33322 .58884 m .40435 .51955 L .39241 .50611 L p .856 0 0 r
F P
0 g
s
.35695 .54051 m .32109 .5753 L .34137 .56594 L p .1 0 0 r
F P
0 g
s
.31262 .53377 m .29316 .53041 L p .33844 .5673 L 0 .308 .954 r
F P
0 g
s
.34137 .56594 m .31262 .53377 L .33844 .5673 L 0 .308 .954 r
F
.32812 .55889 m .30308 .53849 L .32109 .5753 L F
.30308 .53849 m .30051 .53977 L .32109 .5753 L F
.29274 .54362 m .32109 .5753 L p .29682 .53339 L F P
0 g
s
.3416 .56987 m .32812 .55889 L .33322 .58884 L 0 .308 .954 r
F
.32109 .5753 m .33322 .58884 L p .32812 .55889 L F P
0 g
s
.3195 .57902 m .28821 .55499 L .29274 .54362 L .511 0 0 r
F
.3195 .57902 m .29274 .54362 L .32109 .5753 L F
.33299 .58937 m .33264 .5891 L .33273 .58906 L F
.33336 .59036 m .3195 .57902 L .33299 .58937 L F
.37705 .60927 m .36198 .59241 L .34835 .60575 L p 0 .349 .781 r
F P
0 g
s
.35861 .60135 m .34835 .60575 L .33322 .58884 L p 0 .308 .954 r
F P
0 g
s
.33322 .58884 m .34337 .58431 L .35861 .60135 L p 0 .308 .954 r
F P
0 g
s
.34835 .60575 m .35861 .60135 L .34337 .58431 L p 0 .308 .954 r
F P
0 g
s
.34337 .58431 m .33322 .58884 L .34835 .60575 L p 0 .308 .954 r
F P
0 g
s
.34835 .60575 m .33322 .58884 L .33302 .61341 L closepath p 0 .349 .781 r
F P
0 g
s
.33299 .58937 m .32109 .5753 L .33322 .58884 L .511 0 0 r
F
.33322 .58884 m .31467 .60691 L .33302 .61341 L closepath p 0 .349 .781 r
F P
0 g
s
.33281 .63804 m .33302 .61341 L .31467 .60691 L p 0 .349 .781 r
F P
0 g
s
.31467 .60691 m .29602 .62509 L .33281 .63804 L p 0 .349 .781 r
F P
0 g
s
.36198 .59241 m .37705 .60927 L .39058 .59596 L p 0 .349 .781 r
F P
0 g
s
.36902 .59688 m .35861 .60135 L .34337 .58431 L p 0 .308 .954 r
F P
0 g
s
.34337 .58431 m .35367 .5797 L .36902 .59688 L p 0 .308 .954 r
F P
0 g
s
.35367 .5797 m .34337 .58431 L .35861 .60135 L p 0 .308 .954 r
F P
0 g
s
.35861 .60135 m .36902 .59688 L .35367 .5797 L p 0 .308 .954 r
F P
0 g
s
.35367 .5797 m .36902 .59688 L .38281 .58335 L p 0 .349 .781 r
F P
0 g
s
.38281 .58335 m .36902 .59688 L .35367 .5797 L p 0 .349 .781 r
F P
0 g
s
.40558 .61276 m .41901 .59948 L .40405 .5827 L p 0 .349 .781 r
F P
0 g
s
.41465 .57816 m .40405 .5827 L .41901 .59948 L p 0 .31 .951 r
F P
0 g
s
.41901 .59948 m .40405 .5827 L .41465 .57816 L p 0 .31 .951 r
F P
0 g
s
.40405 .5827 m .39058 .59596 L .40558 .61276 L p 0 .349 .781 r
F P
0 g
s
.41465 .57816 m .40405 .5827 L .39058 .59596 L p 0 .05 .1 r
F P
0 g
s
.39058 .59596 m .40405 .5827 L .41465 .57816 L p 0 .05 .1 r
F P
0 g
s
.39209 .6261 m .40558 .61276 L .39058 .59596 L p 0 .349 .781 r
F P
0 g
s
.39058 .59596 m .37705 .60927 L .39209 .6261 L p 0 .349 .781 r
F P
0 g
s
.4011 .5915 m .39058 .59596 L .37705 .60927 L p 0 .05 .1 r
F P
0 g
s
.39058 .59596 m .4011 .5915 L .41465 .57816 L p 0 .05 .1 r
F P
0 g
s
.37705 .60927 m .39058 .59596 L .4011 .5915 L p 0 .05 .1 r
F P
0 g
s
.41465 .57816 m .4011 .5915 L .39058 .59596 L p 0 .05 .1 r
F P
0 g
s
.37705 .60927 m .38749 .60491 L .4011 .5915 L p 0 .05 .1 r
F P
0 g
s
.4011 .5915 m .38749 .60491 L .37705 .60927 L p 0 .05 .1 r
F P
0 g
s
.41178 .58698 m .4011 .5915 L .38749 .60491 L p 0 .05 .1 r
F P
0 g
s
.38749 .60491 m .4011 .5915 L .41178 .58698 L p 0 .05 .1 r
F P
0 g
s
.38749 .60491 m .39809 .60048 L .41178 .58698 L p 0 .05 .1 r
F P
0 g
s
.41178 .58698 m .39809 .60048 L .38749 .60491 L p 0 .05 .1 r
F P
0 g
s
.39809 .60048 m .38281 .58335 L .36902 .59688 L p 0 .349 .781 r
F P
0 g
s
.36902 .59688 m .38281 .58335 L .39809 .60048 L p 0 .349 .781 r
F P
0 g
s
.36413 .57503 m .37959 .59234 L .36902 .59688 L p 0 .308 .954 r
F P
0 g
s
.36902 .59688 m .35367 .5797 L .36413 .57503 L p 0 .308 .954 r
F P
0 g
s
.36413 .57503 m .35367 .5797 L .36902 .59688 L p 0 .308 .954 r
F P
0 g
s
.36902 .59688 m .37959 .59234 L .36413 .57503 L p 0 .308 .954 r
F P
0 g
s
.34835 .60575 m .36346 .62264 L .37705 .60927 L p 0 .349 .781 r
F P
0 g
s
.37855 .63949 m .39209 .6261 L .37705 .60927 L p 0 .349 .781 r
F P
0 g
s
.37705 .60927 m .36346 .62264 L .37855 .63949 L p 0 .349 .781 r
F P
0 g
s
.38749 .60491 m .37705 .60927 L .36346 .62264 L p 0 .05 .1 r
F P
0 g
s
.36346 .62264 m .37705 .60927 L .38749 .60491 L p 0 .05 .1 r
F P
0 g
s
.36346 .62264 m .37382 .61837 L .38749 .60491 L p 0 .05 .1 r
F P
0 g
s
.38749 .60491 m .37382 .61837 L .36346 .62264 L p 0 .05 .1 r
F P
0 g
s
.34835 .60575 m .35861 .60135 L .37382 .61837 L p 0 .308 .954 r
F P
0 g
s
.37382 .61837 m .35861 .60135 L .34835 .60575 L p 0 .308 .954 r
F P
0 g
s
.39809 .60048 m .38749 .60491 L .37382 .61837 L p 0 .05 .1 r
F P
0 g
s
.37382 .61837 m .38749 .60491 L .39809 .60048 L p 0 .05 .1 r
F P
0 g
s
.37382 .61837 m .38434 .61403 L .39809 .60048 L p 0 .05 .1 r
F P
0 g
s
.39809 .60048 m .38434 .61403 L .37382 .61837 L p 0 .05 .1 r
F P
0 g
s
.38434 .61403 m .37382 .61837 L .35861 .60135 L p 0 .308 .954 r
F P
0 g
s
.35861 .60135 m .36902 .59688 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.36902 .59688 m .35861 .60135 L .37382 .61837 L p 0 .308 .954 r
F P
0 g
s
.36902 .59688 m .35367 .5797 L .35349 .60463 L closepath p 0 .349 .781 r
F P
0 g
s
.35349 .60463 m .35367 .5797 L .36902 .59688 L closepath p 0 .349 .781 r
F P
0 g
s
.35349 .60463 m .35367 .5797 L .33489 .59802 L closepath p 0 .349 .781 r
F P
0 g
s
.33489 .59802 m .35367 .5797 L .35349 .60463 L closepath p 0 .349 .781 r
F P
0 g
s
.37382 .61837 m .36346 .62264 L .34835 .60575 L p 0 .308 .954 r
F P
0 g
s
.33302 .61341 m .33281 .63804 L .36346 .62264 L p 0 .349 .781 r
F P
0 g
s
.36346 .62264 m .34835 .60575 L .33302 .61341 L p 0 .349 .781 r
F P
0 g
s
.36346 .62264 m .33281 .63804 L .33269 .65293 L closepath p 0 .349 .781 r
F P
0 g
s
.34835 .60575 m .36346 .62264 L .37382 .61837 L p 0 .308 .954 r
F P
0 g
s
.3533 .62963 m .35349 .60463 L .33489 .59802 L p 0 .349 .781 r
F P
0 g
s
.31601 .61645 m .33489 .59802 L .35349 .60463 L p 0 .349 .781 r
F P
0 g
s
.33489 .59802 m .31601 .61645 L .3533 .62963 L p 0 .349 .781 r
F P
0 g
s
.37959 .59234 m .36413 .57503 L .37475 .57028 L p 0 .308 .954 r
F P
0 g
s
.37475 .57028 m .36413 .57503 L .37959 .59234 L p 0 .308 .954 r
F P
0 g
s
.33663 .60754 m .37475 .57028 L .35367 .5797 L p 0 .05 .1 r
F P
0 g
s
.29602 .62509 m .31601 .61645 L .35367 .5797 L p 0 .05 .1 r
F P
0 g
s
.35367 .5797 m .33322 .58884 L .29602 .62509 L p 0 .05 .1 r
F P
0 g
s
.33273 .58906 m .3195 .57902 L .32109 .5753 L .511 0 0 r
F
.33264 .5891 m .3195 .57902 L .33273 .58906 L F
.32211 .58594 m .29619 .57576 L .28821 .55499 L F
.32211 .58594 m .28821 .55499 L .3195 .57902 L F
.33322 .58884 m .24802 .49364 L .21015 .5295 L p 0 .349 .781 r
F P
0 g
s
.32109 .5753 m .29274 .54362 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.34137 .56594 m .36228 .5563 L p .35956 .54826 L .1 0 0 r
F P
0 g
s
.35695 .54051 m .34137 .56594 L .35956 .54826 L .1 0 0 r
F
.36228 .5563 m .34137 .56594 L p .35956 .54826 L F P
0 g
s
.36228 .5563 m .33995 .53128 L p .3488 .56252 L 0 .308 .954 r
F P
0 g
s
.35367 .5797 m .33995 .53128 L .33331 .54678 L 0 .308 .954 r
F
.33311 .52361 m .31262 .53377 L p .33092 .51615 L .1 0 0 r
F P
0 g
s
.28709 .47203 m .26725 .483 L .35367 .5797 L p 0 .308 .954 r
F P
0 g
s
.36228 .5563 m .34137 .56594 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.34137 .56594 m .32109 .5753 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.33995 .53128 m .28709 .47203 L p .33331 .54678 L 0 .308 .954 r
F P
0 g
s
.33311 .52361 m .36228 .5563 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.29274 .54362 m .31262 .53377 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.31262 .53377 m .33311 .52361 L p .327 .54987 L .511 0 0 r
F P
0 g
s
.30308 .53849 m .29682 .53339 L .30051 .53977 L 0 .308 .954 r
F
.29459 .55112 m .22891 .51935 L .31262 .53377 L 0 .349 .781 r
F
.31262 .53377 m .34137 .56594 L p .29459 .55112 L F P
0 g
s
.35367 .5797 m .34137 .56594 L .33844 .5673 L 0 .308 .954 r
F
.33418 .58842 m .35367 .5797 L p .33588 .58675 L .1 0 0 r
F P
0 g
s
.33322 .58884 m .35367 .5797 L p .3416 .56987 L 0 .308 .954 r
F P
0 g
s
.33322 .58884 m .32109 .5753 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.35367 .5797 m .37475 .57028 L .36228 .5563 L p 0 .308 .954 r
F P
0 g
s
.35367 .5797 m .36228 .5563 L .3488 .56252 L 0 .308 .954 r
F
.37475 .57028 m .35367 .5797 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.35367 .5797 m .33322 .58884 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.36228 .5563 m .37475 .57028 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.32109 .5753 m .34137 .56594 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.34137 .56594 m .36228 .5563 L p .34752 .57283 L .511 0 0 r
F P
0 g
s
.336 .57116 m .29459 .55112 L .34137 .56594 L 0 .349 .781 r
F
.34137 .56594 m .35367 .5797 L p .336 .57116 L F P
0 g
s
.25233 .49715 m .26725 .483 L .24802 .49364 L p 0 .308 .954 r
F P
0 g
s
.22891 .51935 m .26725 .483 L .31262 .53377 L p 0 .349 .781 r
F P
0 g
s
.21015 .5295 m .29602 .62509 L .33322 .58884 L p 0 .349 .781 r
F P
0 g
s
.32471 .6025 m .31467 .60691 L .33322 .58884 L p 0 .05 .1 r
F P
0 g
s
.33322 .58884 m .34337 .58431 L .32471 .6025 L p 0 .05 .1 r
F P
0 g
s
.31467 .60691 m .32471 .6025 L .30594 .6208 L p 0 .05 .1 r
F P
0 g
s
.30594 .6208 m .29602 .62509 L .31467 .60691 L p 0 .05 .1 r
F P
0 g
s
.33489 .59802 m .32471 .6025 L .34337 .58431 L p 0 .05 .1 r
F P
0 g
s
.34337 .58431 m .35367 .5797 L .33489 .59802 L p 0 .05 .1 r
F P
0 g
s
.30594 .6208 m .32471 .6025 L .33489 .59802 L p 0 .05 .1 r
F P
0 g
s
.33489 .59802 m .31601 .61645 L .30594 .6208 L p 0 .05 .1 r
F P
0 g
s
.35367 .5797 m .31601 .61645 L .30362 .60263 L p 0 .349 .781 r
F P
0 g
s
.30362 .60263 m .22891 .51935 L p .336 .57116 L 0 .349 .781 r
F P
0 g
s
.35367 .5797 m .30362 .60263 L .336 .57116 L 0 .349 .781 r
F
.39803 .53101 m .38756 .53591 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.40545 .51971 m .4024 .52215 L .41733 .53896 L p 0 .346 .852 r
F P
0 g
s
.42174 .52295 m .40545 .51971 L p .41733 .53896 L 0 .346 .852 r
F P
0 g
s
.40545 .51971 m .42174 .52295 L .42721 .5204 L p 0 .409 1 r
F P
0 g
s
.42721 .5204 m .41356 .51587 L .40545 .51971 L p 0 .409 1 r
F P
0 g
s
.4024 .52215 m .41155 .51783 L p .41232 .52067 L 0 .311 .95 r
F P
0 g
s
.41733 .53896 m .40439 .5244 L p .41232 .52067 L 0 .311 .95 r
F P
0 g
s
.40439 .5244 m .4024 .52215 L p .41232 .52067 L 0 .311 .95 r
F P
0 g
s
.43284 .52657 m .41733 .53896 L .42657 .53475 L p 0 .05 .1 r
F P
0 g
s
.43284 .52657 m .43474 .52719 L .43837 .52553 L p 0 .387 1 r
F P
0 g
s
.43837 .52553 m .43674 .52478 L .43284 .52657 L p 0 .387 1 r
F P
0 g
s
.41733 .53896 m .43284 .52657 L .43674 .52478 L p 0 .05 .1 r
F P
0 g
s
.43674 .52478 m .42657 .53475 L .41733 .53896 L p 0 .05 .1 r
F P
0 g
s
.41733 .53896 m .43284 .52657 L .42174 .52295 L p 0 .346 .852 r
F P
0 g
s
.41733 .53896 m .42657 .53475 L p .4056 .52382 L 0 .311 .95 r
F P
0 g
s
.4024 .52215 m .40439 .5244 L p .4056 .52382 L 0 .311 .95 r
F P
0 g
s
.40439 .5244 m .41733 .53896 L p .4056 .52382 L 0 .311 .95 r
F P
0 g
s
.38756 .53591 m .38955 .53815 L p .39094 .53751 L 0 .311 .95 r
F P
0 g
s
.4024 .52215 m .39832 .52543 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.41733 .53896 m .40439 .5244 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.40439 .5244 m .4024 .52215 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.41325 .54222 m .41733 .53896 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.39832 .52543 m .40031 .52767 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.40031 .52767 m .41325 .54222 L p .40085 .52723 L 0 .346 .852 r
F P
0 g
s
.42657 .53475 m .41155 .51783 L .4024 .52215 L p 0 .311 .95 r
F P
0 g
s
.39832 .52543 m .4024 .52215 L .41155 .51783 L p 0 .05 .1 r
F P
0 g
s
.38756 .53591 m .39832 .52543 L p .41155 .51783 L 0 .05 .1 r
F P
0 g
s
.4024 .52215 m .40545 .51971 L .41356 .51587 L p 0 .05 .1 r
F P
0 g
s
.41356 .51587 m .41155 .51783 L .4024 .52215 L p 0 .05 .1 r
F P
0 g
s
.37406 .54906 m .38756 .53591 L .39803 .53101 L p 0 .05 .1 r
F P
0 g
s
.41155 .51783 m .39803 .53101 L .38756 .53591 L p 0 .05 .1 r
F P
0 g
s
.39803 .53101 m .38445 .54425 L .37406 .54906 L p 0 .05 .1 r
F P
0 g
s
.41325 .54222 m .41733 .53896 L .42657 .53475 L p 0 .05 .1 r
F P
0 g
s
.41733 .53896 m .41325 .54222 L p .41309 .54795 L 0 .05 .1 r
F P
0 g
s
.41309 .54795 m .42657 .53475 L .41733 .53896 L p 0 .05 .1 r
F P
0 g
s
.41155 .51783 m .42657 .53475 L .41733 .53896 L p 0 .311 .95 r
F P
0 g
s
.42657 .53475 m .41309 .54795 L .39803 .53101 L p 0 .349 .781 r
F P
0 g
s
.39803 .53101 m .41155 .51783 L .42657 .53475 L p 0 .349 .781 r
F P
0 g
s
.41155 .51783 m .39803 .53101 L .41309 .54795 L p 0 .349 .781 r
F P
0 g
s
.41309 .54795 m .42657 .53475 L .41155 .51783 L p 0 .349 .781 r
F P
0 g
s
.42657 .53475 m .41309 .54795 L .42383 .54312 L p 0 .05 .1 r
F P
0 g
s
.44496 .53262 m .45277 .53943 L .45495 .53846 L p 0 .328 .973 r
F P
0 g
s
.44157 .55163 m .45495 .53846 L .45277 .53943 L p 0 .05 .1 r
F P
0 g
s
.45495 .53846 m .44157 .55163 L .42657 .53475 L p 0 .349 .781 r
F P
0 g
s
.43474 .52719 m .44496 .53262 L .44749 .53147 L p 0 .36 1 r
F P
0 g
s
.45495 .53846 m .44749 .53147 L .44496 .53262 L p 0 .328 .973 r
F P
0 g
s
.44749 .53147 m .45495 .53846 L p .42657 .53475 L 0 .349 .781 r
F P
0 g
s
.44749 .53147 m .43837 .52553 L .43474 .52719 L p 0 .36 1 r
F P
0 g
s
.43837 .52553 m .44749 .53147 L p .42657 .53475 L 0 .349 .781 r
F P
0 g
s
.43674 .52478 m .42657 .53475 L .44157 .55163 L p 0 .349 .781 r
F P
0 g
s
.45495 .53846 m .44157 .55163 L .45249 .54684 L p 0 .05 .1 r
F P
0 g
s
.44157 .55163 m .45495 .53846 L .44749 .53147 L p 0 .349 .781 r
F P
0 g
s
.45495 .53846 m .46106 .54677 L .4721 .54195 L p 0 .296 .924 r
F P
0 g
s
.4721 .54195 m .46595 .53357 L .45495 .53846 L p 0 .296 .924 r
F P
0 g
s
.44157 .55163 m .45495 .53846 L .46595 .53357 L p 0 .05 .1 r
F P
0 g
s
.44749 .53147 m .43837 .52553 L p .44157 .55163 L 0 .349 .781 r
F P
0 g
s
.43837 .52553 m .43674 .52478 L p .44157 .55163 L 0 .349 .781 r
F P
0 g
s
.46595 .53357 m .45249 .54684 L .44157 .55163 L p 0 .05 .1 r
F P
0 g
s
.42657 .53475 m .44157 .55163 L .45249 .54684 L p 0 .311 .95 r
F P
0 g
s
.44157 .55163 m .42657 .53475 L .43738 .52982 L p 0 .311 .95 r
F P
0 g
s
.45249 .54684 m .43738 .52982 L .42657 .53475 L p 0 .311 .95 r
F P
0 g
s
.41309 .54795 m .42657 .53475 L .43738 .52982 L p 0 .05 .1 r
F P
0 g
s
.43738 .52982 m .42383 .54312 L .41309 .54795 L p 0 .05 .1 r
F P
0 g
s
.39803 .53101 m .41309 .54795 L .42383 .54312 L p 0 .311 .95 r
F P
0 g
s
.41309 .54795 m .39803 .53101 L .40865 .52605 L p 0 .311 .95 r
F P
0 g
s
.42383 .54312 m .40865 .52605 L .39803 .53101 L p 0 .311 .95 r
F P
0 g
s
.38445 .54425 m .39803 .53101 L .40865 .52605 L p 0 .05 .1 r
F P
0 g
s
.40865 .52605 m .395 .53937 L .38445 .54425 L p 0 .05 .1 r
F P
0 g
s
.40435 .51955 m .36898 .554 L p .38986 .54439 L .1 0 0 r
F P
0 g
s
.35695 .54051 m .39241 .50611 L p .37765 .53068 L .1 0 0 r
F P
0 g
s
.37765 .53068 m .36228 .5563 L .35695 .54051 L .1 0 0 r
F
.46757 .56383 m .46761 .56379 L p .46762 .56383 L 0 .349 .781 r
F P
0 g
s
.46761 .56379 m .47773 .55376 L p .46762 .56383 L 0 .349 .781 r
F P
0 g
s
.47773 .55376 m .48125 .56412 L p .46762 .56383 L 0 .349 .781 r
F P
0 g
s
.48125 .56412 m .47773 .55376 L p .48263 .5808 L 0 .349 .781 r
F P
0 g
s
.47876 .5591 m .48898 .54896 L .49253 .55939 L p 0 .349 .781 r
F P
0 g
s
.50472 .5706 m .49836 .55695 L .49253 .55939 L p 0 .224 .802 r
F P
0 g
s
.48859 .55494 m .49319 .55588 L .50472 .5706 L 0 .332 .563 r
F
.49836 .55695 m .50305 .567 L p .49319 .55588 L F P
0 g
s
.50305 .567 m .50472 .5706 L p .49319 .55588 L 0 .332 .563 r
F P
0 g
s
.47876 .5591 m .49392 .5762 L p .49229 .5672 L 0 .349 .781 r
F P
0 g
s
.48214 .55575 m .47876 .5591 L p .49229 .5672 L 0 .349 .781 r
F P
0 g
s
.44925 .65378 m .48531 .61764 L p .46276 .62625 L .18 0 0 r
F P
0 g
s
.44087 .63461 m .48531 .61764 L .44925 .65378 L p .18 0 0 r
F P
0 g
s
.4918 .58508 m .43687 .63991 L p .45763 .59882 L .166 0 0 r
F P
0 g
s
.46446 .61238 m .47816 .5987 L .46685 .60318 L p 0 .05 .118 r
F P
0 g
s
.46685 .60318 m .45323 .61677 L .46446 .61238 L p 0 .05 .118 r
F P
0 g
s
.4507 .62611 m .46446 .61238 L .45323 .61677 L p 0 .05 .118 r
F P
0 g
s
.45065 .61265 m .43687 .63991 L .42893 .62122 L .166 0 0 r
F
.45323 .61677 m .43955 .63041 L .4507 .62611 L p 0 .05 .118 r
F P
0 g
s
.43687 .63991 m .4507 .62611 L .43955 .63041 L p 0 .05 .118 r
F P
0 g
s
.4692 .59417 m .48263 .5808 L .47151 .58533 L p 0 .05 .118 r
F P
0 g
s
.47151 .58533 m .45816 .59861 L .4692 .59417 L p 0 .05 .118 r
F P
0 g
s
.4541 .57718 m .4692 .59417 L .45816 .59861 L p 0 .311 .95 r
F P
0 g
s
.45572 .6076 m .4692 .59417 L .45816 .59861 L p 0 .05 .118 r
F P
0 g
s
.44316 .58175 m .45816 .59861 L .4692 .59417 L p 0 .311 .95 r
F P
0 g
s
.4692 .59417 m .4541 .57718 L .44316 .58175 L p 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .48263 .5808 L .47151 .58533 L p 0 .311 .95 r
F P
0 g
s
.48263 .5808 m .4692 .59417 L .4541 .57718 L p 0 .349 .781 r
F P
0 g
s
.48263 .5808 m .4692 .59417 L .48042 .58966 L p 0 .05 .118 r
F P
0 g
s
.4692 .59417 m .48263 .5808 L .46757 .56383 L p 0 .349 .781 r
F P
0 g
s
.46757 .56383 m .4541 .57718 L .4692 .59417 L p 0 .349 .781 r
F P
0 g
s
.45816 .59861 m .44727 .60299 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.44316 .58175 m .45616 .59637 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.45616 .59637 m .45816 .59861 L p .44673 .60018 L 0 .311 .95 r
F P
0 g
s
.44475 .61195 m .45816 .59861 L .44727 .60299 L p 0 .05 .118 r
F P
0 g
s
.45816 .59861 m .44475 .61195 L .42971 .59507 L p 0 .349 .781 r
F P
0 g
s
.42971 .59507 m .44316 .58175 L .45816 .59861 L p 0 .349 .781 r
F P
0 g
s
.44475 .61195 m .45816 .59861 L .44316 .58175 L p 0 .349 .781 r
F P
0 g
s
.45816 .59861 m .44475 .61195 L .45572 .6076 L p 0 .05 .118 r
F P
0 g
s
.44316 .58175 m .42971 .59507 L .44475 .61195 L p 0 .349 .781 r
F P
0 g
s
.4692 .59417 m .45572 .6076 L .44057 .59059 L p 0 .349 .781 r
F P
0 g
s
.44057 .59059 m .4541 .57718 L .4692 .59417 L p 0 .349 .781 r
F P
0 g
s
.46685 .60318 m .48042 .58966 L .4692 .59417 L p 0 .05 .118 r
F P
0 g
s
.4692 .59417 m .45572 .6076 L .46685 .60318 L p 0 .05 .118 r
F P
0 g
s
.4541 .57718 m .4692 .59417 L .48042 .58966 L p 0 .311 .95 r
F P
0 g
s
.45572 .6076 m .4692 .59417 L .4541 .57718 L p 0 .349 .781 r
F P
0 g
s
.4541 .57718 m .46757 .56383 L .48263 .5808 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .48042 .58966 L .4692 .59417 L p 0 .311 .95 r
F P
0 g
s
.4692 .59417 m .4541 .57718 L .46521 .57254 L p 0 .311 .95 r
F P
0 g
s
.45323 .61677 m .46685 .60318 L .45572 .6076 L p 0 .05 .118 r
F P
0 g
s
.4541 .57718 m .44057 .59059 L .45572 .6076 L p 0 .349 .781 r
F P
0 g
s
.44057 .59059 m .45572 .6076 L .46685 .60318 L p 0 .31 .951 r
F P
0 g
s
.46685 .60318 m .4516 .58604 L .44057 .59059 L p 0 .31 .951 r
F P
0 g
s
.4516 .58604 m .46685 .60318 L .45572 .6076 L p 0 .31 .951 r
F P
0 g
s
.48042 .58966 m .46685 .60318 L .47816 .5987 L p 0 .05 .118 r
F P
0 g
s
.48042 .58966 m .46521 .57254 L .4541 .57718 L p 0 .311 .95 r
F P
0 g
s
.46685 .60318 m .48042 .58966 L .46521 .57254 L p 0 .349 .781 r
F P
0 g
s
.48042 .58966 m .46685 .60318 L .4516 .58604 L p 0 .349 .781 r
F P
0 g
s
.4516 .58604 m .46521 .57254 L .48042 .58966 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .4516 .58604 L .46685 .60318 L p 0 .349 .781 r
F P
0 g
s
.46685 .60318 m .47816 .5987 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.4516 .58604 m .46482 .6009 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.46482 .6009 m .46685 .60318 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.4628 .58142 m .4516 .58604 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.47816 .5987 m .47611 .5964 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.47611 .5964 m .4628 .58142 L p .4746 .597 L 0 .31 .951 r
F P
0 g
s
.47816 .5987 m .46685 .60318 L p .46632 .6003 L 0 .31 .951 r
F P
0 g
s
.4628 .58142 m .47611 .5964 L p .46632 .6003 L 0 .31 .951 r
F P
0 g
s
.47611 .5964 m .47816 .5987 L p .46632 .6003 L 0 .31 .951 r
F P
0 g
s
.46685 .60318 m .4516 .58604 L .4628 .58142 L p 0 .31 .951 r
F P
0 g
s
.4628 .58142 m .47816 .5987 L .46446 .61238 L p 0 .35 .78 r
F P
0 g
s
.45572 .6076 m .44057 .59059 L .4516 .58604 L p 0 .31 .951 r
F P
0 g
s
.46446 .61238 m .44905 .59507 L .4628 .58142 L p 0 .35 .78 r
F P
0 g
s
.45572 .6076 m .44475 .61195 L .43128 .62535 L p 0 .05 .118 r
F P
0 g
s
.44475 .61195 m .45572 .6076 L .44057 .59059 L p 0 .31 .951 r
F P
0 g
s
.44057 .59059 m .45572 .6076 L .44475 .61195 L p 0 .31 .951 r
F P
0 g
s
.43128 .62535 m .44217 .62109 L .45572 .6076 L p 0 .05 .118 r
F P
0 g
s
.45572 .6076 m .44217 .62109 L .45323 .61677 L p 0 .05 .118 r
F P
0 g
s
.39361 .65632 m .42893 .62122 L p .43649 .63899 L .166 0 0 r
F P
0 g
s
.44475 .61195 m .43394 .61624 L .42056 .62954 L p 0 .05 .118 r
F P
0 g
s
.42056 .62954 m .43128 .62535 L .44475 .61195 L p 0 .05 .118 r
F P
0 g
s
.44057 .59059 m .42971 .59507 L .44475 .61195 L p 0 .31 .951 r
F P
0 g
s
.44475 .61195 m .42971 .59507 L .44057 .59059 L p 0 .31 .951 r
F P
0 g
s
.44217 .62109 m .45572 .6076 L .44057 .59059 L p 0 .349 .781 r
F P
0 g
s
.44057 .59059 m .45572 .6076 L .44217 .62109 L p 0 .349 .781 r
F P
0 g
s
.43955 .63041 m .45323 .61677 L .44217 .62109 L p 0 .05 .118 r
F P
0 g
s
.44905 .59507 m .46446 .61238 L .4507 .62611 L p 0 .35 .78 r
F P
0 g
s
.44057 .59059 m .42699 .60405 L .44217 .62109 L p 0 .349 .781 r
F P
0 g
s
.44217 .62109 m .42699 .60405 L .44057 .59059 L p 0 .349 .781 r
F P
0 g
s
.4507 .62611 m .43525 .60878 L .44905 .59507 L p 0 .35 .78 r
F P
0 g
s
.44217 .62109 m .43128 .62535 L .41776 .6388 L p 0 .05 .118 r
F P
0 g
s
.41776 .6388 m .42857 .63464 L .44217 .62109 L p 0 .05 .118 r
F P
0 g
s
.44217 .62109 m .42857 .63464 L .43955 .63041 L p 0 .05 .118 r
F P
0 g
s
.42056 .62954 m .43394 .61624 L .41901 .59948 L p 0 .349 .781 r
F P
0 g
s
.43128 .62535 m .42056 .62954 L .40711 .64291 L p 0 .05 .118 r
F P
0 g
s
.40711 .64291 m .41776 .6388 L .43128 .62535 L p 0 .05 .118 r
F P
0 g
s
.42857 .63464 m .44217 .62109 L .42699 .60405 L p 0 .349 .781 r
F P
0 g
s
.42699 .60405 m .44217 .62109 L .42857 .63464 L p 0 .349 .781 r
F P
0 g
s
.43477 .64071 m .39361 .65632 L p .43649 .63899 L .166 0 0 r
F P
0 g
s
.42581 .64411 m .43955 .63041 L .42857 .63464 L p 0 .05 .118 r
F P
0 g
s
.43687 .63991 m .43477 .64071 L p .43649 .63899 L .166 0 0 r
F P
0 g
s
.43955 .63041 m .42581 .64411 L .43687 .63991 L p 0 .05 .118 r
F P
0 g
s
.43525 .60878 m .4507 .62611 L .43687 .63991 L p 0 .35 .78 r
F P
0 g
s
.47318 .60356 m .43687 .63991 L .47303 .60382 L .889 0 0 r
F
.47816 .5987 m .4918 .58508 L .48042 .58966 L p 0 .05 .118 r
F P
0 g
s
.49253 .55939 m .49593 .57419 L .50472 .5706 L p 0 .224 .802 r
F P
0 g
s
.50385 .57215 m .50472 .5706 L .49593 .57419 L p 0 .05 .118 r
F P
0 g
s
.49593 .57419 m .49392 .5762 L .50385 .57215 L p 0 .05 .118 r
F P
0 g
s
.50267 .57423 m .50385 .57215 L .49392 .5762 L p 0 .05 .118 r
F P
0 g
s
.4918 .58508 m .50267 .57423 L p .49392 .5762 L 0 .05 .118 r
F P
0 g
s
.49392 .5762 m .48042 .58966 L .4918 .58508 L p 0 .05 .118 r
F P
0 g
s
.49392 .5762 m .49593 .57419 L .49253 .55939 L p 0 .349 .781 r
F P
0 g
s
.49253 .55939 m .49593 .57419 L p .47876 .5591 L 0 .349 .781 r
F P
0 g
s
.49593 .57419 m .49392 .5762 L .47876 .5591 L p 0 .349 .781 r
F P
0 g
s
.47876 .5591 m .49392 .5762 L .50385 .57215 L p 0 .311 .95 r
F P
0 g
s
.48859 .55494 m .50385 .57215 L .49392 .5762 L p 0 .311 .95 r
F P
0 g
s
.50385 .57215 m .48859 .55494 L .47876 .5591 L p 0 .311 .95 r
F P
0 g
s
.48042 .58966 m .4918 .58508 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .48263 .5808 L p .48101 .57187 L 0 .349 .781 r
F P
0 g
s
.48263 .5808 m .48463 .57881 L .48125 .56412 L p 0 .349 .781 r
F P
0 g
s
.48463 .57881 m .48263 .5808 L .46757 .56383 L p 0 .349 .781 r
F P
0 g
s
.48463 .57881 m .48263 .5808 L .49392 .5762 L p 0 .05 .118 r
F P
0 g
s
.48042 .58966 m .49392 .5762 L .48263 .5808 L p 0 .05 .118 r
F P
0 g
s
.48125 .56412 m .48463 .57881 L p .46757 .56383 L 0 .349 .781 r
F P
0 g
s
.47876 .5591 m .49392 .5762 L .48263 .5808 L p 0 .311 .95 r
F P
0 g
s
.47773 .55376 m .47093 .5605 L p .48101 .57187 L 0 .349 .781 r
F P
0 g
s
.47093 .5605 m .46757 .56383 L p .48101 .57187 L 0 .349 .781 r
F P
0 g
s
.48263 .5808 m .46757 .56383 L .47876 .5591 L p 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .48263 .5808 L .49392 .5762 L p 0 .311 .95 r
F P
0 g
s
.49392 .5762 m .47876 .5591 L .46757 .56383 L p 0 .311 .95 r
F P
0 g
s
.48042 .58966 m .49392 .5762 L .47876 .5591 L p 0 .349 .781 r
F P
0 g
s
.49392 .5762 m .48042 .58966 L .46521 .57254 L p 0 .349 .781 r
F P
0 g
s
.47876 .5591 m .46521 .57254 L .48042 .58966 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .47839 .58738 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.47839 .58738 m .48042 .58966 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.4918 .58508 m .48042 .58966 L p .4799 .58677 L 0 .311 .95 r
F P
0 g
s
.46521 .57254 m .47876 .5591 L .49392 .5762 L p 0 .349 .781 r
F P
0 g
s
.47649 .56782 m .48976 .58278 L p .4799 .58677 L 0 .311 .95 r
F P
0 g
s
.48976 .58278 m .4918 .58508 L p .4799 .58677 L 0 .311 .95 r
F P
0 g
s
.47649 .56782 m .46521 .57254 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.4918 .58508 m .48976 .58278 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.48976 .58278 m .47649 .56782 L p .48824 .5834 L 0 .311 .95 r
F P
0 g
s
.43921 .63592 m .43681 .63839 L .43933 .63587 L .884 0 0 r
F
.50472 .5706 m .50385 .57215 L .48859 .55494 L p 0 .332 .563 r
F P
0 g
s
.50385 .57215 m .50267 .57423 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.48859 .55494 m .50182 .56986 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.50182 .56986 m .50385 .57215 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.49392 .5762 m .47876 .5591 L .48859 .55494 L p 0 .311 .95 r
F P
0 g
s
.4874 .55699 m .48859 .55494 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.50267 .57423 m .50064 .57193 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.50064 .57193 m .4874 .55699 L p .5008 .57166 L 0 .332 .563 r
F P
0 g
s
.5079 .56537 m .50579 .56955 L .50876 .56658 L .884 0 0 r
F
.50267 .57423 m .4918 .58508 L .47649 .56782 L p 0 .35 .78 r
F P
0 g
s
.47649 .56782 m .4874 .55699 L .50267 .57423 L p 0 .35 .78 r
F P
0 g
s
.48042 .58966 m .46521 .57254 L .47649 .56782 L p 0 .311 .95 r
F P
0 g
s
.4918 .58508 m .47816 .5987 L .4628 .58142 L p 0 .35 .78 r
F P
0 g
s
.4628 .58142 m .47649 .56782 L .4918 .58508 L p 0 .35 .78 r
F P
0 g
s
.5079 .56537 m .47255 .60167 L .50579 .56955 L .884 0 0 r
F
.47255 .60167 m .47297 .60226 L .50579 .56955 L F
.43921 .63592 m .43933 .63587 L .50876 .56658 L F
.47255 .60167 m .43921 .63592 L .47297 .60226 L F
.44925 .65378 m .43687 .63991 L .50877 .56814 L p .858 0 0 r
F P
0 g
s
.50877 .56814 m .43687 .63991 L .44925 .65378 L .858 0 0 r
F
.47318 .60356 m .43716 .63939 L .43687 .63991 L .889 0 0 r
F
.50908 .5676 m .47332 .60329 L .47318 .60356 L F
.47332 .60329 m .43716 .63939 L .47318 .60356 L F
.50876 .56658 m .47316 .60278 L .50908 .5676 L .949 0 0 r
F
.47316 .60278 m .43716 .63939 L .47332 .60329 L F
.47316 .60278 m .47332 .60329 L .50908 .5676 L F
.4541 .57718 m .46757 .56383 L .45655 .5685 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .45249 .54684 L .44157 .55163 L p 0 .05 .1 r
F P
0 g
s
.42383 .54312 m .43738 .52982 L .42657 .53475 L p 0 .05 .1 r
F P
0 g
s
.45249 .54684 m .46757 .56383 L .45655 .5685 L p 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .4541 .57718 L .43898 .56016 L p 0 .349 .781 r
F P
0 g
s
.43898 .56016 m .45249 .54684 L .46757 .56383 L p 0 .349 .781 r
F P
0 g
s
.4541 .57718 m .46757 .56383 L .47876 .5591 L p 0 .05 .1 r
F P
0 g
s
.46757 .56383 m .4541 .57718 L .46521 .57254 L p 0 .05 .1 r
F P
0 g
s
.4541 .57718 m .46757 .56383 L .45249 .54684 L p 0 .349 .781 r
F P
0 g
s
.43738 .52982 m .45249 .54684 L .44157 .55163 L p 0 .311 .95 r
F P
0 g
s
.45249 .54684 m .43898 .56016 L .42383 .54312 L p 0 .349 .781 r
F P
0 g
s
.42383 .54312 m .43738 .52982 L .45249 .54684 L p 0 .349 .781 r
F P
0 g
s
.45249 .54684 m .43898 .56016 L .4541 .57718 L p 0 .349 .781 r
F P
0 g
s
.45249 .54684 m .43898 .56016 L .44998 .55539 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .45249 .54684 L .43738 .52982 L p 0 .349 .781 r
F P
0 g
s
.47773 .55376 m .47713 .55199 L .46606 .55674 L p 0 .243 .835 r
F P
0 g
s
.46106 .54677 m .46606 .55674 L .47713 .55199 L p 0 .267 .876 r
F P
0 g
s
.47713 .55199 m .47773 .55376 L p .45249 .54684 L 0 .349 .781 r
F P
0 g
s
.47713 .55199 m .4721 .54195 L .46106 .54677 L p 0 .267 .876 r
F P
0 g
s
.4721 .54195 m .47713 .55199 L p .45249 .54684 L 0 .349 .781 r
F P
0 g
s
.46606 .55674 m .46665 .55849 L .47773 .55376 L p 0 .243 .835 r
F P
0 g
s
.46757 .56383 m .47773 .55376 L .46665 .55849 L p 0 .05 .1 r
F P
0 g
s
.47773 .55376 m .46757 .56383 L .45249 .54684 L p 0 .349 .781 r
F P
0 g
s
.45249 .54684 m .46595 .53357 L .4721 .54195 L p 0 .349 .781 r
F P
0 g
s
.46595 .53357 m .45249 .54684 L .46757 .56383 L p 0 .349 .781 r
F P
0 g
s
.47713 .55199 m .4721 .54195 L p .46757 .56383 L 0 .349 .781 r
F P
0 g
s
.46757 .56383 m .47773 .55376 L .47713 .55199 L p 0 .349 .781 r
F P
0 g
s
.46757 .56383 m .47773 .55376 L .48898 .54896 L p 0 .05 .1 r
F P
0 g
s
.47773 .55376 m .46757 .56383 L .47876 .5591 L p 0 .05 .1 r
F P
0 g
s
.4721 .54195 m .46595 .53357 L p .46757 .56383 L 0 .349 .781 r
F P
0 g
s
.48898 .54896 m .47876 .5591 L .46757 .56383 L p 0 .05 .1 r
F P
0 g
s
.45249 .54684 m .46757 .56383 L .47876 .5591 L p 0 .311 .95 r
F P
0 g
s
.46757 .56383 m .45249 .54684 L .46357 .54197 L p 0 .311 .95 r
F P
0 g
s
.47876 .5591 m .46357 .54197 L .45249 .54684 L p 0 .311 .95 r
F P
0 g
s
.43898 .56016 m .45249 .54684 L .46357 .54197 L p 0 .05 .1 r
F P
0 g
s
.42657 .53475 m .43674 .52478 L .43284 .52657 L p 0 .05 .1 r
F P
0 g
s
.42657 .53475 m .43674 .52478 L .43837 .52553 L p 0 .349 .781 r
F P
0 g
s
.43674 .52478 m .42657 .53475 L .43738 .52982 L p 0 .05 .1 r
F P
0 g
s
.43837 .52553 m .44749 .53147 L .45843 .52653 L p 0 .36 1 r
F P
0 g
s
.43674 .52478 m .43837 .52553 L .44925 .52055 L p 0 .387 1 r
F P
0 g
s
.45843 .52653 m .44925 .52055 L .43837 .52553 L p 0 .36 1 r
F P
0 g
s
.44925 .52055 m .44761 .51979 L .43674 .52478 L p 0 .387 1 r
F P
0 g
s
.42657 .53475 m .43674 .52478 L .44761 .51979 L p 0 .05 .1 r
F P
0 g
s
.42174 .52295 m .43284 .52657 L .43674 .52478 L p 0 .387 1 r
F P
0 g
s
.43674 .52478 m .42721 .5204 L .42174 .52295 L p 0 .387 1 r
F P
0 g
s
.43674 .52478 m .42657 .53475 L .41155 .51783 L p 0 .349 .781 r
F P
0 g
s
.42657 .53475 m .43674 .52478 L .42721 .5204 L p 0 .349 .781 r
F P
0 g
s
.42721 .5204 m .41356 .51587 L p .42657 .53475 L 0 .349 .781 r
F P
0 g
s
.41356 .51587 m .41155 .51783 L .42657 .53475 L p 0 .349 .781 r
F P
0 g
s
.44761 .51979 m .43738 .52982 L .42657 .53475 L p 0 .05 .1 r
F P
0 g
s
.41155 .51783 m .42657 .53475 L .43738 .52982 L p 0 .311 .95 r
F P
0 g
s
.42721 .5204 m .43674 .52478 L p .41155 .51783 L 0 .349 .781 r
F P
0 g
s
.41356 .51587 m .42721 .5204 L .43802 .51537 L p 0 .409 1 r
F P
0 g
s
.41155 .51783 m .41356 .51587 L .42721 .5204 L p 0 .349 .781 r
F P
0 g
s
.43802 .51537 m .42428 .5108 L .41356 .51587 L p 0 .409 1 r
F P
0 g
s
.42657 .53475 m .41155 .51783 L .42225 .51278 L p 0 .311 .95 r
F P
0 g
s
.42721 .5204 m .43674 .52478 L .44761 .51979 L p 0 .387 1 r
F P
0 g
s
.44761 .51979 m .43802 .51537 L .42721 .5204 L p 0 .387 1 r
F P
0 g
s
.42225 .51278 m .43738 .52982 L .42657 .53475 L p 0 .311 .95 r
F P
0 g
s
.43738 .52982 m .42383 .54312 L .40865 .52605 L p 0 .349 .781 r
F P
0 g
s
.43738 .52982 m .42383 .54312 L .43898 .56016 L p 0 .349 .781 r
F P
0 g
s
.43738 .52982 m .42383 .54312 L .43472 .53821 L p 0 .05 .1 r
F P
0 g
s
.43738 .52982 m .42225 .51278 L .41155 .51783 L p 0 .311 .95 r
F P
0 g
s
.42383 .54312 m .43738 .52982 L .42225 .51278 L p 0 .349 .781 r
F P
0 g
s
.45249 .54684 m .46595 .53357 L .45495 .53846 L p 0 .05 .1 r
F P
0 g
s
.44749 .53147 m .45495 .53846 L .46595 .53357 L p 0 .328 .973 r
F P
0 g
s
.46595 .53357 m .45843 .52653 L .44749 .53147 L p 0 .328 .973 r
F P
0 g
s
.46595 .53357 m .45249 .54684 L .43738 .52982 L p 0 .349 .781 r
F P
0 g
s
.45843 .52653 m .46595 .53357 L p .43738 .52982 L 0 .349 .781 r
F P
0 g
s
.44925 .52055 m .45843 .52653 L p .43738 .52982 L 0 .349 .781 r
F P
0 g
s
.44761 .51979 m .43738 .52982 L .45249 .54684 L p 0 .349 .781 r
F P
0 g
s
.46595 .53357 m .45249 .54684 L .46357 .54197 L p 0 .05 .1 r
F P
0 g
s
.45249 .54684 m .46595 .53357 L .45843 .52653 L p 0 .349 .781 r
F P
0 g
s
.46595 .53357 m .4721 .54195 L .4833 .53706 L p 0 .296 .924 r
F P
0 g
s
.4833 .53706 m .47711 .52862 L .46595 .53357 L p 0 .296 .924 r
F P
0 g
s
.45249 .54684 m .46595 .53357 L .47711 .52862 L p 0 .05 .1 r
F P
0 g
s
.45843 .52653 m .44925 .52055 L p .45249 .54684 L 0 .349 .781 r
F P
0 g
s
.44925 .52055 m .44761 .51979 L p .45249 .54684 L 0 .349 .781 r
F P
0 g
s
.47711 .52862 m .46357 .54197 L .45249 .54684 L p 0 .05 .1 r
F P
0 g
s
.43738 .52982 m .45249 .54684 L .46357 .54197 L p 0 .311 .95 r
F P
0 g
s
.45249 .54684 m .43738 .52982 L .44836 .52482 L p 0 .311 .95 r
F P
0 g
s
.46357 .54197 m .44836 .52482 L .43738 .52982 L p 0 .311 .95 r
F P
0 g
s
.42383 .54312 m .43738 .52982 L .44836 .52482 L p 0 .05 .1 r
F P
0 g
s
.44057 .59059 m .4541 .57718 L .46521 .57254 L p 0 .05 .1 r
F P
0 g
s
.4516 .58604 m .46521 .57254 L .4541 .57718 L p 0 .05 .1 r
F P
0 g
s
.47876 .5591 m .46521 .57254 L .4541 .57718 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .4541 .57718 L .46521 .57254 L p 0 .311 .95 r
F P
0 g
s
.44998 .55539 m .46521 .57254 L .4541 .57718 L p 0 .311 .95 r
F P
0 g
s
.4541 .57718 m .43898 .56016 L .44998 .55539 L p 0 .311 .95 r
F P
0 g
s
.46357 .54197 m .44998 .55539 L .43898 .56016 L p 0 .05 .1 r
F P
0 g
s
.42383 .54312 m .43898 .56016 L .44998 .55539 L p 0 .311 .95 r
F P
0 g
s
.43898 .56016 m .4541 .57718 L .44316 .58175 L p 0 .311 .95 r
F P
0 g
s
.42541 .57354 m .43898 .56016 L .4541 .57718 L p 0 .349 .781 r
F P
0 g
s
.42971 .59507 m .44316 .58175 L .4541 .57718 L p 0 .05 .1 r
F P
0 g
s
.44316 .58175 m .42971 .59507 L .41465 .57816 L p 0 .349 .781 r
F P
0 g
s
.44057 .59059 m .4541 .57718 L .44316 .58175 L p 0 .05 .1 r
F P
0 g
s
.44316 .58175 m .42971 .59507 L .44057 .59059 L p 0 .05 .1 r
F P
0 g
s
.4541 .57718 m .44057 .59059 L .42971 .59507 L p 0 .05 .1 r
F P
0 g
s
.44057 .59059 m .4541 .57718 L .43898 .56016 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .44998 .55539 L .43898 .56016 L p 0 .311 .95 r
F P
0 g
s
.43898 .56016 m .42541 .57354 L .44057 .59059 L p 0 .349 .781 r
F P
0 g
s
.43633 .56886 m .44998 .55539 L .43898 .56016 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .42383 .54312 L .43472 .53821 L p 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .44998 .55539 L .43898 .56016 L p 0 .311 .95 r
F P
0 g
s
.42541 .57354 m .43898 .56016 L .44998 .55539 L p 0 .05 .1 r
F P
0 g
s
.44998 .55539 m .43472 .53821 L .42383 .54312 L p 0 .311 .95 r
F P
0 g
s
.42225 .51278 m .40865 .52605 L .42383 .54312 L p 0 .349 .781 r
F P
0 g
s
.44836 .52482 m .43472 .53821 L .42383 .54312 L p 0 .05 .1 r
F P
0 g
s
.40865 .52605 m .42383 .54312 L .43472 .53821 L p 0 .311 .95 r
F P
0 g
s
.42383 .54312 m .43898 .56016 L .42814 .56487 L p 0 .311 .95 r
F P
0 g
s
.41021 .55647 m .42383 .54312 L .43898 .56016 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .43898 .56016 L .42814 .56487 L p 0 .05 .1 r
F P
0 g
s
.42541 .57354 m .43898 .56016 L .42383 .54312 L p 0 .349 .781 r
F P
0 g
s
.42383 .54312 m .41021 .55647 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.42103 .55165 m .43472 .53821 L .42383 .54312 L p 0 .05 .1 r
F P
0 g
s
.40865 .52605 m .42225 .51278 L .43738 .52982 L p 0 .349 .781 r
F P
0 g
s
.41944 .521 m .43472 .53821 L .42383 .54312 L p 0 .311 .95 r
F P
0 g
s
.41021 .55647 m .42383 .54312 L .43472 .53821 L p 0 .05 .1 r
F P
0 g
s
.46521 .57254 m .4516 .58604 L .44057 .59059 L p 0 .05 .1 r
F P
0 g
s
.44998 .55539 m .43633 .56886 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.43472 .53821 m .42103 .55165 L .41021 .55647 L p 0 .05 .1 r
F P
0 g
s
.4516 .58604 m .46521 .57254 L .47649 .56782 L p 0 .05 .1 r
F P
0 g
s
.4628 .58142 m .47649 .56782 L .46521 .57254 L p 0 .05 .1 r
F P
0 g
s
.46521 .57254 m .4516 .58604 L .4628 .58142 L p 0 .05 .1 r
F P
0 g
s
.4541 .57718 m .44057 .59059 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.4541 .57718 m .44057 .59059 L .4516 .58604 L p 0 .05 .1 r
F P
0 g
s
.4516 .58604 m .46521 .57254 L .44998 .55539 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .4516 .58604 L .43633 .56886 L p 0 .349 .781 r
F P
0 g
s
.43633 .56886 m .44998 .55539 L .46521 .57254 L p 0 .349 .781 r
F P
0 g
s
.44998 .55539 m .43633 .56886 L .4516 .58604 L p 0 .349 .781 r
F P
0 g
s
.44998 .55539 m .43633 .56886 L .44742 .5641 L p 0 .05 .1 r
F P
0 g
s
.46521 .57254 m .47876 .5591 L .46757 .56383 L p 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .47876 .5591 L .46757 .56383 L p 0 .311 .95 r
F P
0 g
s
.47876 .5591 m .46521 .57254 L .44998 .55539 L p 0 .349 .781 r
F P
0 g
s
.44998 .55539 m .46357 .54197 L .47876 .5591 L p 0 .349 .781 r
F P
0 g
s
.46357 .54197 m .44998 .55539 L .46521 .57254 L p 0 .349 .781 r
F P
0 g
s
.46521 .57254 m .47876 .5591 L .48859 .55494 L p 0 .05 .1 r
F P
0 g
s
.47876 .5591 m .46521 .57254 L .47649 .56782 L p 0 .05 .1 r
F P
0 g
s
.46521 .57254 m .47876 .5591 L .46357 .54197 L p 0 .349 .781 r
F P
0 g
s
.4874 .55699 m .47649 .56782 L .46521 .57254 L p 0 .05 .1 r
F P
0 g
s
.48859 .55494 m .4874 .55699 L p .46521 .57254 L 0 .05 .1 r
F P
0 g
s
.44998 .55539 m .46521 .57254 L .47649 .56782 L p 0 .311 .95 r
F P
0 g
s
.46521 .57254 m .44998 .55539 L .46115 .55054 L p 0 .311 .95 r
F P
0 g
s
.47649 .56782 m .46115 .55054 L .44998 .55539 L p 0 .311 .95 r
F P
0 g
s
.44742 .5641 m .46115 .55054 L .44998 .55539 L p 0 .05 .1 r
F P
0 g
s
.43898 .56016 m .42541 .57354 L .41021 .55647 L p 0 .349 .781 r
F P
0 g
s
.43898 .56016 m .42541 .57354 L .43633 .56886 L p 0 .05 .1 r
F P
0 g
s
.43633 .56886 m .44998 .55539 L .43472 .53821 L p 0 .349 .781 r
F P
0 g
s
.44998 .55539 m .43633 .56886 L .42103 .55165 L p 0 .349 .781 r
F P
0 g
s
.42103 .55165 m .43472 .53821 L .44998 .55539 L p 0 .349 .781 r
F P
0 g
s
.43633 .56886 m .44998 .55539 L .46115 .55054 L p 0 .05 .1 r
F P
0 g
s
.43472 .53821 m .42103 .55165 L .43633 .56886 L p 0 .349 .781 r
F P
0 g
s
.43472 .53821 m .42103 .55165 L .43201 .54676 L p 0 .05 .1 r
F P
0 g
s
.44998 .55539 m .46357 .54197 L .45249 .54684 L p 0 .05 .1 r
F P
0 g
s
.44836 .52482 m .46357 .54197 L .45249 .54684 L p 0 .311 .95 r
F P
0 g
s
.46357 .54197 m .44998 .55539 L .43472 .53821 L p 0 .349 .781 r
F P
0 g
s
.43472 .53821 m .44836 .52482 L .46357 .54197 L p 0 .349 .781 r
F P
0 g
s
.44836 .52482 m .43472 .53821 L .44998 .55539 L p 0 .349 .781 r
F P
0 g
s
.46357 .54197 m .44998 .55539 L .46115 .55054 L p 0 .05 .1 r
F P
0 g
s
.44998 .55539 m .46357 .54197 L .44836 .52482 L p 0 .349 .781 r
F P
0 g
s
.48898 .54896 m .48837 .54718 L .47713 .55199 L p 0 .243 .835 r
F P
0 g
s
.4721 .54195 m .47713 .55199 L .48837 .54718 L p 0 .267 .876 r
F P
0 g
s
.48837 .54718 m .48898 .54896 L p .46357 .54197 L 0 .349 .781 r
F P
0 g
s
.48837 .54718 m .4833 .53706 L .4721 .54195 L p 0 .267 .876 r
F P
0 g
s
.4833 .53706 m .48837 .54718 L p .46357 .54197 L 0 .349 .781 r
F P
0 g
s
.47713 .55199 m .47773 .55376 L .48898 .54896 L p 0 .243 .835 r
F P
0 g
s
.47876 .5591 m .48898 .54896 L .47773 .55376 L p 0 .05 .1 r
F P
0 g
s
.48898 .54896 m .47876 .5591 L .46357 .54197 L p 0 .349 .781 r
F P
0 g
s
.46357 .54197 m .47711 .52862 L .4833 .53706 L p 0 .349 .781 r
F P
0 g
s
.47711 .52862 m .46357 .54197 L .47876 .5591 L p 0 .349 .781 r
F P
0 g
s
.48837 .54718 m .4833 .53706 L p .47876 .5591 L 0 .349 .781 r
F P
0 g
s
.47876 .5591 m .48898 .54896 L .48837 .54718 L p 0 .349 .781 r
F P
0 g
s
.49836 .55695 m .49309 .54721 L .48898 .54896 L p 0 .243 .835 r
F P
0 g
s
.47876 .5591 m .48898 .54896 L .49309 .54721 L p 0 .05 .1 r
F P
0 g
s
.48898 .54896 m .47876 .5591 L .48859 .55494 L p 0 .05 .1 r
F P
0 g
s
.4833 .53706 m .47711 .52862 L p .47876 .5591 L 0 .349 .781 r
F P
0 g
s
.49309 .54721 m .48859 .55494 L .47876 .5591 L p 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .47876 .5591 L .48859 .55494 L p 0 .311 .95 r
F P
0 g
s
.47876 .5591 m .46357 .54197 L .47331 .5377 L p 0 .311 .95 r
F P
0 g
s
.48859 .55494 m .47331 .5377 L .46357 .54197 L p 0 .311 .95 r
F P
0 g
s
.44998 .55539 m .46357 .54197 L .47331 .5377 L p 0 .05 .1 r
F P
0 g
s
.47209 .53973 m .46115 .55054 L .44998 .55539 L p 0 .05 .1 r
F P
0 g
s
.47331 .5377 m .47209 .53973 L p .44998 .55539 L 0 .05 .1 r
F P
0 g
s
.43472 .53821 m .44998 .55539 L .46115 .55054 L p 0 .311 .95 r
F P
0 g
s
.44998 .55539 m .43472 .53821 L .44579 .53322 L p 0 .311 .95 r
F P
0 g
s
.46115 .55054 m .44579 .53322 L .43472 .53821 L p 0 .311 .95 r
F P
0 g
s
.43201 .54676 m .44579 .53322 L .43472 .53821 L p 0 .05 .1 r
F P
0 g
s
.41021 .55647 m .42383 .54312 L .41309 .54795 L p 0 .05 .1 r
F P
0 g
s
.40865 .52605 m .42383 .54312 L .41309 .54795 L p 0 .311 .95 r
F P
0 g
s
.42383 .54312 m .41021 .55647 L .395 .53937 L p 0 .349 .781 r
F P
0 g
s
.395 .53937 m .40865 .52605 L .42383 .54312 L p 0 .349 .781 r
F P
0 g
s
.42383 .54312 m .41021 .55647 L .42103 .55165 L p 0 .05 .1 r
F P
0 g
s
.41021 .55647 m .42383 .54312 L .40865 .52605 L p 0 .349 .781 r
F P
0 g
s
.42383 .54312 m .40865 .52605 L .41944 .521 L p 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .41944 .521 L .40865 .52605 L p 0 .311 .95 r
F P
0 g
s
.42103 .55165 m .43472 .53821 L .41944 .521 L p 0 .349 .781 r
F P
0 g
s
.40865 .52605 m .395 .53937 L .41021 .55647 L p 0 .349 .781 r
F P
0 g
s
.43472 .53821 m .42103 .55165 L .4057 .53442 L p 0 .349 .781 r
F P
0 g
s
.42103 .55165 m .43472 .53821 L .44579 .53322 L p 0 .05 .1 r
F P
0 g
s
.47649 .56782 m .4628 .58142 L .4516 .58604 L p 0 .05 .1 r
F P
0 g
s
.46115 .55054 m .44742 .5641 L .43633 .56886 L p 0 .05 .1 r
F P
0 g
s
.44579 .53322 m .43201 .54676 L .42103 .55165 L p 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .47711 .52862 L .46595 .53357 L p 0 .05 .1 r
F P
0 g
s
.45843 .52653 m .46595 .53357 L .47711 .52862 L p 0 .328 .973 r
F P
0 g
s
.44925 .52055 m .45843 .52653 L .46954 .52152 L p 0 .36 1 r
F P
0 g
s
.47711 .52862 m .46954 .52152 L .45843 .52653 L p 0 .328 .973 r
F P
0 g
s
.43738 .52982 m .44761 .51979 L .44925 .52055 L p 0 .349 .781 r
F P
0 g
s
.44761 .51979 m .44925 .52055 L .46029 .51548 L p 0 .387 1 r
F P
0 g
s
.46954 .52152 m .46029 .51548 L .44925 .52055 L p 0 .36 1 r
F P
0 g
s
.43802 .51537 m .44761 .51979 L .45864 .51472 L p 0 .387 1 r
F P
0 g
s
.44761 .51979 m .43738 .52982 L .44836 .52482 L p 0 .05 .1 r
F P
0 g
s
.46029 .51548 m .45864 .51472 L .44761 .51979 L p 0 .387 1 r
F P
0 g
s
.44836 .52482 m .45864 .51472 L .44761 .51979 L p 0 .05 .1 r
F P
0 g
s
.43738 .52982 m .44761 .51979 L .45864 .51472 L p 0 .05 .1 r
F P
0 g
s
.45864 .51472 m .44899 .51026 L .43802 .51537 L p 0 .387 1 r
F P
0 g
s
.43738 .52982 m .44761 .51979 L .43674 .52478 L p 0 .05 .1 r
F P
0 g
s
.44761 .51979 m .43738 .52982 L .42225 .51278 L p 0 .349 .781 r
F P
0 g
s
.43738 .52982 m .44761 .51979 L .43802 .51537 L p 0 .349 .781 r
F P
0 g
s
.43802 .51537 m .42428 .5108 L p .43738 .52982 L 0 .349 .781 r
F P
0 g
s
.42428 .5108 m .42225 .51278 L .43738 .52982 L p 0 .349 .781 r
F P
0 g
s
.45864 .51472 m .44836 .52482 L .43738 .52982 L p 0 .05 .1 r
F P
0 g
s
.42225 .51278 m .43738 .52982 L .44836 .52482 L p 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .44836 .52482 L .43738 .52982 L p 0 .05 .1 r
F P
0 g
s
.43802 .51537 m .44761 .51979 L p .42225 .51278 L 0 .349 .781 r
F P
0 g
s
.42225 .51278 m .42428 .5108 L .43802 .51537 L p 0 .349 .781 r
F P
0 g
s
.42428 .5108 m .43802 .51537 L .44899 .51026 L p 0 .409 1 r
F P
0 g
s
.44899 .51026 m .43516 .50565 L .42428 .5108 L p 0 .409 1 r
F P
0 g
s
.43312 .50764 m .44836 .52482 L .43738 .52982 L p 0 .311 .95 r
F P
0 g
s
.44836 .52482 m .43312 .50764 L .42225 .51278 L p 0 .311 .95 r
F P
0 g
s
.42541 .57354 m .44057 .59059 L .4516 .58604 L p 0 .31 .951 r
F P
0 g
s
.4516 .58604 m .43633 .56886 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.43633 .56886 m .4516 .58604 L .44057 .59059 L p 0 .31 .951 r
F P
0 g
s
.49309 .54721 m .49219 .54554 L .48837 .54718 L p 0 .243 .835 r
F P
0 g
s
.48837 .54718 m .48898 .54896 L .49309 .54721 L p 0 .243 .835 r
F P
0 g
s
.4833 .53706 m .48837 .54718 L .49219 .54554 L p 0 .267 .876 r
F P
0 g
s
.48859 .55494 m .49309 .54721 L .48898 .54896 L p 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .47331 .5377 L p .47427 .53541 L 0 .05 .1 r
F P
0 g
s
.47711 .52862 m .46696 .53863 L p .47427 .53541 L 0 .05 .1 r
F P
0 g
s
.46696 .53863 m .46357 .54197 L p .47427 .53541 L 0 .05 .1 r
F P
0 g
s
.50762 .56133 m .51372 .55162 L .51636 .55052 L p 0 .05 .444 r
F P
0 g
s
.50674 .56311 m .50762 .56133 L .5114 .55977 L p 0 .099 .551 r
F P
0 g
s
.5114 .55977 m .51081 .56143 L .50674 .56311 L p 0 .099 .551 r
F P
0 g
s
.51636 .55052 m .5114 .55977 L .50762 .56133 L p 0 .05 .444 r
F P
0 g
s
.5114 .55977 m .51636 .55052 L .52774 .54575 L p 0 .05 .444 r
F P
0 g
s
.52774 .54575 m .52276 .55507 L .5114 .55977 L p 0 .05 .444 r
F P
0 g
s
.51081 .56143 m .5114 .55977 L .52276 .55507 L p 0 .099 .551 r
F P
0 g
s
.52276 .55507 m .52216 .55675 L .51081 .56143 L p 0 .099 .551 r
F P
0 g
s
.5079 .56537 m .51487 .56251 L p .48279 .53166 L .535 0 0 r
F P
0 g
s
.47711 .52862 m .4833 .53706 L .48594 .5359 L p 0 .296 .924 r
F P
0 g
s
.46954 .52152 m .47711 .52862 L .47936 .52762 L p 0 .328 .973 r
F P
0 g
s
.48594 .5359 m .47936 .52762 L .47711 .52862 L p 0 .296 .924 r
F P
0 g
s
.47331 .5377 m .47936 .52762 L .47711 .52862 L p 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .47711 .52862 L .46954 .52152 L p 0 .349 .781 r
F P
0 g
s
.47711 .52862 m .46357 .54197 L .44836 .52482 L p 0 .349 .781 r
F P
0 g
s
.46954 .52152 m .47711 .52862 L p .44836 .52482 L 0 .349 .781 r
F P
0 g
s
.46357 .54197 m .47711 .52862 L .47936 .52762 L p 0 .05 .1 r
F P
0 g
s
.46029 .51548 m .46954 .52152 L .47216 .52034 L p 0 .36 1 r
F P
0 g
s
.47936 .52762 m .47216 .52034 L .46954 .52152 L p 0 .328 .973 r
F P
0 g
s
.46954 .52152 m .46029 .51548 L p .46357 .54197 L 0 .349 .781 r
F P
0 g
s
.46029 .51548 m .46954 .52152 L p .44836 .52482 L 0 .349 .781 r
F P
0 g
s
.45864 .51472 m .46029 .51548 L .46405 .51377 L p 0 .387 1 r
F P
0 g
s
.47216 .52034 m .46405 .51377 L .46029 .51548 L p 0 .36 1 r
F P
0 g
s
.44899 .51026 m .45864 .51472 L .46268 .51287 L p 0 .387 1 r
F P
0 g
s
.46029 .51548 m .45864 .51472 L p .46357 .54197 L 0 .349 .781 r
F P
0 g
s
.44836 .52482 m .45864 .51472 L .46029 .51548 L p 0 .349 .781 r
F P
0 g
s
.46405 .51377 m .46268 .51287 L .45864 .51472 L p 0 .387 1 r
F P
0 g
s
.45864 .51472 m .44836 .52482 L .46357 .54197 L p 0 .349 .781 r
F P
0 g
s
.45801 .52043 m .46268 .51287 L .45864 .51472 L p 0 .05 .1 r
F P
0 g
s
.44836 .52482 m .45864 .51472 L .46268 .51287 L p 0 .05 .1 r
F P
0 g
s
.47331 .5377 m .47936 .52762 L .48594 .5359 L p 0 .332 .563 r
F P
0 g
s
.47936 .52762 m .47331 .5377 L .46357 .54197 L p 0 .05 .1 r
F P
0 g
s
.47936 .52762 m .47331 .5377 L .45801 .52043 L p 0 .332 .563 r
F P
0 g
s
.47216 .52034 m .47936 .52762 L p .45801 .52043 L 0 .332 .563 r
F P
0 g
s
.46268 .51287 m .45467 .50762 L .44899 .51026 L p 0 .387 1 r
F P
0 g
s
.46405 .51377 m .47216 .52034 L p .45801 .52043 L 0 .332 .563 r
F P
0 g
s
.46268 .51287 m .45801 .52043 L .44836 .52482 L p 0 .05 .1 r
F P
0 g
s
.45801 .52043 m .46268 .51287 L .46405 .51377 L p 0 .332 .563 r
F P
0 g
s
.45864 .51472 m .44836 .52482 L .45801 .52043 L p 0 .05 .1 r
F P
0 g
s
.44836 .52482 m .45864 .51472 L .44899 .51026 L p 0 .349 .781 r
F P
0 g
s
.45864 .51472 m .44836 .52482 L .43312 .50764 L p 0 .349 .781 r
F P
0 g
s
.44899 .51026 m .45864 .51472 L p .43312 .50764 L 0 .349 .781 r
F P
0 g
s
.43516 .50565 m .44899 .51026 L .45467 .50762 L p 0 .409 1 r
F P
0 g
s
.45467 .50762 m .44362 .50165 L .43516 .50565 L p 0 .409 1 r
F P
0 g
s
.46268 .51287 m .45801 .52043 L .44268 .50313 L p 0 .332 .563 r
F P
0 g
s
.45467 .50762 m .46268 .51287 L p .44268 .50313 L 0 .332 .563 r
F P
0 g
s
.45075 .50086 m .47937 .53316 L p .48279 .53166 L .535 0 0 r
F P
0 g
s
.49219 .54554 m .48594 .5359 L .4833 .53706 L p 0 .267 .876 r
F P
0 g
s
.48594 .5359 m .49219 .54554 L p .47331 .5377 L 0 .332 .563 r
F P
0 g
s
.49219 .54554 m .49309 .54721 L p .47331 .5377 L 0 .332 .563 r
F P
0 g
s
.48859 .55494 m .49309 .54721 L .49836 .55695 L p 0 .332 .563 r
F P
0 g
s
.49309 .54721 m .48859 .55494 L .47331 .5377 L p 0 .332 .563 r
F P
0 g
s
.47937 .53316 m .5079 .56537 L p .48279 .53166 L .535 0 0 r
F P
0 g
s
.4874 .55699 m .48859 .55494 L .47876 .5591 L p 0 .05 .1 r
F P
0 g
s
.47649 .56782 m .4874 .55699 L p .47876 .5591 L 0 .05 .1 r
F P
0 g
s
.47331 .5377 m .48859 .55494 L .47876 .5591 L p 0 .311 .95 r
F P
0 g
s
.44836 .52482 m .46357 .54197 L .47331 .5377 L p 0 .311 .95 r
F P
0 g
s
.47331 .5377 m .46357 .54197 L p .46115 .55054 L 0 .05 .1 r
F P
0 g
s
.46357 .54197 m .44836 .52482 L .45801 .52043 L p 0 .311 .95 r
F P
0 g
s
.45801 .52043 m .47331 .5377 L .46357 .54197 L p 0 .311 .95 r
F P
0 g
s
.44899 .51026 m .43516 .50565 L p .44836 .52482 L 0 .349 .781 r
F P
0 g
s
.43516 .50565 m .43312 .50764 L .44836 .52482 L p 0 .349 .781 r
F P
0 g
s
.43312 .50764 m .44836 .52482 L .45801 .52043 L p 0 .311 .95 r
F P
0 g
s
.44836 .52482 m .43472 .53821 L .44579 .53322 L p 0 .05 .1 r
F P
0 g
s
.47331 .5377 m .45801 .52043 L .44836 .52482 L p 0 .311 .95 r
F P
0 g
s
.45801 .52043 m .44836 .52482 L p .44579 .53322 L 0 .05 .1 r
F P
0 g
s
.43738 .52982 m .42225 .51278 L .43312 .50764 L p 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .44836 .52482 L .43312 .50764 L p 0 .349 .781 r
F P
0 g
s
.44836 .52482 m .43472 .53821 L .41944 .521 L p 0 .349 .781 r
F P
0 g
s
.41944 .521 m .43312 .50764 L .44836 .52482 L p 0 .349 .781 r
F P
0 g
s
.43312 .50764 m .43516 .50565 L .44899 .51026 L p 0 .349 .781 r
F P
0 g
s
.44836 .52482 m .43312 .50764 L .44268 .50313 L p 0 .311 .95 r
F P
0 g
s
.44268 .50313 m .45801 .52043 L .44836 .52482 L p 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .44836 .52482 L .45801 .52043 L p 0 .05 .1 r
F P
0 g
s
.46115 .55054 m .47649 .56782 L .46521 .57254 L p 0 .311 .95 r
F P
0 g
s
.45801 .52043 m .44268 .50313 L .43312 .50764 L p 0 .311 .95 r
F P
0 g
s
.44579 .53322 m .46115 .55054 L .44998 .55539 L p 0 .311 .95 r
F P
0 g
s
.44579 .53322 m .43472 .53821 L p .45801 .52043 L 0 .05 .1 r
F P
0 g
s
.43633 .56886 m .4516 .58604 L .4628 .58142 L p 0 .31 .951 r
F P
0 g
s
.4628 .58142 m .44742 .5641 L .43633 .56886 L p 0 .31 .951 r
F P
0 g
s
.44742 .5641 m .4628 .58142 L .4516 .58604 L p 0 .31 .951 r
F P
0 g
s
.4516 .58604 m .43633 .56886 L .44742 .5641 L p 0 .31 .951 r
F P
0 g
s
.44268 .50313 m .44362 .50165 L .45467 .50762 L p 0 .332 .563 r
F P
0 g
s
.44057 .59059 m .42541 .57354 L .43633 .56886 L p 0 .31 .951 r
F P
0 g
s
.43363 .57773 m .44742 .5641 L .43633 .56886 L p 0 .05 .1 r
F P
0 g
s
.43633 .56886 m .44742 .5641 L .43201 .54676 L p 0 .31 .951 r
F P
0 g
s
.43633 .56886 m .44742 .5641 L .43363 .57773 L p 0 .05 .1 r
F P
0 g
s
.43201 .54676 m .44742 .5641 L .43633 .56886 L p 0 .31 .951 r
F P
0 g
s
.47331 .5377 m .48859 .55494 L .4874 .55699 L p 0 .332 .563 r
F P
0 g
s
.46115 .55054 m .47209 .53973 L .47331 .5377 L p 0 .05 .1 r
F P
0 g
s
.45801 .52043 m .47331 .5377 L .47209 .53973 L p 0 .332 .563 r
F P
0 g
s
.4874 .55699 m .47209 .53973 L .47331 .5377 L p 0 .332 .563 r
F P
0 g
s
.4874 .55699 m .47649 .56782 L .46115 .55054 L p 0 .35 .78 r
F P
0 g
s
.46115 .55054 m .47209 .53973 L .4874 .55699 L p 0 .35 .78 r
F P
0 g
s
.47209 .53973 m .45676 .52244 L .45801 .52043 L p 0 .332 .563 r
F P
0 g
s
.44579 .53322 m .45676 .52244 L .45801 .52043 L p 0 .05 .1 r
F P
0 g
s
.45801 .52043 m .45676 .52244 L .44579 .53322 L p 0 .05 .1 r
F P
0 g
s
.44268 .50313 m .45801 .52043 L .45676 .52244 L p 0 .332 .563 r
F P
0 g
s
.47209 .53973 m .46115 .55054 L .44579 .53322 L p 0 .35 .78 r
F P
0 g
s
.44579 .53322 m .45676 .52244 L .47209 .53973 L p 0 .35 .78 r
F P
0 g
s
.44141 .50511 m .44268 .50313 L p .44455 .5057 L 0 .332 .563 r
F P
0 g
s
.45676 .52244 m .44346 .50743 L p .44455 .5057 L 0 .332 .563 r
F P
0 g
s
.44346 .50743 m .44141 .50511 L p .44455 .5057 L 0 .332 .563 r
F P
0 g
s
.4057 .53442 m .395 .53937 L .41021 .55647 L p 0 .31 .951 r
F P
0 g
s
.41021 .55647 m .42103 .55165 L .4057 .53442 L p 0 .31 .951 r
F P
0 g
s
.41021 .55647 m .395 .53937 L .4057 .53442 L p 0 .31 .951 r
F P
0 g
s
.4057 .53442 m .42103 .55165 L .41021 .55647 L p 0 .31 .951 r
F P
0 g
s
.43312 .50764 m .41944 .521 L .43472 .53821 L p 0 .349 .781 r
F P
0 g
s
.43472 .53821 m .44579 .53322 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.41944 .521 m .42148 .5233 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.42148 .5233 m .43472 .53821 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.45676 .52244 m .44579 .53322 L .4304 .51588 L p 0 .35 .78 r
F P
0 g
s
.4304 .51588 m .44141 .50511 L .45676 .52244 L p 0 .35 .78 r
F P
0 g
s
.47649 .56782 m .4628 .58142 L .44742 .5641 L p 0 .35 .78 r
F P
0 g
s
.44742 .5641 m .46115 .55054 L .47649 .56782 L p 0 .35 .78 r
F P
0 g
s
.46115 .55054 m .44742 .5641 L .43201 .54676 L p 0 .35 .78 r
F P
0 g
s
.43201 .54676 m .44579 .53322 L .46115 .55054 L p 0 .35 .78 r
F P
0 g
s
.44742 .5641 m .4628 .58142 L .44905 .59507 L p 0 .35 .78 r
F P
0 g
s
.42103 .55165 m .41021 .55647 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.42541 .57354 m .43633 .56886 L .42103 .55165 L p 0 .31 .951 r
F P
0 g
s
.42541 .57354 m .41021 .55647 L .42103 .55165 L p 0 .31 .951 r
F P
0 g
s
.42103 .55165 m .43633 .56886 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.43201 .54676 m .42103 .55165 L .43633 .56886 L p 0 .31 .951 r
F P
0 g
s
.43633 .56886 m .42103 .55165 L .43201 .54676 L p 0 .31 .951 r
F P
0 g
s
.41817 .56036 m .43201 .54676 L .44742 .5641 L p 0 .35 .78 r
F P
0 g
s
.42971 .59507 m .44057 .59059 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.42541 .57354 m .41465 .57816 L .42971 .59507 L p 0 .31 .951 r
F P
0 g
s
.42541 .57354 m .44057 .59059 L .42971 .59507 L p 0 .31 .951 r
F P
0 g
s
.42971 .59507 m .41465 .57816 L .42541 .57354 L p 0 .31 .951 r
F P
0 g
s
.41901 .59948 m .42971 .59507 L .41465 .57816 L p 0 .31 .951 r
F P
0 g
s
.41465 .57816 m .42971 .59507 L .41901 .59948 L p 0 .31 .951 r
F P
0 g
s
.42699 .60405 m .44057 .59059 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .44057 .59059 L .42699 .60405 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .41178 .58698 L .42699 .60405 L p 0 .349 .781 r
F P
0 g
s
.42699 .60405 m .41178 .58698 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.42262 .58239 m .43633 .56886 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.42541 .57354 m .43633 .56886 L .42262 .58239 L p 0 .05 .1 r
F P
0 g
s
.43633 .56886 m .42262 .58239 L .43363 .57773 L p 0 .05 .1 r
F P
0 g
s
.43363 .57773 m .42262 .58239 L .43633 .56886 L p 0 .05 .1 r
F P
0 g
s
.44742 .5641 m .43363 .57773 L .41817 .56036 L p 0 .35 .78 r
F P
0 g
s
.44905 .59507 m .43363 .57773 L .44742 .5641 L p 0 .35 .78 r
F P
0 g
s
.43363 .57773 m .44905 .59507 L .43525 .60878 L p 0 .35 .78 r
F P
0 g
s
.41901 .59948 m .40558 .61276 L .42056 .62954 L p 0 .349 .781 r
F P
0 g
s
.42699 .60405 m .41334 .61757 L .42857 .63464 L p 0 .349 .781 r
F P
0 g
s
.42857 .63464 m .41334 .61757 L .42699 .60405 L p 0 .349 .781 r
F P
0 g
s
.43687 .63991 m .42138 .62255 L .43525 .60878 L p 0 .35 .78 r
F P
0 g
s
.43592 .63717 m .5079 .56537 L .45075 .50086 L p .858 0 0 r
F P
0 g
s
.42541 .57354 m .41465 .57816 L .4011 .5915 L p 0 .05 .1 r
F P
0 g
s
.4011 .5915 m .41465 .57816 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.41021 .55647 m .42541 .57354 L .41465 .57816 L p 0 .31 .951 r
F P
0 g
s
.4011 .5915 m .41178 .58698 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.42541 .57354 m .41178 .58698 L .4011 .5915 L p 0 .05 .1 r
F P
0 g
s
.39654 .56988 m .41178 .58698 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .41021 .55647 L .39654 .56988 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .41178 .58698 L .42262 .58239 L p 0 .05 .1 r
F P
0 g
s
.42262 .58239 m .41178 .58698 L .42541 .57354 L p 0 .05 .1 r
F P
0 g
s
.39654 .56988 m .41021 .55647 L .42541 .57354 L p 0 .349 .781 r
F P
0 g
s
.42541 .57354 m .41178 .58698 L .39654 .56988 L p 0 .349 .781 r
F P
0 g
s
.41334 .61757 m .42699 .60405 L .41178 .58698 L p 0 .349 .781 r
F P
0 g
s
.41178 .58698 m .42699 .60405 L .41334 .61757 L p 0 .349 .781 r
F P
0 g
s
.38281 .58335 m .39809 .60048 L .41178 .58698 L p 0 .349 .781 r
F P
0 g
s
.41178 .58698 m .39654 .56988 L .38281 .58335 L p 0 .349 .781 r
F P
0 g
s
.41178 .58698 m .39809 .60048 L .41334 .61757 L p 0 .349 .781 r
F P
0 g
s
.41334 .61757 m .39809 .60048 L .41178 .58698 L p 0 .349 .781 r
F P
0 g
s
.40885 .59598 m .42262 .58239 L .41178 .58698 L p 0 .05 .1 r
F P
0 g
s
.41178 .58698 m .39809 .60048 L .40885 .59598 L p 0 .05 .1 r
F P
0 g
s
.40885 .59598 m .39809 .60048 L .41178 .58698 L p 0 .05 .1 r
F P
0 g
s
.41178 .58698 m .42262 .58239 L .40885 .59598 L p 0 .05 .1 r
F P
0 g
s
.38281 .58335 m .39654 .56988 L .41178 .58698 L p 0 .349 .781 r
F P
0 g
s
.41178 .58698 m .39809 .60048 L .38281 .58335 L p 0 .349 .781 r
F P
0 g
s
.40711 .64291 m .42056 .62954 L .40558 .61276 L p 0 .349 .781 r
F P
0 g
s
.40558 .61276 m .39209 .6261 L .40711 .64291 L p 0 .349 .781 r
F P
0 g
s
.39964 .63115 m .41334 .61757 L .39809 .60048 L p 0 .349 .781 r
F P
0 g
s
.39809 .60048 m .41334 .61757 L .39964 .63115 L p 0 .349 .781 r
F P
0 g
s
.39809 .60048 m .38434 .61403 L .39964 .63115 L p 0 .349 .781 r
F P
0 g
s
.39964 .63115 m .38434 .61403 L .39809 .60048 L p 0 .349 .781 r
F P
0 g
s
.39502 .60962 m .40885 .59598 L .39809 .60048 L p 0 .05 .1 r
F P
0 g
s
.39809 .60048 m .40885 .59598 L .39502 .60962 L p 0 .05 .1 r
F P
0 g
s
.4057 .53442 m .41944 .521 L .43472 .53821 L p 0 .349 .781 r
F P
0 g
s
.41944 .521 m .4304 .51588 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.43472 .53821 m .42148 .5233 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.42148 .5233 m .41944 .521 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.44579 .53322 m .43472 .53821 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.4304 .51588 m .43245 .5182 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.43245 .5182 m .44579 .53322 L p .43098 .51888 L 0 .311 .95 r
F P
0 g
s
.41944 .521 m .4057 .53442 L .42103 .55165 L p 0 .349 .781 r
F P
0 g
s
.4304 .51588 m .41944 .521 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.44579 .53322 m .43245 .5182 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.43245 .5182 m .4304 .51588 L p .42293 .52262 L 0 .311 .95 r
F P
0 g
s
.41658 .52939 m .4057 .53442 L .40775 .53672 L p 0 .31 .951 r
F P
0 g
s
.40775 .53672 m .42103 .55165 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.41717 .53238 m .41658 .52939 L .40775 .53672 L 0 .31 .951 r
F
.42103 .55165 m .43201 .54676 L .41864 .53171 L p F P
0 g
s
.41864 .53171 m .41658 .52939 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.42103 .55165 m .41864 .53171 L .41717 .53238 L 0 .31 .951 r
F
.4057 .53442 m .41658 .52939 L p .41717 .53238 L F P
0 g
s
.42103 .55165 m .40775 .53672 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.40775 .53672 m .4057 .53442 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.43201 .54676 m .42103 .55165 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.41658 .52939 m .41864 .53171 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.41864 .53171 m .43201 .54676 L p .41717 .53238 L 0 .31 .951 r
F P
0 g
s
.41978 .59141 m .43363 .57773 L .42262 .58239 L p 0 .05 .1 r
F P
0 g
s
.42262 .58239 m .40885 .59598 L .41978 .59141 L p 0 .05 .1 r
F P
0 g
s
.41978 .59141 m .40885 .59598 L .42262 .58239 L p 0 .05 .1 r
F P
0 g
s
.42262 .58239 m .43363 .57773 L .41978 .59141 L p 0 .05 .1 r
F P
0 g
s
.40586 .60515 m .41978 .59141 L .40885 .59598 L p 0 .05 .1 r
F P
0 g
s
.40885 .59598 m .39502 .60962 L .40586 .60515 L p 0 .05 .1 r
F P
0 g
s
.40586 .60515 m .39502 .60962 L .40885 .59598 L p 0 .05 .1 r
F P
0 g
s
.40885 .59598 m .41978 .59141 L .40586 .60515 L p 0 .05 .1 r
F P
0 g
s
.44579 .53322 m .43201 .54676 L .41658 .52939 L p 0 .35 .78 r
F P
0 g
s
.41658 .52939 m .4304 .51588 L .44579 .53322 L p 0 .35 .78 r
F P
0 g
s
.40269 .54296 m .41658 .52939 L .43201 .54676 L p 0 .35 .78 r
F P
0 g
s
.43201 .54676 m .41817 .56036 L .40269 .54296 L p 0 .35 .78 r
F P
0 g
s
.40428 .57402 m .41817 .56036 L .43363 .57773 L p 0 .35 .78 r
F P
0 g
s
.43363 .57773 m .41978 .59141 L .40428 .57402 L p 0 .35 .78 r
F P
0 g
s
.43525 .60878 m .41978 .59141 L .43363 .57773 L p 0 .35 .78 r
F P
0 g
s
.38875 .55659 m .40269 .54296 L .41817 .56036 L p 0 .35 .78 r
F P
0 g
s
.41817 .56036 m .40428 .57402 L .38875 .55659 L p 0 .35 .78 r
F P
0 g
s
.41978 .59141 m .43525 .60878 L .42138 .62255 L p 0 .35 .78 r
F P
0 g
s
.39032 .58773 m .40428 .57402 L .41978 .59141 L p 0 .35 .78 r
F P
0 g
s
.41978 .59141 m .40586 .60515 L .39032 .58773 L p 0 .35 .78 r
F P
0 g
s
.42138 .62255 m .40586 .60515 L .41978 .59141 L p 0 .35 .78 r
F P
0 g
s
.37475 .57028 m .38875 .55659 L .40428 .57402 L p 0 .35 .78 r
F P
0 g
s
.40428 .57402 m .39032 .58773 L .37475 .57028 L p 0 .35 .78 r
F P
0 g
s
.45075 .50086 m .3779 .57213 L .43592 .63717 L p .858 0 0 r
F P
0 g
s
.43449 .51725 m .42208 .53013 L .43356 .51768 L .1 0 0 r
F
.42208 .53013 m .38437 .56926 L .42138 .53045 L F
.42208 .53013 m .42138 .53045 L .43356 .51768 L F
.38437 .56926 m .3779 .57213 L p .41973 .5312 L F P
0 g
s
.43356 .51768 m .42138 .53045 L .41973 .5312 L .1 0 0 r
F
.42138 .53045 m .38437 .56926 L .41973 .5312 L F
.43514 .51694 m .42256 .5299 L .43449 .51725 L F
.42256 .5299 m .38437 .56926 L .42208 .53013 L F
.42256 .5299 m .42208 .53013 L .43449 .51725 L F
.43514 .51694 m .42256 .5299 L .44023 .51458 L F
.42256 .5299 m .38437 .56926 L .42636 .52816 L F
.42256 .5299 m .42636 .52816 L .44023 .51458 L F
.45075 .50086 m .43514 .51694 L .45044 .50376 L F
.51487 .56251 m .45749 .49768 L .45075 .50086 L p .535 0 0 r
F P
0 g
s
.45075 .50086 m .45044 .50376 L .45749 .49768 L .1 0 0 r
F
.43514 .51694 m .44023 .51458 L .45749 .49768 L F
.44172 .51016 m .43514 .51694 L .44251 .50892 L F
.43514 .51694 m .43449 .51725 L .44251 .50892 L F
.43356 .51768 m .44251 .50892 L p .43449 .51725 L F P
0 g
s
.45075 .50086 m .45749 .49768 L .44023 .51458 L p .1 0 0 r
F P
0 g
s
.44023 .51458 m .38437 .56926 L p .43514 .51694 L .1 0 0 r
F P
0 g
s
.45075 .50086 m .44023 .51458 L .43514 .51694 L .1 0 0 r
F
.44251 .50892 m .45075 .50086 L p .44172 .51016 L F P
0 g
s
.50876 .56658 m .43681 .63839 L .43716 .63939 L .949 0 0 r
F
.5079 .56537 m .43592 .63717 L .43681 .63839 L .884 0 0 r
F
.47212 .60107 m .44265 .63461 L .43592 .63717 L .164 0 0 r
F
.49091 .58232 m .47446 .60014 L .47212 .60107 L F
.47446 .60014 m .44265 .63461 L .47212 .60107 L F
.50876 .56658 m .50908 .5676 L .52314 .57813 L .535 0 0 r
F
.50876 .56658 m .52314 .57813 L .52092 .57102 L F
.5079 .56537 m .50876 .56658 L .52092 .57102 L F
.5079 .56537 m .52092 .57102 L .51487 .56251 L F
.51487 .56251 m .5079 .56537 L p .49902 .57479 L .164 0 0 r
F P
0 g
s
.49902 .57479 m .49255 .58166 L .49757 .57735 L .164 0 0 r
F
.49902 .57479 m .49757 .57735 L .51487 .56251 L F
.49975 .5735 m .49255 .58166 L .49091 .58232 L F
.5079 .56537 m .49902 .57479 L .49975 .5735 L F
.49902 .57479 m .49255 .58166 L .49975 .5735 L F
.49255 .58166 m .44265 .63461 L .49091 .58232 L F
.49255 .58166 m .48019 .59477 L .49562 .58041 L F
.4781 .59863 m .47811 .59865 L .50877 .56814 L .889 0 0 r
F
.50908 .5676 m .4781 .59863 L .50877 .56814 L F
.47318 .60356 m .47303 .60382 L .50877 .56814 L F
.50877 .56814 m .52096 .5819 L .44925 .65378 L p .858 0 0 r
F P
0 g
s
.50877 .56814 m .44925 .65378 L .52096 .5819 L .858 0 0 r
F
.50908 .5676 m .52096 .5819 L .52314 .57813 L .535 0 0 r
F
.50908 .5676 m .50877 .56814 L .52096 .5819 L F
.49255 .58166 m .49562 .58041 L .51487 .56251 L .164 0 0 r
F
.48695 .58688 m .47725 .59594 L .47869 .59537 L F
.48695 .58688 m .47869 .59537 L .48019 .59477 L F
.49255 .58166 m .48695 .58688 L .48019 .59477 L F
.5079 .56537 m .49091 .58232 L p .49255 .58166 L F P
0 g
s
.49091 .58232 m .47725 .59594 L p .49255 .58166 L .164 0 0 r
F P
0 g
s
.43592 .63717 m .43898 .63601 L p .48019 .59477 L .164 0 0 r
F P
0 g
s
.43898 .63601 m .44265 .63461 L p .47845 .59662 L .164 0 0 r
F P
0 g
s
.48019 .59477 m .43898 .63601 L .47845 .59662 L .164 0 0 r
F
.47725 .59594 m .43592 .63717 L p .48019 .59477 L F P
0 g
s
.4781 .59863 m .47318 .60356 L .47811 .59865 L .889 0 0 r
F
.44265 .63461 m .48412 .5932 L p .48019 .59477 L .164 0 0 r
F P
0 g
s
.48412 .5932 m .51487 .56251 L p .48019 .59477 L .164 0 0 r
F P
0 g
s
.5079 .56537 m .51487 .56251 L .44265 .63461 L .164 0 0 r
F
.45749 .49768 m .51487 .56251 L .44265 .63461 L p .858 0 0 r
F P
0 g
s
.44265 .63461 m .38437 .56926 L .42114 .53326 L p .858 0 0 r
F P
0 g
s
.42114 .53326 m .45749 .49768 L p .4501 .56586 L .858 0 0 r
F P
0 g
s
.4501 .56586 m .44265 .63461 L .42114 .53326 L .858 0 0 r
F
.41155 .51783 m .41356 .51587 L .42428 .5108 L p 0 .05 .1 r
F P
0 g
s
.42428 .5108 m .42225 .51278 L .41155 .51783 L p 0 .05 .1 r
F P
0 g
s
.39803 .53101 m .41155 .51783 L .42225 .51278 L p 0 .05 .1 r
F P
0 g
s
.42225 .51278 m .40865 .52605 L .39803 .53101 L p 0 .05 .1 r
F P
0 g
s
.42225 .51278 m .42428 .5108 L .43516 .50565 L p 0 .05 .1 r
F P
0 g
s
.43516 .50565 m .43312 .50764 L .42225 .51278 L p 0 .05 .1 r
F P
0 g
s
.40865 .52605 m .42225 .51278 L .43312 .50764 L p 0 .05 .1 r
F P
0 g
s
.395 .53937 m .40865 .52605 L .41944 .521 L p 0 .05 .1 r
F P
0 g
s
.43312 .50764 m .41944 .521 L .40865 .52605 L p 0 .05 .1 r
F P
0 g
s
.395 .53937 m .4057 .53442 L .3919 .5479 L p 0 .05 .1 r
F P
0 g
s
.41944 .521 m .4057 .53442 L .395 .53937 L p 0 .05 .1 r
F P
0 g
s
.43312 .50764 m .43516 .50565 L .44362 .50165 L p 0 .05 .1 r
F P
0 g
s
.41944 .521 m .43312 .50764 L .44268 .50313 L p 0 .05 .1 r
F P
0 g
s
.44362 .50165 m .44268 .50313 L .43312 .50764 L p 0 .05 .1 r
F P
0 g
s
.4057 .53442 m .41944 .521 L .4304 .51588 L p 0 .05 .1 r
F P
0 g
s
.4304 .51588 m .41944 .521 L p .44268 .50313 L 0 .05 .1 r
F P
0 g
s
.44759 .49907 m .40435 .51955 L p .38986 .54439 L .1 0 0 r
F P
0 g
s
.40269 .54296 m .3919 .5479 L .4057 .53442 L p 0 .05 .1 r
F P
0 g
s
.4057 .53442 m .41658 .52939 L .40269 .54296 L p 0 .05 .1 r
F P
0 g
s
.3919 .5479 m .40269 .54296 L .38875 .55659 L p 0 .05 .1 r
F P
0 g
s
.37475 .57028 m .41138 .53447 L p .38986 .54439 L .1 0 0 r
F P
0 g
s
.4304 .51588 m .41658 .52939 L .4057 .53442 L p 0 .05 .1 r
F P
0 g
s
.44268 .50313 m .44141 .50511 L .4304 .51588 L p 0 .05 .1 r
F P
0 g
s
.41138 .53447 m .44759 .49907 L p .38986 .54439 L .1 0 0 r
F P
0 g
s
.39241 .50611 m .40435 .51955 L .44759 .49907 L p .535 0 0 r
F P
0 g
s
.44759 .49907 m .4353 .48521 L .39241 .50611 L p .535 0 0 r
F P
0 g
s
.4353 .48521 m .44759 .49907 L .37475 .57028 L p .858 0 0 r
F P
0 g
s
.44759 .49907 m .37556 .57035 L .44842 .49912 L .553 0 0 r
F
.44759 .49907 m .37475 .57028 L .37556 .57035 L F
.44759 .49907 m .36228 .5563 L .37475 .57028 L .858 0 0 r
F
.44842 .49912 m .37672 .57103 L .44958 .49977 L .761 0 0 r
F
.44842 .49912 m .37556 .57035 L .37672 .57103 L F
.44958 .49977 m .3779 .57213 L .45075 .50086 L .832 0 0 r
F
.44958 .49977 m .37672 .57103 L .3779 .57213 L F
.45075 .50086 m .3779 .57213 L .38437 .56926 L .1 0 0 r
F
.44759 .49907 m .44111 .48549 L .4353 .48521 L .535 0 0 r
F
.44759 .49907 m .44842 .49912 L .44111 .48549 L F
.44759 .49907 m .4353 .48521 L .36228 .5563 L .858 0 0 r
F
.44842 .49912 m .44924 .49006 L .44111 .48549 L .535 0 0 r
F
.37475 .57028 m .36228 .5563 L .4353 .48521 L p .858 0 0 r
F P
0 g
s
.44111 .48549 m .44924 .49006 L .37605 .56152 L .761 0 0 r
F
.44924 .49006 m .38437 .56926 L .37605 .56152 L .832 0 0 r
F
.44842 .49912 m .44958 .49977 L .44924 .49006 L .535 0 0 r
F
.44958 .49977 m .45749 .49768 L .44924 .49006 L F
.44958 .49977 m .45075 .50086 L .45749 .49768 L F
.44924 .49006 m .45749 .49768 L .38437 .56926 L .832 0 0 r
F
.41434 .52561 m .4299 .52594 L .41276 .52384 L .523 0 0 r
F
.4299 .52594 m .43679 .52609 L .4308 .52553 L F
.4299 .52594 m .4308 .52553 L .41276 .52384 L F
.39241 .50611 m .4353 .48521 L .399 .52055 L p .1 0 0 r
F P
0 g
s
.399 .52055 m .36228 .5563 L p .37765 .53068 L .1 0 0 r
F P
0 g
s
.39241 .50611 m .399 .52055 L .37765 .53068 L .1 0 0 r
F
.41276 .52384 m .43679 .52609 L .42003 .51057 L .523 0 0 r
F
.399 .52055 m .36796 .55678 L .36228 .5563 L .55 0 0 r
F
.4353 .48521 m .40187 .52074 L .399 .52055 L F
.40187 .52074 m .36796 .55678 L .399 .52055 L F
.44111 .48549 m .37605 .56152 L .36796 .55678 L .761 0 0 r
F
.40474 .52093 m .41285 .52558 L .41264 .52145 L .523 0 0 r
F
.4353 .48521 m .44111 .48549 L .36796 .55678 L .55 0 0 r
F
.40474 .52093 m .41264 .52145 L .41166 .50281 L .523 0 0 r
F
.41226 .51426 m .42003 .51057 L .41166 .50281 L F
.41276 .52384 m .42003 .51057 L .41226 .51426 L F
.41285 .52558 m .41434 .52561 L .41276 .52384 L F
.43275 .54633 m .46736 .58529 L p .42628 .53733 L F P
0 g
s
.46736 .58529 m .47897 .59835 L p .46716 .58467 L .523 0 0 r
F P
0 g
s
.46736 .58529 m .46716 .58467 L .42628 .53733 L .523 0 0 r
F
.51487 .56251 m .52092 .57102 L .48509 .60688 L .885 0 0 r
F
.48203 .60262 m .48509 .60688 L .44885 .64314 L F
.51487 .56251 m .48509 .60688 L .48203 .60262 L F
.51487 .56251 m .44885 .64314 L .44265 .63461 L F
.4952 .59191 m .43679 .52609 L .42948 .52944 L p .523 0 0 r
F P
0 g
s
.42948 .52944 m .42114 .53326 L p .44685 .55362 L .523 0 0 r
F P
0 g
s
.44685 .55362 m .4952 .59191 L .42948 .52944 L .523 0 0 r
F
.47897 .59835 m .4952 .59191 L p .48434 .58331 L F P
0 g
s
.42628 .53733 m .47718 .59628 L .48434 .58331 L .523 0 0 r
F
.47718 .59628 m .47897 .59835 L .48434 .58331 L F
.42114 .53326 m .43275 .54633 L p .42628 .53733 L F P
0 g
s
.43716 .63939 m .45126 .65016 L .44925 .65378 L .511 0 0 r
F
.52092 .57102 m .52314 .57813 L .48741 .61394 L .95 0 0 r
F
.48625 .61041 m .48741 .61394 L .45126 .65016 L F
.52092 .57102 m .48741 .61394 L .48625 .61041 L F
.48741 .61394 m .45126 .65016 L .44925 .65378 L .881 0 0 r
F
.48741 .61394 m .44925 .65378 L .45126 .65016 L F
.52314 .57813 m .48636 .61579 L .48741 .61394 L F
.48741 .61394 m .44925 .65378 L .48531 .61764 L F
.48636 .61579 m .44925 .65378 L .48741 .61394 L F
.51391 .6498 m .48531 .61764 L p .47607 .63395 L .523 0 0 r
F P
0 g
s
.57177 .66991 m .58357 .65782 L p .57515 .6688 L 0 .05 .212 r
F P
0 g
s
.59576 .66204 m .57177 .66991 L p .53695 .63066 L .535 0 0 r
F P
0 g
s
.55794 .68408 m .56773 .69084 L .57177 .66991 L .257 0 0 r
F
.54406 .69831 m .57177 .66991 L p .55524 .69478 L 0 .05 .212 r
F P
0 g
s
.56773 .69084 m .59576 .66204 L .57177 .66991 L p .257 0 0 r
F P
0 g
s
.57515 .6688 m .55524 .69478 L .57177 .66991 L 0 .05 .212 r
F
.55803 .71402 m .53623 .784 L .54406 .69831 L 0 .349 .781 r
F
.55524 .69478 m .52317 .73662 L .54406 .69831 L 0 .05 .212 r
F
.59576 .66204 m .56773 .69084 L p .57515 .6688 L F P
0 g
s
.56773 .69084 m .52317 .73662 L p .55166 .69945 L 0 .05 .212 r
F P
0 g
s
.57515 .6688 m .56773 .69084 L .55166 .69945 L 0 .05 .212 r
F
.57177 .66991 m .54849 .67755 L p .53695 .63066 L .535 0 0 r
F P
0 g
s
.61917 .69798 m .53623 .784 L .55991 .7778 L p 0 .05 .248 r
F P
0 g
s
.55991 .7778 m .52317 .73662 L .6077 .64978 L p 0 .35 .78 r
F P
0 g
s
.56372 .65295 m .59576 .66204 L .56282 .64446 L .535 0 0 r
F
.56372 .65295 m .56282 .64446 L .53695 .63066 L F
.55438 .6503 m .56372 .65295 L .53695 .63066 L F
.59576 .66204 m .56046 .62218 L .53695 .63066 L p F P
0 g
s
.57177 .66991 m .59576 .66204 L p .55438 .6503 L .535 0 0 r
F P
0 g
s
.55438 .6503 m .57177 .66991 L .55438 .6503 L .535 0 0 r
F
.51414 .63889 m .57177 .66991 L .55438 .6503 L F
.56046 .62218 m .59576 .66204 L .56773 .69084 L p .858 0 0 r
F P
0 g
s
.59576 .66204 m .53221 .65085 L .56773 .69084 L .858 0 0 r
F
.60191 .65872 m .59576 .66204 L .56773 .69084 L .257 0 0 r
F
.55438 .6503 m .53695 .63066 L .53695 .63066 L .535 0 0 r
F
.53695 .63066 m .51414 .63889 L p .55438 .6503 L F P
0 g
s
.56773 .69084 m .53221 .65085 L .56046 .62218 L p .858 0 0 r
F P
0 g
s
.60191 .65872 m .56773 .69084 L .58614 .68097 L .257 0 0 r
F
.58614 .68097 m .56773 .69084 L .53221 .65085 L .669 0 0 r
F
.52108 .70556 m .54849 .67755 L p .53303 .70179 L 0 .05 .212 r
F P
0 g
s
.53221 .65085 m .56773 .69084 L p .52656 .67864 L .526 0 0 r
F P
0 g
s
.59576 .66204 m .56046 .62218 L .53221 .65085 L .858 0 0 r
F
.61917 .69798 m .60139 .67792 L .61348 .67409 L p 0 .312 .948 r
F P
0 g
s
.61348 .67409 m .63138 .69431 L .61917 .69798 L p 0 .312 .948 r
F P
0 g
s
.55991 .7778 m .64378 .69057 L .61917 .69798 L p 0 .05 .248 r
F P
0 g
s
.64378 .69057 m .63138 .69431 L .61348 .67409 L p 0 .312 .948 r
F P
0 g
s
.61348 .67409 m .62576 .67019 L .64378 .69057 L p 0 .312 .948 r
F P
0 g
s
.6077 .64978 m .64378 .69057 L .55991 .7778 L p 0 .35 .78 r
F P
0 g
s
.6083 .64958 m .6077 .64978 L .59576 .66204 L .257 0 0 r
F
.53713 .57001 m .6077 .64978 L .59576 .66204 L p .858 0 0 r
F P
0 g
s
.60858 .6493 m .59576 .66204 L .60191 .65872 L .257 0 0 r
F
.60191 .65872 m .56046 .62218 L .59576 .66204 L .672 0 0 r
F
.60191 .65872 m .59576 .66204 L .52502 .58216 L F
.60191 .65872 m .56653 .61875 L .56046 .62218 L F
.6077 .64978 m .53713 .57001 L .52502 .58216 L .858 0 0 r
F
.56653 .61875 m .52502 .58216 L .53102 .57864 L .672 0 0 r
F
.60191 .65872 m .56349 .62047 L .56653 .61875 L F
.56349 .62047 m .52502 .58216 L .56653 .61875 L F
.60858 .6493 m .53713 .57001 L .6077 .64978 L .673 0 0 r
F
.60975 .64841 m .60858 .6493 L .60191 .65872 L .257 0 0 r
F
.60975 .64841 m .60191 .65872 L .61017 .65242 L F
.61017 .65242 m .60191 .65872 L .56653 .61875 L .776 0 0 r
F
.57065 .61558 m .56653 .61875 L .53102 .57864 L F
.61017 .65242 m .56653 .61875 L .57065 .61558 L F
.60858 .6493 m .53799 .5695 L .53713 .57001 L .673 0 0 r
F
.60975 .64841 m .53799 .5695 L .60858 .6493 L .776 0 0 r
F
.61091 .64733 m .53916 .56859 L .60975 .64841 L .832 0 0 r
F
.61091 .64733 m .54033 .56752 L .53916 .56859 L F
.60975 .64841 m .53916 .56859 L .53799 .5695 L .776 0 0 r
F
.54033 .56752 m .54743 .56467 L .61831 .64486 L p .54 0 0 r
F P
0 g
s
.61831 .64486 m .58293 .60484 L .57477 .6124 L .832 0 0 r
F
.61831 .64486 m .53923 .57223 L .54743 .56467 L F
.60858 .6493 m .6077 .64978 L .6083 .64958 L .257 0 0 r
F
.61091 .64733 m .61017 .65242 L .61831 .64486 L F
.61091 .64733 m .60975 .64841 L .61017 .65242 L F
.61831 .64486 m .61017 .65242 L .53923 .57223 L .832 0 0 r
F
.58293 .60484 m .58205 .60679 L .57477 .6124 L .221 0 0 r
F
.61831 .64486 m .57477 .6124 L .61017 .65242 L .832 0 0 r
F
.61017 .65242 m .57477 .6124 L .56653 .61875 L .776 0 0 r
F
.57477 .6124 m .53102 .57864 L .53923 .57223 L F
.61017 .65242 m .57065 .61558 L .57477 .6124 L F
.57065 .61558 m .53102 .57864 L .57477 .6124 L F
.666 .59072 m .60355 .50834 L .67358 .58802 L .556 0 0 r
F
.63863 .54825 m .58293 .60484 L .61831 .64486 L p .858 0 0 r
F P
0 g
s
.61831 .64486 m .54743 .56467 L .60355 .50834 L p .858 0 0 r
F P
0 g
s
.61831 .64486 m .67358 .58802 L .666 .59072 L p .257 0 0 r
F P
0 g
s
.67358 .58802 m .61831 .64486 L .63583 .639 L p .257 0 0 r
F P
0 g
s
.61831 .64486 m .67358 .58802 L .63863 .54825 L p .858 0 0 r
F P
0 g
s
.60355 .50834 m .67358 .58802 L .61831 .64486 L p .858 0 0 r
F P
0 g
s
.63583 .639 m .61831 .64486 L .58293 .60484 L p .54 0 0 r
F P
0 g
s
.61831 .64486 m .60011 .59854 L .58293 .60484 L .54 0 0 r
F
.58293 .60484 m .60011 .59854 L .63583 .639 L p F P
0 g
s
.58205 .60679 m .60011 .59854 L .57535 .62147 L .221 0 0 r
F
.58293 .60484 m .58605 .6037 L .58205 .60679 L F
.58605 .6037 m .60011 .59854 L .58205 .60679 L F
.58205 .60679 m .57535 .62147 L .57477 .6124 L F
.57477 .6124 m .57191 .61572 L .56653 .61875 L F
.61017 .65242 m .56653 .61875 L .60191 .65872 L .776 0 0 r
F
.57191 .61572 m .5504 .64068 L .56653 .61875 L .221 0 0 r
F
.56438 .62076 m .53221 .65085 L .56046 .62218 L F
.56653 .61875 m .56438 .62076 L .56046 .62218 L F
.52314 .57813 m .52096 .5819 L .48531 .61764 L .881 0 0 r
F
.48636 .61579 m .48531 .61764 L .44925 .65378 L F
.52314 .57813 m .48531 .61764 L .48636 .61579 L F
.5 .74345 m .46349 .78087 L p .43803 .71135 L 0 .349 .781 r
F P
0 g
s
.45553 .69369 m .5 .74345 L p .43803 .71135 L 0 .349 .781 r
F P
0 g
s
.45553 .69369 m .5 .74345 L p .45553 .69369 L 0 .308 .954 r
F P
0 g
s
.54406 .69831 m .52108 .70556 L p .52656 .67864 L .526 0 0 r
F P
0 g
s
.56773 .69084 m .54406 .69831 L p .52656 .67864 L .526 0 0 r
F P
0 g
s
.52656 .67864 m .52656 .67864 L .54406 .69831 L .526 0 0 r
F
.48653 .66678 m .50903 .65894 L p .52656 .67864 L F P
0 g
s
.50903 .65894 m .53221 .65085 L p .52656 .67864 L .526 0 0 r
F P
0 g
s
.56046 .62218 m .53221 .65085 L p .52302 .64477 L .221 0 0 r
F P
0 g
s
.51414 .63889 m .53695 .63066 L p .52302 .64477 L .221 0 0 r
F P
0 g
s
.53695 .63066 m .56046 .62218 L p .52302 .64477 L .221 0 0 r
F P
0 g
s
0 0 0 r
.45368 .22882 m
.45368 .22882 L
s
.45368 .22882 m
.45368 .22882 L
s
.62361 .327 m
.62361 .327 L
s
.51767 .2456 m
.51767 .2456 L
s
.75876 .51304 m .77181 .50806 L .74741 .50624 L p 0 .458 1 r
F P
0 g
s
.75876 .51304 m .77181 .50806 L .79608 .50986 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.52752 .29385 m
.52752 .29385 L
s
.58593 .2465 m
.58593 .2465 L
s
.58593 .2465 m
.58593 .2465 L
s
.52752 .29385 m
.52752 .29385 L
s
0 g
.39394 .35327 m
.39417 .35308 L
s
.39332 .35575 m .38602 .36044 L .39394 .35327 L .1 0 0 r
F
.39443 .35483 m .39332 .35575 L .39394 .35327 L F
0 g
.38828 .35839 m
.39394 .35327 L
s
.54366 .49266 m .53608 .48756 L .5402 .48569 L p 0 .387 1 r
F P
0 g
s
.5402 .48569 m .5495 .49004 L .54366 .49266 L p 0 .387 1 r
F P
0 g
s
.52108 .70556 m .51479 .70367 L .48052 .66523 L .1 0 0 r
F
0 g
.51627 .70077 m
.51647 .70038 L
s
.39332 .35575 m .39218 .35677 L .38602 .36044 L .1 0 0 r
F
0 g
.38602 .36044 m
.39218 .35677 L
s
.38602 .36044 m
.38828 .35839 L
s
0 0 0 r
.38763 .28762 m
.38763 .28762 L
s
.38763 .28762 m
.38763 .28762 L
s
.68723 .38345 m .69977 .3775 L .67046 .34377 L p 0 .319 .936 r
F P
0 g
s
0 0 0 r
.67779 .39286 m
.68723 .38345 L
s
0 g
.39218 .35677 m
.39236 .35697 L
s
.5 .21005 m .5 .18847 L .53524 .22894 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .18847 m .53524 .22894 L .54665 .22184 L p 0 .319 .936 r
F P
0 g
s
.53524 .22894 m .5 .18847 L .5 .21005 L closepath p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.40999 .2697 m
.45368 .22882 L
s
.45368 .22882 m
.45368 .22882 L
s
.5 .18847 m .4645 .22171 L .45368 .22882 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.72925 .60167 m
.72925 .60167 L
s
.72925 .60167 m
.72925 .60167 L
s
.53608 .48756 m .53478 .48668 L .53861 .48494 L p 0 .387 1 r
F P
0 g
s
.53861 .48494 m .5402 .48569 L .53608 .48756 L p 0 .387 1 r
F P
0 g
s
.52108 .70556 m .48052 .66523 L .48653 .66678 L .1 0 0 r
F
0 g
.48052 .66523 m
.48568 .66656 L
s
.48568 .66656 m
.48653 .66678 L
s
.48052 .66523 m
.48296 .66075 L
s
.51479 .70367 m
.52108 .70556 L
s
.79608 .50986 m .8161 .51135 L .78241 .54638 L closepath p 0 .35 .78 r
F P
0 g
s
.78135 .47137 m .8161 .51135 L .79608 .50986 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.70207 .54453 m
.7345 .51126 L
s
.7345 .51126 m
.7345 .51126 L
s
.7345 .51126 m
.7345 .51126 L
s
.69703 .46833 m
.7345 .51126 L
s
.69525 .46628 m
.69703 .46833 L
s
.5495 .49004 m .5402 .48569 L p .5647 .49261 L 0 .349 .781 r
F P
0 g
s
.5647 .49261 m .56276 .49453 L .5495 .49004 L p 0 .349 .781 r
F P
0 g
s
.5647 .49261 m .56276 .49453 L .5744 .48939 L p 0 .05 .118 r
F P
0 g
s
.53478 .48668 m .52701 .48027 L .52966 .47905 L p 0 .361 1 r
F P
0 g
s
.52966 .47905 m .53861 .48494 L .53478 .48668 L p 0 .361 1 r
F P
0 g
s
.5067 .45422 m .50158 .44491 L .50729 .4421 L p 0 .248 .836 r
F P
0 g
s
.56276 .49453 m .5495 .49004 L .56106 .48486 L p 0 .408 1 r
F P
0 g
s
.56106 .48486 m .5744 .48939 L .56276 .49453 L p 0 .408 1 r
F P
0 g
s
0 0 0 r
.38763 .28762 m
.38763 .28762 L
s
.4645 .22171 m .5 .18847 L .5 .21005 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .18847 m .5 .21005 L .51119 .20279 L p 0 .181 .719 r
F P
0 g
s
.54665 .22184 m .51118 .18106 L .5 .18847 L p 0 .319 .936 r
F P
0 g
s
.51119 .20279 m .51118 .18106 L .5 .18847 L p 0 .181 .719 r
F P
0 g
s
.5 .21005 m .5 .18847 L .4645 .22171 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .21005 m .5 .18847 L .51118 .18106 L p 0 .181 .719 r
F P
0 g
s
.4645 .22171 m .5 .18847 L .51118 .18106 L p 0 .05 .1 r
F P
0 g
s
.51354 .63876 m
.51414 .63889 L
s
.51206 .63845 m
.51354 .63876 L
s
.50729 .4421 m .51075 .45226 L .5067 .45422 L p 0 .248 .836 r
F P
0 g
s
.50758 .45581 m .5067 .45422 L .51075 .45226 L p 0 .248 .836 r
F P
0 g
s
0 0 0 r
.69383 .56128 m
.69383 .56128 L
s
.52701 .48027 m .52006 .47317 L .52231 .47211 L p 0 .33 .967 r
F P
0 g
s
.52231 .47211 m .52966 .47905 L .52701 .48027 L p 0 .33 .967 r
F P
0 g
s
.51366 .46512 m .50758 .45581 L .51134 .45399 L p 0 .272 .876 r
F P
0 g
s
.51075 .45226 m .51134 .45399 L .50758 .45581 L p 0 .248 .836 r
F P
0 g
s
.5495 .49004 m .5402 .48569 L .55169 .48047 L p 0 .387 1 r
F P
0 g
s
.55169 .48047 m .56106 .48486 L .5495 .49004 L p 0 .387 1 r
F P
0 g
s
.76443 .48876 m .78135 .47137 L .79608 .50986 L p 0 .35 .78 r
F P
0 g
s
.4645 .22171 m .5 .21005 L .5 .23617 L p 0 .349 .781 r
F P
0 g
s
.5 .21005 m .5 .23617 L .5112 .22909 L p 0 .181 .719 r
F P
0 g
s
.5112 .22909 m .51119 .20279 L .5 .21005 L p 0 .181 .719 r
F P
0 g
s
.5 .21005 m .4645 .22171 L .48227 .24205 L p 0 .349 .781 r
F P
0 g
s
.51118 .18106 m .51119 .20279 L .5 .21005 L p 0 .181 .719 r
F P
0 g
s
.5 .23617 m .5 .21005 L .51119 .20279 L p 0 .181 .719 r
F P
0 g
s
0 0 0 r
.54665 .22184 m
.54665 .22184 L
s
.54665 .22184 m
.54665 .22184 L
s
.77181 .50806 m .79608 .50986 L .78241 .54638 L p 0 .35 .78 r
F P
0 g
s
.79608 .50986 m .77181 .50806 L .76443 .48876 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.76443 .48876 m
.76443 .48876 L
s
.51628 .46387 m .52231 .47211 L .52006 .47317 L p 0 .3 .921 r
F P
0 g
s
.52006 .47317 m .51366 .46512 L .51628 .46387 L p 0 .3 .921 r
F P
0 g
s
.51134 .45399 m .51628 .46387 L .51366 .46512 L p 0 .272 .876 r
F P
0 g
s
.53083 .65767 m
.53083 .65767 L
s
.49057 .61236 m
.4961 .61859 L
s
.4961 .61859 m
.51414 .63889 L
s
.5402 .48569 m .53861 .48494 L .55009 .47972 L p 0 .387 1 r
F P
0 g
s
.55009 .47972 m .55169 .48047 L .5402 .48569 L p 0 .387 1 r
F P
0 g
s
.39218 .35677 m
.39332 .35575 L
s
.39332 .35575 m
.39443 .35483 L
s
.52709 .5383 m .53487 .53417 L .5387 .53254 L p 0 .05 .1 r
F P
0 g
s
.36995 .66235 m
.38431 .65687 L
s
.36995 .66235 m
.3722 .66445 L
s
.3722 .66445 m
.37902 .67083 L
s
.53861 .48494 m .52966 .47905 L .54108 .47377 L p 0 .361 1 r
F P
0 g
s
.54108 .47377 m .55009 .47972 L .53861 .48494 L p 0 .361 1 r
F P
0 g
s
.39443 .35483 m
.39521 .35427 L
s
.39521 .35427 m .37741 .33409 L .37226 .35226 L closepath p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.37741 .33409 m
.37741 .33409 L
s
.39521 .35427 m .40564 .34807 L .39053 .36239 L p 0 .05 .1 r
F P
0 g
s
.39053 .36239 m .38019 .36849 L .39521 .35427 L p 0 .05 .1 r
F P
0 g
s
.40564 .34807 m .39521 .35427 L .38019 .36849 L p 0 .05 .1 r
F P
0 g
s
.38019 .36849 m .39521 .35427 L .37226 .35226 L closepath p 0 .349 .781 r
F P
0 g
s
.38771 .32774 m .37741 .33409 L .39521 .35427 L p 0 .315 .944 r
F P
0 g
s
.39521 .35427 m .40564 .34807 L .38771 .32774 L p 0 .315 .944 r
F P
0 g
s
0 0 0 r
.55051 .28046 m
.55051 .28046 L
s
.52752 .29385 m
.55051 .28046 L
s
.52752 .29385 m
.52752 .29385 L
s
.51119 .20279 m .5112 .22909 L .5 .23617 L p 0 .181 .719 r
F P
0 g
s
0 0 0 r
.72009 .47492 m
.72009 .47492 L
s
.72009 .47492 m
.75424 .44017 L
s
.75424 .44017 m
.75424 .44017 L
s
.52966 .47905 m .52231 .47211 L .53369 .46679 L p 0 .33 .967 r
F P
0 g
s
.53369 .46679 m .54108 .47377 L .52966 .47905 L p 0 .33 .967 r
F P
0 g
s
.52762 .45848 m .53369 .46679 L .52231 .47211 L p 0 .3 .921 r
F P
0 g
s
.52231 .47211 m .51628 .46387 L .52762 .45848 L p 0 .3 .921 r
F P
0 g
s
.34919 .35024 m .37226 .35226 L .37741 .33409 L p 0 .349 .781 r
F P
0 g
s
.37741 .33409 m .35957 .31387 L .34919 .35024 L p 0 .349 .781 r
F P
0 g
s
.37741 .33409 m .38771 .32774 L .36975 .30736 L p 0 .315 .944 r
F P
0 g
s
.36975 .30736 m .35957 .31387 L .37741 .33409 L p 0 .315 .944 r
F P
0 g
s
.51075 .45226 m .50729 .4421 L .51855 .43655 L p 0 .248 .836 r
F P
0 g
s
.52264 .44853 m .52762 .45848 L .51628 .46387 L p 0 .272 .876 r
F P
0 g
s
.51628 .46387 m .51134 .45399 L .52264 .44853 L p 0 .272 .876 r
F P
0 g
s
.51855 .43655 m .52204 .44678 L .51075 .45226 L p 0 .248 .836 r
F P
0 g
s
.51134 .45399 m .51075 .45226 L .52204 .44678 L p 0 .248 .836 r
F P
0 g
s
.52204 .44678 m .52264 .44853 L .51134 .45399 L p 0 .248 .836 r
F P
0 g
s
.48653 .66678 m
.49765 .65555 L
s
.50891 .64418 m
.51414 .63889 L
s
.52013 .54404 m .52709 .5383 L .52975 .53717 L p 0 .05 .1 r
F P
0 g
s
.5387 .53254 m .52975 .53717 L .52709 .5383 L p 0 .05 .1 r
F P
0 g
s
.5 .26235 m .48227 .24205 L .49336 .235 L p 0 .318 .939 r
F P
0 g
s
.48661 .20719 m .4645 .22171 L .5 .26235 L p 0 .318 .939 r
F P
0 g
s
.52258 .22191 m .5112 .22909 L .51122 .25546 L p 0 .181 .719 r
F P
0 g
s
.52261 .24846 m .51122 .25546 L .5112 .22909 L p 0 .181 .719 r
F P
0 g
s
.51122 .25546 m .52261 .24846 L .52258 .22191 L p 0 .181 .719 r
F P
0 g
s
.5 .26235 m .52261 .24846 L .48661 .20719 L p 0 .318 .939 r
F P
0 g
s
.76443 .48876 m .77181 .50806 L .74741 .50624 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.76443 .48876 m
.76443 .48876 L
s
.68756 .40046 m
.72163 .43959 L
s
.72163 .43959 m
.76443 .48876 L
s
.76443 .48876 m
.76443 .48876 L
s
.69269 .4435 m
.69269 .4435 L
s
.69269 .4435 m
.69269 .4435 L
s
.69874 .43741 m
.72705 .40888 L
s
.72705 .40888 m
.72705 .40888 L
s
.78241 .54638 m .76493 .52633 L .77181 .50806 L p 0 .35 .78 r
F P
0 g
s
.74741 .50624 m .77181 .50806 L .76493 .52633 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.76493 .52633 m
.76493 .52633 L
s
.55395 .68676 m
.55395 .68676 L
s
.33522 .34902 m .34919 .35024 L .35957 .31387 L p 0 .349 .781 r
F P
0 g
s
.35957 .31387 m .32923 .34225 L .33522 .34902 L p 0 .349 .781 r
F P
0 g
s
.35957 .31387 m .38008 .30075 L .41621 .34178 L p 0 .315 .944 r
F P
0 g
s
.35957 .31387 m .36975 .30736 L .33923 .33592 L p 0 .05 .1 r
F P
0 g
s
.33923 .33592 m .32923 .34225 L .35957 .31387 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.36975 .30736 m
.36975 .30736 L
s
.52975 .53717 m .5387 .53254 L .55021 .52766 L p 0 .05 .1 r
F P
0 g
s
.38019 .36849 m .39053 .36239 L .37534 .37677 L p 0 .05 .1 r
F P
0 g
s
.37534 .37677 m .39053 .36239 L .38019 .36849 L p 0 .05 .1 r
F P
0 g
s
.37534 .37677 m .3651 .38278 L .38019 .36849 L p 0 .05 .1 r
F P
0 g
s
.38019 .36849 m .3651 .38278 L .37534 .37677 L p 0 .05 .1 r
F P
0 g
s
.3651 .38278 m .38019 .36849 L .37226 .35226 L p 0 .349 .781 r
F P
0 g
s
.38019 .36849 m .39053 .36239 L .40564 .34807 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.40564 .34807 m
.40564 .34807 L
s
.37226 .35226 m .34919 .35024 L .3651 .38278 L p 0 .349 .781 r
F P
0 g
s
.48227 .24205 m .4645 .22171 L .47547 .21451 L p 0 .318 .939 r
F P
0 g
s
.47547 .21451 m .49336 .235 L .48227 .24205 L p 0 .318 .939 r
F P
0 g
s
.52975 .53717 m .52239 .54308 L .52013 .54404 L p 0 .05 .1 r
F P
0 g
s
.51372 .55162 m .52013 .54404 L .52239 .54308 L p 0 .05 .259 r
F P
0 g
s
.67046 .34377 m .69977 .3775 L .66481 .36393 L p 0 .35 .78 r
F P
0 g
s
.69977 .3775 m .68254 .39469 L .66501 .38793 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.68254 .39469 m
.68629 .399 L
s
.68254 .39469 m
.68254 .39469 L
s
.68254 .39469 m
.68254 .39469 L
s
.66501 .38793 m .66481 .36393 L .69977 .3775 L p 0 .35 .78 r
F P
0 g
s
.55021 .52766 m .54121 .53232 L .52975 .53717 L p 0 .05 .1 r
F P
0 g
s
.52239 .54308 m .52975 .53717 L .54121 .53232 L p 0 .05 .1 r
F P
0 g
s
.52252 .17354 m .51118 .18106 L .54665 .22184 L p 0 .319 .936 r
F P
0 g
s
.54665 .22184 m .55824 .21464 L .52252 .17354 L p 0 .319 .936 r
F P
0 g
s
0 0 0 r
.5226 .24466 m
.54665 .22184 L
s
.54665 .22184 m
.54665 .22184 L
s
.51118 .18106 m .47547 .21451 L .4645 .22171 L p 0 .05 .1 r
F P
0 g
s
.4645 .22171 m .38008 .30075 L .41621 .34178 L p 0 .349 .781 r
F P
0 g
s
.50463 .22785 m .49336 .235 L .47547 .21451 L p 0 .318 .939 r
F P
0 g
s
.47547 .21451 m .48661 .20719 L .50463 .22785 L p 0 .318 .939 r
F P
0 g
s
.38008 .30075 m .4645 .22171 L .48661 .20719 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.43849 .28329 m
.48227 .24205 L
s
.41031 .30984 m
.43849 .28329 L
s
.36975 .30736 m
.40999 .2697 L
s
.38763 .28762 m
.40847 .27417 L
s
.40847 .27417 m
.40847 .27417 L
s
.41545 .26161 m
.43661 .24783 L
s
.43661 .24783 m
.43661 .24783 L
s
.72307 .56959 m
.76493 .52633 L
s
.76493 .52633 m
.76493 .52633 L
s
.52239 .54308 m .51636 .55052 L .51372 .55162 L p 0 .05 .259 r
F P
0 g
s
.48653 .66678 m
.52108 .70556 L
s
.54121 .53232 m .53381 .53827 L .52239 .54308 L p 0 .05 .1 r
F P
0 g
s
.51636 .55052 m .52239 .54308 L .53381 .53827 L p 0 .05 .259 r
F P
0 g
s
.56106 .48486 m .55169 .48047 L p .57634 .48746 L 0 .349 .781 r
F P
0 g
s
.57634 .48746 m .5744 .48939 L .56106 .48486 L p 0 .349 .781 r
F P
0 g
s
.57634 .48746 m .5744 .48939 L .58621 .48417 L p 0 .05 .118 r
F P
0 g
s
0 0 0 r
.51122 .25546 m
.51122 .25546 L
s
.51304 .25754 m
.55473 .3053 L
s
.3651 .38278 m .34919 .35024 L .33522 .34902 L closepath p 0 .349 .781 r
F P
0 g
s
.37534 .37677 m .3651 .38278 L .33522 .34902 L p 0 .314 .946 r
F P
0 g
s
.34993 .39714 m .3651 .38278 L .3351 .36348 L p 0 .349 .781 r
F P
0 g
s
.34993 .39714 m .3651 .38278 L .37534 .37677 L p 0 .05 .1 r
F P
0 g
s
.3651 .38278 m .37534 .37677 L .34526 .34274 L p 0 .314 .946 r
F P
0 g
s
.34526 .34274 m .33522 .34902 L .3651 .38278 L p 0 .314 .946 r
F P
0 g
s
.33522 .34902 m .3351 .36348 L .3651 .38278 L closepath p 0 .349 .781 r
F P
0 g
s
.37534 .37677 m .36009 .39122 L .34993 .39714 L p 0 .05 .1 r
F P
0 g
s
.3651 .38278 m .34993 .39714 L .36009 .39122 L p 0 .05 .1 r
F P
0 g
s
.36009 .39122 m .37534 .37677 L .3651 .38278 L p 0 .05 .1 r
F P
0 g
s
.39068 .50186 m
.39243 .50191 L
s
.66481 .36393 m .66469 .34947 L .67046 .34377 L p 0 .35 .78 r
F P
0 g
s
.64106 .30994 m .67046 .34377 L .66469 .34947 L p 0 .35 .78 r
F P
0 g
s
.5744 .48939 m .56106 .48486 L .57278 .4796 L p 0 .408 1 r
F P
0 g
s
.57278 .4796 m .58621 .48417 L .5744 .48939 L p 0 .408 1 r
F P
0 g
s
0 0 0 r
.51145 .72349 m
.53248 .70196 L
s
.54883 .68524 m
.54883 .68524 L
s
0 g
.32428 .48991 m
.3283 .48995 L
s
.52252 .17354 m .51118 .18106 L .51119 .20279 L p 0 .181 .719 r
F P
0 g
s
.48661 .20719 m .47547 .21451 L .51118 .18106 L p 0 .05 .1 r
F P
0 g
s
.52255 .19542 m .51119 .20279 L .51118 .18106 L p 0 .181 .719 r
F P
0 g
s
.51118 .18106 m .52252 .17354 L .52255 .19542 L p 0 .181 .719 r
F P
0 g
s
.51118 .18106 m .52252 .17354 L .48661 .20719 L p 0 .05 .1 r
F P
0 g
s
.53381 .53827 m .52774 .54575 L .51636 .55052 L p 0 .05 .259 r
F P
0 g
s
.66063 .66393 m .64825 .66782 L .64237 .66115 L p 0 .314 .946 r
F P
0 g
s
.64825 .66782 m .66063 .66393 L .6547 .65722 L p 0 .314 .946 r
F P
0 g
s
.6547 .65722 m .64237 .66115 L .64825 .66782 L p 0 .314 .946 r
F P
0 g
s
.64825 .66782 m .64237 .66115 L .62881 .66038 L p 0 .349 .781 r
F P
0 g
s
.66469 .34947 m .65117 .34824 L .64106 .30994 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.43661 .24783 m
.43661 .24783 L
s
.64237 .66115 m .6547 .65722 L .66063 .66393 L p 0 .314 .946 r
F P
0 g
s
0 0 0 r
.46661 .28207 m
.47232 .28859 L
s
.43661 .24783 m
.43661 .24783 L
s
.43823 .24968 m
.46661 .28207 L
s
.56106 .48486 m .55169 .48047 L .56336 .47518 L p 0 .387 1 r
F P
0 g
s
.56336 .47518 m .57278 .4796 L .56106 .48486 L p 0 .387 1 r
F P
0 g
s
0 0 0 r
.52811 .71465 m
.52811 .71465 L
s
.52811 .71465 m
.52811 .71465 L
s
.50886 .72059 m
.52811 .71465 L
s
.33522 .34902 m .34526 .34274 L .37534 .37677 L p 0 .314 .946 r
F P
0 g
s
.33923 .33592 m .34526 .34274 L .33522 .34902 L p 0 .314 .946 r
F P
0 g
s
.33522 .34902 m .32923 .34225 L .33923 .33592 L p 0 .314 .946 r
F P
0 g
s
.32923 .34225 m .33522 .34902 L .34526 .34274 L p 0 .314 .946 r
F P
0 g
s
.3351 .36348 m .33522 .34902 L .32923 .34225 L p 0 .349 .781 r
F P
0 g
s
.51119 .20279 m .52255 .19542 L .52252 .17354 L p 0 .181 .719 r
F P
0 g
s
.52255 .19542 m .51119 .20279 L .5112 .22909 L p 0 .181 .719 r
F P
0 g
s
.52258 .22191 m .5112 .22909 L .51119 .20279 L p 0 .181 .719 r
F P
0 g
s
.51119 .20279 m .52255 .19542 L .52258 .22191 L p 0 .181 .719 r
F P
0 g
s
.34526 .34274 m .33923 .33592 L .32923 .34225 L p 0 .314 .946 r
F P
0 g
s
.32923 .34225 m .2986 .3709 L .3351 .36348 L p 0 .349 .781 r
F P
0 g
s
.32923 .34225 m .33923 .33592 L .30841 .36476 L p 0 .05 .1 r
F P
0 g
s
.30841 .36476 m .2986 .3709 L .32923 .34225 L p 0 .05 .1 r
F P
0 g
s
.532 .43702 m .52204 .44678 L .51855 .43655 L p 0 .349 .781 r
F P
0 g
s
.532 .43702 m .52204 .44678 L .5335 .44123 L p 0 .05 .1 r
F P
0 g
s
.55169 .48047 m .55009 .47972 L .56175 .47442 L p 0 .387 1 r
F P
0 g
s
.56175 .47442 m .56336 .47518 L .55169 .48047 L p 0 .387 1 r
F P
0 g
s
0 0 0 r
.72074 .53364 m
.72074 .53364 L
s
.72074 .53364 m
.75595 .57391 L
s
.75595 .57391 m
.75595 .57391 L
s
.3351 .36348 m .3349 .3875 L .34993 .39714 L p 0 .349 .781 r
F P
0 g
s
.3349 .3875 m .3351 .36348 L .2986 .3709 L p 0 .349 .781 r
F P
0 g
s
.55009 .47972 m .54108 .47377 L .55268 .46843 L p 0 .361 1 r
F P
0 g
s
.55268 .46843 m .56175 .47442 L .55009 .47972 L p 0 .361 1 r
F P
0 g
s
0 0 0 r
.36975 .30736 m
.36975 .30736 L
s
.40564 .34807 m
.40564 .34807 L
s
.40564 .34807 m .41621 .34178 L .40102 .35619 L p 0 .05 .1 r
F P
0 g
s
.40102 .35619 m .39053 .36239 L .40564 .34807 L p 0 .05 .1 r
F P
0 g
s
.41621 .34178 m .40564 .34807 L .39053 .36239 L p 0 .05 .1 r
F P
0 g
s
.39816 .32129 m .38771 .32774 L .40564 .34807 L p 0 .315 .944 r
F P
0 g
s
.40564 .34807 m .41621 .34178 L .39816 .32129 L p 0 .315 .944 r
F P
0 g
s
.47806 .68607 m .51391 .6498 L .46868 .6658 L p .212 0 0 r
F P
0 g
s
.46217 .6585 m
.46868 .6658 L
s
.46217 .6585 m
.46217 .6585 L
s
.45385 .64917 m
.46217 .6585 L
s
.4641 .67042 m
.46868 .6658 L
s
.36505 .4711 m
.37581 .48321 L
s
.37581 .48321 m
.38502 .49357 L
s
.38502 .49357 m
.39243 .50191 L
s
.5112 .22909 m .52258 .22191 L .52255 .19542 L p 0 .181 .719 r
F P
0 g
s
.5112 .22909 m .52258 .22191 L .52261 .24846 L p 0 .181 .719 r
F P
0 g
s
.54108 .47377 m .53369 .46679 L .54524 .46138 L p 0 .33 .967 r
F P
0 g
s
.54524 .46138 m .55268 .46843 L .54108 .47377 L p 0 .33 .967 r
F P
0 g
s
0 0 0 r
.61354 .27827 m
.61354 .27827 L
s
0 g
.37557 .52244 m
.39241 .50611 L
s
0 0 0 r
.43661 .24783 m
.43661 .24783 L
s
.53912 .45301 m .54524 .46138 L .53369 .46679 L p 0 .3 .921 r
F P
0 g
s
.53369 .46679 m .52762 .45848 L .53912 .45301 L p 0 .3 .921 r
F P
0 g
s
.64649 .45609 m
.64703 .45554 L
s
.677 .42551 m .71235 .44486 L .67955 .4214 L .577 0 0 r
F
.36975 .30736 m .38771 .32774 L .39816 .32129 L p 0 .315 .944 r
F P
0 g
s
0 0 0 r
.36975 .30736 m
.40564 .34807 L
s
.52204 .44678 m .51855 .43655 L .52999 .43092 L p 0 .248 .836 r
F P
0 g
s
.70232 .62969 m .6896 .63384 L .66063 .66393 L p 0 .05 .248 r
F P
0 g
s
.68452 .60945 m .67192 .61376 L .6896 .63384 L p 0 .315 .944 r
F P
0 g
s
.6896 .63384 m .70232 .62969 L .68452 .60945 L p 0 .315 .944 r
F P
0 g
s
0 0 0 r
.67101 .61273 m
.6896 .63384 L
s
.53411 .44299 m .53912 .45301 L .52762 .45848 L p 0 .272 .876 r
F P
0 g
s
.52762 .45848 m .52264 .44853 L .53411 .44299 L p 0 .272 .876 r
F P
0 g
s
.52999 .43092 m .5335 .44123 L .52204 .44678 L p 0 .248 .836 r
F P
0 g
s
.52264 .44853 m .52204 .44678 L .5335 .44123 L p 0 .248 .836 r
F P
0 g
s
.5335 .44123 m .53411 .44299 L .52264 .44853 L p 0 .248 .836 r
F P
0 g
s
.52466 .78703 m .51326 .79001 L .47744 .82706 L p 0 .05 .248 r
F P
0 g
s
.47746 .80445 m .47744 .82706 L .51326 .79001 L closepath p 0 .349 .781 r
F P
0 g
s
.51326 .79001 m .52466 .78703 L .50669 .76693 L p 0 .308 .954 r
F P
0 g
s
.47749 .77723 m .47746 .80445 L .51326 .79001 L p 0 .349 .781 r
F P
0 g
s
.5 .74345 m .53623 .784 L .51326 .79001 L p 0 .308 .954 r
F P
0 g
s
.5 .74345 m .5 .77101 L .48866 .77414 L p 0 .181 .719 r
F P
0 g
s
.55991 .7778 m .53623 .784 L .5 .74345 L p 0 .308 .954 r
F P
0 g
s
.50669 .76693 m .52466 .78703 L .53623 .784 L p 0 .308 .954 r
F P
0 g
s
.53623 .784 m .51813 .76375 L .50669 .76693 L p 0 .308 .954 r
F P
0 g
s
.5 .77101 m .5 .74345 L .51813 .76375 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .74345 m .51813 .76375 L .52976 .76052 L p 0 .308 .954 r
F P
0 g
s
.51813 .76375 m .5 .74345 L .5 .77101 L closepath p 0 .349 .781 r
F P
0 g
s
.4818 .76211 m .5 .74345 L .5 .77101 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .77101 m .5 .74345 L .4818 .76211 L closepath p 0 .349 .781 r
F P
0 g
s
.52976 .76052 m .5115 .74007 L .5 .74345 L p 0 .308 .954 r
F P
0 g
s
.5 .77101 m .51813 .76375 L .53623 .784 L p 0 .349 .781 r
F P
0 g
s
.51813 .76375 m .5 .77101 L .5 .79863 L p 0 .349 .781 r
F P
0 g
s
.5 .74345 m .52317 .73662 L .55991 .7778 L p 0 .308 .954 r
F P
0 g
s
.51151 .76782 m .5115 .74007 L .5 .74345 L p 0 .181 .719 r
F P
0 g
s
.5 .74345 m .5 .77101 L .51151 .76782 L p 0 .181 .719 r
F P
0 g
s
.5 .77101 m .5 .74345 L .5115 .74007 L p 0 .181 .719 r
F P
0 g
s
.48866 .77414 m .47749 .77723 L .47746 .80445 L p 0 .181 .719 r
F P
0 g
s
.47749 .77723 m .48866 .77414 L .48865 .80156 L p 0 .181 .719 r
F P
0 g
s
.47746 .80445 m .48865 .80156 L .48866 .77414 L p 0 .181 .719 r
F P
0 g
s
.5 .79863 m .5 .77101 L .48866 .77414 L p 0 .181 .719 r
F P
0 g
s
.48866 .77414 m .48865 .80156 L .5 .79863 L p 0 .181 .719 r
F P
0 g
s
.48865 .80156 m .48866 .77414 L .5 .77101 L p 0 .181 .719 r
F P
0 g
s
.5 .77101 m .5 .79863 L .48865 .80156 L p 0 .181 .719 r
F P
0 g
s
.4818 .76211 m .5 .77101 L .5 .79863 L p 0 .349 .781 r
F P
0 g
s
.5 .77101 m .4818 .76211 L .46349 .78087 L p 0 .349 .781 r
F P
0 g
s
.5115 .74007 m .51151 .76782 L .5 .77101 L p 0 .181 .719 r
F P
0 g
s
.48865 .80156 m .47746 .80445 L .47749 .77723 L p 0 .181 .719 r
F P
0 g
s
.5 .79863 m .46349 .78087 L .4818 .76211 L p 0 .349 .781 r
F P
0 g
s
.52317 .73662 m .5115 .74007 L .52976 .76052 L p 0 .308 .954 r
F P
0 g
s
.52317 .73662 m .5115 .74007 L .51151 .76782 L p 0 .181 .719 r
F P
0 g
s
.51813 .76375 m .53623 .784 L .54798 .78092 L p 0 .308 .954 r
F P
0 g
s
.47744 .82706 m .48863 .82434 L .52466 .78703 L p 0 .05 .248 r
F P
0 g
s
.52466 .78703 m .48863 .82434 L .5 .82158 L p 0 .05 .248 r
F P
0 g
s
.5 .82158 m .53623 .784 L .52466 .78703 L p 0 .05 .248 r
F P
0 g
s
.5 .79863 m .53623 .784 L .51813 .76375 L p 0 .349 .781 r
F P
0 g
s
.54798 .78092 m .52976 .76052 L .51813 .76375 L p 0 .308 .954 r
F P
0 g
s
.5232 .76459 m .51151 .76782 L .5115 .74007 L p 0 .181 .719 r
F P
0 g
s
.5115 .74007 m .52317 .73662 L .5232 .76459 L p 0 .181 .719 r
F P
0 g
s
.48623 .77458 m .52317 .73662 L .5 .74345 L p 0 .05 .212 r
F P
0 g
s
.60017 .47692 m
.60257 .47452 L
s
.52261 .24846 m .51122 .25546 L .49336 .235 L p 0 .318 .939 r
F P
0 g
s
0 0 0 r
.51122 .25546 m
.51122 .25546 L
s
.51122 .25546 m
.51122 .25546 L
s
.51122 .25546 m
.51122 .25546 L
s
.47547 .21451 m
.47547 .21451 L
s
.58411 .28163 m
.62361 .327 L
s
.62361 .327 m
.62361 .327 L
s
.39816 .32129 m .38008 .30075 L .36975 .30736 L p 0 .315 .944 r
F P
0 g
s
.36975 .30736 m .38008 .30075 L .34938 .3295 L p 0 .05 .1 r
F P
0 g
s
.34938 .3295 m .33923 .33592 L .36975 .30736 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.55051 .28046 m
.55051 .28046 L
s
.55051 .28046 m
.58593 .2465 L
s
.58593 .2465 m
.58593 .2465 L
s
.54121 .53232 m .55021 .52766 L .5619 .52271 L p 0 .05 .1 r
F P
0 g
s
.35751 .46261 m .39941 .44034 L .36335 .39963 L p .535 0 0 r
F P
0 g
s
.33329 .43536 m
.35751 .46261 L
s
.59938 .47411 m
.60148 .47201 L
s
.39053 .36239 m .40102 .35619 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.38574 .37067 m .37534 .37677 L .39053 .36239 L p 0 .05 .1 r
F P
0 g
s
.40102 .35619 m .39053 .36239 L .37534 .37677 L p 0 .05 .1 r
F P
0 g
s
.39053 .36239 m .40102 .35619 L .41621 .34178 L p 0 .05 .1 r
F P
0 g
s
.49336 .235 m .50463 .22785 L .52261 .24846 L p 0 .318 .939 r
F P
0 g
s
.3917 .65555 m .38431 .65687 L .39056 .65448 L .511 0 0 r
F
0 g
.38431 .65687 m
.38659 .65899 L
s
.38659 .65899 m
.38883 .66108 L
s
.32661 .38527 m .31667 .39125 L .2986 .3709 L p 0 .312 .948 r
F P
0 g
s
0 0 0 r
.40847 .27417 m
.40847 .27417 L
s
.43864 .30853 m
.44439 .31507 L
s
.40847 .27417 m
.40847 .27417 L
s
.40928 .2751 m
.43864 .30853 L
s
.5619 .52271 m .55284 .5274 L .54121 .53232 L p 0 .05 .1 r
F P
0 g
s
.53381 .53827 m .54121 .53232 L .55284 .5274 L p 0 .05 .1 r
F P
0 g
s
.52255 .19542 m .52252 .17354 L .55824 .21464 L closepath p 0 .35 .78 r
F P
0 g
s
.55824 .21464 m .54047 .2315 L .52258 .22191 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.5226 .24255 m
.54047 .2315 L
s
.54047 .2315 m
.58411 .28163 L
s
.54047 .2315 m
.54047 .2315 L
s
.54047 .2315 m
.54047 .2315 L
s
.52258 .22191 m .52255 .19542 L .55824 .21464 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.47547 .21451 m
.47547 .21451 L
s
.67955 .4214 m .70705 .42304 L .67773 .41413 L .577 0 0 r
F
0 g
.677 .42551 m
.67955 .4214 L
s
.67955 .4214 m .71235 .44486 L .70705 .42304 L .577 0 0 r
F
.35498 .39983 m .31838 .35852 L .2986 .3709 L p 0 .312 .948 r
F P
0 g
s
.2986 .3709 m .30841 .36476 L .32661 .38527 L p 0 .312 .948 r
F P
0 g
s
.32661 .38527 m .30841 .36476 L .31838 .35852 L p 0 .312 .948 r
F P
0 g
s
.21127 .45258 m .2986 .3709 L .31838 .35852 L p 0 .05 .1 r
F P
0 g
s
.70539 .54941 m .71347 .54997 L .67871 .51026 L .204 0 0 r
F
0 g
.67435 .51396 m
.70539 .54941 L
s
0 0 0 r
.69383 .56128 m
.69383 .56128 L
s
.69383 .56128 m
.69383 .56128 L
s
.6965 .56432 m
.72925 .60167 L
s
.72925 .60167 m
.72925 .60167 L
s
.55284 .5274 m .5454 .53339 L .53381 .53827 L p 0 .05 .1 r
F P
0 g
s
.52774 .54575 m .53381 .53827 L .5454 .53339 L p 0 .05 .259 r
F P
0 g
s
.57278 .4796 m .56336 .47518 L p .58817 .48223 L 0 .349 .781 r
F P
0 g
s
.58817 .48223 m .58621 .48417 L .57278 .4796 L p 0 .349 .781 r
F P
0 g
s
.58817 .48223 m .58621 .48417 L .5954 .48012 L p 0 .05 .118 r
F P
0 g
s
.54017 .40857 m
.54275 .40604 L
s
.37534 .37677 m .38574 .37067 L .40102 .35619 L p 0 .05 .1 r
F P
0 g
s
.38574 .37067 m .37534 .37677 L .34526 .34274 L p 0 .314 .946 r
F P
0 g
s
.36009 .39122 m .37534 .37677 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.37534 .37677 m .38574 .37067 L .35545 .33637 L p 0 .314 .946 r
F P
0 g
s
.35545 .33637 m .34526 .34274 L .37534 .37677 L p 0 .314 .946 r
F P
0 g
s
.38574 .37067 m .37534 .37677 L .36009 .39122 L p 0 .05 .1 r
F P
0 g
s
.58621 .48417 m .57278 .4796 L .57885 .47688 L p 0 .408 1 r
F P
0 g
s
.57885 .47688 m .5954 .48012 L .58621 .48417 L p 0 .408 1 r
F P
0 g
s
.67076 .49107 m .67843 .47917 L .71235 .44486 L .86 0 0 r
F
0 g
.65179 .45077 m
.677 .42551 L
s
.64311 .45947 m .67843 .47917 L .67076 .49107 L .569 0 0 r
F
0 g
.67076 .49107 m
.70444 .45698 L
s
.67076 .49107 m
.67183 .4894 L
s
.64818 .46526 m
.67076 .49107 L
s
.64311 .45947 m
.64818 .46526 L
s
.62521 .47742 m
.64311 .45947 L
s
0 0 0 r
.40847 .27417 m
.40847 .27417 L
s
.40847 .27417 m
.40847 .27417 L
s
.60024 .33043 m .56641 .29869 L .59418 .33054 L .577 0 0 r
F
0 0 0 r
.57963 .31109 m
.61354 .27827 L
s
.57832 .31235 m
.57832 .31235 L
s
.57832 .31235 m
.57832 .31235 L
s
.57832 .31235 m
.57832 .31235 L
s
0 g
.54145 .38187 m
.55472 .36896 L
s
.55472 .36896 m
.55968 .36413 L
s
.56264 .36124 m
.56373 .36018 L
s
.56658 .35741 m
.57421 .34998 L
s
.48661 .20719 m .52252 .17354 L .52255 .19542 L closepath p 0 .35 .78 r
F P
0 g
s
.54335 .41027 m
.54529 .40837 L
s
.52276 .55507 m .52774 .54575 L .5393 .54092 L p 0 .05 .444 r
F P
0 g
s
.5454 .53339 m .5393 .54092 L .52774 .54575 L p 0 .05 .259 r
F P
0 g
s
.39361 .65632 m .40711 .64291 L .39209 .6261 L p 0 .349 .781 r
F P
0 g
s
.41776 .6388 m .40711 .64291 L .39361 .65632 L p 0 .05 .118 r
F P
0 g
s
.66063 .66393 m .67319 .65998 L .70232 .62969 L p 0 .05 .248 r
F P
0 g
s
.66063 .66393 m .6547 .65722 L .66722 .65322 L p 0 .314 .946 r
F P
0 g
s
.66722 .65322 m .67319 .65998 L .66063 .66393 L p 0 .314 .946 r
F P
0 g
s
.6547 .65722 m .66063 .66393 L .67319 .65998 L p 0 .314 .946 r
F P
0 g
s
.67773 .41413 m .70705 .42304 L .68978 .39738 L .577 0 0 r
F
0 g
.67773 .41413 m
.67955 .4214 L
s
.67583 .41132 m
.67773 .41413 L
s
.67201 .51007 m
.6761 .51018 L
s
.67092 .51004 m
.67201 .51007 L
s
.64868 .53262 m
.67092 .51004 L
s
.64493 .53642 m
.64868 .53262 L
s
.48865 .80156 m .47746 .80445 L .47744 .82706 L p 0 .181 .719 r
F P
0 g
s
.44143 .78697 m .47744 .82706 L .47746 .80445 L closepath p 0 .349 .781 r
F P
0 g
s
.47746 .80445 m .48865 .80156 L .48863 .82434 L p 0 .181 .719 r
F P
0 g
s
.48863 .82434 m .47744 .82706 L .47746 .80445 L p 0 .181 .719 r
F P
0 g
s
.36228 .5563 m .399 .52055 L .35695 .54051 L p .1 0 0 r
F P
0 g
s
.32881 .50895 m .35695 .54051 L .399 .52055 L p .523 0 0 r
F P
0 g
s
.35225 .54507 m
.35695 .54051 L
s
.67319 .65998 m .66722 .65322 L .6547 .65722 L p 0 .314 .946 r
F P
0 g
s
.57278 .4796 m .56336 .47518 L .56763 .47324 L p 0 .387 1 r
F P
0 g
s
.56763 .47324 m .57885 .47688 L .57278 .4796 L p 0 .387 1 r
F P
0 g
s
.52261 .24846 m .52258 .22191 L .54047 .2315 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.54047 .2315 m
.54047 .2315 L
s
.34526 .34274 m .35545 .33637 L .38574 .37067 L p 0 .314 .946 r
F P
0 g
s
.35545 .33637 m .34526 .34274 L .33923 .33592 L p 0 .314 .946 r
F P
0 g
s
.34938 .3295 m .33923 .33592 L .34526 .34274 L p 0 .314 .946 r
F P
0 g
s
.34526 .34274 m .35545 .33637 L .34938 .3295 L p 0 .314 .946 r
F P
0 g
s
.64311 .45947 m
.64382 .45832 L
s
.52255 .19542 m .52258 .22191 L .50463 .22785 L p 0 .35 .78 r
F P
0 g
s
.50463 .22785 m .48661 .20719 L .52255 .19542 L p 0 .35 .78 r
F P
0 g
s
.39209 .6261 m .37855 .63949 L .39361 .65632 L p 0 .349 .781 r
F P
0 g
s
.39056 .65448 m
.3913 .65374 L
s
.38431 .65687 m
.39056 .65448 L
s
.39056 .65448 m
.39056 .65448 L
s
.5393 .54092 m .53429 .5503 L .52276 .55507 L p 0 .05 .444 r
F P
0 g
s
.52216 .55675 m .52276 .55507 L .53429 .5503 L p 0 .099 .551 r
F P
0 g
s
0 0 0 r
.26975 .39788 m
.26975 .39788 L
s
.26975 .39788 m
.26975 .39788 L
s
.33391 .42758 m .37018 .46842 L .32897 .48995 L p .526 0 0 r
F P
0 g
s
.3283 .48995 m
.32897 .48995 L
s
.51867 .56659 m .52216 .55675 L .53369 .55199 L p 0 .099 .551 r
F P
0 g
s
.53429 .5503 m .53369 .55199 L .52216 .55675 L p 0 .099 .551 r
F P
0 g
s
.33923 .33592 m .34938 .3295 L .35545 .33637 L p 0 .314 .946 r
F P
0 g
s
.33923 .33592 m .34938 .3295 L .31838 .35852 L p 0 .05 .1 r
F P
0 g
s
.31838 .35852 m .30841 .36476 L .33923 .33592 L p 0 .05 .1 r
F P
0 g
s
.60024 .33043 m .5845 .29811 L .56641 .29869 L .577 0 0 r
F
.54963 .33183 m .56641 .29869 L .5845 .29811 L .541 0 0 r
F
.54963 .33183 m .5317 .33216 L .56641 .29869 L F
0 g
.65095 .42667 m
.672 .40566 L
s
.672 .40566 m .68978 .39738 L .63376 .33302 L p .577 0 0 r
F P
0 g
s
.56336 .47518 m .56175 .47442 L .56571 .47262 L p 0 .387 1 r
F P
0 g
s
.56571 .47262 m .56763 .47324 L .56336 .47518 L p 0 .387 1 r
F P
0 g
s
.39056 .65448 m
.3917 .65555 L
s
.47744 .82706 m .48863 .82434 L .48865 .80156 L p 0 .181 .719 r
F P
0 g
s
.48863 .82434 m .47744 .82706 L .44143 .78697 L p 0 .305 .956 r
F P
0 g
s
.39801 .66123 m
.39983 .66327 L
s
.56175 .47442 m .55268 .46843 L .55542 .46716 L p 0 .361 1 r
F P
0 g
s
.55542 .46716 m .56571 .47262 L .56175 .47442 L p 0 .361 1 r
F P
0 g
s
.38574 .37067 m .3704 .38521 L .36009 .39122 L p 0 .05 .1 r
F P
0 g
s
.36009 .39122 m .3704 .38521 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.3917 .65555 m
.39282 .65622 L
s
.39282 .65622 m
.39361 .65632 L
s
0 0 0 r
.61608 .71939 m
.61608 .71939 L
s
.61608 .71939 m
.61608 .71939 L
s
.40102 .35619 m .41621 .34178 L .42695 .3354 L p 0 .05 .1 r
F P
0 g
s
.41621 .34178 m .42695 .3354 L .40877 .31474 L p 0 .315 .944 r
F P
0 g
s
.40877 .31474 m .39816 .32129 L .41621 .34178 L p 0 .315 .944 r
F P
0 g
s
.42695 .3354 m .41621 .34178 L .40102 .35619 L p 0 .05 .1 r
F P
0 g
s
.39296 .33971 m .41621 .34178 L .39816 .32129 L closepath p 0 .349 .781 r
F P
0 g
s
.40102 .35619 m .41621 .34178 L .39296 .33971 L closepath p 0 .349 .781 r
F P
0 g
s
.40121 .28724 m .43785 .32892 L .41621 .34178 L p 0 .315 .944 r
F P
0 g
s
.41621 .34178 m .38008 .30075 L .40121 .28724 L p 0 .315 .944 r
F P
0 g
s
.39816 .32129 m .41621 .34178 L .39296 .33971 L closepath p 0 .349 .781 r
F P
0 g
s
.39296 .33971 m .41621 .34178 L .40102 .35619 L closepath p 0 .349 .781 r
F P
0 g
s
.399 .52055 m .37005 .48799 L .32881 .50895 L p .523 0 0 r
F P
0 g
s
.32881 .50895 m .37005 .48799 L .33311 .52361 L p .1 0 0 r
F P
0 g
s
.30113 .4587 m
.32897 .48995 L
s
.33782 .51906 m
.35695 .54051 L
s
.32408 .5135 m
.32881 .50895 L
s
.53369 .55199 m .53018 .5619 L .51867 .56659 L p 0 .099 .551 r
F P
0 g
s
.67843 .47917 m .70705 .42304 L .71235 .44486 L .952 0 0 r
F
0 g
.70444 .45698 m
.71235 .44486 L
s
.39361 .65632 m .40418 .65231 L .41776 .6388 L p 0 .05 .118 r
F P
0 g
s
.39361 .65632 m .37855 .63949 L .38902 .63535 L p 0 .308 .954 r
F P
0 g
s
.38902 .63535 m .40418 .65231 L .39361 .65632 L p 0 .308 .954 r
F P
0 g
s
.3703 .65502 m .3753 .67453 L .39361 .65632 L closepath p 0 .349 .781 r
F P
0 g
s
.39361 .65632 m .40418 .65231 L .38902 .63535 L p 0 .308 .954 r
F P
0 g
s
.38902 .63535 m .37855 .63949 L .39361 .65632 L p 0 .308 .954 r
F P
0 g
s
.3703 .65502 m .39361 .65632 L .37855 .63949 L closepath p 0 .349 .781 r
F P
0 g
s
.50463 .22785 m .52258 .22191 L .52261 .24846 L closepath p 0 .35 .78 r
F P
0 g
s
.60843 .33462 m .5845 .29811 L .60024 .33043 L .577 0 0 r
F
0 g
.5771 .34717 m
.59418 .33054 L
s
.59418 .33054 m
.60024 .33043 L
s
.55268 .46843 m .54524 .46138 L .54757 .46029 L p 0 .33 .967 r
F P
0 g
s
.54757 .46029 m .55542 .46716 L .55268 .46843 L p 0 .33 .967 r
F P
0 g
s
.54184 .45172 m .54757 .46029 L .54524 .46138 L p 0 .3 .921 r
F P
0 g
s
.54524 .46138 m .53912 .45301 L .54184 .45172 L p 0 .3 .921 r
F P
0 g
s
0 0 0 r
.26975 .39788 m
.26975 .39788 L
s
.38008 .30075 m .39816 .32129 L .40877 .31474 L p 0 .315 .944 r
F P
0 g
s
.39816 .32129 m .38008 .30075 L .3696 .33763 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.37741 .33409 m
.39816 .32129 L
s
.3696 .33763 m .39296 .33971 L .39816 .32129 L p 0 .349 .781 r
F P
0 g
s
.38008 .30075 m .39816 .32129 L .39296 .33971 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.39816 .32129 m
.39816 .32129 L
s
.39816 .32129 m
.39816 .32129 L
s
.5335 .44123 m .52999 .43092 L .53591 .42801 L p 0 .248 .836 r
F P
0 g
s
.66722 .65322 m .6671 .63834 L .70232 .62969 L p 0 .35 .78 r
F P
0 g
s
.70232 .62969 m .67319 .65998 L .66722 .65322 L p 0 .35 .78 r
F P
0 g
s
.68452 .60945 m .70232 .62969 L .6671 .63834 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.68452 .60945 m
.72307 .56959 L
s
.68452 .60945 m
.68452 .60945 L
s
.66691 .61547 m
.68452 .60945 L
s
.37855 .63949 m .36346 .62264 L .37382 .61837 L p 0 .308 .954 r
F P
0 g
s
.37382 .61837 m .38902 .63535 L .37855 .63949 L p 0 .308 .954 r
F P
0 g
s
.37855 .63949 m .36346 .62264 L .34688 .65372 L p 0 .349 .781 r
F P
0 g
s
.34688 .65372 m .3703 .65502 L .37855 .63949 L p 0 .349 .781 r
F P
0 g
s
.36346 .62264 m .37855 .63949 L .38902 .63535 L p 0 .308 .954 r
F P
0 g
s
.538 .44111 m .54184 .45172 L .53912 .45301 L p 0 .272 .876 r
F P
0 g
s
.53912 .45301 m .53411 .44299 L .538 .44111 L p 0 .272 .876 r
F P
0 g
s
.53591 .42801 m .5377 .4392 L .5335 .44123 L p 0 .248 .836 r
F P
0 g
s
.53411 .44299 m .5335 .44123 L .5377 .4392 L p 0 .248 .836 r
F P
0 g
s
.5377 .4392 m .538 .44111 L .53411 .44299 L p 0 .248 .836 r
F P
0 g
s
.44143 .78697 m .35688 .69284 L .37774 .68527 L p 0 .305 .956 r
F P
0 g
s
.37774 .68527 m .46349 .78087 L .44143 .78697 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.41333 .75569 m
.41333 .75569 L
s
.41333 .75569 m
.41333 .75569 L
s
.38515 .72431 m
.38515 .72431 L
s
.38515 .72431 m
.38515 .72431 L
s
.44143 .78697 m .45238 .78394 L .48863 .82434 L p 0 .305 .956 r
F P
0 g
s
.48661 .20719 m .52261 .24846 L .43785 .32892 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.50463 .22785 m
.50463 .22785 L
s
.49461 .27504 m
.49461 .27504 L
s
.49461 .27504 m
.49461 .27504 L
s
.45855 .46749 m .44937 .47211 L .46039 .46669 L p 0 .05 .1 r
F P
0 g
s
.64558 .45544 m .67288 .45745 L .67843 .47917 L .569 0 0 r
F
0 g
.64382 .45832 m
.64558 .45544 L
s
.33269 .65293 m .34688 .65372 L .36346 .62264 L closepath p 0 .349 .781 r
F P
0 g
s
.38902 .63535 m .37382 .61837 L .36346 .62264 L p 0 .308 .954 r
F P
0 g
s
.36346 .62264 m .37382 .61837 L .34286 .64886 L p 0 .05 .1 r
F P
0 g
s
.34286 .64886 m .33269 .65293 L .36346 .62264 L p 0 .05 .1 r
F P
0 g
s
.37382 .61837 m .36346 .62264 L .33269 .65293 L p 0 .05 .1 r
F P
0 g
s
.40877 .31474 m .39056 .29405 L .38008 .30075 L p 0 .315 .944 r
F P
0 g
s
.3696 .33763 m .38008 .30075 L .34938 .3295 L p 0 .349 .781 r
F P
0 g
s
.35545 .33637 m .34938 .3295 L .38008 .30075 L p 0 .349 .781 r
F P
0 g
s
.35968 .32298 m .34938 .3295 L .38008 .30075 L p 0 .05 .1 r
F P
0 g
s
.38008 .30075 m .3696 .33763 L .35545 .33637 L p 0 .349 .781 r
F P
0 g
s
.39296 .33971 m .3696 .33763 L .38008 .30075 L p 0 .349 .781 r
F P
0 g
s
.38008 .30075 m .39056 .29405 L .35968 .32298 L p 0 .05 .1 r
F P
0 g
s
.48661 .20719 m .40121 .28724 L .38008 .30075 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.43128 .25591 m
.47547 .21451 L
s
.6671 .63834 m .66689 .61372 L .68452 .60945 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.68452 .60945 m
.68452 .60945 L
s
.60843 .33462 m .60922 .31066 L .5845 .29811 L .577 0 0 r
F
0 g
.60024 .33043 m
.60843 .33462 L
s
.61652 .342 m .60922 .31066 L .60843 .33462 L .577 0 0 r
F
0 0 0 r
.30841 .36476 m
.30841 .36476 L
s
.55284 .5274 m .5619 .52271 L .56587 .52102 L p 0 .05 .1 r
F P
0 g
s
.59476 .3633 m
.61652 .342 L
s
.61652 .342 m .63376 .33302 L .60922 .31066 L .577 0 0 r
F
0 g
.60843 .33462 m
.61652 .342 L
s
.59476 .3633 m
.61652 .342 L
s
.38574 .37067 m .40102 .35619 L .41166 .3499 L p 0 .05 .1 r
F P
0 g
s
.42695 .3354 m .41166 .3499 L .40102 .35619 L p 0 .05 .1 r
F P
0 g
s
.41166 .3499 m .40102 .35619 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.40102 .35619 m .41166 .3499 L .42695 .3354 L p 0 .05 .1 r
F P
0 g
s
.3696 .33763 m .38574 .37067 L .40102 .35619 L p 0 .349 .781 r
F P
0 g
s
.40102 .35619 m .39296 .33971 L .3696 .33763 L p 0 .349 .781 r
F P
0 g
s
.39296 .33971 m .40102 .35619 L .38574 .37067 L p 0 .349 .781 r
F P
0 g
s
.38574 .37067 m .3696 .33763 L .39296 .33971 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.50463 .22785 m
.50463 .22785 L
s
.35688 .69284 m .3753 .67453 L .3703 .65502 L p 0 .349 .781 r
F P
0 g
s
.3703 .65502 m .34688 .65372 L .35688 .69284 L p 0 .349 .781 r
F P
0 g
s
.45874 .46721 m .46039 .46669 L .44937 .47211 L p 0 .485 .947 r
F P
0 g
s
.44937 .47211 m .44773 .47262 L .45874 .46721 L p 0 .485 .947 r
F P
0 g
s
.31838 .35852 m .3367 .3792 L .32661 .38527 L p 0 .312 .948 r
F P
0 g
s
.32661 .38527 m .3367 .3792 L .35498 .39983 L p 0 .312 .948 r
F P
0 g
s
0 0 0 r
.41333 .75569 m
.41333 .75569 L
s
.44909 .47023 m .45874 .46721 L .44773 .47262 L p 0 .485 .947 r
F P
0 g
s
.5454 .53339 m .55284 .5274 L .55558 .52623 L p 0 .05 .1 r
F P
0 g
s
.56587 .52102 m .55558 .52623 L .55284 .5274 L p 0 .05 .1 r
F P
0 g
s
.55456 .35828 m
.55968 .36413 L
s
.55968 .36413 m
.56139 .36412 L
s
0 0 0 r
.24064 .42511 m
.24064 .42511 L
s
.24064 .42511 m
.24064 .42511 L
s
.43785 .32892 m .40121 .28724 L .48661 .20719 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.46035 .26961 m
.50463 .22785 L
s
.42993 .26032 m
.42993 .26032 L
s
.40847 .27417 m
.42993 .26032 L
s
.4584 .23363 m
.4584 .23363 L
s
.43661 .24783 m
.4584 .23363 L
s
.64367 .44821 m .65539 .43176 L .67288 .45745 L .569 0 0 r
F
.64367 .44821 m .63788 .43972 L .65539 .43176 L F
0 g
.64367 .44821 m
.64558 .45544 L
s
.63953 .44215 m
.64367 .44821 L
s
.63788 .43972 m
.63953 .44215 L
s
.68096 .57746 m .7085 .56169 L .71347 .54997 L .257 0 0 r
F
.68096 .57746 m .67923 .58141 L .7085 .56169 L F
0 0 0 r
.30841 .36476 m
.30841 .36476 L
s
.55558 .52623 m .54774 .5324 L .5454 .53339 L p 0 .05 .1 r
F P
0 g
s
.5393 .54092 m .5454 .53339 L .54774 .5324 L p 0 .05 .259 r
F P
0 g
s
0 0 0 r
.52811 .71465 m
.52811 .71465 L
s
.58812 .74846 m
.58812 .74846 L
s
.58812 .74846 m
.58812 .74846 L
s
.52811 .71465 m
.52811 .71465 L
s
.59688 .4802 m .61123 .48986 L .60884 .49382 L .56 0 0 r
F
0 g
.60884 .49382 m
.62521 .47742 L
s
0 0 0 r
.38515 .72431 m
.38515 .72431 L
s
.59702 .50994 m .60886 .49807 L .61128 .4981 L .183 0 0 r
F
0 g
.6099 .49925 m
.6104 .49981 L
s
.38087 .37911 m .3704 .38521 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.38574 .37067 m .3963 .36447 L .38087 .37911 L p 0 .05 .1 r
F P
0 g
s
.41166 .3499 m .3963 .36447 L .38574 .37067 L p 0 .05 .1 r
F P
0 g
s
.38574 .37067 m .3963 .36447 L .41166 .3499 L p 0 .05 .1 r
F P
0 g
s
.3696 .33763 m .35545 .33637 L .38574 .37067 L closepath p 0 .349 .781 r
F P
0 g
s
.38574 .37067 m .35545 .33637 L .3696 .33763 L closepath p 0 .349 .781 r
F P
0 g
s
.3963 .36447 m .38574 .37067 L .35545 .33637 L p 0 .314 .946 r
F P
0 g
s
.34938 .3295 m .35545 .33637 L .3696 .33763 L p 0 .349 .781 r
F P
0 g
s
.36579 .3299 m .35545 .33637 L .38574 .37067 L p 0 .314 .946 r
F P
0 g
s
.38574 .37067 m .3963 .36447 L .36579 .3299 L p 0 .314 .946 r
F P
0 g
s
.3963 .36447 m .38574 .37067 L .3704 .38521 L p 0 .05 .1 r
F P
0 g
s
.35516 .37541 m .3704 .38521 L .38574 .37067 L p 0 .349 .781 r
F P
0 g
s
.38574 .37067 m .35534 .35104 L .35516 .37541 L p 0 .349 .781 r
F P
0 g
s
.38574 .37067 m .35545 .33637 L .35534 .35104 L closepath p 0 .349 .781 r
F P
0 g
s
.35534 .35104 m .38574 .37067 L .3704 .38521 L p 0 .349 .781 r
F P
0 g
s
.35534 .35104 m .35545 .33637 L .38574 .37067 L closepath p 0 .349 .781 r
F P
0 g
s
.56568 .3641 m .5317 .33216 L .54963 .33183 L .569 0 0 r
F
0 g
.56139 .36412 m
.56568 .3641 L
s
.5317 .33216 m
.55456 .35828 L
s
.5317 .33216 m
.56641 .29869 L
s
.63788 .43972 m
.64105 .43828 L
s
0 0 0 r
.51919 .73217 m
.54679 .70385 L
s
.54679 .70385 m
.55044 .70011 L
s
.55044 .70011 m
.5558 .6946 L
s
.59688 .4802 m .59722 .47963 L .61123 .48986 L .56 0 0 r
F
0 g
.59735 .47973 m
.60017 .47692 L
s
.59688 .4802 m
.60884 .49382 L
s
.32649 .65902 m .35688 .69284 L .34688 .65372 L p 0 .349 .781 r
F P
0 g
s
.34688 .65372 m .33269 .65293 L .32649 .65902 L p 0 .349 .781 r
F P
0 g
s
.71347 .54997 m .67343 .52168 L .67871 .51026 L .981 0 0 r
F
.71347 .54997 m .7085 .56169 L .67343 .52168 L F
0 0 0 r
.24064 .42511 m
.24064 .42511 L
s
.53429 .5503 m .5393 .54092 L .54202 .53978 L p 0 .05 .444 r
F P
0 g
s
.54774 .5324 m .54202 .53978 L .5393 .54092 L p 0 .05 .259 r
F P
0 g
s
.59722 .47963 m .60924 .48266 L .61123 .48986 L .56 0 0 r
F
0 g
.60884 .49382 m
.61123 .48986 L
s
.59722 .47963 m .59693 .4786 L .60924 .48266 L .56 0 0 r
F
0 g
.59688 .4802 m
.59722 .47963 L
s
.67843 .47917 m .67288 .45745 L .70705 .42304 L .952 0 0 r
F
0 g
.67183 .4894 m
.67843 .47917 L
s
.42857 .63464 m .41776 .6388 L .40418 .65231 L p 0 .05 .118 r
F P
0 g
s
.67319 .65998 m .64378 .69057 L .65349 .65243 L p 0 .35 .78 r
F P
0 g
s
.65349 .65243 m .66722 .65322 L .67319 .65998 L p 0 .35 .78 r
F P
0 g
s
.64619 .53785 m .67871 .51026 L .67343 .52168 L .221 0 0 r
F
0 g
.6761 .51018 m
.67871 .51026 L
s
.59693 .4786 m .60337 .47417 L .60924 .48266 L .56 0 0 r
F
.59693 .4786 m .59609 .47739 L .60337 .47417 L F
0 g
.59693 .4786 m
.59722 .47963 L
s
.33269 .65293 m .33281 .63804 L .29602 .62509 L p 0 .349 .781 r
F P
0 g
s
.54706 .41 m .60337 .47417 L .59609 .47739 L p .56 0 0 r
F P
0 g
s
.59609 .47739 m
.60337 .47417 L
s
.59609 .47739 m
.59693 .4786 L
s
.60337 .47417 m
.63788 .43972 L
s
.35688 .69284 m .36723 .68908 L .38576 .67065 L p 0 .05 .118 r
F P
0 g
s
.37774 .68527 m .39638 .6667 L .38576 .67065 L p 0 .05 .118 r
F P
0 g
s
.38576 .67065 m .36723 .68908 L .37774 .68527 L p 0 .05 .118 r
F P
0 g
s
.38576 .67065 m .39638 .6667 L .41491 .64824 L p 0 .05 .118 r
F P
0 g
s
.41491 .64824 m .37774 .68527 L .35688 .69284 L p 0 .05 .118 r
F P
0 g
s
0 0 0 r
.40418 .65231 m
.40418 .65231 L
s
.40418 .65231 m
.40418 .65231 L
s
.36723 .68908 m .35688 .69284 L .32649 .65902 L p 0 .305 .956 r
F P
0 g
s
.5 .82158 m .5 .79863 L .48865 .80156 L p 0 .181 .719 r
F P
0 g
s
.48865 .80156 m .48863 .82434 L .5 .82158 L p 0 .181 .719 r
F P
0 g
s
.48863 .82434 m .48865 .80156 L .5 .79863 L p 0 .181 .719 r
F P
0 g
s
0 0 0 r
.4584 .23363 m
.4584 .23363 L
s
.4584 .23363 m
.49461 .27504 L
s
.49461 .27504 m
.49461 .27504 L
s
.5516 .70741 m
.5516 .70741 L
s
.52811 .71465 m
.5516 .70741 L
s
.52811 .71465 m
.52811 .71465 L
s
.35545 .33637 m .36579 .3299 L .3963 .36447 L p 0 .314 .946 r
F P
0 g
s
.36579 .3299 m .35545 .33637 L .34938 .3295 L p 0 .314 .946 r
F P
0 g
s
.35545 .33637 m .36579 .3299 L .35968 .32298 L p 0 .314 .946 r
F P
0 g
s
.35968 .32298 m .34938 .3295 L .35545 .33637 L p 0 .314 .946 r
F P
0 g
s
.31838 .35852 m .35534 .35104 L .35545 .33637 L p 0 .349 .781 r
F P
0 g
s
.35545 .33637 m .34938 .3295 L .31838 .35852 L p 0 .349 .781 r
F P
0 g
s
.34938 .3295 m .35545 .33637 L .35534 .35104 L p 0 .349 .781 r
F P
0 g
s
.53369 .55199 m .53429 .5503 L .53821 .54868 L p 0 .099 .551 r
F P
0 g
s
.54202 .53978 m .53821 .54868 L .53429 .5503 L p 0 .05 .444 r
F P
0 g
s
.59702 .50994 m .61128 .4981 L .59736 .50995 L .183 0 0 r
F
0 g
.59702 .50994 m
.59724 .51019 L
s
.59702 .50994 m
.60886 .49807 L
s
.67288 .45745 m .68978 .39738 L .70705 .42304 L .886 0 0 r
F
0 g
.70705 .42304 m
.71235 .44486 L
s
.32649 .65902 m .33269 .65293 L .34286 .64886 L p 0 .05 .1 r
F P
0 g
s
.33269 .65293 m .34286 .64886 L .37382 .61837 L p 0 .05 .1 r
F P
0 g
s
.34286 .64886 m .33663 .655 L .32649 .65902 L p 0 .05 .1 r
F P
0 g
s
.33663 .655 m .34286 .64886 L .33269 .65293 L p 0 .05 .1 r
F P
0 g
s
.33269 .65293 m .32649 .65902 L .33663 .655 L p 0 .05 .1 r
F P
0 g
s
.29602 .62509 m .32649 .65902 L .33269 .65293 L p 0 .349 .781 r
F P
0 g
s
.53018 .5619 m .53369 .55199 L .53791 .55025 L p 0 .099 .551 r
F P
0 g
s
.53821 .54868 m .53791 .55025 L .53369 .55199 L p 0 .099 .551 r
F P
0 g
s
.67923 .58141 m .63863 .54825 L .67358 .58802 L .888 0 0 r
F
.67923 .58141 m .69154 .58161 L .7085 .56169 L .257 0 0 r
F
0 g
.67923 .58141 m
.68096 .57746 L
s
.67923 .58141 m .67358 .58802 L .69154 .58161 L .257 0 0 r
F
.34938 .3295 m .35968 .32298 L .36579 .3299 L p 0 .314 .946 r
F P
0 g
s
.35534 .35104 m .31838 .35852 L .34938 .3295 L p 0 .349 .781 r
F P
0 g
s
.32849 .35219 m .31838 .35852 L .34938 .3295 L p 0 .05 .1 r
F P
0 g
s
.34938 .3295 m .35968 .32298 L .32849 .35219 L p 0 .05 .1 r
F P
0 g
s
.48465 .28859 m .51369 .33051 L .52014 .32913 L .204 0 0 r
F
.48465 .28859 m .4785 .29034 L .51369 .33051 L F
.48757 .35722 m .52014 .32913 L .51369 .33051 L .1 0 0 r
F
0 g
.49068 .35262 m
.51369 .33051 L
s
.4868 .35635 m
.49068 .35262 L
s
.57431 .34462 m .5845 .29811 L .60922 .31066 L .76 0 0 r
F
.57431 .34462 m .54963 .33183 L .5845 .29811 L F
0 g
.56641 .29869 m
.5845 .29811 L
s
.59736 .50995 m .60934 .50186 L .59708 .51049 L .183 0 0 r
F
.59736 .50995 m .61128 .4981 L .60934 .50186 L F
0 g
.59702 .50994 m
.59736 .50995 L
s
.60886 .49807 m
.61128 .4981 L
s
.35516 .37541 m .35534 .35104 L .31838 .35852 L p 0 .349 .781 r
F P
0 g
s
.3367 .3792 m .31838 .35852 L .35534 .35104 L p 0 .349 .781 r
F P
0 g
s
.35534 .35104 m .35516 .37541 L .3367 .3792 L p 0 .349 .781 r
F P
0 g
s
.3704 .38521 m .35516 .37541 L .35534 .35104 L p 0 .349 .781 r
F P
0 g
s
.5 .79863 m .5 .82158 L .48863 .82434 L p 0 .181 .719 r
F P
0 g
s
.46349 .78087 m .5 .82158 L .48863 .82434 L p 0 .305 .956 r
F P
0 g
s
.48863 .82434 m .45238 .78394 L .46349 .78087 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.45238 .78394 m
.45238 .78394 L
s
.36536 .39383 m .35498 .39983 L .3704 .38521 L p 0 .05 .1 r
F P
0 g
s
.3704 .38521 m .38087 .37911 L .36536 .39383 L p 0 .05 .1 r
F P
0 g
s
.3704 .38521 m .38087 .37911 L .3963 .36447 L p 0 .05 .1 r
F P
0 g
s
.38087 .37911 m .3704 .38521 L .35498 .39983 L p 0 .05 .1 r
F P
0 g
s
.35516 .37541 m .35498 .39983 L .3704 .38521 L closepath p 0 .349 .781 r
F P
0 g
s
.3704 .38521 m .35498 .39983 L .35516 .37541 L closepath p 0 .349 .781 r
F P
0 g
s
.60924 .48266 m
.61123 .48986 L
s
.59708 .51049 m .60355 .50834 L .59626 .51142 L .183 0 0 r
F
.59708 .51049 m .60934 .50186 L .60355 .50834 L F
0 g
.59708 .51049 m
.59736 .50995 L
s
.59626 .51142 m
.59708 .51049 L
s
.41166 .3499 m .42695 .3354 L .43785 .32892 L p 0 .05 .1 r
F P
0 g
s
.43785 .32892 m .42695 .3354 L .41166 .3499 L p 0 .05 .1 r
F P
0 g
s
.42695 .3354 m .43785 .32892 L .41955 .3081 L p 0 .315 .944 r
F P
0 g
s
.41955 .3081 m .40877 .31474 L .42695 .3354 L p 0 .315 .944 r
F P
0 g
s
.53791 .55025 m .53614 .55948 L .53018 .5619 L p 0 .099 .551 r
F P
0 g
s
.57966 .37369 m
.58199 .37581 L
s
.57386 .36837 m .54963 .33183 L .57431 .34462 L .569 0 0 r
F
0 g
.57386 .36837 m
.57966 .37369 L
s
.5317 .33216 m
.54963 .33183 L
s
.56568 .3641 m
.57386 .36837 L
s
.63065 .65111 m .65349 .65243 L .64378 .69057 L p 0 .35 .78 r
F P
0 g
s
.32649 .65902 m .33663 .655 L .36723 .68908 L p 0 .305 .956 r
F P
0 g
s
.33663 .655 m .32649 .65902 L .29602 .62509 L p 0 .305 .956 r
F P
0 g
s
.60934 .50186 m
.61128 .4981 L
s
.59626 .51142 m
.60355 .50834 L
s
0 0 0 r
.40418 .65231 m
.40418 .65231 L
s
.40418 .65231 m .41491 .64824 L .42857 .63464 L p 0 .05 .118 r
F P
0 g
s
.40418 .65231 m .38902 .63535 L .39964 .63115 L p 0 .308 .954 r
F P
0 g
s
.39964 .63115 m .41491 .64824 L .40418 .65231 L p 0 .308 .954 r
F P
0 g
s
.40418 .65231 m .41491 .64824 L .39964 .63115 L p 0 .308 .954 r
F P
0 g
s
.39964 .63115 m .38902 .63535 L .40418 .65231 L p 0 .308 .954 r
F P
0 g
s
0 0 0 r
.36723 .68908 m
.40418 .65231 L
s
0 g
.58199 .37581 m
.58507 .37424 L
s
.25756 .48836 m .24802 .49364 L .22914 .51152 L p 0 .05 .1 r
F P
0 g
s
.23857 .50636 m .22914 .51152 L .21015 .5295 L p 0 .05 .1 r
F P
0 g
s
.22914 .51152 m .23857 .50636 L .25756 .48836 L p 0 .05 .1 r
F P
0 g
s
.25756 .48836 m .23857 .50636 L .24814 .50112 L p 0 .05 .1 r
F P
0 g
s
.24814 .50112 m .26725 .483 L .25756 .48836 L p 0 .05 .1 r
F P
0 g
s
.21015 .5295 m .24802 .49364 L .26725 .483 L p 0 .05 .1 r
F P
0 g
s
.22966 .47313 m .22167 .49175 L .24802 .49364 L closepath p 0 .349 .781 r
F P
0 g
s
.24802 .49364 m .25756 .48836 L .23907 .46769 L p 0 .308 .954 r
F P
0 g
s
.23907 .46769 m .22966 .47313 L .24802 .49364 L p 0 .308 .954 r
F P
0 g
s
.26725 .483 m .24802 .49364 L .21127 .45258 L p 0 .308 .954 r
F P
0 g
s
.24802 .49364 m .25756 .48836 L .23104 .48644 L p 0 .458 1 r
F P
0 g
s
.23104 .48644 m .22167 .49175 L .24802 .49364 L p 0 .458 1 r
F P
0 g
s
.24802 .49364 m .22167 .49175 L .22914 .51152 L closepath p 0 .349 .781 r
F P
0 g
s
.25756 .48836 m .24802 .49364 L .22167 .49175 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.22966 .47313 m
.22966 .47313 L
s
.22966 .47313 m
.22966 .47313 L
s
.53769 .41184 m .53684 .41182 L .52479 .3981 L .56 0 0 r
F
0 g
.53728 .4114 m
.54017 .40857 L
s
.31838 .35852 m .3367 .3792 L .35516 .37541 L p 0 .349 .781 r
F P
0 g
s
.3367 .3792 m .35498 .39983 L .35516 .37541 L closepath p 0 .349 .781 r
F P
0 g
s
.35516 .37541 m .35498 .39983 L .3367 .3792 L closepath p 0 .349 .781 r
F P
0 g
s
.40121 .28724 m .39056 .29405 L .40877 .31474 L p 0 .315 .944 r
F P
0 g
s
.40877 .31474 m .41955 .3081 L .40121 .28724 L p 0 .315 .944 r
F P
0 g
s
.67358 .58802 m .65625 .54141 L .69154 .58161 L .556 0 0 r
F
.67358 .58802 m .63863 .54825 L .65625 .54141 L F
.63583 .639 m .69154 .58161 L .67358 .58802 L p .257 0 0 r
F P
0 g
s
.63863 .54825 m .67358 .58802 L .69154 .58161 L p .556 0 0 r
F P
0 g
s
.64435 .54171 m .67343 .52168 L .65625 .54141 L .221 0 0 r
F
0 g
.64435 .54171 m
.64619 .53785 L
s
.38902 .63535 m .37382 .61837 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.38434 .61403 m .39964 .63115 L .38902 .63535 L p 0 .308 .954 r
F P
0 g
s
.38434 .61403 m .37382 .61837 L .38902 .63535 L p 0 .308 .954 r
F P
0 g
s
.38902 .63535 m .39964 .63115 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.45206 .31679 m .4785 .29034 L .48465 .28859 L .1 0 0 r
F
0 g
.48028 .29237 m
.51369 .33051 L
s
.45206 .31679 m .4501 .31729 L .4785 .29034 L .1 0 0 r
F
0 0 0 r
.41955 .3081 m
.46035 .26961 L
s
0 g
.45532 .31234 m
.4785 .29034 L
s
.4501 .31729 m
.45532 .31234 L
s
.53769 .41184 m .52479 .3981 L .53074 .39815 L .56 0 0 r
F
0 g
.52479 .3981 m
.54145 .38187 L
s
.53886 .41246 m .53769 .41184 L .53074 .39815 L .56 0 0 r
F
0 g
.53684 .41182 m
.53769 .41184 L
s
.19517 .48985 m .22167 .49175 L .22966 .47313 L p 0 .349 .781 r
F P
0 g
s
.22966 .47313 m .21127 .45258 L .19517 .48985 L p 0 .349 .781 r
F P
0 g
s
.22966 .47313 m .23907 .46769 L .22055 .44698 L p 0 .308 .954 r
F P
0 g
s
.22055 .44698 m .21127 .45258 L .22966 .47313 L p 0 .308 .954 r
F P
0 g
s
.53623 .784 m .5 .82158 L .5 .79863 L closepath p 0 .349 .781 r
F P
0 g
s
.53623 .784 m .5 .79863 L .5 .77101 L p 0 .349 .781 r
F P
0 g
s
.53623 .784 m .5 .82158 L .51154 .81877 L p 0 .05 .248 r
F P
0 g
s
.51154 .81877 m .54798 .78092 L .53623 .784 L p 0 .05 .248 r
F P
0 g
s
.5 .79863 m .5 .82158 L .53623 .784 L closepath p 0 .349 .781 r
F P
0 g
s
.53886 .41246 m .53074 .39815 L .5389 .40251 L .56 0 0 r
F
0 g
.52479 .3981 m
.53684 .41182 L
s
.54002 .41352 m .53886 .41246 L .5389 .40251 L .56 0 0 r
F
0 g
.53769 .41184 m
.53886 .41246 L
s
.52479 .3981 m
.53074 .39815 L
s
.54002 .41352 m .5389 .40251 L .54706 .41 L .56 0 0 r
F
0 g
.54002 .41352 m
.54706 .41 L
s
.53886 .41246 m
.54002 .41352 L
s
.54706 .41 m
.58199 .37581 L
s
0 0 0 r
.36723 .68908 m
.36723 .68908 L
s
.36723 .68908 m
.36723 .68908 L
s
.36723 .68908 m
.40787 .73436 L
s
.40787 .73436 m
.45238 .78394 L
s
.45238 .78394 m
.45238 .78394 L
s
.31601 .61645 m .29602 .62509 L .21015 .5295 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.23886 .56146 m
.23886 .56146 L
s
.23886 .56146 m
.23886 .56146 L
s
.26748 .59332 m
.26748 .59332 L
s
.26748 .59332 m
.26748 .59332 L
s
.29602 .62509 m .30594 .6208 L .33663 .655 L p 0 .305 .956 r
F P
0 g
s
.37382 .61837 m .38434 .61403 L .35319 .64474 L p 0 .05 .1 r
F P
0 g
s
.35319 .64474 m .34286 .64886 L .37382 .61837 L p 0 .05 .1 r
F P
0 g
s
.38434 .61403 m .37382 .61837 L .34286 .64886 L p 0 .05 .1 r
F P
0 g
s
.37382 .61837 m .38434 .61403 L .36902 .59688 L p 0 .308 .954 r
F P
0 g
s
.48963 .3623 m
.50399 .37865 L
s
.50399 .37865 m
.52077 .39776 L
s
.51287 .40544 m
.52077 .39776 L
s
.37014 .31636 m .35968 .32298 L .39056 .29405 L p 0 .05 .1 r
F P
0 g
s
.39056 .29405 m .40121 .28724 L .37014 .31636 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.39056 .29405 m
.39056 .29405 L
s
.39209 .29578 m
.42695 .3354 L
s
.39056 .29405 m
.43128 .25591 L
s
.39056 .29405 m
.39056 .29405 L
s
0 g
.60337 .47417 m
.60924 .48266 L
s
.22998 .44129 m .31838 .35852 L .35498 .39983 L p 0 .349 .781 r
F P
0 g
s
.35498 .39983 m .36536 .39383 L .38087 .37911 L p 0 .05 .1 r
F P
0 g
s
.36536 .39383 m .35498 .39983 L .3367 .3792 L p 0 .312 .948 r
F P
0 g
s
.35498 .39983 m .31838 .35852 L .22998 .44129 L p 0 .349 .781 r
F P
0 g
s
.33877 .34576 m .31838 .35852 L .35498 .39983 L p 0 .312 .948 r
F P
0 g
s
.37589 .38773 m .36536 .39383 L .38087 .37911 L p 0 .05 .1 r
F P
0 g
s
.38087 .37911 m .3915 .37292 L .37589 .38773 L p 0 .05 .1 r
F P
0 g
s
.3915 .37292 m .38087 .37911 L .36536 .39383 L p 0 .05 .1 r
F P
0 g
s
.36536 .39383 m .37589 .38773 L .3915 .37292 L p 0 .05 .1 r
F P
0 g
s
.35498 .39983 m .37589 .38773 L .33877 .34576 L p 0 .312 .948 r
F P
0 g
s
.21127 .45258 m .17311 .48827 L .19517 .48985 L closepath p 0 .349 .781 r
F P
0 g
s
.21127 .45258 m .22998 .44129 L .26725 .483 L p 0 .308 .954 r
F P
0 g
s
.21127 .45258 m .22055 .44698 L .18216 .4829 L p 0 .05 .1 r
F P
0 g
s
.18216 .4829 m .17311 .48827 L .21127 .45258 L p 0 .05 .1 r
F P
0 g
s
.31838 .35852 m .22998 .44129 L .21127 .45258 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.26687 .40363 m
.30841 .36476 L
s
.67288 .45745 m .65539 .43176 L .68978 .39738 L .886 0 0 r
F
0 g
.67288 .45745 m
.67843 .47917 L
s
.63376 .33302 m .68978 .39738 L .65539 .43176 L p .859 0 0 r
F P
0 g
s
.68978 .39738 m
.70705 .42304 L
s
.43785 .32892 m .42247 .34351 L .41166 .3499 L p 0 .05 .1 r
F P
0 g
s
.3963 .36447 m .41166 .3499 L .42247 .34351 L p 0 .05 .1 r
F P
0 g
s
.42247 .34351 m .40702 .35818 L .3963 .36447 L p 0 .05 .1 r
F P
0 g
s
.40702 .35818 m .42247 .34351 L .41166 .3499 L p 0 .05 .1 r
F P
0 g
s
.41166 .3499 m .3963 .36447 L .40702 .35818 L p 0 .05 .1 r
F P
0 g
s
.41166 .3499 m .42247 .34351 L .43785 .32892 L p 0 .05 .1 r
F P
0 g
s
.64378 .69057 m .62576 .67019 L .63065 .65111 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.62576 .67019 m
.62576 .67019 L
s
.69154 .58161 m .65625 .54141 L .63863 .54825 L p .556 0 0 r
F P
0 g
s
.60011 .59854 m .58293 .60484 L .63863 .54825 L p .221 0 0 r
F P
0 g
s
.63863 .54825 m .65625 .54141 L .60011 .59854 L p .221 0 0 r
F P
0 g
s
.63863 .54825 m
.64183 .54701 L
s
.63863 .54825 m
.64435 .54171 L
s
.60355 .50834 m
.63863 .54825 L
s
.64377 .55411 m
.67358 .58802 L
s
.60355 .50834 m
.60934 .50186 L
s
.46277 .46523 m .46413 .46485 L .46039 .46669 L p 0 .485 .947 r
F P
0 g
s
.46039 .46669 m .45874 .46721 L .46277 .46523 L p 0 .485 .947 r
F P
0 g
s
.32849 .35219 m .34694 .37303 L .3367 .3792 L p 0 .312 .948 r
F P
0 g
s
.3367 .3792 m .31838 .35852 L .32849 .35219 L p 0 .312 .948 r
F P
0 g
s
.3367 .3792 m .34694 .37303 L .36536 .39383 L p 0 .312 .948 r
F P
0 g
s
0 0 0 r
.42993 .26032 m
.42993 .26032 L
s
.42993 .26032 m
.46636 .30186 L
s
.45476 .46743 m .46277 .46523 L .45874 .46721 L p 0 .485 .947 r
F P
0 g
s
.45874 .46721 m .44909 .47023 L .45476 .46743 L p 0 .485 .947 r
F P
0 g
s
.23104 .48644 m .22167 .49175 L .19517 .48985 L p 0 .458 1 r
F P
0 g
s
.22167 .49175 m .23104 .48644 L .25756 .48836 L p 0 .458 1 r
F P
0 g
s
.22167 .49175 m .23104 .48644 L .20437 .48451 L p 0 .458 1 r
F P
0 g
s
.20437 .48451 m .19517 .48985 L .22167 .49175 L p 0 .458 1 r
F P
0 g
s
.21015 .5295 m .22914 .51152 L .22167 .49175 L p 0 .349 .781 r
F P
0 g
s
.22167 .49175 m .19517 .48985 L .21015 .5295 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.26748 .59332 m
.26748 .59332 L
s
.5 .74345 m .46349 .78087 L .48623 .77458 L p 0 .05 .212 r
F P
0 g
s
.4818 .76211 m .5 .74345 L .5115 .74007 L p 0 .05 .212 r
F P
0 g
s
.4507 .31797 m
.45097 .31828 L
s
.24927 .42964 m .22998 .44129 L .31838 .35852 L p 0 .05 .1 r
F P
0 g
s
.35735 .36677 m .34694 .37303 L .32849 .35219 L p 0 .312 .948 r
F P
0 g
s
.32849 .35219 m .33877 .34576 L .35735 .36677 L p 0 .312 .948 r
F P
0 g
s
.31838 .35852 m .33877 .34576 L .24927 .42964 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.22055 .44698 m
.26687 .40363 L
s
.24064 .42511 m
.25971 .41345 L
s
.25971 .41345 m
.25971 .41345 L
s
.28918 .38586 m
.28918 .38586 L
s
.26975 .39788 m
.28918 .38586 L
s
.29506 .41842 m
.32426 .39091 L
s
.32426 .39091 m
.3367 .3792 L
s
0 g
.53074 .39815 m
.5389 .40251 L
s
0 0 0 r
.62576 .67019 m
.62576 .67019 L
s
.59896 .36714 m .60922 .31066 L .63376 .33302 L .832 0 0 r
F
.59896 .36714 m .57431 .34462 L .60922 .31066 L F
0 g
.5845 .29811 m
.60922 .31066 L
s
0 0 0 r
.23886 .56146 m
.23886 .56146 L
s
.51153 .79566 m .51151 .76782 L .5 .77101 L p 0 .181 .719 r
F P
0 g
s
.5 .77101 m .5 .79863 L .51153 .79566 L p 0 .181 .719 r
F P
0 g
s
.46349 .78087 m .5 .79863 L .5 .77101 L p 0 .349 .781 r
F P
0 g
s
.5 .79863 m .5 .77101 L .51151 .76782 L p 0 .181 .719 r
F P
0 g
s
.3915 .37292 m .38087 .37911 L .3963 .36447 L p 0 .05 .1 r
F P
0 g
s
.3963 .36447 m .40702 .35818 L .3915 .37292 L p 0 .05 .1 r
F P
0 g
s
.40702 .35818 m .3963 .36447 L .36579 .3299 L p 0 .314 .946 r
F P
0 g
s
.3763 .32334 m .36579 .3299 L .3963 .36447 L p 0 .314 .946 r
F P
0 g
s
.3963 .36447 m .40702 .35818 L .3763 .32334 L p 0 .314 .946 r
F P
0 g
s
.3963 .36447 m .38087 .37911 L .3915 .37292 L p 0 .05 .1 r
F P
0 g
s
.3915 .37292 m .40702 .35818 L .3963 .36447 L p 0 .05 .1 r
F P
0 g
s
.47921 .36687 m .52075 .40099 L .51476 .40732 L .888 0 0 r
F
.44353 .32627 m .48225 .36374 L .47921 .36687 L F
.48225 .36374 m .52075 .40099 L .47921 .36687 L F
.50784 .41087 m .51476 .40732 L .44353 .32627 L p .556 0 0 r
F P
0 g
s
.4369 .33021 m .44353 .32627 L .51476 .40732 L .556 0 0 r
F
.44353 .32627 m .51476 .40732 L .45756 .463 L p .858 0 0 r
F P
0 g
s
.38546 .38142 m .44353 .32627 L p .45052 .39445 L .858 0 0 r
F P
0 g
s
.45756 .463 m .42158 .42229 L p .45052 .39445 L .858 0 0 r
F P
0 g
s
.42158 .42229 m .38546 .38142 L p .45052 .39445 L .858 0 0 r
F P
0 g
s
.37589 .38773 m .44767 .46887 L .4485 .46833 L .673 0 0 r
F
.3767 .38716 m .4485 .46833 L .44966 .4674 L .776 0 0 r
F
.37589 .38773 m .4485 .46833 L .3767 .38716 L .673 0 0 r
F
.37786 .38621 m .45084 .46632 L .37904 .38514 L .832 0 0 r
F
.37786 .38621 m .44966 .4674 L .45084 .46632 L F
.3767 .38716 m .44966 .4674 L .37786 .38621 L .776 0 0 r
F
.37904 .38514 m .45756 .463 L .38546 .38142 L .54 0 0 r
F
.44767 .46887 m .44113 .4771 L .4485 .46833 L .1 0 0 r
F
.4485 .46833 m .44929 .47054 L .44966 .4674 L F
.4485 .46833 m .44113 .4771 L .44929 .47054 L F
.44966 .4674 m .45756 .463 L .45084 .46632 L F
.44966 .4674 m .44929 .47054 L .45756 .463 L F
.37712 .38896 m .45756 .463 L .44929 .47054 L .832 0 0 r
F
.37712 .38896 m .38546 .38142 L .45756 .463 L F
.41327 .42983 m .41476 .42884 L .42158 .42229 L .1 0 0 r
F
.41476 .42884 m .43715 .41394 L .42158 .42229 L F
.47921 .36687 m .42158 .42229 L p .44726 .39988 L F P
0 g
s
.48527 .36061 m .52294 .3975 L .52075 .40099 L .978 0 0 r
F
.48642 .35891 m .52294 .3975 L .48527 .36061 L F
.44353 .32627 m .44967 .32007 L .52075 .40099 L .888 0 0 r
F
.49526 .358 m .47921 .36687 L p .44726 .39988 L .1 0 0 r
F P
0 g
s
.47921 .36687 m .48324 .36361 L .48527 .36061 L .1 0 0 r
F
.48324 .36361 m .51349 .33913 L .48527 .36061 L F
.44967 .32007 m .48642 .35891 L .48527 .36061 L .978 0 0 r
F
0 g
.52075 .40099 m
.52294 .3975 L
s
.51459 .33032 m
.51798 .3296 L
s
.51369 .33051 m
.51459 .33032 L
s
0 0 0 r
.4666 .71702 m
.47172 .71181 L
s
.46356 .7201 m
.4666 .71702 L
s
0 g
.54963 .33183 m
.57431 .34462 L
s
.65539 .43176 m .59896 .36714 L .63376 .33302 L p .859 0 0 r
F P
0 g
s
.65539 .43176 m
.67288 .45745 L
s
.60922 .31066 m
.63376 .33302 L
s
.58507 .37424 m
.59896 .36714 L
s
.65539 .43176 m
.68978 .39738 L
s
.64105 .43828 m
.65539 .43176 L
s
.59896 .36714 m
.63376 .33302 L
s
.43813 .32885 m .43785 .32892 L .4501 .31729 L .1 0 0 r
F
0 g
.5389 .40251 m
.54706 .41 L
s
.42857 .63464 m .41491 .64824 L .42581 .64411 L p 0 .05 .118 r
F P
0 g
s
.41491 .64824 m .42857 .63464 L .41334 .61757 L p 0 .349 .781 r
F P
0 g
s
.41334 .61757 m .42857 .63464 L .41491 .64824 L p 0 .349 .781 r
F P
0 g
s
.19517 .48985 m .17311 .48827 L .21015 .5295 L closepath p 0 .349 .781 r
F P
0 g
s
.20437 .48451 m .19517 .48985 L .17311 .48827 L p 0 .458 1 r
F P
0 g
s
.19517 .48985 m .20437 .48451 L .23104 .48644 L p 0 .458 1 r
F P
0 g
s
.19517 .48985 m .20437 .48451 L .18216 .4829 L p 0 .458 1 r
F P
0 g
s
.18216 .4829 m .17311 .48827 L .19517 .48985 L p 0 .458 1 r
F P
0 g
s
.37774 .68527 m .36723 .68908 L .33663 .655 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.36723 .68908 m
.36723 .68908 L
s
.5 .79863 m .5 .82158 L .46349 .78087 L closepath p 0 .349 .781 r
F P
0 g
s
.51154 .81877 m .51153 .79566 L .5 .79863 L p 0 .181 .719 r
F P
0 g
s
.5 .79863 m .5 .82158 L .51154 .81877 L p 0 .181 .719 r
F P
0 g
s
.46349 .78087 m .5 .82158 L .5 .79863 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .82158 m .5 .79863 L .51153 .79566 L p 0 .181 .719 r
F P
0 g
s
.51151 .76782 m .51153 .79566 L .5 .79863 L p 0 .181 .719 r
F P
0 g
s
.7085 .56169 m .65625 .54141 L .67343 .52168 L .889 0 0 r
F
0 g
.67343 .52168 m
.67871 .51026 L
s
.7085 .56169 m .69154 .58161 L .65625 .54141 L .889 0 0 r
F
0 g
.7085 .56169 m
.71347 .54997 L
s
.21015 .5295 m .21946 .52446 L .23857 .50636 L p 0 .05 .1 r
F P
0 g
s
.23857 .50636 m .21946 .52446 L .22891 .51935 L p 0 .05 .1 r
F P
0 g
s
.22891 .51935 m .24814 .50112 L .23857 .50636 L p 0 .05 .1 r
F P
0 g
s
.26725 .483 m .22891 .51935 L .21015 .5295 L p 0 .05 .1 r
F P
0 g
s
.21015 .5295 m .22891 .51935 L .31601 .61645 L p 0 .305 .956 r
F P
0 g
s
.21946 .52446 m .21015 .5295 L .17311 .48827 L p 0 .305 .956 r
F P
0 g
s
.46349 .78087 m .4818 .76211 L .49319 .75885 L p 0 .05 .212 r
F P
0 g
s
.5115 .74007 m .49319 .75885 L .4818 .76211 L p 0 .05 .212 r
F P
0 g
s
0 0 0 r
.43821 .68526 m
.44336 .68007 L
s
.43501 .68847 m
.43821 .68526 L
s
.36579 .3299 m .3763 .32334 L .40702 .35818 L p 0 .314 .946 r
F P
0 g
s
.37014 .31636 m .3763 .32334 L .36579 .3299 L p 0 .314 .946 r
F P
0 g
s
.36579 .3299 m .35968 .32298 L .37014 .31636 L p 0 .314 .946 r
F P
0 g
s
.35968 .32298 m .36579 .3299 L .3763 .32334 L p 0 .314 .946 r
F P
0 g
s
.41334 .61757 m .39964 .63115 L .41491 .64824 L p 0 .349 .781 r
F P
0 g
s
.41491 .64824 m .39964 .63115 L .41334 .61757 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.28918 .38586 m
.28918 .38586 L
s
.28918 .38586 m
.28918 .38586 L
s
.29227 .38934 m
.326 .4273 L
s
.34693 .65092 m .33663 .655 L .34286 .64886 L p 0 .05 .1 r
F P
0 g
s
.34286 .64886 m .35319 .64474 L .34693 .65092 L p 0 .05 .1 r
F P
0 g
s
.34286 .64886 m .35319 .64474 L .38434 .61403 L p 0 .05 .1 r
F P
0 g
s
.35319 .64474 m .34286 .64886 L .33663 .655 L p 0 .05 .1 r
F P
0 g
s
.44967 .32007 m .48757 .35722 L .45206 .31679 L .978 0 0 r
F
.44967 .32007 m .48527 .36061 L .48757 .35722 L F
0 g
.4386 .32821 m
.4501 .31729 L
s
.48527 .36061 m .52014 .32913 L .48757 .35722 L .1 0 0 r
F
.3763 .32334 m .37014 .31636 L .35968 .32298 L p 0 .314 .946 r
F P
0 g
s
.33877 .34576 m .32849 .35219 L .35968 .32298 L p 0 .05 .1 r
F P
0 g
s
.35968 .32298 m .37014 .31636 L .33877 .34576 L p 0 .05 .1 r
F P
0 g
s
.56155 .62341 m
.5624 .62437 L
s
.56344 .62555 m
.59576 .66204 L
s
.56155 .62341 m
.5624 .62437 L
s
.56344 .62555 m
.59576 .66204 L
s
.51153 .79566 m .51154 .81877 L .5 .82158 L p 0 .181 .719 r
F P
0 g
s
.47477 .77775 m .51154 .81877 L .5 .82158 L p 0 .305 .956 r
F P
0 g
s
.5 .82158 m .46349 .78087 L .47477 .77775 L p 0 .305 .956 r
F P
0 g
s
.36902 .59688 m .38434 .61403 L .39809 .60048 L p 0 .349 .781 r
F P
0 g
s
.39809 .60048 m .38434 .61403 L .39502 .60962 L p 0 .05 .1 r
F P
0 g
s
.39502 .60962 m .38434 .61403 L .39809 .60048 L p 0 .05 .1 r
F P
0 g
s
.39809 .60048 m .38434 .61403 L .36902 .59688 L p 0 .349 .781 r
F P
0 g
s
.4143 .32678 m .41955 .3081 L .43785 .32892 L closepath p 0 .35 .78 r
F P
0 g
s
.43785 .32892 m
.4386 .32821 L
s
.4143 .32678 m .43785 .32892 L .42247 .34351 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.58333 .68248 m
.61608 .71939 L
s
.61608 .71939 m
.61608 .71939 L
s
0 g
.51476 .40732 m
.52075 .40099 L
s
.33663 .655 m .34693 .65092 L .37774 .68527 L p 0 .305 .956 r
F P
0 g
s
.33663 .655 m .34693 .65092 L .35319 .64474 L p 0 .05 .1 r
F P
0 g
s
.34693 .65092 m .33663 .655 L .30594 .6208 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.30594 .6208 m
.30594 .6208 L
s
.30594 .6208 m
.30594 .6208 L
s
.42581 .64411 m .41491 .64824 L .39964 .63115 L p 0 .308 .954 r
F P
0 g
s
.41491 .64824 m .37774 .68527 L .46349 .78087 L p 0 .349 .781 r
F P
0 g
s
.42581 .64411 m .41491 .64824 L .39638 .6667 L p 0 .05 .118 r
F P
0 g
s
.39964 .63115 m .41043 .62688 L .42581 .64411 L p 0 .308 .954 r
F P
0 g
s
.41043 .62688 m .39964 .63115 L .41491 .64824 L p 0 .308 .954 r
F P
0 g
s
.41491 .64824 m .42581 .64411 L .41043 .62688 L p 0 .308 .954 r
F P
0 g
s
.39638 .6667 m .41491 .64824 L .3913 .6469 L closepath p 0 .349 .781 r
F P
0 g
s
.3913 .6469 m .41491 .64824 L .39964 .63115 L closepath p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.43715 .71224 m
.4818 .76211 L
s
.38841 .6814 m .40717 .6627 L .39638 .6667 L p 0 .05 .118 r
F P
0 g
s
.39638 .6667 m .37774 .68527 L .38841 .6814 L p 0 .05 .118 r
F P
0 g
s
.39638 .6667 m .40717 .6627 L .42581 .64411 L p 0 .05 .118 r
F P
0 g
s
.41812 .65863 m .40717 .6627 L .38841 .6814 L p 0 .05 .118 r
F P
0 g
s
.38841 .6814 m .39925 .67746 L .41812 .65863 L p 0 .05 .118 r
F P
0 g
s
.39925 .67746 m .37774 .68527 L .41491 .64824 L p 0 .05 .118 r
F P
0 g
s
.43687 .63991 m .42581 .64411 L .40717 .6627 L p 0 .05 .118 r
F P
0 g
s
.40717 .6627 m .41812 .65863 L .43687 .63991 L p 0 .05 .118 r
F P
0 g
s
.41491 .64824 m .43687 .63991 L .39925 .67746 L p 0 .05 .118 r
F P
0 g
s
.3913 .6469 m .41491 .64824 L .39638 .6667 L closepath p 0 .349 .781 r
F P
0 g
s
.39964 .63115 m .41491 .64824 L .3913 .6469 L closepath p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.25756 .48836 m
.25756 .48836 L
s
.23907 .46769 m .25756 .48836 L .26725 .483 L p 0 .308 .954 r
F P
0 g
s
.23104 .48644 m .25756 .48836 L .26725 .483 L p 0 .458 1 r
F P
0 g
s
.24055 .48105 m .26725 .483 L .25756 .48836 L p 0 .458 1 r
F P
0 g
s
.25756 .48836 m .23104 .48644 L .24055 .48105 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.25756 .48836 m
.25756 .48836 L
s
.43778 .32932 m .43813 .32885 L .45206 .31679 L .1 0 0 r
F
0 g
.43785 .32892 m
.43813 .32885 L
s
.17311 .48827 m .18216 .4829 L .20437 .48451 L p 0 .458 1 r
F P
0 g
s
.17311 .48827 m .18216 .4829 L .21946 .52446 L p 0 .305 .956 r
F P
0 g
s
.48527 .36061 m .51349 .33913 L .52014 .32913 L .1 0 0 r
F
.47769 .29827 m .52014 .32913 L .51349 .33913 L .981 0 0 r
F
.47769 .29827 m .48465 .28859 L .52014 .32913 L F
.43778 .32932 m .45206 .31679 L .44967 .32007 L .1 0 0 r
F
.4369 .33021 m .43778 .32932 L .44967 .32007 L F
0 g
.43778 .32932 m
.43813 .32885 L
s
0 0 0 r
.28918 .38586 m
.28918 .38586 L
s
.40121 .28724 m .41955 .3081 L .4143 .32678 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.41955 .3081 m
.41955 .3081 L
s
.39816 .32129 m
.41005 .31395 L
s
.41955 .3081 m
.41955 .3081 L
s
.44967 .32007 m .45206 .31679 L .48465 .28859 L .1 0 0 r
F
0 g
.4501 .31729 m
.45206 .31679 L
s
.37904 .38514 m .4369 .33021 L .44353 .32627 L p .1 0 0 r
F P
0 g
s
.43793 .33138 m
.43803 .33149 L
s
.4369 .33021 m .44967 .32007 L .44353 .32627 L .1 0 0 r
F
0 g
.4369 .33021 m
.43778 .32932 L
s
.41043 .62688 m .39964 .63115 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.38434 .61403 m .39502 .60962 L .41043 .62688 L p 0 .308 .954 r
F P
0 g
s
.39964 .63115 m .41043 .62688 L .39502 .60962 L p 0 .308 .954 r
F P
0 g
s
.39502 .60962 m .38434 .61403 L .39964 .63115 L p 0 .308 .954 r
F P
0 g
s
.3913 .6469 m .39964 .63115 L .38434 .61403 L p 0 .349 .781 r
F P
0 g
s
.36757 .64555 m .38434 .61403 L .39964 .63115 L p 0 .349 .781 r
F P
0 g
s
.39964 .63115 m .3913 .6469 L .36757 .64555 L p 0 .349 .781 r
F P
0 g
s
.53799 .5695 m .52502 .58216 L .53713 .57001 L .183 0 0 r
F
0 g
.53729 .57019 m
.53915 .57229 L
s
.55531 .62741 m
.56046 .62218 L
s
.22055 .44698 m .23907 .46769 L .24863 .46217 L p 0 .308 .954 r
F P
0 g
s
.26725 .483 m .24863 .46217 L .23907 .46769 L p 0 .308 .954 r
F P
0 g
s
0 0 0 r
.22055 .44698 m
.25176 .48187 L
s
.55991 .7778 m .54798 .78092 L .51154 .81877 L p 0 .05 .248 r
F P
0 g
s
.54156 .75723 m .52976 .76052 L .54798 .78092 L p 0 .308 .954 r
F P
0 g
s
.54798 .78092 m .55991 .7778 L .54156 .75723 L p 0 .308 .954 r
F P
0 g
s
0 0 0 r
.54798 .78092 m
.54798 .78092 L
s
.53799 .5695 m .53102 .57864 L .52502 .58216 L .183 0 0 r
F
0 g
.52502 .58216 m
.56046 .62218 L
s
.53916 .56859 m .53102 .57864 L .53799 .5695 L .183 0 0 r
F
0 g
.53713 .57001 m
.53799 .5695 L
s
.49319 .75885 m .47477 .77775 L .46349 .78087 L p 0 .05 .212 r
F P
0 g
s
.48623 .77458 m .47477 .77775 L .49319 .75885 L p 0 .05 .212 r
F P
0 g
s
.48623 .77458 m .46349 .78087 L .37774 .68527 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.40282 .6739 m
.43715 .71224 L
s
.43499 .7491 m
.43499 .7491 L
s
.41333 .75569 m
.43499 .7491 L
s
.40641 .71723 m
.40641 .71723 L
s
.38515 .72431 m
.40641 .71723 L
s
.43499 .7491 m
.43499 .7491 L
s
.43499 .7491 m
.43499 .7491 L
s
.44408 .73988 m
.46356 .7201 L
s
.40641 .71723 m
.40641 .71723 L
s
.40641 .71723 m
.40641 .71723 L
s
.41098 .71263 m
.43501 .68847 L
s
.54033 .56752 m .53923 .57223 L .53916 .56859 L .183 0 0 r
F
.54033 .56752 m .54743 .56467 L .53923 .57223 L F
0 g
.54033 .56752 m
.54743 .56467 L
s
.53916 .56859 m .53923 .57223 L .53102 .57864 L .183 0 0 r
F
0 g
.53916 .56859 m
.54033 .56752 L
s
.53799 .5695 m
.53916 .56859 L
s
.52502 .58216 m
.53713 .57001 L
s
0 0 0 r
.21946 .52446 m
.21946 .52446 L
s
.21946 .52446 m
.21946 .52446 L
s
.30594 .6208 m
.30594 .6208 L
s
.30594 .6208 m .31601 .61645 L .34693 .65092 L p 0 .305 .956 r
F P
0 g
s
.61017 .65242 m .60191 .65872 L .58614 .68097 L .257 0 0 r
F
0 g
.59576 .66204 m
.60191 .65872 L
s
.48176 .36978 m
.49785 .38808 L
s
.49785 .38808 m
.51476 .40732 L
s
.37959 .59234 m .39502 .60962 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.38434 .61403 m .36902 .59688 L .37959 .59234 L p 0 .308 .954 r
F P
0 g
s
.38434 .61403 m .35319 .64474 L .36757 .64555 L closepath p 0 .349 .781 r
F P
0 g
s
.36757 .64555 m .35319 .64474 L .38434 .61403 L closepath p 0 .349 .781 r
F P
0 g
s
.36368 .64055 m .35319 .64474 L .38434 .61403 L p 0 .05 .1 r
F P
0 g
s
.38434 .61403 m .36757 .64555 L .3913 .6469 L p 0 .349 .781 r
F P
0 g
s
.38434 .61403 m .39502 .60962 L .36368 .64055 L p 0 .05 .1 r
F P
0 g
s
.39502 .60962 m .38434 .61403 L .35319 .64474 L p 0 .05 .1 r
F P
0 g
s
.38434 .61403 m .39502 .60962 L .37959 .59234 L p 0 .308 .954 r
F P
0 g
s
.37959 .59234 m .36902 .59688 L .38434 .61403 L p 0 .308 .954 r
F P
0 g
s
.3533 .62963 m .38434 .61403 L .36902 .59688 L p 0 .349 .781 r
F P
0 g
s
.3533 .62963 m .35319 .64474 L .38434 .61403 L closepath p 0 .349 .781 r
F P
0 g
s
.35349 .60463 m .36902 .59688 L .38434 .61403 L p 0 .349 .781 r
F P
0 g
s
.38434 .61403 m .3533 .62963 L .35349 .60463 L p 0 .349 .781 r
F P
0 g
s
.38434 .61403 m .35319 .64474 L .3533 .62963 L closepath p 0 .349 .781 r
F P
0 g
s
.44353 .32627 m .48527 .36061 L .44967 .32007 L .888 0 0 r
F
.44353 .32627 m .47921 .36687 L .48527 .36061 L F
0 g
.48527 .36061 m
.48757 .35722 L
s
.4143 .32678 m .39063 .32464 L .40121 .28724 L p 0 .35 .78 r
F P
0 g
s
.37014 .31636 m .40121 .28724 L .39063 .32464 L p 0 .35 .78 r
F P
0 g
s
.37589 .38773 m .36536 .39383 L .34694 .37303 L p 0 .312 .948 r
F P
0 g
s
0 0 0 r
.32849 .35219 m
.32849 .35219 L
s
.24863 .46217 m .22998 .44129 L .22055 .44698 L p 0 .308 .954 r
F P
0 g
s
.18216 .4829 m .22055 .44698 L .22998 .44129 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.22055 .44698 m
.22055 .44698 L
s
.22055 .44698 m
.22055 .44698 L
s
.52976 .76052 m .54156 .75723 L .52317 .73662 L p 0 .308 .954 r
F P
0 g
s
0 0 0 r
.52319 .75316 m
.54798 .78092 L
s
.61831 .64486 m .61116 .66194 L .63583 .639 L .257 0 0 r
F
.61831 .64486 m .61017 .65242 L .61116 .66194 L F
.61831 .64486 m .63583 .639 L .60011 .59854 L .54 0 0 r
F
0 g
.5876 .61013 m
.61831 .64486 L
s
.61017 .65242 m
.61831 .64486 L
s
.54743 .56467 m
.58293 .60484 L
s
.5876 .61013 m
.61831 .64486 L
s
.42247 .34351 m .40702 .35818 L .39063 .32464 L p 0 .35 .78 r
F P
0 g
s
.39063 .32464 m .4143 .32678 L .42247 .34351 L p 0 .35 .78 r
F P
0 g
s
.57431 .34462 m
.59896 .36714 L
s
.44967 .32007 m .48465 .28859 L .47769 .29827 L .1 0 0 r
F
0 g
.4785 .29034 m
.48465 .28859 L
s
.36902 .59688 m .35349 .60463 L .3533 .62963 L p 0 .349 .781 r
F P
0 g
s
.3913 .6469 m .36757 .64555 L .37774 .68527 L p 0 .349 .781 r
F P
0 g
s
.37774 .68527 m .39638 .6667 L .3913 .6469 L p 0 .349 .781 r
F P
0 g
s
.36757 .64555 m .3913 .6469 L .39638 .6667 L p 0 .349 .781 r
F P
0 g
s
.61017 .65242 m .58614 .68097 L .61116 .66194 L .257 0 0 r
F
0 g
.60191 .65872 m
.61017 .65242 L
s
0 0 0 r
.58595 .71135 m
.62576 .67019 L
s
.34694 .37303 m .35735 .36677 L .37589 .38773 L p 0 .312 .948 r
F P
0 g
s
0 0 0 r
.43499 .7491 m
.43499 .7491 L
s
0 g
.52502 .58216 m
.53102 .57864 L
s
.20437 .48451 m .23104 .48644 L .24055 .48105 L p 0 .458 1 r
F P
0 g
s
.26725 .483 m .24055 .48105 L .23104 .48644 L p 0 .458 1 r
F P
0 g
s
.2137 .47909 m .24055 .48105 L .23104 .48644 L p 0 .458 1 r
F P
0 g
s
.23104 .48644 m .20437 .48451 L .2137 .47909 L p 0 .458 1 r
F P
0 g
s
.39638 .6667 m .37774 .68527 L .36757 .64555 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.39638 .6667 m
.39638 .6667 L
s
.39638 .6667 m
.39638 .6667 L
s
.50475 .75554 m .49319 .75885 L .5115 .74007 L p 0 .05 .212 r
F P
0 g
s
.5115 .74007 m .52317 .73662 L .50475 .75554 L p 0 .05 .212 r
F P
0 g
s
0 0 0 r
.5115 .74007 m
.5115 .74007 L
s
.5115 .74007 m
.5115 .74007 L
s
.5115 .74007 m
.5115 .74007 L
s
.5115 .74007 m
.5115 .74007 L
s
.25971 .41345 m
.25971 .41345 L
s
.35367 .5797 m .36413 .57503 L .34524 .59348 L p 0 .05 .1 r
F P
0 g
s
.35367 .5797 m .31601 .61645 L .33663 .60754 L p 0 .05 .1 r
F P
0 g
s
.34524 .59348 m .33489 .59802 L .35367 .5797 L p 0 .05 .1 r
F P
0 g
s
.22891 .51935 m .31601 .61645 L .35367 .5797 L p 0 .349 .781 r
F P
0 g
s
.35367 .5797 m .26725 .483 L .22891 .51935 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.21946 .52446 m
.25756 .48836 L
s
.21946 .52446 m
.26486 .57503 L
s
.26486 .57503 m
.30594 .6208 L
s
.25971 .41345 m
.25971 .41345 L
s
.26282 .41694 m
.29676 .45503 L
s
0 g
.51584 .57612 m
.51614 .57646 L
s
.50404 .59887 m
.52096 .5819 L
s
.52096 .5819 m
.52314 .57813 L
s
.56653 .61875 m .5504 .64068 L .53221 .65085 L .221 0 0 r
F
0 g
.56046 .62218 m
.56653 .61875 L
s
.45922 .31695 m .44353 .32627 L .47921 .36687 L p .556 0 0 r
F P
0 g
s
.47921 .36687 m .49526 .358 L .51349 .33913 L .1 0 0 r
F
.47921 .36687 m .49526 .358 L .45922 .31695 L p .556 0 0 r
F P
0 g
s
.42158 .42229 m .47921 .36687 L .44353 .32627 L p .858 0 0 r
F P
0 g
s
.4369 .33021 m
.44353 .32627 L
s
.44353 .32627 m .49526 .358 L .47921 .36687 L .556 0 0 r
F
0 g
.47921 .36687 m
.48212 .36526 L
s
.44353 .32627 m .44967 .32007 L .47769 .29827 L .1 0 0 r
F
0 g
.44967 .32007 m
.45206 .31679 L
s
0 0 0 r
.32849 .35219 m
.32849 .35219 L
s
.65625 .54141 m .69154 .58161 L .63583 .639 L p .859 0 0 r
F P
0 g
s
.69154 .58161 m
.7085 .56169 L
s
.58293 .60484 m
.58605 .6037 L
s
0 0 0 r
.5516 .70741 m
.5516 .70741 L
s
.5516 .70741 m
.58812 .74846 L
s
.58812 .74846 m
.58812 .74846 L
s
.40641 .71723 m
.40641 .71723 L
s
.57477 .6124 m .57535 .62147 L .5504 .64068 L .221 0 0 r
F
0 g
.57477 .6124 m
.58293 .60484 L
s
.56653 .61875 m
.57477 .6124 L
s
.5232 .76459 m .51151 .76782 L .51153 .79566 L p 0 .181 .719 r
F P
0 g
s
.51151 .76782 m .5232 .76459 L .52317 .73662 L p 0 .181 .719 r
F P
0 g
s
.52323 .79263 m .51153 .79566 L .51151 .76782 L p 0 .181 .719 r
F P
0 g
s
.51151 .76782 m .5232 .76459 L .52323 .79263 L p 0 .181 .719 r
F P
0 g
s
.35349 .60463 m .3533 .62963 L .31601 .61645 L p 0 .349 .781 r
F P
0 g
s
.3763 .32334 m .39063 .32464 L .40702 .35818 L closepath p 0 .35 .78 r
F P
0 g
s
.37605 .36295 m .3762 .33823 L .40702 .35818 L p 0 .35 .78 r
F P
0 g
s
.40702 .35818 m .3915 .37292 L .37605 .36295 L p 0 .35 .78 r
F P
0 g
s
.40702 .35818 m .3762 .33823 L .3763 .32334 L closepath p 0 .35 .78 r
F P
0 g
s
.39063 .32464 m .3763 .32334 L .37014 .31636 L p 0 .35 .78 r
F P
0 g
s
.37774 .68527 m .36757 .64555 L .35319 .64474 L p 0 .349 .781 r
F P
0 g
s
.34693 .65092 m .35319 .64474 L .36757 .64555 L p 0 .349 .781 r
F P
0 g
s
.36757 .64555 m .37774 .68527 L .34693 .65092 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.25971 .41345 m
.25971 .41345 L
s
0 g
.53102 .57864 m
.53923 .57223 L
s
.44353 .32627 m .38546 .38142 L .37904 .38514 L p .1 0 0 r
F P
0 g
s
.44353 .32627 m .38546 .38142 L .42158 .42229 L p .858 0 0 r
F P
0 g
s
.44353 .32627 m .45922 .31695 L .49526 .358 L .556 0 0 r
F
.38546 .38142 m .44353 .32627 L .45922 .31695 L p .1 0 0 r
F P
0 g
s
.44571 .32876 m
.47921 .36687 L
s
.44353 .32627 m .47769 .29827 L .45922 .31695 L .1 0 0 r
F
0 g
.44353 .32627 m
.44967 .32007 L
s
.58614 .68097 m .53221 .65085 L .5504 .64068 L .669 0 0 r
F
0 g
.53221 .65085 m
.53476 .64943 L
s
.53221 .65085 m
.55531 .62741 L
s
.53221 .65085 m
.56773 .69084 L
s
.18216 .4829 m .20437 .48451 L .2137 .47909 L p 0 .458 1 r
F P
0 g
s
.24055 .48105 m .2137 .47909 L .20437 .48451 L p 0 .458 1 r
F P
0 g
s
.19134 .47746 m .2137 .47909 L .20437 .48451 L p 0 .458 1 r
F P
0 g
s
.20437 .48451 m .18216 .4829 L .19134 .47746 L p 0 .458 1 r
F P
0 g
s
.63583 .639 m .60011 .59854 L .65625 .54141 L p .859 0 0 r
F P
0 g
s
.64183 .54701 m
.65625 .54141 L
s
.65625 .54141 m
.67343 .52168 L
s
.65625 .54141 m
.69154 .58161 L
s
.44767 .46887 m
.44776 .46882 L
s
.44024 .47609 m
.44767 .46887 L
s
.41185 .42838 m
.41697 .43417 L
s
.41697 .43417 m
.43063 .44961 L
s
.44154 .46194 m
.44767 .46887 L
s
.43063 .44961 m
.44154 .46194 L
s
.34693 .65092 m .35319 .64474 L .3533 .62963 L p 0 .349 .781 r
F P
0 g
s
.3533 .62963 m .31601 .61645 L .34693 .65092 L p 0 .349 .781 r
F P
0 g
s
.31601 .61645 m .3533 .62963 L .35319 .64474 L p 0 .349 .781 r
F P
0 g
s
.35319 .64474 m .34693 .65092 L .37774 .68527 L p 0 .349 .781 r
F P
0 g
s
.38841 .6814 m .37774 .68527 L .34693 .65092 L p 0 .305 .956 r
F P
0 g
s
.37774 .68527 m .39925 .67746 L .48623 .77458 L p 0 .305 .956 r
F P
0 g
s
.52323 .79263 m .51153 .79566 L .51154 .81877 L p 0 .181 .719 r
F P
0 g
s
.51153 .79566 m .52323 .79263 L .5232 .76459 L p 0 .181 .719 r
F P
0 g
s
.51154 .81877 m .52326 .81592 L .55991 .7778 L p 0 .05 .248 r
F P
0 g
s
.52326 .81592 m .51154 .81877 L .51153 .79566 L p 0 .181 .719 r
F P
0 g
s
.51153 .79566 m .52323 .79263 L .52326 .81592 L p 0 .181 .719 r
F P
0 g
s
.53923 .57223 m
.54743 .56467 L
s
.2137 .47909 m .19134 .47746 L .18216 .4829 L p 0 .458 1 r
F P
0 g
s
.21946 .52446 m .18216 .4829 L .19134 .47746 L p 0 .305 .956 r
F P
0 g
s
.19134 .47746 m .22891 .51935 L .21946 .52446 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.21946 .52446 m
.21946 .52446 L
s
.49319 .75885 m .50475 .75554 L .48623 .77458 L p 0 .05 .212 r
F P
0 g
s
.31601 .61645 m .33489 .59802 L .34524 .59348 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.29368 .55199 m
.33489 .59802 L
s
.3763 .32334 m .3762 .33823 L .33877 .34576 L p 0 .35 .78 r
F P
0 g
s
.33877 .34576 m .37014 .31636 L .3763 .32334 L p 0 .35 .78 r
F P
0 g
s
.35319 .64474 m .36368 .64055 L .35738 .64677 L p 0 .05 .1 r
F P
0 g
s
.35738 .64677 m .34693 .65092 L .35319 .64474 L p 0 .05 .1 r
F P
0 g
s
.35319 .64474 m .36368 .64055 L .39502 .60962 L p 0 .05 .1 r
F P
0 g
s
.36368 .64055 m .35319 .64474 L .34693 .65092 L p 0 .05 .1 r
F P
0 g
s
.35319 .64474 m .34693 .65092 L .31601 .61645 L p 0 .349 .781 r
F P
0 g
s
.3762 .33823 m .37605 .36295 L .35735 .36677 L p 0 .35 .78 r
F P
0 g
s
.35735 .36677 m .33877 .34576 L .3762 .33823 L p 0 .35 .78 r
F P
0 g
s
.51154 .81877 m .52326 .81592 L .52323 .79263 L p 0 .181 .719 r
F P
0 g
s
.52326 .81592 m .51154 .81877 L .47477 .77775 L p 0 .305 .956 r
F P
0 g
s
.3915 .37292 m .37589 .38773 L .37605 .36295 L closepath p 0 .35 .78 r
F P
0 g
s
.48531 .61764 m .47806 .68607 L .51391 .6498 L .858 0 0 r
F
.48741 .61394 m .51391 .6498 L .52046 .63893 L .523 0 0 r
F
.48741 .61394 m .48531 .61764 L .51391 .6498 L F
.48531 .61764 m .51391 .6498 L .47806 .68607 L p .858 0 0 r
F P
0 g
s
.52046 .63893 m .51391 .6498 L .47806 .68607 L .86 0 0 r
F
.34693 .65092 m .35738 .64677 L .38841 .6814 L p 0 .305 .956 r
F P
0 g
s
.34693 .65092 m .35738 .64677 L .36368 .64055 L p 0 .05 .1 r
F P
0 g
s
.35738 .64677 m .34693 .65092 L .31601 .61645 L p 0 .305 .956 r
F P
0 g
s
.40059 .44167 m
.43532 .48089 L
s
.43687 .63991 m .42581 .64411 L .41043 .62688 L p 0 .308 .954 r
F P
0 g
s
.41043 .62688 m .42138 .62255 L .43687 .63991 L p 0 .308 .954 r
F P
0 g
s
.42138 .62255 m .41043 .62688 L .42581 .64411 L p 0 .308 .954 r
F P
0 g
s
.42581 .64411 m .43687 .63991 L .42138 .62255 L p 0 .308 .954 r
F P
0 g
s
.26725 .483 m .24814 .50112 L .25786 .4958 L p 0 .05 .1 r
F P
0 g
s
.24814 .50112 m .22891 .51935 L .23852 .51415 L p 0 .05 .1 r
F P
0 g
s
.23852 .51415 m .25786 .4958 L .24814 .50112 L p 0 .05 .1 r
F P
0 g
s
.26773 .4904 m .25786 .4958 L .23852 .51415 L p 0 .05 .1 r
F P
0 g
s
.23852 .51415 m .24827 .50888 L .26773 .4904 L p 0 .05 .1 r
F P
0 g
s
.24827 .50888 m .22891 .51935 L .26725 .483 L p 0 .05 .1 r
F P
0 g
s
.25786 .4958 m .27709 .47756 L .26725 .483 L p 0 .05 .1 r
F P
0 g
s
.28709 .47203 m .27709 .47756 L .25786 .4958 L p 0 .05 .1 r
F P
0 g
s
.25786 .4958 m .26773 .4904 L .28709 .47203 L p 0 .05 .1 r
F P
0 g
s
.26725 .483 m .28709 .47203 L .24827 .50888 L p 0 .05 .1 r
F P
0 g
s
.24863 .46217 m .26725 .483 L .24055 .48105 L closepath p 0 .349 .781 r
F P
0 g
s
.24055 .48105 m .26725 .483 L .24814 .50112 L closepath p 0 .349 .781 r
F P
0 g
s
.24055 .48105 m .26725 .483 L .24863 .46217 L closepath p 0 .349 .781 r
F P
0 g
s
.24814 .50112 m .26725 .483 L .24055 .48105 L closepath p 0 .349 .781 r
F P
0 g
s
.24863 .46217 m .26725 .483 L .27709 .47756 L p 0 .308 .954 r
F P
0 g
s
.24927 .42964 m .28709 .47203 L .26725 .483 L p 0 .308 .954 r
F P
0 g
s
.26725 .483 m .22998 .44129 L .24927 .42964 L p 0 .308 .954 r
F P
0 g
s
.24055 .48105 m .26725 .483 L .27709 .47756 L p 0 .458 1 r
F P
0 g
s
.25021 .47558 m .27709 .47756 L .26725 .483 L p 0 .458 1 r
F P
0 g
s
.26725 .483 m .24055 .48105 L .25021 .47558 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.26474 .44699 m
.29506 .41842 L
s
0 g
.4353 .48521 m
.44111 .48549 L
s
.40421 .51548 m
.40838 .51142 L
s
.41451 .50545 m
.41807 .50199 L
s
.41807 .50199 m
.4353 .48521 L
s
.22998 .44129 m .19134 .47746 L .18216 .4829 L p 0 .05 .1 r
F P
0 g
s
.37589 .38773 m .35735 .36677 L .37605 .36295 L closepath p 0 .35 .78 r
F P
0 g
s
.52092 .57102 m .48625 .61041 L .48509 .60688 L .95 0 0 r
F
.48304 .60062 m .48509 .60688 L .51368 .61774 L .523 0 0 r
F
.47897 .59835 m .48509 .60688 L .48304 .60062 L F
.48509 .60688 m .45126 .65016 L .44885 .64314 L .95 0 0 r
F
.48625 .61041 m .45126 .65016 L .48509 .60688 L F
0 g
.51487 .56251 m
.52092 .57102 L
s
.48531 .61764 m
.49055 .62353 L
s
.48832 .61463 m
.49304 .60989 L
s
.4954 .60753 m
.50404 .59887 L
s
.51391 .6498 m
.51482 .64828 L
s
.49055 .62353 m
.5123 .648 L
s
.52092 .57102 m
.52314 .57813 L
s
.42138 .62255 m .41043 .62688 L .39502 .60962 L p 0 .308 .954 r
F P
0 g
s
.39502 .60962 m .41043 .62688 L .42138 .62255 L p 0 .308 .954 r
F P
0 g
s
.45922 .31695 m .51349 .33913 L .49526 .358 L .889 0 0 r
F
.45922 .31695 m .47769 .29827 L .51349 .33913 L F
0 g
.51349 .33913 m
.52014 .32913 L
s
.47769 .29827 m
.48465 .28859 L
s
.2137 .47909 m .22998 .44129 L .24863 .46217 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.22966 .47313 m
.24863 .46217 L
s
.24863 .46217 m .24055 .48105 L .2137 .47909 L p 0 .349 .781 r
F P
0 g
s
.24055 .48105 m .24863 .46217 L .22998 .44129 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.24863 .46217 m
.24863 .46217 L
s
.22998 .44129 m .24863 .46217 L .25834 .45656 L p 0 .308 .954 r
F P
0 g
s
0 0 0 r
.24863 .46217 m
.24863 .46217 L
s
.27709 .47756 m .25834 .45656 L .24863 .46217 L p 0 .308 .954 r
F P
0 g
s
.55991 .7778 m .52326 .81592 L .52323 .79263 L closepath p 0 .35 .78 r
F P
0 g
s
.54156 .75723 m .55991 .7778 L .52323 .79263 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.5232 .76234 m
.54156 .75723 L
s
.54156 .75723 m
.58595 .71135 L
s
.54156 .75723 m
.54156 .75723 L
s
.47477 .77775 m .48623 .77458 L .52326 .81592 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.47477 .77775 m
.47477 .77775 L
s
.38841 .6814 m
.38841 .6814 L
s
.38841 .6814 m
.38841 .6814 L
s
.38841 .6814 m
.42963 .72739 L
s
.47477 .77775 m
.47477 .77775 L
s
.47806 .68607 m .44925 .65378 L .48531 .61764 L p .858 0 0 r
F P
0 g
s
.48531 .61764 m .44925 .65378 L .47806 .68607 L .858 0 0 r
F
.31601 .61645 m .32624 .61203 L .35738 .64677 L p 0 .305 .956 r
F P
0 g
s
.34524 .59348 m .32624 .61203 L .31601 .61645 L p 0 .05 .1 r
F P
0 g
s
.33663 .60754 m .32624 .61203 L .34524 .59348 L p 0 .05 .1 r
F P
0 g
s
.24827 .50888 m .33663 .60754 L .31601 .61645 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.30242 .56934 m
.32495 .54757 L
s
.31601 .61645 m .22891 .51935 L .24827 .50888 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.28707 .58418 m
.28707 .58418 L
s
.26748 .59332 m
.28707 .58418 L
s
.23886 .56146 m
.25804 .55181 L
s
.25804 .55181 m
.25804 .55181 L
s
.28707 .58418 m
.28707 .58418 L
s
.28707 .58418 m
.28707 .58418 L
s
.25804 .55181 m
.25804 .55181 L
s
.25804 .55181 m
.25804 .55181 L
s
.27348 .53703 m
.29614 .51533 L
s
.25195 .50538 m
.29368 .55199 L
s
.39032 .58773 m .40586 .60515 L .39502 .60962 L p 0 .308 .954 r
F P
0 g
s
.39502 .60962 m .37959 .59234 L .39032 .58773 L p 0 .308 .954 r
F P
0 g
s
.39502 .60962 m .40586 .60515 L .42138 .62255 L p 0 .308 .954 r
F P
0 g
s
.37434 .6363 m .36368 .64055 L .39502 .60962 L p 0 .05 .1 r
F P
0 g
s
.42138 .62255 m .40586 .60515 L .39502 .60962 L p 0 .308 .954 r
F P
0 g
s
.39502 .60962 m .40586 .60515 L .37434 .6363 L p 0 .05 .1 r
F P
0 g
s
.40586 .60515 m .39502 .60962 L .36368 .64055 L p 0 .05 .1 r
F P
0 g
s
.37959 .59234 m .39502 .60962 L .40586 .60515 L p 0 .308 .954 r
F P
0 g
s
.49061 .58673 m
.51487 .56251 L
s
.37589 .38773 m .36902 .39564 L .36335 .39963 L .1 0 0 r
F
.37589 .38773 m .3767 .38716 L .36902 .39564 L F
0 g
.37604 .38789 m
.41185 .42838 L
s
.24927 .42964 m .33877 .34576 L .37589 .38773 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.35735 .36677 m
.35735 .36677 L
s
.30921 .37347 m
.30921 .37347 L
s
.28918 .38586 m
.30921 .37347 L
s
.37589 .38773 m .28709 .47203 L .24927 .42964 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.28644 .39158 m
.32849 .35219 L
s
.25971 .41345 m
.27937 .40142 L
s
.27937 .40142 m
.27937 .40142 L
s
0 g
.37589 .38773 m
.37589 .38773 L
s
0 0 0 r
.31696 .44367 m
.31696 .44367 L
s
.31696 .44367 m
.31696 .44367 L
s
.36335 .39963 m .39941 .44034 L .37018 .46842 L p .858 0 0 r
F P
0 g
s
.36335 .39963 m .39941 .44034 L .40515 .43645 L .672 0 0 r
F
.39941 .44034 m .37018 .46842 L .38736 .45684 L .1 0 0 r
F
.36335 .39963 m .37018 .46842 L .39941 .44034 L .858 0 0 r
F
.2137 .47909 m .19134 .47746 L .22998 .44129 L closepath p 0 .349 .781 r
F P
0 g
s
.25834 .45656 m .23955 .43551 L .22998 .44129 L p 0 .308 .954 r
F P
0 g
s
.22998 .44129 m .2137 .47909 L .24055 .48105 L p 0 .349 .781 r
F P
0 g
s
.22998 .44129 m .19134 .47746 L .2137 .47909 L closepath p 0 .349 .781 r
F P
0 g
s
.19134 .47746 m .22998 .44129 L .23955 .43551 L p 0 .05 .1 r
F P
0 g
s
.52323 .79263 m .5232 .76459 L .54156 .75723 L p 0 .35 .78 r
F P
0 g
s
.54156 .75723 m .5232 .76459 L .52317 .73662 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.54156 .75723 m
.54156 .75723 L
s
.3767 .38716 m .37712 .38896 L .36902 .39564 L .1 0 0 r
F
.3767 .38716 m .37786 .38621 L .37712 .38896 L F
0 g
.37589 .38773 m
.3767 .38716 L
s
.37786 .38621 m .37904 .38514 L .38546 .38142 L .1 0 0 r
F
0 g
.37923 .38535 m
.38007 .3863 L
s
.37786 .38621 m .38546 .38142 L .37712 .38896 L .1 0 0 r
F
0 g
.3767 .38716 m
.37786 .38621 L
s
.37786 .38621 m
.37904 .38514 L
s
.36902 .39564 m .44929 .47054 L .44113 .4771 L .776 0 0 r
F
0 g
.39941 .44034 m
.40104 .43923 L
s
.39408 .44546 m
.39941 .44034 L
s
.43532 .48089 m
.44113 .4771 L
s
.37475 .57028 m .39032 .58773 L .37959 .59234 L p 0 .308 .954 r
F P
0 g
s
.40586 .60515 m .39032 .58773 L .37959 .59234 L p 0 .308 .954 r
F P
0 g
s
.37959 .59234 m .39032 .58773 L .37475 .57028 L p 0 .308 .954 r
F P
0 g
s
.44111 .48549 m
.44924 .49006 L
s
0 0 0 r
.26819 .45086 m
.3152 .40652 L
s
.34476 .37864 m
.35735 .36677 L
s
.35735 .36677 m
.35735 .36677 L
s
.24055 .48105 m .24814 .50112 L .22891 .51935 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.22914 .51152 m
.23172 .5101 L
s
.22891 .51935 m .2137 .47909 L .24055 .48105 L p 0 .349 .781 r
F P
0 g
s
.2137 .47909 m .24055 .48105 L .25021 .47558 L p 0 .458 1 r
F P
0 g
s
.24814 .50112 m .24055 .48105 L .2137 .47909 L p 0 .349 .781 r
F P
0 g
s
.27709 .47756 m .25021 .47558 L .24055 .48105 L p 0 .458 1 r
F P
0 g
s
.22318 .47359 m .25021 .47558 L .24055 .48105 L p 0 .458 1 r
F P
0 g
s
.24055 .48105 m .2137 .47909 L .22318 .47359 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.28707 .58418 m
.28707 .58418 L
s
.2137 .47909 m .22891 .51935 L .24814 .50112 L p 0 .349 .781 r
F P
0 g
s
0 0 0 r
.24814 .50112 m
.24814 .50112 L
s
.24814 .50112 m
.24814 .50112 L
s
.61116 .66194 m .58614 .68097 L .5504 .64068 L .775 0 0 r
F
0 g
.56773 .69084 m
.58614 .68097 L
s
.43687 .63991 m .52317 .73662 L .48623 .77458 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.42963 .72739 m
.47477 .77775 L
s
.49449 .70448 m
.49449 .70448 L
s
.49449 .70448 m
.49449 .70448 L
s
.52317 .73662 m .5232 .76459 L .50475 .75554 L closepath p 0 .35 .78 r
F P
0 g
s
.36413 .57503 m .37475 .57028 L .35575 .58886 L p 0 .05 .1 r
F P
0 g
s
.35575 .58886 m .34524 .59348 L .36413 .57503 L p 0 .05 .1 r
F P
0 g
s
.36902 .39564 m .37712 .38896 L .44929 .47054 L .776 0 0 r
F
0 g
.44929 .47054 m
.45756 .463 L
s
.4227 .42356 m
.45756 .463 L
s
.44113 .4771 m
.44929 .47054 L
s
.37018 .46842 m .33391 .42758 L .36335 .39963 L p .858 0 0 r
F P
0 g
s
.36335 .39963 m .40515 .43645 L .36902 .39564 L .672 0 0 r
F
0 g
.36335 .39963 m
.37589 .38773 L
s
.36335 .39963 m .33391 .42758 L .37018 .46842 L .858 0 0 r
F
.36335 .39963 m .35085 .41569 L .33391 .42758 L .1 0 0 r
F
0 0 0 r
.3152 .40652 m
.34476 .37864 L
s
.36335 .39963 m .36902 .39564 L .35085 .41569 L .1 0 0 r
F
0 g
.36437 .40077 m
.39941 .44034 L
s
.36437 .40077 m
.39941 .44034 L
s
.48509 .60688 m .45126 .65016 L .48741 .61394 L .95 0 0 r
F
.48509 .60688 m .48741 .61394 L .52046 .63893 L .523 0 0 r
F
.36902 .39564 m .40515 .43645 L .41327 .42983 L .776 0 0 r
F
.40515 .43645 m .41196 .43684 L .41327 .42983 L .1 0 0 r
F
.40515 .43645 m .38736 .45684 L .41196 .43684 L F
0 g
.40104 .43923 m
.40515 .43645 L
s
.44924 .49006 m
.45749 .49768 L
s
0 0 0 r
.25804 .55181 m
.25804 .55181 L
s
.48623 .77458 m .50475 .75554 L .5232 .76459 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.50475 .75554 m
.50475 .75554 L
s
.5232 .76459 m .52323 .79263 L .48623 .77458 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.49449 .70448 m
.49449 .70448 L
s
0 g
.43251 .52213 m
.45749 .49768 L
s
.42158 .42229 m .43715 .41394 L .49526 .358 L p .1 0 0 r
F P
0 g
s
.40066 .37261 m .43715 .41394 L .42158 .42229 L p .54 0 0 r
F P
0 g
s
.42158 .42229 m .38546 .38142 L .40066 .37261 L p .54 0 0 r
F P
0 g
s
.38546 .38142 m .42158 .42229 L .43715 .41394 L .54 0 0 r
F
.37712 .38896 m .42158 .42229 L .38546 .38142 L .832 0 0 r
F
0 g
.37904 .38514 m
.38546 .38142 L
s
.37712 .38896 m .41327 .42983 L .42158 .42229 L .832 0 0 r
F
.61116 .66194 m .5504 .64068 L .57535 .62147 L .775 0 0 r
F
0 g
.53476 .64943 m
.5504 .64068 L
s
.63583 .639 m .57535 .62147 L .60011 .59854 L .832 0 0 r
F
0 g
.58605 .6037 m
.60011 .59854 L
s
.63583 .639 m .61116 .66194 L .57535 .62147 L .832 0 0 r
F
0 g
.5504 .64068 m
.57535 .62147 L
s
.61116 .66194 m
.63583 .639 L
s
.60011 .59854 m
.63583 .639 L
s
.58614 .68097 m
.61116 .66194 L
s
.41327 .42983 m .41196 .43684 L .43715 .41394 L .1 0 0 r
F
0 g
.42158 .42229 m
.4244 .42077 L
s
.36902 .39564 m .41327 .42983 L .37712 .38896 L .776 0 0 r
F
0 g
.41327 .42983 m
.42158 .42229 L
s
.40515 .43645 m
.41327 .42983 L
s
.52046 .63893 m .47806 .68607 L .48435 .67545 L .86 0 0 r
F
.45126 .65016 m .47806 .68607 L .44925 .65378 L .511 0 0 r
F
.45126 .65016 m .48435 .67545 L .47806 .68607 L F
0 g
.44925 .65378 m
.47806 .68607 L
s
.47806 .68607 m
.51391 .6498 L
s
.22891 .51935 m .19134 .47746 L .2137 .47909 L closepath p 0 .349 .781 r
F P
0 g
s
.19134 .47746 m .2137 .47909 L .22318 .47359 L p 0 .458 1 r
F P
0 g
s
.25021 .47558 m .22318 .47359 L .2137 .47909 L p 0 .458 1 r
F P
0 g
s
.20067 .47193 m .22318 .47359 L .2137 .47909 L p 0 .458 1 r
F P
0 g
s
.2137 .47909 m .19134 .47746 L .20067 .47193 L p 0 .458 1 r
F P
0 g
s
.2137 .47909 m .19134 .47746 L .22891 .51935 L closepath p 0 .349 .781 r
F P
0 g
s
.39925 .67746 m .38841 .6814 L .35738 .64677 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.39528 .67455 m
.42581 .64411 L
s
.38841 .6814 m
.38841 .6814 L
s
.52323 .79263 m .52326 .81592 L .48623 .77458 L closepath p 0 .35 .78 r
F P
0 g
s
.37005 .48799 m .399 .52055 L .36228 .5563 L p .858 0 0 r
F P
0 g
s
.399 .52055 m .36796 .55678 L .40474 .52093 L .55 0 0 r
F
.399 .52055 m .36228 .5563 L .36796 .55678 L F
.399 .52055 m .38717 .48888 L .37005 .48799 L .523 0 0 r
F
.399 .52055 m .40474 .52093 L .38717 .48888 L F
0 g
.40261 .51704 m
.40421 .51548 L
s
.399 .52055 m .33311 .52361 L .36228 .5563 L .858 0 0 r
F
.399 .52055 m .37005 .48799 L .33311 .52361 L F
0 g
.399 .52055 m
.40064 .52066 L
s
.39371 .5146 m
.399 .52055 L
s
.22318 .47359 m .20067 .47193 L .19134 .47746 L p 0 .458 1 r
F P
0 g
s
.22891 .51935 m .19134 .47746 L .20067 .47193 L p 0 .305 .956 r
F P
0 g
s
.20067 .47193 m .23852 .51415 L .22891 .51935 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.50475 .75554 m
.50475 .75554 L
s
.36902 .39564 m .37538 .3955 L .35085 .41569 L .1 0 0 r
F
.36902 .39564 m .37712 .38896 L .37538 .3955 L F
0 g
.36335 .39963 m
.36902 .39564 L
s
.34524 .59348 m .35575 .58886 L .33663 .60754 L p 0 .05 .1 r
F P
0 g
s
.48509 .60688 m .44885 .64314 L .45126 .65016 L .95 0 0 r
F
.48509 .60688 m .52046 .63893 L .51368 .61774 L .523 0 0 r
F
.47897 .59835 m .44885 .64314 L .48509 .60688 L .885 0 0 r
F
0 g
.48072 .60079 m
.48509 .60688 L
s
.48509 .60688 m
.48741 .61394 L
s
0 0 0 r
.30921 .37347 m
.30921 .37347 L
s
.30921 .37347 m
.34656 .41557 L
s
.33391 .42758 m .38736 .45684 L .37018 .46842 L .669 0 0 r
F
0 g
.37018 .46842 m
.37258 .4668 L
s
.38409 .45506 m
.39408 .44546 L
s
.35738 .64677 m .36368 .64055 L .37434 .6363 L p 0 .05 .1 r
F P
0 g
s
.36368 .64055 m .37434 .6363 L .40586 .60515 L p 0 .05 .1 r
F P
0 g
s
.37434 .6363 m .36799 .64256 L .35738 .64677 L p 0 .05 .1 r
F P
0 g
s
.36799 .64256 m .37434 .6363 L .36368 .64055 L p 0 .05 .1 r
F P
0 g
s
.36368 .64055 m .35738 .64677 L .36799 .64256 L p 0 .05 .1 r
F P
0 g
s
.45922 .31695 m .49526 .358 L .43715 .41394 L p .859 0 0 r
F P
0 g
s
.49526 .358 m
.51349 .33913 L
s
.45922 .31695 m .40066 .37261 L .38546 .38142 L p .1 0 0 r
F P
0 g
s
.38546 .38142 m .43715 .41394 L .40066 .37261 L .54 0 0 r
F
.37712 .38896 m .38546 .38142 L .40066 .37261 L .1 0 0 r
F
0 g
.38642 .38251 m
.42158 .42229 L
s
.43716 .63939 m .44925 .65378 L .43687 .63991 L .511 0 0 r
F
0 g
.43729 .63949 m
.4419 .63489 L
s
.57535 .62147 m
.60011 .59854 L
s
.37712 .38896 m .40066 .37261 L .37538 .3955 L .1 0 0 r
F
0 g
.36902 .39564 m
.37712 .38896 L
s
.37712 .38896 m
.38546 .38142 L
s
.36228 .5563 m .33311 .52361 L .37005 .48799 L p .858 0 0 r
F P
0 g
s
.37005 .48799 m .35003 .52478 L .33311 .52361 L .541 0 0 r
F
.37005 .48799 m .38717 .48888 L .35003 .52478 L F
0 g
.37839 .49737 m
.39371 .5146 L
s
.47897 .59835 m .44265 .63461 L .44885 .64314 L .885 0 0 r
F
.47897 .59835 m .51368 .61774 L .4952 .59191 L .523 0 0 r
F
.45858 .62853 m .4952 .59191 L .47897 .59835 L p .164 0 0 r
F P
0 g
s
.47897 .59835 m .44265 .63461 L .45858 .62853 L p .164 0 0 r
F P
0 g
s
.44265 .63461 m .47897 .59835 L .42114 .53326 L p .858 0 0 r
F P
0 g
s
.47897 .59835 m .45858 .62853 L .44265 .63461 L .164 0 0 r
F
.47897 .59835 m .4952 .59191 L .45858 .62853 L F
.35738 .64677 m .36799 .64256 L .39925 .67746 L p 0 .305 .956 r
F P
0 g
s
.36799 .64256 m .35738 .64677 L .32624 .61203 L p 0 .305 .956 r
F P
0 g
s
.48623 .77458 m .39925 .67746 L .43687 .63991 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.42833 .70993 m
.42833 .70993 L
s
.45947 .70489 m
.50475 .75554 L
s
.41812 .65863 m
.43054 .67253 L
s
.41812 .65863 m
.41812 .65863 L
s
.45732 .7423 m
.49449 .70448 L
s
.45732 .7423 m
.45732 .7423 L
s
.43499 .7491 m
.45732 .7423 L
s
.45732 .7423 m
.45732 .7423 L
s
.42833 .70993 m
.42833 .70993 L
s
.40641 .71723 m
.42833 .70993 L
s
.43687 .63991 m .41812 .65863 L .41295 .63853 L closepath p 0 .35 .78 r
F P
0 g
s
.43687 .63991 m
.44925 .65378 L
s
.42138 .62255 m .43687 .63991 L .41295 .63853 L closepath p 0 .35 .78 r
F P
0 g
s
.26819 .45086 m .25834 .45656 L .27709 .47756 L p 0 .308 .954 r
F P
0 g
s
.27709 .47756 m .28709 .47203 L .26819 .45086 L p 0 .308 .954 r
F P
0 g
s
.26002 .47002 m .25021 .47558 L .27709 .47756 L p 0 .458 1 r
F P
0 g
s
.27709 .47756 m .28709 .47203 L .26002 .47002 L p 0 .458 1 r
F P
0 g
s
.28709 .47203 m .27709 .47756 L .25021 .47558 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.27709 .47756 m
.27709 .47756 L
s
.23955 .43551 m .20067 .47193 L .19134 .47746 L p 0 .05 .1 r
F P
0 g
s
.43681 .63839 m .45126 .65016 L .43716 .63939 L .511 0 0 r
F
0 g
.43687 .63991 m
.43716 .63939 L
s
.51368 .61774 m .52046 .63893 L .48435 .67545 L .952 0 0 r
F
0 g
.51482 .64828 m
.52046 .63893 L
s
.33391 .42758 m .35085 .41569 L .38736 .45684 L .669 0 0 r
F
0 g
.33391 .42758 m
.36335 .39963 L
s
.33391 .42758 m
.37018 .46842 L
s
.43681 .63839 m .44885 .64314 L .45126 .65016 L .511 0 0 r
F
.43592 .63717 m .44885 .64314 L .43681 .63839 L F
0 g
.43681 .63839 m
.43716 .63939 L
s
.40474 .52093 m .37605 .56152 L .41285 .52558 L .761 0 0 r
F
.40474 .52093 m .36796 .55678 L .37605 .56152 L F
.40474 .52093 m .41166 .50281 L .38717 .48888 L .523 0 0 r
F
0 g
.40064 .52066 m
.40474 .52093 L
s
.43715 .41394 m .40066 .37261 L .45922 .31695 L p .859 0 0 r
F P
0 g
s
.45922 .31695 m
.47769 .29827 L
s
.44353 .32627 m
.45922 .31695 L
s
.45922 .31695 m
.49526 .358 L
s
.40586 .60515 m .42138 .62255 L .41295 .63853 L p 0 .35 .78 r
F P
0 g
s
.44265 .63461 m .43592 .63717 L .3779 .57213 L p .511 0 0 r
F P
0 g
s
.44054 .63257 m
.44069 .63241 L
s
.43592 .63717 m .44265 .63461 L .44885 .64314 L .511 0 0 r
F
0 g
.43592 .63717 m
.43681 .63839 L
s
.24927 .42964 m .23955 .43551 L .25834 .45656 L p 0 .308 .954 r
F P
0 g
s
.25834 .45656 m .26819 .45086 L .24927 .42964 L p 0 .308 .954 r
F P
0 g
s
.32624 .61203 m .33663 .60754 L .36799 .64256 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.32624 .61203 m
.32624 .61203 L
s
.23852 .51415 m
.23852 .51415 L
s
.23852 .51415 m
.23852 .51415 L
s
.32624 .61203 m
.32624 .61203 L
s
.40586 .60515 m .3889 .63714 L .37434 .6363 L closepath p 0 .35 .78 r
F P
0 g
s
.39032 .58773 m .40586 .60515 L .37443 .62096 L p 0 .35 .78 r
F P
0 g
s
.41295 .63853 m .3889 .63714 L .40586 .60515 L p 0 .35 .78 r
F P
0 g
s
.37434 .6363 m .37443 .62096 L .40586 .60515 L closepath p 0 .35 .78 r
F P
0 g
s
.21014 .46631 m .20067 .47193 L .23955 .43551 L p 0 .05 .1 r
F P
0 g
s
.23955 .43551 m .24927 .42964 L .21014 .46631 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.23955 .43551 m
.23955 .43551 L
s
.24112 .43728 m
.27109 .47084 L
s
.23955 .43551 m
.28644 .39158 L
s
.23955 .43551 m
.23955 .43551 L
s
.44885 .64314 m .48435 .67545 L .45126 .65016 L .511 0 0 r
F
0 0 0 r
.43054 .67253 m
.45947 .70489 L
s
.42833 .70993 m
.46573 .67225 L
s
.37443 .62096 m .37459 .59559 L .39032 .58773 L p 0 .35 .78 r
F P
0 g
s
.37459 .59559 m .37475 .57028 L .39032 .58773 L closepath p 0 .35 .78 r
F P
0 g
s
.41285 .52558 m .38437 .56926 L .42114 .53326 L .832 0 0 r
F
.41285 .52558 m .37605 .56152 L .38437 .56926 L F
.41285 .52558 m .42114 .53326 L .43679 .52609 L .523 0 0 r
F
0 g
.40474 .52093 m
.41285 .52558 L
s
.3889 .63714 m .41295 .63853 L .41812 .65863 L p 0 .35 .78 r
F P
0 g
s
.42114 .53326 m .38437 .56926 L .44265 .63461 L p .858 0 0 r
F P
0 g
s
.43592 .63717 m
.44265 .63461 L
s
.39971 .56244 m .38437 .56926 L .42114 .53326 L p .1 0 0 r
F P
0 g
s
.42114 .53326 m .43679 .52609 L .39971 .56244 L p .1 0 0 r
F P
0 g
s
.42114 .53326 m .39971 .56244 L .43679 .52609 L .1 0 0 r
F
.42114 .53326 m .38437 .56926 L .39971 .56244 L F
0 g
.41285 .52558 m
.42114 .53326 L
s
.42114 .53326 m
.42398 .53196 L
s
.26002 .47002 m .25021 .47558 L .22318 .47359 L p 0 .458 1 r
F P
0 g
s
.25021 .47558 m .26002 .47002 L .28709 .47203 L p 0 .458 1 r
F P
0 g
s
.23281 .468 m .22318 .47359 L .25021 .47558 L p 0 .458 1 r
F P
0 g
s
.25021 .47558 m .26002 .47002 L .23281 .468 L p 0 .458 1 r
F P
0 g
s
.41812 .65863 m .39925 .67746 L .3889 .63714 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.41812 .65863 m
.41812 .65863 L
s
.39638 .6667 m
.39648 .66666 L
s
.41812 .65863 m
.41812 .65863 L
s
.24827 .50888 m .28709 .47203 L .37475 .57028 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.3164 .50488 m
.3164 .50488 L
s
.3164 .50488 m
.3164 .50488 L
s
.37475 .57028 m .33663 .60754 L .24827 .50888 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.25804 .55181 m
.27781 .54187 L
s
.27781 .54187 m
.27781 .54187 L
s
0 g
.33311 .52361 m
.37005 .48799 L
s
0 0 0 r
.23852 .51415 m
.28457 .56554 L
s
.28457 .56554 m
.32624 .61203 L
s
0 g
.36228 .5563 m
.399 .52055 L
s
0 0 0 r
.30727 .57476 m
.30727 .57476 L
s
.28707 .58418 m
.30727 .57476 L
s
.37475 .57028 m .36796 .55678 L .37556 .57035 L .511 0 0 r
F
0 g
.37525 .56979 m
.37998 .56517 L
s
.37475 .57028 m .36228 .5563 L .36796 .55678 L .511 0 0 r
F
.37459 .59559 m .35575 .58886 L .37475 .57028 L closepath p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.27937 .40142 m
.27937 .40142 L
s
.27937 .40142 m
.31696 .44367 L
s
.31696 .44367 m
.31696 .44367 L
s
.37556 .57035 m .37605 .56152 L .37672 .57103 L .511 0 0 r
F
.37556 .57035 m .36796 .55678 L .37605 .56152 L F
0 g
.37475 .57028 m
.37556 .57035 L
s
.36228 .5563 m
.37475 .57028 L
s
.37672 .57103 m .38437 .56926 L .3779 .57213 L .511 0 0 r
F
0 g
.37974 .57033 m
.38256 .56757 L
s
.37672 .57103 m .37605 .56152 L .38437 .56926 L .511 0 0 r
F
0 g
.37556 .57035 m
.37672 .57103 L
s
.36228 .5563 m .35003 .52478 L .36796 .55678 L .511 0 0 r
F
0 g
.36578 .55289 m
.399 .52055 L
s
.36228 .5563 m .33311 .52361 L .35003 .52478 L .511 0 0 r
F
0 g
.33311 .52361 m
.36228 .5563 L
s
.3779 .57213 m .38437 .56926 L .44265 .63461 L p .511 0 0 r
F P
0 g
s
.37672 .57103 m
.3779 .57213 L
s
.44885 .64314 m .47728 .65438 L .48435 .67545 L .511 0 0 r
F
.44265 .63461 m .47728 .65438 L .44885 .64314 L F
0 g
.44885 .64314 m
.45126 .65016 L
s
.33663 .60754 m .35575 .58886 L .37459 .59559 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.35575 .58886 m
.35575 .58886 L
s
.37459 .59559 m .37443 .62096 L .33663 .60754 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.30727 .57476 m
.30727 .57476 L
s
.30727 .57476 m
.34562 .53763 L
s
.37434 .6363 m .3889 .63714 L .39925 .67746 L p 0 .35 .78 r
F P
0 g
s
.44265 .63461 m .45858 .62853 L .47728 .65438 L .511 0 0 r
F
.45858 .62853 m .44265 .63461 L .38437 .56926 L p F P
0 g
s
.45311 .62416 m
.47897 .59835 L
s
.44265 .63461 m
.44885 .64314 L
s
.23281 .468 m .22318 .47359 L .20067 .47193 L p 0 .458 1 r
F P
0 g
s
.22318 .47359 m .23281 .468 L .26002 .47002 L p 0 .458 1 r
F P
0 g
s
.21014 .46631 m .20067 .47193 L .22318 .47359 L p 0 .458 1 r
F P
0 g
s
.22318 .47359 m .23281 .468 L .21014 .46631 L p 0 .458 1 r
F P
0 g
s
.36799 .64256 m .33663 .60754 L .37443 .62096 L p 0 .35 .78 r
F P
0 g
s
.37443 .62096 m .37434 .6363 L .36799 .64256 L p 0 .35 .78 r
F P
0 g
s
.39925 .67746 m .36799 .64256 L .37434 .6363 L p 0 .35 .78 r
F P
0 g
s
.35085 .41569 m .41196 .43684 L .38736 .45684 L .775 0 0 r
F
0 g
.37258 .4668 m
.38736 .45684 L
s
.24827 .50888 m .23852 .51415 L .20067 .47193 L p 0 .305 .956 r
F P
0 g
s
0 0 0 r
.24596 .50709 m
.27709 .47756 L
s
.23852 .51415 m
.23852 .51415 L
s
.26773 .4904 m
.26773 .4904 L
s
.26773 .4904 m
.31394 .54209 L
s
.35575 .58886 m
.35575 .58886 L
s
.35575 .58886 m
.35575 .58886 L
s
.51368 .61774 m .48435 .67545 L .47728 .65438 L .952 0 0 r
F
0 g
.47806 .68607 m
.48435 .67545 L
s
0 0 0 r
.27781 .54187 m
.27781 .54187 L
s
.27781 .54187 m
.3164 .50488 L
s
.3164 .50488 m
.3164 .50488 L
s
.36796 .55678 m .37448 .53899 L .37605 .56152 L .511 0 0 r
F
.36796 .55678 m .35003 .52478 L .37448 .53899 L F
0 g
.36228 .5563 m
.36796 .55678 L
s
0 0 0 r
.31394 .54209 m
.35575 .58886 L
s
.4952 .59191 m .51368 .61774 L .47728 .65438 L .886 0 0 r
F
0 g
.51368 .61774 m
.52046 .63893 L
s
.38717 .48888 m .37448 .53899 L .35003 .52478 L .76 0 0 r
F
0 g
.33311 .52361 m
.35003 .52478 L
s
.38717 .48888 m .41166 .50281 L .37448 .53899 L .76 0 0 r
F
0 g
.37005 .48799 m
.38717 .48888 L
s
.35085 .41569 m .37538 .3955 L .41196 .43684 L .775 0 0 r
F
0 g
.33391 .42758 m
.35085 .41569 L
s
.28709 .47203 m .26002 .47002 L .26819 .45086 L closepath p 0 .35 .78 r
F P
0 g
s
.26773 .4904 m .26002 .47002 L .28709 .47203 L closepath p 0 .35 .78 r
F P
0 g
s
.20067 .47193 m .21014 .46631 L .23281 .468 L p 0 .458 1 r
F P
0 g
s
.20067 .47193 m .21014 .46631 L .24827 .50888 L p 0 .305 .956 r
F P
0 g
s
.37538 .3955 m .43715 .41394 L .41196 .43684 L .832 0 0 r
F
0 g
.38736 .45684 m
.41196 .43684 L
s
.37538 .3955 m .40066 .37261 L .43715 .41394 L .832 0 0 r
F
0 g
.35085 .41569 m
.37538 .3955 L
s
.40066 .37261 m
.43715 .41394 L
s
.41196 .43684 m
.43715 .41394 L
s
.38546 .38142 m
.40066 .37261 L
s
.37605 .56152 m .39971 .56244 L .38437 .56926 L .511 0 0 r
F
0 g
.39166 .56212 m
.42114 .53326 L
s
.3779 .57213 m
.38437 .56926 L
s
.37605 .56152 m .37448 .53899 L .39971 .56244 L .511 0 0 r
F
0 g
.36796 .55678 m
.37605 .56152 L
s
.38437 .56926 m .39971 .56244 L .45858 .62853 L p .511 0 0 r
F P
0 g
s
.37605 .56152 m
.38437 .56926 L
s
.24927 .42964 m .26819 .45086 L .26002 .47002 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.26819 .45086 m
.26819 .45086 L
s
.24863 .46217 m
.25669 .45751 L
s
.26819 .45086 m
.26819 .45086 L
s
.23281 .468 m .21014 .46631 L .24927 .42964 L closepath p 0 .35 .78 r
F P
0 g
s
.26002 .47002 m .23281 .468 L .24927 .42964 L p 0 .35 .78 r
F P
0 g
s
.37538 .3955 m
.40066 .37261 L
s
.43679 .52609 m .4952 .59191 L .45858 .62853 L p .859 0 0 r
F P
0 g
s
.4952 .59191 m .47728 .65438 L .45858 .62853 L .886 0 0 r
F
0 g
.4952 .59191 m
.51368 .61774 L
s
.47728 .65438 m
.48435 .67545 L
s
.23281 .468 m .26002 .47002 L .26773 .4904 L p 0 .35 .78 r
F P
0 g
s
.26773 .4904 m .24827 .50888 L .23281 .468 L p 0 .35 .78 r
F P
0 g
s
0 0 0 r
.26773 .4904 m
.26773 .4904 L
s
.26773 .4904 m
.26773 .4904 L
s
.41166 .50281 m .39971 .56244 L .37448 .53899 L .832 0 0 r
F
.41166 .50281 m .43679 .52609 L .39971 .56244 L F
0 g
.38717 .48888 m
.41166 .50281 L
s
.35003 .52478 m
.37448 .53899 L
s
.24827 .50888 m .21014 .46631 L .23281 .468 L closepath p 0 .35 .78 r
F P
0 g
s
.45858 .62853 m .39971 .56244 L .43679 .52609 L p .859 0 0 r
F P
0 g
s
.45858 .62853 m
.47728 .65438 L
s
.41166 .50281 m
.43679 .52609 L
s
.38437 .56926 m
.39971 .56244 L
s
.44265 .63461 m
.45858 .62853 L
s
.45858 .62853 m
.4952 .59191 L
s
.39971 .56244 m
.43679 .52609 L
s
.37448 .53899 m
.39971 .56244 L
s
[ .01 .01 ] 0 setdash
.22109 .10325 m
.85599 .17427 L
s
.85599 .17427 m
.86804 .83832 L
s
.86804 .83832 m
.21096 .81296 L
s
.21096 .81296 m
.22109 .10325 L
s
.14322 .17203 m
.13112 .83753 L
s
.13112 .83753 m
.21096 .81296 L
s
.21096 .81296 m
.22109 .10325 L
s
.22109 .10325 m
.14322 .17203 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{489, 489},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007Y0001jB000`400?l00000o`00003oo`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3oool90?ooo`<00000gP3oool00?l0oooo2@3o
ool00`3^k^h000000>k^kP3N0?ooo`00o`3oool:0?ooo`030000003oool0oooo0=d0oooo003o0?oo
o`T0oooo00<0k^k^0000003^k^h0gP3oool00?l0oooo2@3oool304A4A=h0oooo003o0?ooo`P0oooo
00D0QhN704A4A03oool0<S8b0:VYZ@3M0?ooo`00o`3oool70?ooo`070<c<c0000000k^k^0?ooo`3<
c<`000000<c<c03L0?ooo`00o`3oool70?ooo`80000000<0<S8b0?ooo`0000000P00003L0?ooo`00
o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00
o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00N03oool4000000030;Zj^P3oool0V9RH00<0000000<0V9RH
0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`3o0?oooel0oooo001h0?ooo`0A0<c<c03^k^h0oooo
0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000o`3o
oomQ0?ooo`00N@3oool00`3<c<`0k^k^0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo0?l0ooooG`3oool00700oooo1`0000030?ooo`050:VYZ@3^
k^h0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0?l0oooo
G`3oool007X0oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0o`3ooomO0?ooo`00N03oool0101gMgL0oooo0?ooo`0000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0?l0ooooG`3oool007P0
oooo00@0000009RHV02HV9P000000P3oool02`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH
0?ooo`2HV9P000000?l0ooooH@3oool007P0oooo00@0V9RH000000000000V9RH0P3oool01`2HV9P0
0000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`3o0?oooel0oooo00320?oo
o`<0000000<0oooo09RHV00000000P0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo
0?l0oooo5`3oool00<<0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool00000
09RHV03oool0V9RH00000?l0oooo6@3oool00<<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0?l0oooo5`3oool00;T0oooo1`0000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`3o0?oo
oaL0oooo00330?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`3o0?oooaL0oooo001[0?ooo`H00000DP3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00JP3oool200000004
0?ooo`000000oooo0?ooo`T00000BP3oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P00000o`3ooolI0?ooo`00J@3oool01@000000oooo0000003oool0
000000/0oooo2P00000o0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo09RH
V0030000000309RHV03oool0oooo0?l0oooo5`3oool006P0oooo00@000000?ooo`3oool00000403o
ool00`000000oooo0?ooo`030?ooo`X00000O@3oool01@2HV9P00000000000000000V9RH0=/0oooo
001[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool;000007<0oooo00D0
000009RHV03oool0V9RH0000003K0?ooo`00J`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01P3oool<000006T0oooo00D000000?ooo`3oool0oooo
0000003K0?ooo`00I03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00`00000H03o
ool01@000000oooo0?ooo`3oool000000=/0oooo001S0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02@3oool8000005/0oooo00D000000?ooo`3oool0oooo0000003K0?ooo`00HP3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo2P00001A0?ooo`050000003o
ool0oooo0?ooo`000000f`3oool00640oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0<0?ooo`T00000B@3oool01@000000V9RH0?ooo`2HV9P000000=/0oooo001P0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`060?ooo`T00000@03o
ool01@2HV9P00000000000000000V9RH03/0oooo0`0000000`3oool0V9RH000000020000000309RH
V03oool0V9RH00<0000000<0V9RH0?ooo`3oool0S`3oool006/0oooo00<000000?ooo`3oool0E`3o
ool010000000oooo0?ooo`3oool9000007P0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH
0000003oool0000009RHV03oool0V9RH00000940oooo001[0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool02P3oool:000006h0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo08l0oooo001L0?ooo`8000003@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool;000006@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo08l0
oooo001K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`09000005d0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo08l0oooo001J0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
203oool;000005<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo08l0oooo001I0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0
0P3oool<000004T0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RH
V03oool0V9RH00000940oooo003`0?ooo`030000003oool0oooo00/0oooo3000000o0?ooo`05024Q
8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo08l0
oooo003n0?ooo`030000003oool0oooo00H0oooo3@00001e0?ooo`@0000000<0^[Zj0?ooo`2HV9P0
0`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo04d0oooo001E0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0WP3oool010000000oooo0?ooo`3oool>000006/0oooo
0140c<c<0>k^kP3oool0c<c<05EEE@3oool0000009RHV03oool0V9RH0000003oool0000009RHV03o
ool0V9RH0000001?0?ooo`00E@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool02P3oool9000006P0oooo00<0c<c<0>k^kP3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`1=0?ooo`00E03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`060?ooo`P00000H@3oool01@2YZJT0k^k^0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`1=0?ooo`00D`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0;T0oooo00<000000?ooo`3oool02@0000020?ooo`030000003oool0oooo
05<0oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0C@3oool00580oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo00T0oooo2P00001<0?ooo`0407MgM`3oool0oooo00000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0C@3oool006/0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`040?ooo`/00000@P3oool010000000V9RH09RH
V00000020?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000C`3o
ool00?l0oooo@`3oool00`000000oooo0?ooo`0<000003P0oooo00@0V9RH000000000000V9RH0P3o
ool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`1=0?ooo`00
C@3oool200000?<0oooo00<000000?ooo`3oool02@3oool<000008l0oooo001<0?ooo`030000003o
ool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`040?ooo`/00000Q`3oool004/0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03000001m
0?ooo`00BP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>80oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`d00000M03oool006/0oooo00<000000?ooo`3o
ool0o@3oool00`000000oooo0?ooo`030?ooo`T0000000<0oooo0000000000000P00001Z0?ooo`00
J`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`000000200000020?ooo`@00000
H03oool004H0oooo0P00000S0?ooo`030000003oool0oooo0?l0oooo2`3oool00`000000oooo0?oo
o`080?ooo`T000000P3oool4000005L0oooo00150?ooo`<000008`3oool00`000000oooo0?ooo`3o
0?oooaP0oooo00<000000?ooo`3oool0103oool9000005@0oooo00150?ooo`040000003oool0oooo
000000@0oooo1000000J0?ooo`030000003oool0oooo08l0oooo0P00002C0?ooo`030000003oool0
oooo00T0000000<0oooo0000003oool0B03oool004D0oooo0P00000:0?ooo`8000000`3oool40000
0:80oooo0`00002C0?ooo`030000003oool0oooo00T0oooo100000170?ooo`00A@3oool00`000000
oooo0000000B0?ooo`800000103oool4000009L0oooo0P0000000`00FLL000000000002B0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`000000A`3oool004D0oooo00<000000?ooo`3oool0
703oool2000000@0oooo1000002<0?ooo`8000000P00FLL00`00000005W70000002P0?ooo`030000
003oool0oooo04D0oooo00150?ooo`030000003oool0oooo02H0oooo0P0000040?ooo`<00000P@3o
ool3000000<005W700@00000001Ia`00FLL00000U`3oool2000000H0oooo00<000000?ooo`3oool0
A@3oool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`800000103o
ool4000007D0oooo0P0000000`0031T00000001Ia`03001Ia`0500000000FLL005W7001Ia`000000
U@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04D0oooo00150?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool04`3oool2000000@0oooo1000001Z0?ooo`80000000<0
00`I00000000FLL01@00FLL01@00000005W7001Ia`00FLL0000009<0oooo00<000000?ooo`3oool0
C`3oool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`800000103o
ool3000005l0oooo0`0000000`0031T00000001Ia`06001Ia`0300000000FLL005W7008005W700<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`1@0?ooo`00A@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02H0oooo0P0000040?ooo`@00000E03oool01@00000000`I00000000
31T0000000P005W700<00000001Ia`00FLL00`00FLL00`000000oooo0?ooo`3Q0?ooo`00A@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo0P0000040?ooo`@00000B03oool2
00000004000<6@00000000`I000000T005W700<00000001Ia`00FLL01000FLL00`000000oooo0?oo
o`280?ooo`800000EP3oool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0j
0?ooo`800000103oool4000003d0oooo0P000000100031T00000000<6@00000:001Ia`0300000000
FLL005W700D005W700<000000?ooo`3oool0Q03oool300000100oooo00<000000?ooo`3oool0A@3o
ool004D0oooo00<000000?ooo`3oool0JP3oool2000000<0oooo1000000b0?ooo`<0000000@000`I
0000000031T000002P00FLL3000000H005W700<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04D0oooo000[0?ooo`@0000000<0^[Zj0?ooo`2HV9P00`000000
0`2HV9P0oooo09RHV0030000000309RHV03oool0oooo00L0oooo00<000000?ooo`3oool0L`3oool2
000000@0oooo1000000W0?ooo`070000000031T00000000<6@00000000`I00000008001Ia`<00000
00<005W700000000FLL00P000005001Ia`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
A@3oool002/0oooo0140c<c<0>k^kP3oool0c<c<05EEE@3oool0000009RHV03oool0V9RH0000003o
ool0000009RHV03oool0V9RH000000090?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`@0
0000703oool01`00000000`I0000000031T00000000<6@0000001P00FLL3000000@005W700@00000
001Ia`00FLL005W70P000004001Ia`030000003oool0oooo09D0oooo00<000000?ooo`3oool0A@3o
ool002`0oooo00<0c<c<0>k^kP3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08L0oooo0P0000040?ooo`<00000
4P3oool01`00000000`I0000000031T00000000<6@0000001000FLL3000000L005W700<00000001I
a`00FLL00`00FLL2000000<005W700<000000?ooo`3oool0N`3oool2000001L0oooo00<000000?oo
o`3oool0A@3oool002@0oooo1`0000020?ooo`050:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1Z0?ooo`800000103oool4000000H0oooo0P0000001P0031T00000000<6@000000
00`I0000008005W70`00000:001Ia`0300000000FLL005W700D005W70P000002001Ia`030000003o
ool0oooo07P0oooo0P00000I0?ooo`030000003oool0oooo04D0oooo000]0?ooo`050=gMg@1VIVH0
oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00L0oooo1000
000R0?ooo`030000003oool0oooo07@0oooo0P0000030?ooo`80000000D000`I0000000031T00000
000<6@04000000d005W700<00000001Ia`00FLL01`00FLL01000000005W7001Ia`00001h0?ooo`03
0000003oool0oooo0640oooo000[0?ooo`0407MgM`3oool0oooo00000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo07P0oooo0P0000000`0031T00000000<6@040000010005W700<00000
001Ia`00FLL02000FLL200000003001Ia`000000oooo0=X0oooo000[0?ooo`040000002HV9P0V9RH
00000080oooo00/0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH000000090?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0M`3oool200000003000<6@00000000`I
0080000000<005W700000000FLL04000FLL00`00000005W7001Ia`0:001Ia`<00000L03oool20000
06P0oooo000[0?ooo`0409RHV0000000000009RHV080oooo00L0V9RH000000000000000009RHV03o
ool0V9RH00<0000000<0V9RH0?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo07H0oooo0P0000000`0031T00000000<6@02000000<005W700<00000001Ia`00FLL03P00
FLL00`00000005W7001Ia`0<001Ia`800000KP3oool00`000000oooo0?ooo`1X0?ooo`00A@3oool0
0`000000oooo0?ooo`2K0?ooo`80000000<000`I0000000000000P000005001Ia`0300000000FLL0
05W700d005W700<00000001Ia`00FLL03P00FLL3000006X0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`140?ooo`00A@3oool00`000000oooo0?ooo`2J0?ooo`80000000D000`I0000
0000000000`I00000007001Ia`0300000000FLL005W700`005W700<00000001Ia`00FLL03000FLL3
00000080oooo0P0000040?ooo`<00000H03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo04@0oooo00150?ooo`030000003oool0oooo09T0oooo0P0000001@0031T000000000000031T0
000000T005W700<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`0;001Ia`8000000P00FLL0
0`000000oooo0?ooo`080?ooo`800000103oool4000007`0oooo00<000000?ooo`3oool0A03oool0
04D0oooo00<000000?ooo`3oool0V03oool200000005000<6@0000000000000<6@0000002`00FLL0
0`00000005W7001Ia`0:001Ia`0300000000FLL005W700X005W70P000004001Ia`030000003oool0
oooo0140oooo0P0000040?ooo`@00000A`3oool2000002T0oooo00<000000?ooo`3oool0A03oool0
04D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1a0?ooo`D0000000<000`I0000
0000FLL03000FLL00`00000005W7001Ia`08001Ia`<000002P00FLL2000000H005W700<000000?oo
o`3oool06P3oool2000000@0oooo1000000k0?ooo`800000:`3oool00`000000oooo0?ooo`140?oo
o`00A@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0700oooo0`000000100031T0
0000000<6@00000?001Ia`0300000000FLL005W700@005W70`0000000`00FLL00000001Ia`020000
00L005W70P000008001Ia`030000003oool0oooo02<0oooo0P0000030?ooo`@00000<@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo04@0oooo00150?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0K`3oool300000004000<6@00000000`I0000014005W70P0000001000
FLL00000000000000004001Ia`0400000000FLL005W7001Ia`8000001000FLL2000000X005W700<0
00000?ooo`3oool0:`3oool2000000@0oooo1000002L0?ooo`00A03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06l0oooo0`000000100031T00000000<6@00000B001Ia`<000001`00
FLL00`00000005W7001Ia`03001Ia`80000000<005W70000000000003000FLL00`000000oooo0?oo
o`0d0?ooo`800000103oool400000980oooo00140?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0KP3oool300000004000<6@00000000`I0000018005W700<00000001Ia`0000002000
FLL00`00000005W7001Ia`05001Ia`8000003@00FLL00`000000oooo0?ooo`0n0?ooo`800000103o
ool3000000h0oooo0P00001i0?ooo`00A03oool2000002@0oooo00<000000?ooo`3oool0K@3oool3
00000004000<6@00000000`I0000018005W700D00000001Ia`00FLL005W700000007001Ia`030000
0000FLL005W700D005W700<00000001Ia`00FLL03@00FLL00`000000oooo0?ooo`160?ooo`800000
103oool400000080oooo0P00001k0?ooo`00A03oool400000940oooo00<00000000<6@0000001000
000B001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL01000FLL00`00000005W7001I
a`04001Ia`0300000000FLL0000000l005W700<000000?ooo`3oool0C`3oool2000003H0oooo00<0
00000?ooo`3oool0A03oool004@0oooo0P00002A0?ooo`80000000<000`I0000000000000P000000
0`00FLL00000001Ia`0@001Ia`0300000000FLL005W700D005W700<00000001Ia`00FLL00`00FLL0
0`00000005W7001Ia`03001Ia`0500000000FLL005W7001Ia`0000003`00FLL00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0A03oool004@0oooo0P00002@
0?ooo`80000000<000`I0000000000000P000003001Ia`0300000000FLL005W700d005W700<00000
001Ia`00FLL01`00FLL00`00000005W7001Ia`02001Ia`0300000000FLL005W7008005W700<00000
001Ia`00FLL00`00FLL00`00000005W7001Ia`0=001Ia`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`140?ooo`00A03oool2000008l0oooo0P0000000`00
31T0000000000002000000D005W700<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`09001I
a`0500000000FLL005W7001Ia`0000000`00FLL00`00000005W7001Ia`05001Ia`0300000000FLL0
05W700d005W700<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo04@0oooo00140?ooo`800000903oool00`000000oooo0?ooo`1W0?ooo`80000000D000`I0000
0000000000`I00000007001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL02`00FLL0
1000000005W7001Ia`000002001Ia`0300000000FLL005W700L005W700<00000001Ia`00FLL03000
FLL00`000000oooo0?ooo`240?ooo`030000003oool0oooo04@0oooo00140?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0IP3oool200000005000<6@0000000000000<6@0000002@00
FLL00`00000005W7001Ia`07001Ia`0300000000FLL005W700d005W700D00000001Ia`00000005W7
0000000;001Ia`0300000000FLL005W700`005W700<000000?ooo`000000P`3oool00`000000oooo
0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06D0oooo1@00
00000`0031T00000001Ia`0:001Ia`0300000000FLL005W700D005W700<00000001Ia`00FLL03`00
FLL3000000d005W700<00000001Ia`00FLL02`00FLL200000</0oooo00140?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0I03oool500000003000<6@00000005W700`005W700<00000
001Ia`00FLL00P00FLL20000018005W70P00000>001Ia`0300000000FLL005W700X005W700@00000
001Ia`00FLL00000C03oool00`000000oooo0?ooo`1k0?ooo`00A03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06<0oooo0`000000100031T00000000<6@00000?001Ia`0400000000
FLL005W7000001<005W700<00000001Al00000003`00FLL00`00000005W7001Ia`08001Ia`030000
0000FLL005W7008005W700<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1k0?ooo`00A03o
ool2000002@0oooo00<000000?ooo`3oool0HP3oool300000004000<6@00000000`I0000014005W7
0P00000C001Ia`0500000000DO00057`001Al00000003`00FLL00`00000005W7001Ia`06001Ia`03
00000000FLL005W700@005W700<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1k0?ooo`00
A03oool2000008P0oooo1@0000000`0031T00000001Ia`0A001Ia`8000004P00FLL00`000000057`
001Al003001Al00300000000FLL005W700d005W700<00000001Ia`00FLL01000FLL00`00000005W7
001Ia`06001Ia`030000003oool0oooo04L0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`140?ooo`00A03oool2000008H0oooo1@000002000<6@0300000000FLL005W7010005W700<0
0000001Ia`0000004@00FLL00`000000057`001Al005001Al00300000000FLL005W700d005W700<0
0000001Ia`00FLL00P00FLL00`00000005W7001Ia`07001Ia`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`140?ooo`00A03oool2000008D0oooo1@000002
000<6@0300000000FLL005W7010005W700D00000001Ia`00FLL005W70000000?001Ia`8000002000
DO000`00000005W7001Ia`0=001Ia`0400000000FLL005W7000000/005W700<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04@0oooo00140?ooo`800000Q03o
ool500000003000<6@0000000000018005W700<00000001Ia`00FLL00`00FLL00`00000005W7001I
a`0;001Ia`0400000000DO00057`000000P0057`00<00000001Ia`00FLL03@00FLL2000000d005W7
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`140?ooo`00A03oool3000002<0oooo00<0
00000?ooo`3oool0G03oool700000003001Ia`00000005W7010005W700<00000001Ia`00FLL01@00
FLL00`00000005W7001Ia`09001Ia`0300000000DO00057`0080057`00<00000001Al000DO001P00
DO000`00000005W7001Ia`0<001Ia`8000003P00FLL00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo04@0oooo00140?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0F`3oool0
0`00000000`I00000004000000<005W700<00000001Ia`00FLL03@00FLL00`00000005W7001Ia`07
001Ia`0300000000FLL005W700L005W700<00000001Al000DO001000DO000`000000057`001Al006
001Al00300000000FLL005W700X005W700@00000001Ia`00FLL000003P00FLL00`000000oooo0?oo
o`310?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05X0oooo00<00000
000<6@00000010000005001Ia`0300000000FLL005W700/005W700<00000001Ia`00FLL02@00FLL0
0`00000005W7001Ia`05001Ia`0300000000DO00057`00H0057`00<00000001Al000DO001@00DO00
0`00000005W7001Ia`09001Ia`0500000000FLL005W7001Ia`0000003`00FLL00`000000oooo0?oo
o`300?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo1@000000
0`0031T00000001Ia`06001Ia`0300000000FLL005W700P005W70P00000=001Ia`0300000000FLL0
05W700<005W700<00000001Al000DO002000DO000`000000057`001Al005001Al00300000000FLL0
05W700L005W700<00000001Ia`00FLL00`00FLL00`00000005W7001Ia`0=001Ia`030000003oool0
oooo0440oooo00<000000?ooo`3oool0N`3oool004@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1H0?ooo`80000000D000`I00000000000000`I00000009001Ia`0300000000FLL0
05W700H005W700<00000001Ia`00FLL03P00FLL01@00000005W7001Ia`00FLL0000000`0057`00<0
0000001Al000DO001@00DO000`00000005W7001Ia`05001Ia`0300000000FLL005W700D005W700<0
0000001Ia`00FLL03000FLL00`000000oooo0?ooo`110?ooo`030000003oool0oooo07/0oooo0014
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0E`3oool500000003000<6@000000
05W700X005W700<00000001Ia`00FLL01000FLL00`00000005W7001Ia`0@001Ia`<000003P00DO00
0`000000057`001Al005001Al00300000000FLL005W700<005W700<00000001Ia`00FLL01`00FLL0
0`00000005W7001Ia`0<001Ia`030000003oool0oooo0400oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`1l0?ooo`<0000000@000`I0000
000031T000003@00FLL00`00000005W7001Ia`02001Ia`0300000000FLL005W7014005W70P00000?
001Al00300000000DO00057`00H0057`00D00000001Ia`00FLL005W70000000;001Ia`0300000000
FLL005W700`005W700<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo04@0oooo00140?ooo`030000003oool0oooo07/0oooo0`000000100031T00000000<6@00
000?001Ia`0400000000FLL005W7000001<005W700<00000001Al00000004000DO000`000000057`
001Al006001Al00300000000FLL0000000d005W700<00000001Ia`00FLL03000FLL2000003l0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?oo
o`1j0?ooo`<0000000@000`I0000000031T000004@00FLL2000001<005W700D00000001Al000DO00
057`0000000@001Al00300000000DO00057`00D0057`0P00000?001Ia`0300000000FLL005W700X0
05W700<00000001Ia`000000?`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04@0
oooo00140?ooo`030000003oool0oooo07T0oooo0`000000100031T00000000<6@00000B001Ia`80
00004P00FLL00`000000057`001Al003001Al00300000000DO00057`00D0057`00<00000001Al000
DO001P00DO000`000000057`001Al003001Al00400000000DO00057`000000l005W700<00000001I
a`00FLL02000FLL01@00000005W7001Ia`00FLL0000007D0oooo00<000000?ooo`3oool0A03oool0
04@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1B0?ooo`<0000000@000`I0000
000031T000004P00FLL00`00000005W70000000A001Ia`0300000000DO00057`00D0057`00<00000
001Al000DO001@00DO000`000000057`001Al006001Al00300000000DO00057`008000000`00DO00
0`00000005W7001Ia`0=001Ia`0300000000FLL005W700L005W700<00000001Ia`00FLL00`00FLL0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04@0oooo00140?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0D@3oool300000004000<6@00000000`I0000018005W700D00000
001Ia`00FLL005W70000000?001Ia`030000003oool0000000L0057`00<00000001Al000DO001@00
DO000`000000057`001Al006001Al08000001P00DO000`00000005W7001Ia`0=001Ia`0300000000
FLL005W700D005W700<00000001Ia`00FLL01000FLL00`000000oooo0?ooo`2i0?ooo`00A03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04l0oooo10000000100031T0000000000000
000B001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL02`00FLL3000000030?ooo`00
0000057`00H0057`00<00000001Al000DO001@00DO000`000000057`001Al004001Al00300000000
DO00000000L0057`00<00000001Ia`00FLL03@00FLL00`00000005W7001Ia`03001Ia`0300000000
FLL005W700H005W700<000000?ooo`3oool0^03oool004@0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1>0?ooo`80000000<000`I0000000031T00P0000000`00FLL00000001Ia`0@
001Ia`0300000000FLL005W700D005W700<00000001Ia`00FLL02@00FLL20000000501T000000000
oooo0?ooo`0000001`00DO000`000000057`001Al005001Al00400000000DO00057`001Al0800000
0P00DO000`000000057`001Al006001Al00300000000FLL005W700d005W700D00000001Ia`00FLL0
05W70000000:001Ia`030000003oool0oooo03T0oooo00<000000?ooo`3oool0N`3oool004@0oooo
0`00000S0?ooo`030000003oool0oooo04d0oooo0P0000000`0031T00000000<6@020000008005W7
0P00000?001Ia`0300000000FLL005W700L005W700<00000001Ia`00FLL01`00FLL01@0000006@00
01T000000000n`0000<0oooo00<00000001Al000DO001000DO000`000000057`001Al006001Al003
00000000DO00000000D0057`00<00000001Al000DO001P00DO000`00000005W7001Ia`0=001Ia`03
00000000FLL0000000`005W700<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1k0?ooo`00
A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04`0oooo0P0000000`0031T00000
000000020000008005W700@00000001Ia`00FLL000003@00FLL00`00000005W7001Ia`09001Ia`03
00000000FLL005W700D005W700@0000001T0000I000000000`3k00020?ooo`0300000000DO00057`
00D0057`00<00000001Al000DO001@00DO02000000L0057`00<00000001Al000DO001P00DO000`00
000005W7001Ia`0=001Ia`0300000000FLL005W700`005W700<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo04@0oooo00140?ooo`030000003oool0oooo0740
oooo0P0000001@0031T000000000000031T0000000<005W700D00000001Ia`00FLL005W70000000;
001Ia`0300000000FLL005W700/005W700<00000001Ia`00FLL00`00FLL01@0000006@0001T0000I
0000000000@0n`000P3oool00`000000057`001Al005001Al00300000000DO00057`0080057`0P00
0002001Al00300000000DO00057`00D0057`00<00000001Al000DO001P00DO000`00000005W7001I
a`0;001Ia`0300000000FLL0000000h005W700<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo04@0oooo00140?ooo`030000003oool0oooo0700oooo0P000000
1@0031T000000000000031T0000000@005W700<00000001Ia`00FLL00P00FLL00`00000005W7001I
a`07001Ia`0300000000FLL005W700d005W700D00000001Ia`00FLL005W70000000301T000030000
003k0000n`0000@0n`000P3oool00`000000057`001Al005001Al00400000000DO000000000000@0
057`00<00000001Al000DO001P00DO000`000000057`001Al006001Al0/0000000D005W700000000
FLL005W70000000>001Ia`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`1_0?ooo`D0000000<000`I00000000
FLL00`00FLL00`00000005W7001Ia`04001Ia`0300000000FLL005W700D005W700<00000001Ia`00
FLL03`00FLL00`00000005W70000000301T000030000003k0000n`0000H0n`000P3oool00`000000
057`001Al005001Al00300000000DO00057`00D0057`00<00000001Al000DO001P00DO000`000000
057`001Al004001Al0030000002:0000RP0000H0RP000`320002000000<005W700<00000001Ia`00
FLL03000FLL00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0A03oool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`180?ooo`<00000
00@000`I0000000031T000001@00FLL00`00000005W7001Ia`05001Ia`0300000000FLL005W700<0
05W700<00000001Ia`00FLL04000FLL2000000<06@0000<000000><0003S0000203k00020?ooo`03
00000000DO00057`0080057`0P0000000`00DO000000001Al006001Al00300000000DO00057`00H0
057`00<00000001Al000DO000P00DO000`000000RP0008X0000608X000H0`P000P000002001Ia`03
00000000FLL005W700`005W700<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`140?ooo`00
A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04L0oooo0`000000100031T00000
000<6@000006001Ia`0300000000FLL005W700H005W700D00000001Ia`00FLL005W70000000B001I
a`8000000`0I00000`000000h`000><000020><000L0n`000`3oool010000000057`000000000004
001Al00300000000DO00057`00D0057`00<00000001Ia`00DO001P00DO0010000000057`01T00000
000808X000T0`P000P0000000`00FLL00000001Ia`0=001Ia`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0A03oool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`16
0?ooo`<0000000@000`I0000000031T000001`00FLL00`00000005W7001Ia`07001Ia`0300000000
FLL00000018005W70P00000301T000030000003S0000h`0000@0h`001`3k00030?ooo`0300000000
DO00057`00@0057`00<00000001Al000DO001P00DO000`00000005W7001Al004001Al00400000000
DO006@00000000P0RP0030320003000000h005W700<000000?ooo`3oool0/03oool004@0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`150?ooo`070000000031T00000000<6@000000
00`I00000007001Ia`0300000000FLL005W700T005W70P00000A001Ia`8000000`0I00000`000000
h`000><000060><000L0n`000P3oool2000000H0057`00<00000001Al000DO001P00DO0010000000
05W7001Al000DO02000000806@0000<0000008X0002:00001P2:000?0<80008000003P00FLL00`00
0000oooo0?ooo`2_0?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04@0
oooo00L00000000<6@00000000`I0000000031T0000000P005W700<00000001Ia`00FLL02@00FLL0
0`00000005W7001Ia`0?001Ia`8000000`0I00000`000000h`000><000080><000L0n`000P3oool0
0`000000057`001Al005001Al00300000000DO00057`00H0057`00<00000001Ia`0000000`0I0000
0`000000RP0008X0000608X00180`P000P00000<001Ia`800000<`3oool00`000000oooo0?ooo`1j
0?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04<0oooo00L00000000<
6@00000000`I0000000031T0000000T005W700<00000001Ia`00FLL02@00FLL2000000l005W70P00
000301T000030000003S0000h`0000X0h`001`3k00020?ooo`0300000000DO00057`00D0057`00<0
0000001Al000DO001@00DO02000000<06@0000<0000008X0002:00001P2:000C0<800080e00000<0
0000001Ia`00FLL02000FLL3000003<0oooo00<000000?ooo`3oool0NP3oool004@0oooo00<00000
0?ooo`3oool0I`3oool200000006000<6@00000000`I0000000031T000002P00FLL00`00000005W7
001Ia`05001Ia`0400000000FLL005W70000008005W700<00000001Ia`00FLL02`00FLL00`000000
6@0001T0000201T000030000003S0000h`0000/0h`00203k00020?ooo`0300000000DO00057`00D0
057`00<00000001Al000DO000P00DO02000000@06@0000<0000008X0002:00001P2:000C0<8000@0
e00000<00000001Ia`00FLL01P00FLL200000003001Ia`00000000000380oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`1V0?ooo`800000
00<000`I0000000031T00`00000:001Ia`0300000000FLL005W700T005W700D00000001Ia`00FLL0
05W70000000;001Ia`8000000P0I0002000000l0h`001`3k00030?ooo`0300000000DO00057`00D0
057`00@00000001Al000000000001@0I00000`000000RP0008X0000608X001<0`P001P3D00000`00
000005W7001Ia`04001Ia`8000000`00FLL200000340oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`140?ooo`00A03oool00`000000oooo0?ooo`1U0?ooo`80000000<000`I00000000
31T00P000002001Ia`0300000000FLL005W700L005W700<00000001Ia`00FLL02@00FLL00`000000
05W7001Ia`02001Ia`0300000000FLL005W700L005W700L0000001T0000000006@000000003K0000
00000100h`001`3k00030?ooo`0300000000DO00057`00D0057`00<0000001T0000I0000100I0000
0`000000RP0008X0000608X001<0`P00203D00000`00000005W7001Ia`02001Ia`8000001000FLL0
0`00000005W70000000`0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0A03oool0
04@0oooo0P00001U0?ooo`80000000<000`I0000000031T00P000004001Ia`0300000000FLL005W7
00H005W700<00000001Ia`00FLL02@00FLL00`00000005W7001Ia`03001Ia`0300000000FLL005W7
00D005W700<0000001T0000000000P0000030=/000030000003S0000h`0000h0h`001`3k00030?oo
o`0300000000DO00057`0080057`0P00000601T000030000002:0000RP0000H0RP004`32000:0=@0
000300000000FLL005W7008000001@00FLL01000000005W7001Ia`00000_0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0@`3oool004@0oooo00<000000?ooo`0000008`3oool00`00
0000oooo0?ooo`0m0?ooo`80000000<000`I0000000000000P000006001Ia`D000000P00FLL00`00
000005W7001Ia`0:001Ia`0300000000FLL005W700@005W700<00000001Ia`00FLL00`00FLL00`00
00006@0000000002000000D0f`0000<000000><0003S00003P3S00070?/000<0oooo00@00000001A
l000000000001`0I00000`000000RP0008X0000608X001<0`P00303D0003000000L005W700@00000
001Ia`00FLL00000I@3oool00`000000oooo0?ooo`130?ooo`00A03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03`0oooo0P0000001@0031T000000000000031T0000000L005W700<0
0000001Ia`00FLL00P00FLL9000000D005W700<00000001Ia`00FLL01P00FLL02@00000005W7001I
a`00FLL0000001T0000000006@00000000070=/000030000003S0000h`0000h0h`001`3k00020?oo
o`800000200I00000`000000RP0008X0000608X001<0`P003P3D00000`00000005W7001Ia`06001I
a`0500000000FLL005W7001Ia`000000I03oool00`000000oooo0?ooo`130?ooo`00A03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo0P0000001@0031T000000000000031T0
000000P005W70P000005001Ia`0300000000FLL005W700@005W730000003001Ia`0300000000FLL0
00000080000000<06@000000003K0000203K00000`000000h`000><0000=0><000P0n`0000<00000
01T0000I00001`0I00000`000000RP0008X0000608X001<0`P00403D00000`00000005W7001Ia`05
001Ia`0300000000FLL005W7008005W700<000000?ooo`3oool0Y`3oool004@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0j0?ooo`D0000000<000`I00000000FLL02000FLL00`00
000005W700000005001Ia`0300000000FLL005W700P005W700<00000001Ia`00FLL01000FLL60000
00806@0000<000000=/0003K00002@3K00000`000000h`000><0000=0><000P0n`0000<0000001T0
000I00001@0I00000`000000RP0008X0000608X001<0`P004P3D00000`00000005W7001Ia`04001I
a`0300000000FLL005W700<005W700<000000?ooo`3oool0YP3oool004@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0i0?ooo`<0000000@000`I0000000031T000002P00FLL01000
000005W7001Ia`000004001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL01P00FLL2
000000806@0000<000000=/0003K00002`3K00000`000000h`000><0000=0><000L0n`0000<00000
01T0000I0000100I000010000000RP0008X0002:000600000180`P00503D00000`00000005W7001I
a`04001Ia`0300000000FLL005W700<005W700<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1j0?ooo`00A03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03P0oooo0`000000
100031T00000000<6@00000;001Ia`0500000000FLL005W7001Ia`0000001000FLL00`00000005W7
001Ia`08001Ia`0300000000FLL005W700D005W70P00000201T000030000003K0000f`0000`0f`00
00<000000><0003S00003P3S00050?/000030000000I00006@0000<06@001P000006094000800000
3`32000F0=@0000300000000FLL005W700<005W700<00000001Ia`00FLL01000FLL00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo07X0oooo00140?ooo`030000003oool0oooo05d0oooo0`00
0000100031T00000000<6@00000<001Ia`0300000000FLL005W7008005W700D00000001Ia`00FLL0
05W70000000;001Ia`0300000000FLL005W700<005W70P00000201T000030000003K0000f`0000h0
f`0000<000000><0003S00003P3S00030?/000030000000I00006@0000806@000P0000000`2A0000
00000940000;09400003000000320000`P0000/0`P005P3D0002000000D005W700<00000001Ia`00
FLL01@00FLL00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0@`3oool004@0oooo00<000000?ooo`3oool0G03oool300000004000<6@00000000`I000000d0
05W700<00000001Ia`00FLL00`00FLL01@00000005W7001Ia`00FLL0000000X005W700<00000001I
a`00FLL00P00FLL2000000806@0000<000000=/0003K0000403K00000`000000h`000><0000>0><0
0080n`0000<0000001T0000I00000P000004094000030000002A0000T@0000X0T@000P00000:0<80
01H0e00000@000000=/0003K000000001000FLL00`00000005W7001Ia`06001Ia`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`130?ooo`00@`3oool20000
05d0oooo0`000000100031T00000000<6@00000;001Ia`D000001@00FLL01000000005W7001Ia`00
000;001Ia`0300000000FLL005W7008000000P0I00000`000000f`000=/0000B0=/000030000003S
0000h`0000h0h`0000@0000001T0000I000000001`2A00000`000000T@000940000;094000800000
1`32000F0=@000030000003K0000f`000080f`0000<00000001Ia`00FLL00P00FLL00`00000005W7
001Ia`06001Ia`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`130?ooo`00@`3oool2000005`0oooo0`000000100031T00000000<6@000006001Ia`H00000
0`00FLL01000000005W7000000000004001Ia`0400000000FLL005W7000000X005W700@00000001I
a`00000000000P0I00000`000000f`000=/0000D0=/000030000003S0000h`0000`0h`0000@00000
01T00000000000002@2A00000`000000T@000940000<09400003000000320000`P0000<0`P005P3D
00000`000000f`000=/000040=/0000500000000FLL005W7001Ia`0000002@00FLL00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0<P3oool400000005000<6@00000000`I00000000FLL01P000009001Ia`050000
0000FLL005W7001Ia`0000000`00FLL01000000005W7001Ia`00000:001Ia`<0000000<06@000000
00000000603K00000`000000h`000><0000:0><000<00000302A00000`000000T@00094000050940
00030=/0002A0000T@0000@0T@000P0000020<8001H0e00000<000000=/0003K00001P3K00001000
000005W7001Ia`00000:001Ia`030000003oool0oooo05T0oooo00<000000?ooo`3oool0@`3oool0
02`0oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0V9RH00<0000000<0V9RH0?oo
o`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00D00000000<
6@0000000000000<6@05000000l005W700<00000001Ia`00FLL00P00FLL20000008005W700@00000
001Ia`00FLL000002000FLL30000000301T000000000f`0001T0f`0000<000000><0003S00002@3S
0002000000l0T@0000<000000940002A00003@2A0002000001D0e00000<000000=/0003K0000203K
00001000000005W7001Ia`000008001Ia`800000F`3oool00`000000oooo0?ooo`130?ooo`00;@3o
ool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
203oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0300oooo00D00000000<6@000000
0000000<6@0200000003001Ia`00000005W7010005W700<00000001Ia`00FLL01000FLL200000004
001Ia`00000005W7000000L005W70`0000000`0I000000000=/0000K0=/000030000003S0000h`00
00L0h`0000<000000940002A0000402A00000`000000T@000940000=0940008000004`3D00000`00
0000f`000=/0000:0=/000L000000`00FLL01000000005W7001Ia`00002P0?ooo`00;@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo00D00000000<6@0000000000000<
6@02000000<005W700<00000001Ia`00FLL03P00FLL00`00000005W7001Ia`06001Ia`0500000000
FLL00000001Ia`0000001@00FLL30000000301T000000000f`0001d0f`0000<000000><0003S0000
1@3S00000`000000T@000940000B094000030000002A0000T@0000@0T@0000<0f`000940002A0000
102A000010000000T@0009400000000A0=@000030000003K0000f`0000`0f`000P000004001Ia`<0
00001000FLL00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo07X0oooo000S0?ooo`L00000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01P3oool500000280oooo00<000000?ooo`3oool0;P3oool00`00000000`I00000004000000D0
05W700<00000001Ia`00FLL03@00FLL00`00000005W7001Ia`07001Ia`@000001000FLL01@000000
6@000000000I000000000200f`0000<000000><0003S00000`3S00000`000000T@000940000D0940
00030000002A0000T@0000h0T@0000<000000=@0003D00003@3D00000`000000f`000=/0000=0=/0
000300000000FLL005W700@005W70P000005001Ia`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0NP3oool002d0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?oo
o`030000003oool0oooo00H0oooo0P00000U0?ooo`030000003oool0oooo02d0oooo00<00000000<
6@0000000P0000000`0031T00000001Ia`06001Ia`0300000000FLL005W700`005W700<00000001I
a`00FLL02@00FLL30000008005W700D0000001T0000000006@000000000R0=/000050000003S0000
h`000><000000000602A00000`000000T@000940000>094000030000003D0000e00000/0e00000<0
00000=/0003K00003`3K00000`00000005W7001Ia`02001Ia`0300000000FLL0000000H005W700<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo000]
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`800000D`3oool200000006000<6@00000000000000000031T000002@00FLL00`000000
05W7001Ia`0;001Ia`0300000000FLL005W700/005W700L00000001Ia`0000006@000000000I0000
000002@0f`0000<000000><0000000006P2A00000`000000T@0009400003094000030=/0002A0000
T@0000P0T@0000<000000=@0003D00002@3D00000`000000f`000=/0000A0=/0000400000000FLL0
05W70000008005W700<00000001Ia`00FLL01@00FLL00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0@`3oool002d0oooo00h000000?ooo`3oool0000009RH
V03oool0V9RH0000003oool0000009RHV03oool0V9RH000000P0oooo0P00001B0?ooo`0300000000
31T000`I00<0000000<000`I00000000FLL02P00FLL00`00000005W7001Ia`0:001Ia`0300000000
FLL005W700`005W700D0000001T0000000006@000000000V0=/000030000002A0000T@0001X0T@00
00<000000940002A00003P2A00000`000000e0000=@000070=@000030000003K0000f`0001<0f`00
0P000003001Ia`0300000000FLL005W700D005W700<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo04<0oooo000/0?ooo`05024Q8@000000oooo0?ooo`2HV9P0
0`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo00H0oooo0P00001A0?ooo`080000
000031T000000000000031T00000000<6@00000=001Ia`0300000000FLL005W700T005W700<00000
001Ia`00FLL02`00FLL01@0000006@000000000I0000000002H0f`0000<000000940002A0000702A
00001P000000T@000940002A0000000008`000@0T@0000<0`P000940002A0000102A00000`000000
e0000=@000050=@000030000003K0000f`0001D0f`0000D00000001Ia`00FLL005W700000008001I
a`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`130?oo
o`00@`3oool200000500oooo00P00000000<6@0000000000000<6@00000000`I000000h005W70P00
000:001Ia`0300000000FLL005W700X005W700D0000001T0000000006@000000000V0=/000030000
002A0000T@0001h0T@0000<000000940000000000P2A00000`2<0000T@0009400009094000030000
003D0000e00000<0e00000<000000=/0003K00005`3K00001000000005W7001Ia`000009001Ia`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0@`3oool004<0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0W0?ooo`@0000000@000`I0000000031T000004000FLL2000000D0
05W71P00000:001Ia`050000000I0000000001T0000000009P3K000200000200T@001P00000<0940
00050000003D0000e0000=@0000000006`3K0004000000T005W700<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02H0oooo10000000100031T00000000<6@00000B001Ia`H000001000FLL01000000005W700000000
0007001Ia`050000000I0000000001T0000000009P3K000010000000nP000?X00000000M094000<0
00000`2<00020<80008000002`2A00000`000000e0000000000M0=/00080000000@005W700000000
000000001`00FLL00`000000oooo0?ooo`2F0?ooo`00@`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02D0oooo00P00000000<6@0000000000000<6@00000000`I000001<005W70P00
0008001Ia`0400000000FLL005W7001Ia`8000001000FLL01@0000006@000000000I0000000002H0
f`0000<000000><0003S00000P3j00000`000000T@000940000H09400080000000<06@000000002<
00000P2<00050<8000030000002A0000T@0000P0T@000P00000N0=/0008000001000FLL2000000D0
05W700<000000?ooo`3oool0UP3oool004<0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0S0?ooo`80000000L000`I00000000000000`I0000000031T0000001<005W700@00000001I
a`00FLL000001`00FLL00`00000005W7001Ia`03001Ia`80000000H005W70000000I0000000001T0
0000000V0=/000030000003S0000h`000080h`000P3j00000`000000T@000940000E094000800000
0P0I000010000000S00008`0002<00050<8000030=@000000000T@0000H0T@000`0000000`2A0000
00000=/0000N0=/0000300000000FLL005W700@005W70`000003001Ia`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0NP3oool004<0oooo0P00000U0?ooo`030000003oool0oooo0280oooo
00<00000000<6@0031T00P000000100031T00000000<6@00000C001Ia`0300000000FLL005W70080
05W700<00000001Ia`00FLL01000FLL00`00000005W7001Ia`05001Ia`030000000I000000000080
00009P3K0002000000D0h`000P3j00000`000000T@000940000B0940008000000`0I000010000000
S00008`0002<00050<8000<0e00000@000000940002A0000T@000`000005094000030000003K0000
f`0001d0f`0000<00000001Ia`00FLL01P00FLL20000008005W700<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`1j0?ooo`00@`3oool2000002D0oooo00<000000?ooo`3oool08@3oool00`00
000000`I000<6@0200000004000<6@0000000000000001<005W700<00000001Ia`00FLL01000FLL0
0`00000005W7001Ia`03001Ia`0300000000FLL005W700@005W700<0000001T0000000000`00000U
0=/000040000003K0000f`00000000D0h`000P3j00000`000000T@000940000?094000800000100I
000010000000S00008`0002<00050<8000D0e00010000008094000030000003K0000f`0001d0f`00
00<00000001Ia`00FLL01`00FLL200000003001Ia`000000oooo01L0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`130?ooo`00@`3oool2000004P0oooo00<00000000<6@0031T00P00
00001@0031T0000000000000FLL00000018005W700<00000001Ia`00FLL01@00FLL2000000@005W7
00<00000001Ia`00FLL00`00FLL00`0000006@000000000200000080e00000<000000=/0003K0000
8@3K00000`000000f`000=/000020=/000030000003S0000h`0000<0h`000P3j000@094000030000
000I00006@0000<06@0000@0000008`0002<0000S0001@3200070=@0008000002P2A00000`000000
f`000=/0000M0=/0000300000000FLL005W700P005W70`00000G0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0@`3oool004<0oooo0P0000170?ooo`030000000031T000`I00800000
00<000`I0000000000000`00FLL00`00000005W7001Ia`0=001Ia`8000002@00FLL2000000<005W7
00<00000001Ia`00FLL00P00FLL01@0000006@000000000I0000000000@0e00000<000000=/0003K
00007`3K00000`000000f`000=/000040=/000030000003S0000h`0000<0h`000P3j000=09400080
00001@0I000010000000S00008`0002<00050<8000L0e00000<000000=/0000000002`2A00000`00
0000f`000=/0000M0=/0000300000000FLL005W700X005W700<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo00130?ooo`<00000A@3oool00`000000
00`I000<6@0200000003000<6@000000000000D005W700<00000001Ia`00FLL02`00FLL00`000000
05W7001Ia`0:001Ia`0500000000FLL005W7001Ia`0000000`00FLL01@0000006@000000000I0000
000000H0e00000<000000=/0003K00007@3K00000`000000f`000=/000060=/000030000003S0000
h`0000<0h`000P3j000:0940008000001P0I000010000000S00008`0002<00050<8000L0e00000D0
00000=/0003K0000f`000000000;094000030000003K0000f`0001d0f`0000<00000001Ia`00FLL0
2000FLL2000001H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`130?ooo`00@`3o
ool2000002@0oooo00<000000?ooo`3oool07P3oool00`00000000`I000<6@05000000L005W700<0
0000001Ia`00FLL02@00FLL00`00000005W7001Ia`0<001Ia`0400000000FLL005W70000008005W7
0`0000000`0I000000000=@000070=@000030000003K0000f`0001/0f`0000<000000=/0003K0000
1`3K0002000000@0h`000`3j00070940008000001`0I000010000000S00008`0002<00050<8000L0
e00000<000000=/0003K00000`3K00000`000000T@0009400009094000030000003K0000f`0001`0
f`0000<00000001Ia`00FLL01`00FLL01000000005W7001Ia`00001<0?ooo`030000003oool0oooo
04<0oooo00130?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool00`000000
00`I00000005000000T005W700<00000001Ia`00FLL01`00FLL00`00000005W7001Ia`0>001Ia`03
00000000FLL0000000<000000P0I00000`000000e0000=@000080=@000030000003K0000f`0001T0
f`0000<000000=/0003K00002@3K0002000000@0h`000`3j00040940008000001`0I00000`3K0000
000008`0000208`000D0`P001`3D00000`000000f`000=/000050=/000`0T@0000<000000=/0003K
0000703K00000`00000005W7001Ia`05001Ia`0300000000FLL005W7008005W700<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01`0oooo00@00000000<6@00000000`I1000000;001Ia`0300000000FLL005W700D0
05W700<00000001Ia`00FLL04000FLL4000000806@0000<000000=@0003D00002P3D00000`000000
f`000=/0000G0=/000030000003K0000f`0000/0f`000P0000040><000<0nP0000<0T@0000000000
0000200I00000`3K0000000008`0000208`000D0`P001`3D00000`000000f`000=/000070=/000/0
T@0000<000000=/0003K00007@3K00000`00000005W7001Ia`03001Ia`0300000000FLL005W700@0
05W700<000000?ooo`3oool0SP3oool004<0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0K0?ooo`030000000031T000000080000000<000`I0000000000003@00FLL00`00000005W7
001Ia`03001Ia`0300000000FLL005W7014005W70`00000201T000030000003D0000e00000/0e000
00<000000=/0003K00005P3K00000`000000f`000=/0000=0=/000030000003S0000h`0000<0h`00
0`3j000901T000030=/000000000S0000080S0001@3200070=@000030000003K0000f`0000T0f`00
00<000000940002A0000202A00000`000000f`000=/0000M0=/0000500000000FLL005W7001Ia`00
00002000FLL00`000000oooo0?ooo`2=0?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01X0oooo00<00000000<6@0000000P0000000`0031T000000000000?001Ia`050000
0000FLL005W7001Ia`0000004`00FLL3000000806@0000<000000=@0003D00003@3D00000`000000
f`000=/0000D0=/000030000003K0000f`0000l0f`0000<000000><0003S00000`3S00030?X000P0
6@0000@0000008`0002<0000S0001@3200070=@000030000003K0000f`0000X0f`0000<000000940
002A00002@2A00000`000000f`000=/0000M0=/0000300000000FLL0000000X005W700<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01T0oooo00<00000000<6@0000001@00000A001Ia`0300000000FLL0000001<0
05W70`00000201T000030000003D0000e00000l0e00000<000000=/0003K00004P3K00000`000000
f`000=/0000A0=/000030000003S0000h`0000<0h`000`3j000601T000040000002<0000S00008`0
00D0`P001`3D00000`000000f`000=/0000<0=/000030000002A0000T@0000T0T@0000<000000=/0
003K00007@3K00000`00000005W7001Ia`0:001Ia`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0NP3oool004<0oooo00<000000?ooo`3oool0?P3oool300000005000<6@0000000000000<
6@0000004`00FLL00`00000005W7001Ia`0A001Ia`<000000P0I00000`000000e0000=@0000A0=@0
00030000003K0000f`000100f`0000<000000=/0003K00004`3K00000`000000h`000><000030><0
00<0nP00100I000010000000S00008`0002<00050<8000L0e00000<000000=/0003K00003P3K0000
0`000000T@0009400009094000030000003K0000f`0001d0f`0000<00000001Ia`00FLL02P00FLL0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@`3oool0
04<0oooo00<000000?ooo`3oool0?@3oool300000005000<6@0000000000000<6@0000004`00FLL0
0`00000005W70000000A001Ia`<0000000<06@000000000000005@3D00000`000000f`000=/0000>
0=/000030000003K0000f`0001D0f`0000<000000><0003S00000`3S00030?X000030000000I0000
000000<0S0001@3200070=@000030000003K0000f`000100f`0000<000000940002A00002@2A0000
0`000000f`000=/0000M0=/0000300000000FLL005W700T005W700<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo
03`0oooo1P0000000`0031T00000001Ia`0B001Ia`0500000000FLL005W7001Ia`0000003`00FLL2
000000806@0000<000000<H0003D00005P3D00000`000000f`000=/0000<0=/000030000003K0000
f`0001L0f`0000<000000><0003S00000`3S00020?X000H00000103200070=@000030000003K0000
f`000180f`0000<000000940002A00002@2A00000`000000f`000=/0000K0=/0008000003000FLL0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@`3oool0
04<0oooo00<000000?ooo`3oool0>`3oool01@00000000`I00000000000000`I00<000004`00FLL0
0`00000005W7001Ia`03001Ia`0300000000FLL005W700/005W70P00000201T00004000000360000
aP000<H001L0e00000<000000=/0003K00002P3K00000`000000f`000=/0000I0=/000030000003S
0000h`0000<0h`0000<0000008l000000000102?00000`000000`P000<8000070=@000030000003K
0000f`0001@0f`0000<000000940002A00002@2A00000`000000f`000=/0000I0=/000040000003R
0000hP00000000`005W700<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo04<0oooo00130?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0503o
ool400000005000<6@0000000000001Ia`0000004P00FLL00`00000005W7001Ia`05001Ia`030000
0000FLL005W700T005W700<0000001T0000000000P0000050<H001H0e00000<000000=/0003K0000
2@3K00000`000000f`000=/0000K0=/000050000003S0000h`000><0000000000`2?00000`000000
S`0008l0000208l000030000003D0000e00000D0e00000<000000=/0003K00005@3K00000`000000
T@0009400009094000030000003K0000f`0001P0f`0000<000000>80003R00000P3R00000`000000
05W7001Ia`0:001Ia`030000003oool0oooo0440oooo00<000000?ooo`3oool0@`3oool004<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`80000000<000`I0000000031T0
0P000003001Ia`0300000000FLL005W700h005W700<00000001Ia`00FLL01`00FLL00`00000005W7
001Ia`07001Ia`040000000I00006@00000000P0aP005P3D00000`000000f`000=/000070=/00003
0000003K0000f`0001d0f`0000<000000><0000000001@2?00000`000000S`0008l0000208l00003
0000003D0000e00000<0e00000<000000=/0003K00005`3K00000`000000T@000940000909400003
0000003K0000f`0001H0f`0000<000000>80003R00000`3R00000`00000005W7001Ia`0;001Ia`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0@`3oool004<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0B0?ooo`80000000<000`I0000000000000P000005001Ia`030000
0000FLL005W700/005W70P00000;001Ia`0300000000FLL005W700D005W700@0000001T0000I0000
00002P36000F0=@000030000003K0000f`0000D0f`0000<000000=/0003K00007P3K0002000000L0
S`0000<0000008l0002?00000P2?00001@000000e0000=@0003D0000000001/0f`0000<000000940
002A00002@2A00000`000000f`000=/0000D0=/000030000003R0000hP0000D0hP0000<00000001I
a`00FLL02`00FLL00`000000oooo0?ooo`250?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0140oooo0P0000000`0031T0000000000002000000L005W700<00000001Ia`00
FLL02@00FLL00`00000005W7001Ia`0<001Ia`0300000000FLL005W700<005W700@0000001T00000
000000003036000F0=@000030000003K0000f`0000<0f`0000<000000=/0003K00007P3K00000`00
0000S`0008l0000808l000030000002?0000S`000080S`000`00000M0=/000030000002A0000T@00
00T0T@0000<000000=/0003K00004P3K00000`000000hP000>8000070>80000300000000FLL005W7
00/005W70P0000250?ooo`00@`3oool3000002<0oooo00<000000?ooo`3oool03`3oool300000003
000<6@00000000`I008000002@00FLL00`00000005W7001Ia`07001Ia`0300000000FLL005W700h0
05W700L00000001Ia`00FLL005W70000000I0000000000l0aP005P3D00001@000000f`000=/0003K
000000000200f`0000<0000008l0002?00002P2?000200000080S`000P00000O0=/000030000002A
0000T@0000T0T@0000<000000=/0003K0000403K00000`000000hP000>8000090>80000300000000
FLL005W700T005W70P0000090?ooo`030000003oool0oooo07X0oooo00130?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03P3oool00`00000000`I00000005000000/005W700<00000
001Ia`00FLL01@00FLL00`00000005W7001Ia`0@001Ia`<0000000<06@000000003600004036000F
0=@000030000003K000000000200f`0000<0000008l0002?00002@2?00060000000308l000000000
f`0001l0f`0000<000000940002A00002@2A00000`000000f`000=/0000>0=/000030000003R0000
hP0000X0hP0000<00000001Ia`00FLL02000FLL01000000005W7001Ia`0000080?ooo`030000003o
ool0oooo07X0oooo00130?ooo`030000003oool0oooo03<0oooo00<00000000<6@0000000`000000
0`0031T00000001Ia`0<001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL04@00FLL4
000001<0aP005@3D000200000200f`0000<0000008l0002?0000202?00020000008003[=00<00000
001HfP0000000`2?00000`000000f`000=/0000N0=/000030000002A0000T@0000T0T@0000<00000
0=/0003K0000303K00000`000000hP000>80000<0>80000300000000FLL005W700H005W700<00000
001Ia`00FLL00P00FLL00`000000oooo0?ooo`050?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0@`3oool004<0oooo00<000000?ooo`3oool0<P3oool00`00000000`I000000030000
0003000<6@00000005W700d005W700<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`0A001I
a`040000000I000000000:/001D0aP004`3D00000`000000f`000=/0000O0=/000040000002?0000
S`00000000H0S`000P000004000jc@0400000000F=X005SJ000000<0S`0000<000000=/0003K0000
7@3K00000`000000T@0009400009094000030000003K0000f`0000/0f`0000<000000>80003R0000
3P3R00000`00000005W7001Ia`04001Ia`0300000000FLL005W700@005W700<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo00130?ooo`030000003o
ool0oooo0340oooo00@00000000<6@00000000`I0P0000000`0031T00000001Ia`0?001Ia`040000
0000FLL005W7000001<005W70`0000030:/001@0aP004P3D00000`000000f`000=/0000O0=/00003
0000002?0000S`0000H0S`000P0000000`00>/d00000000jc@03000jc@0500000000F=X005SJ001H
fP0000000`2?00000`000000f`000=/0000M0=/000030000002A0000T@0000T0T@0000<000000=/0
003K00002@3K00000`000000hP000>80000?0>80000300000000FLL005W700<005W700<00000001I
a`00FLL01P00FLL00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0@`3oool004<0oooo00<000000?ooo`3oool0<03oool300000005000<6@0000000000000<
6@0000004P00FLL2000001<005W70P0000060:/001@0aP00403D00000`000000f`000=/0000O0=/0
008000001P2?0002000000<003[=00<00000000jc@00>/d00P00>/d00`00000005SJ001HfP02001H
fP050000002?0000S`0008l0000000007`3K000010000000T@000940003K0008094000030000003K
0000f`0000L0f`0000<000000>80003R00004@3R00001@00000005W7001Ia`00FLL0000000X005W7
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00T0oooo0`0000001@0031T000000000000031T0000001<005W7
0P00000B001Ia`800000202[000D0<H000h0e00000<000000=/0003K00007`3K00001`00000006kO
000000000000S`000000002?00000`000005000jc@0500000000>/d003[=000jc@0000001000F=X0
0`000000S`0008l0000208l000030000003K0000f`0001d0f`0000<000000940002A00002@2A0000
0`000000f`000=/000050=/000030000003R0000hP0001<0hP0000<00000001Ia`0000003000FLL0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool300000005000<6@0000000000000<6@0000004`00FLL0
1000000005W7001Ia`00000@001Ia`030000002[0000Z`0000T0Z`005036000<0=@000030000003K
0000f`0001l0f`0000<00000001^g`0000000P0000000`2?0000000000000002000jc@0300000000
>/d003[=00<003[=00D00000000jc@00>/d003[=00000005001HfP030000002?0000S`000080S`00
00<000000=/0003K00007@3K00000`000000T@0009400009094000030000003K0000f`0000<0f`00
00<000000>80003R0000503R0002000000h005W700<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`130?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00@0
0000000<6@00000000`I0P0000000`0031T00000001Ia`0B001Ia`0300000000FLL005W7008005W7
00<00000001Ia`00FLL03000FLL00`000000Z`000:/0000;0:/001@0aP002P3D000200000200f`00
00<00000001^g`00K]l00P0000000`2?0000000000000003000jc@03001Ia`00000003[=00<003[=
00<00000000jc@00>/d00P000006001HfP030000002?0000S`000080S`0000<000000=/0003K0000
7@3K00000`000000T@0009400009094000050000003K0000f`000=/0000000005P3R00000`3c0000
00000000000>001Ia`030000003oool0oooo07d0oooo00130?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01P3oool01000000000`I0000000031T4000001<005W700<00000001Ia`00
FLL01000FLL00`00000005W7001Ia`0:001Ia`8000003P2[000D0<H000P0e00000@000000=@0003D
000000007P3K00001`00000006kO001^g`000000S`000000002?00001P00>/d00`00000003[=000j
c@03000jc@80000000<003oF00000000F=X01@00F=X2000000@0S`0000<000000=/0003K00007@3K
00000`000000T@0009400009094000030000003K0000000001H0hP000P3c00000`00000005W70000
000>001Ia`030000003oool0000007`0oooo00130?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool01@3oool01000000000`I0000000031T300000003001Ia`00000005W7014005W700<0
0000001Ia`00FLL01@00FLL00`00000005W7001Ia`09001Ia`80000000<0QP000000002[00003@2[
000D0<H000H0e00000<000000=@0003D00000P3D00000`000000f`000=/0000J0=/00080000000H0
06kO0000002?00000000000jc@000006000jc@0300000000>/d003[=008003[=0P000002000oeP03
00000000F=X005SJ00<005SJ00<00000001HfP0000001@2?00000`000000f`000=/0000M0=/00003
0000002A0000T@0000P0T@000P00000F0>8000@0l`0000<00000001Ia`0000003P00FLL2000007`0
oooo00130?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool01000000000`I
0000000031T300000004001Ia`00000005W70000010005W700<00000001Ia`00FLL01`00FLL00`00
000005W7001Ia`07001Ia`8000000`2600000`000000Z`000:/0000<0:/001@0aP00103D00000`00
0000e0000=@000040=@000030000003K0000f`0001P0f`0000<00000001^g`00K]l00`000003000j
c@0300000000>/d003[=00<003[=00<00000000jc@00>/d00P0000001@00?mH00000000oeP00?mH0
000000<005SJ0P000003001HfP030000002?0000S`000080S`0000<000000=/0003K00007P3K0000
0`000000T@0009400004094000<0000000<0T@000000003R0000503R00050?<0000400000000FLL0
05W7000000h005W700<000000?ooo`3oool0=03oool00`000000oooo0?ooo`130?ooo`00@`3oool0
0`000000oooo0?ooo`0Y0?ooo`040000000031T00000000<6@<000000P00FLL01000000005W7001I
a`00000>001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL01@00FLL2000000D0QP00
00<000000:/0002[0000302[000D0<H00080e00000<000000<H0003D00001P3D00000`000000f`00
0=/0000F0=/0000400000000K]l006kO001^g`<000000`00>/d00`00000003[=000jc@04000jc@80
00001000?mH01P00000003oF000oeP00000005SJ000000H005SJ00<0000008l0002?00000P2?0000
0`000000f`000=/0000N0=/000040000002A0000T@00094000<00000102A00000`000000hP000>80
000A0>8000H0l`0000D00000001Ia`00FLL005W70000000>001Ia`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0@`3oool004<0oooo00<000000?ooo`3oool0:03oool01`00000000`I0000
000031T00000000<6@0000000`00FLL01@00000005W7001Ia`00FLL0000000`005W700<00000001I
a`00FLL02`00FLL00`00000005W7001Ia`03001Ia`03000000260000QP0000H0QP0000<000000:/0
002[00002`2[000D0<H0008000000`3600070=@000030000003K0000f`0001@0f`0000<00000001^
g`00K]l00P00K]l00`000000f`0000000003000jc@0300000000>/d003[=00<003[=0P000005000o
eP0300000000?mH003oF008000002000F=X00`000000S`0008l0000208l000030000003K0000f`00
01h0f`0000@0000009400000000000001`2A00000`000000hP000>80000?0>8000L0l`0000<00000
001Ia`00FLL00P00FLL00`00000005W7001Ia`0<001Ia`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0@`3oool004<0oooo0`00000W0?ooo`070000000031T00000000<6@00000000`I0000
0003001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL02000FLL00`00000005W7001I
a`0=001Ia`0500000000FLL005W7001Ia`0000002P2600000`000000Z`000:/0000;0:/00180aP00
00<000000<H0003600000`3600000`000000e0000=@000050=@000030000003K0000f`000180f`00
00<00000001^g`00K]l00`00K]l010000000f`000=/000000003000jc@0300000000>/d000000080
000000<003oF00000000?mH01000?mH01000000003oF00000000000:001HfP030000002?0000S`00
0080S`0000<000000=/0003K00007P3K00000`000000T@0009400007094000030000003R0000hP00
00h0hP00203c00000`00000005W7001Ia`03001Ia`0300000000FLL005W700`005W70P00000c0?oo
o`030000003oool0oooo0480oooo00130?ooo`030000003oool0oooo02H0oooo00<00000000<6@00
00000P0000000`0031T00000001Ia`03001Ia`0300000000FLL005W700@005W700<00000001Ia`00
FLL01P00FLL00`00000005W7001Ia`0?001Ia`0300000000FLL0000000`0QP0000<000000:/0002[
00002`2[000@0<H00003000000360000aP0000D0aP0000<000000=@0003D00001@3D00000`000000
f`000=/0000@0=/0000300000000K]l006kO00<006kO00D0000008l000000000f`0000000002000j
c@<000001000?mH00`00000003oF000oeP03000oeP@000002`00F=X00`000000S`0008l0000208l0
00030000003K0000f`0001`0f`0000<000000940000000002@2A00000`000000hP000>80000<0>80
00X0l`0000<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`0<001Ia`800000<`3oool00`00
0000oooo0?ooo`120?ooo`00@`3oool00`000000oooo0?ooo`0S0?ooo`040000003oool00000000<
6@<0000000<000`I00000000FLL00`00FLL00`00000005W7001Ia`05001Ia`8000001P00FLL00`00
000005W7001Ia`0A001Ia`03000000260000QP0000`0QP0000<000000:/0002[00002`2[000=0<H0
008000000P2/00070<H000030000003D0000e00000@0e0000P00000@0=/0000300000000K]l006kO
00<006kO00@0000008l0002?0000S`000P0000001000>/d00000000oeP000006000oeP0300000000
?mH003oF00@0000000<004GP00000000F=X02`00F=X00`000000S`0008l0000208l000030000003K
0000f`0001X0f`0000@000000>80003R000000002P2A00000`000000hP000>80000:0>8000/0l`00
00<00000001Ia`00FLL00`00FLL00`00000005W7001Ia`0:001Ia`0300000000FLL0000003<0oooo
00<000000?ooo`3oool0@P3oool004<0oooo00<000000?ooo`3oool08`3oool600000003000<6@00
000005W700@005W700<00000001Ia`00FLL01P00FLL2000000@005W700<00000001Ia`00FLL04@00
FLL00`000000QP0008H0000>08H000030000002[0000Z`0000/0Z`002`360002000000@0[0001`36
00000`000000e0000=@000040=@000030000003K0000f`0000d0f`000P000005001^g`030000002?
0000S`000080S`000P000003000oeP0300000000?mH003oF00<003oF1@0000001@00AN0000000015
h000AN00000000/005SJ0P00000408l000030000003K0000f`0001P0f`0000<000000>80003R0000
0P3R00000`000000T@0009400008094000030000003R0000hP0000P0hP00303c00000`00000005W7
001Ia`04001Ia`0300000000FLL005W700P005W700D00000001Ia`00FLL005W70000001g0?ooo`00
@`3oool00`000000oooo0?ooo`0S0?ooo`D0000000<000`I00000000FLL01000FLL00`00000005W7
001Ia`08001Ia`8000000P00FLL00`00000005W7001Ia`0A001Ia`03000000260000QP000100QP00
00<000000:/0002[00002`2[00090<H00004000000280000R000000000@0[0001`3600000`000000
e0000=@000040=@000030000003K0000f`0000/0f`0000<00000001^g`0000001000K]l00`000000
oooo0000000408l0000500000000?mH003oF000oeP0000001000?mH3000000D004GP00<000000015
h00000002P00F=X01000000005SJ001HfP00000408l000030000003K0000f`0001H0f`0000<00000
0>80003R0000103R00000`000000T@0009400007094000030000003R0000hP0000L0hP003@3c0000
0`00000005W7001Ia`05001Ia`0300000000FLL005W700H005W700<00000001Ia`00FLL00`00FLL0
0`000000oooo0?ooo`1d0?ooo`00@P3oool00`000000oooo0?ooo`0S0?ooo`80000000D000`I0000
0000000000`I00000006001Ia`0300000000FLL005W700T005W70`00000C001Ia`03000000260000
QP000140QP0000<000000:/0002[0000302[00060<H000800000102800000`000000[0000:`00002
0:`000L0aP0000<000000=@0003D0000103D00000`000000f`000=/000090=/0000400000000K]l0
06kO000000<006kO00D000000?ooo`3oool0oooo0000000408l0000500000000?mH003oF00000000
?mH0100000000`00AN0000000015h0050015h08000002@00F=X00`00000005SJ001HfP02001HfP03
0000002?0000S`000080S`0000<000000=/0003K0000503K00000`000000hP000>8000050>800003
0000002A0000T@0000P0T@0000<000000>80003R00001@3R000=0?<0000300000000FLL005W700L0
05W700<00000001Ia`00FLL01000FLL00`00000005W7001Ia`05001Ia`030000003oool0oooo07<0
oooo00120?ooo`8000008P3oool600000003000<6@00000005W700H005W700<00000001Ia`00FLL0
2P00FLL20000018005W700<0000008H0002600004`2600000`000000Z`000:/0000<0:/000@0aP00
00<0000008P0002800001@2800000`000000[0000:`000020:`000L0aP001`3D00000`000000f`00
0=/000070=/0000300000000K]l006kO008006kO00<00000001^g`0000001@3oool00`000000S`00
08l0000208l0000300000000?mH0000000<000001000AN000`00000004GP0015h0030015h0030000
0000AN00000000H005SJ0P000006001HfP030000002?0000S`000080S`0000<000000=/0003K0000
4P3K00000`000000hP000>8000050>8000030?<000000000T@0000X0T@0000<000000>80003R0000
0`3R000=0?<0000300000000FLL005W700T005W700<00000001Ia`00FLL00P00FLL00`00000005W7
001Ia`07001Ia`030000003oool0oooo0780oooo00120?ooo`8000008@3oool01000000000`I0000
000031T200000003000<6@00000005W700H005W700<00000001Ia`00FLL02`00FLL20000014005W7
00<0000008H0002600005@2600000`000000Z`000:/0000<0:/00080aP0000<0000008P000280000
1`2800000`000000[0000:`000020:`000L0aP001`3D00000`000000f`000=/000050=/000030000
0000K]l006kO00<006kO0P0000070?ooo`030000002?0000S`000080S`000`0000060015h0030000
0000AN0004GP00<004GP0`000005001HfP0300000000F=X005SJ00L005SJ00<0000008l0002?0000
0P2?00000`000000f`000=/0000@0=/000030000003R0000hP0000D0hP000`3c00000`000000T@00
09400008094000030000003R0000hP000080hP003@3c00000`3L00000000001Ia`0;001Ia`040000
0000FLL005W7000000/005W700<000000?ooo`3oool0;03oool00`000000oooo0?ooo`120?ooo`00
@P3oool200000200oooo00@00000000<6@00000000`I0P0000000`0031T00000001Ia`07001Ia`03
00000000FLL005W700X005W700@00000001Ia`00FLL000003`00FLL00`000000QP0008H0000G08H0
00030000002[0000Z`0000X0Z`000`00000;08P000030000002/0000[0000080[0001P3600000`00
0000e0000=@000050=@000030000003K0000f`0000<0f`0000<00000001^g`00K]l00`00K]l20000
00T0oooo00L0000008l0002?0000S`0000000000AN00000000H004GP00<000000015h000AN000`00
00001000C>/00000001<j`000003001HfP0300000000F=X005SJ00P005SJ00<0000008l0002?0000
0P2?00000`000000f`000=/0000?0=/000030000003R0000hP0000D0hP00103c00000`000000T@00
09400009094000030000003R0000hP0000d0l`0000<0g00000000000FLL03@00FLL2000000d005W7
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`120?ooo`00@P3oool2000001l0oooo00<0
0000000<6@0000000`0000000`0031T00000001Ia`07001Ia`0300000000FLL005W700H005W70P00
0003001Ia`0500000000FLL005W7001Ia`0000003@00FLL00`000000QP0008H0000I08H000030000
002[0000Z`0000T0Z`0000<0000008P0002800003028000010000000[0000:`0002/00070<H00003
0000003D0000e00000D0e00000D000000=/0003K0000f`0000000005001^g`030000003oool0oooo
00X0oooo00@0000008l0002?000000000P00AN000`00000004GP0015h0030015h0<000001@00C>/0
1@00000004c[00000000F=X0000000`005SJ00<0000008l0002?00000P2?00000`000000f`000=/0
000=0=/000030000003R0000hP0000D0hP00103c00000`000000T@000=/0000;094000030000003c
0000l`0000/0l`0000<0g00000000000FLL03P00FLL00`00000005W7001Ia`0<001Ia`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0@P3oool00480oooo0P00000N0?ooo`080000000031T0
00000000000031T00000000<6@000009001Ia`0300000000FLL005W700X005W700<00000001Ia`00
FLL00`00FLL00`00000005W7001Ia`09001Ia`800000702600000`000000Z`000:/000060:/00080
00004028000010000000[0000:`0002/00070<H000030000003D0000e00000D0e00000<000000=/0
000000001000K]l2000000d0oooo00L0000008l0002?0000S`0000000000AN00000000<004GP0P00
00000`00C>/00000001<j`06001<j`0400000000C>/00000000000d005SJ00<0000008l0002?0000
0P2?00000`000000f`000=/0000;0=/000030000003R0000hP0000D0hP00103c00000`000000T@00
0940000<094000030000003c0000l`0000X0l`0000@0g00000000000000000003@00FLL00`000000
05W70000000>001Ia`030000003oool0oooo02X0oooo00<000000?ooo`3oool0@P3oool00480oooo
0P00000M0?ooo`070000000031T000000000000031T00000000<6@02000000P005W700<00000001I
a`00FLL02`00FLL00`00000005W7001Ia`04001Ia`0300000000FLL005W700L005W700@0000001T0
000000000000702600000`000000Z`000:/000030:/0008000004P2800000`2/000000000:`00002
0:`000L0aP0000<000000=@0003D00001@3D000300000004001^g`0000000000000000l0oooo00@0
000008l0002?0000S`000P0000000`00AN00000000000004001<j`0300000000C>/004c[00@004c[
0P000002001Dm`0300000000F=X005SJ00X005SJ0P00000408l000030000003K0000f`0000T0f`00
00<000000>80003R00001@3R00040?<000030000002A0000000000@0T@0000<0f`000940002A0000
1P2A00000`000000l`000?<000090?<000050=`000000000057`001Al00000003000FLL01@000000
05W7001Ia`00FLL0000000h005W700<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`120?oo
o`00@P3oool00`000000oooo0?ooo`0K0?ooo`@0000000H000`I0000000031T00000001Ia`000008
001Ia`0300000000FLL005W700/005W700<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`05
001Ia`040000003oool0oooo01T000800000702600001P000000Z`000:/0002[000000000:/001@0
R00000<000000:`0002/00000P2/00070<H000030000003D0000e00000<0e00000<00000001^g`00
K]l00`00000B0?ooo`040000002?0000S`0008l0008000001`00C>/00`00000004c[001<j`030000
008005Cg00@00000001Dm`00E?L000002P00F=X01000000005SJ001HfP00000408l000030000003K
0000f`0000L0f`0000<000000>80003R00001@3R00040?<000050000002A0000T@00094000000000
3@2A00000`000000l`000?<000070?<000030=`000000000057`00<0057`00<00000001Ia`00FLL0
2000FLL00`00000005W7001Ia`03001Ia`0300000000FLL005W700`005W700<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`0J0?ooo`80000000<0
00`I0000000031T02@000005001Ia`0300000000FLL005W700X005W700<00000001Ia`00FLL01`00
FLL00`00000005W7001Ia`03001Ia`040000003oool0oooo0?ooo`806@0000<0000008H000260000
6`2600000`000000Z`000000000G08P000030000002/0000[0000080[0001`36000010000000e000
0=@0003D0005000001D0oooo00<0000008l0002?00000P000007001<j`<000002000E?L3000000L0
05SJ00<00000001HfP00F=X00P00F=X00`000000S`0008l0000208l000030000003K0000f`0000D0
f`0000<000000>80003R00001@3R00040?<000030000002A0000T@0000<0T@0000<000000940002A
00000`2A00000`3K0000T@0009400004094000030000003c0000l`0000H0l`0000<0g00000000000
DO001@00DO000`00000005W7001Ia`06001Ia`0300000000FLL005W700D005W700<00000001Ia`00
FLL03000FLL00`000000oooo0?ooo`1/0?ooo`00@P3oool00`000000oooo0?ooo`0I0?ooo`800000
00<000`I0000000031T00P0000001@00C_@00000001Ia`00FLL0000000<005W730000006001Ia`03
00000000FLL005W700P005W700D00000001Ia`00FLL005W7000000050?ooo`806@0000<0000008H0
002600006P260002000001T0R00000<000000:`0002/00000P2/00070<H000030000003D00000000
00<00000603oool00`000000S`0008l00002000000@004c[0P000002001Dm`0300000000E?L005Cg
00@005Cg0`000002001Lo`8000001000F=X00`00000005SJ001HfP04001HfP030000002?0000S`00
0080S`0000<000000=/0003K00000`3K00000`000000hP000>8000050>8000@0l`0000<000000940
002A0000102A00000`000000T@000940000:094000030000003c0000l`0000D0l`0000@0g0000000
0000DO0000001P00DO000`00000005W7001Ia`04001Ia`0300000000FLL005W700L005W700<00000
001Ia`00FLL03000FLL00`000000oooo0?ooo`1[0?ooo`00@P3oool4000001L0oooo0P0000001000
31T00000000<6@000004001>m00300000000FLL0000000L005W700<00000001Ia`00FLL01@00FLL=
000000D005W700<00000001Ia`0000001`3oool201T00003000000260000QP0001L0QP000P00000L
08P000030000002/0000[0000080[0001P36000200000003001llP000000oooo01X0oooo00<00000
08l0002?00000P0000000`00C>/0000000000005001Dm`0400000000E?L005Cg001Dm`8000000`00
G?l01@00000005co001Lo`00G?l00000008005SJ00<00000001HfP00F=X01P00F=X508l000050000
003K0000f`000=/0000000001`3R00040?<000030000002A0000T@0000H0T@0000<000000940002A
00002P2A00000`000000l`000?<000030?<000050=`000000000057`001Al00000001`00DO000`00
000005W7001Ia`02001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL03000FLL00`00
0000oooo0?ooo`1Z0?ooo`00@P3oool2000001P0oooo0P000000100031T00000000000000006001>
m08000002000FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W700D005W71`0000090?oo
o`806@0000<0000008H000260000502600020000000301T000000000R00001`0R00000<000000:`0
002/00000P2/00040<H000<000007P3oool00`000000S`0008l00003000000L005Cg00<00000001D
m`0000002@00G?l4000000T005SJ1@2?00000`000000f`00000000070>8000@0l`0000<000000940
002A0000202A00000`000000T@0009400009094000030000003c0000l`000080l`0000<0g0000000
0000DO000`00DO000`000000057`001Al005001Al00400000000FLL005W7000000d005W700<00000
001Ia`00FLL03000FLL00`000000oooo0?ooo`1Y0?ooo`00@P3oool2000001L0oooo0P0000001@00
31T0000000000000C_@0000000L004kd00<00000001Ia`00FLL01P00FLL00`00000005W7001Ia`0:
001Ia`0300000000FLL005W700P005W700<00000001Ia`0000002P3oool201T00003000000260000
QP000180QP0000H000000?ooo`3oool0oooo01T00000000M08P000030000002/0000[0000080[000
0P36000200000200oooo00@0000008l0002?0000S`000P00E?L00`00000005Cg001Dm`04001Dm`<0
00001`00G?l3000000<006?o0`000007001HfP<0S`000`0000070>8000@0l`0000<000000940002A
00002P2A00000`000000T@0009400008094000060000003c0000l`000?<0003L000000001P00DO00
0`000000057`001Al005001Al08000003P00FLL00`00000005W7001Ia`0;001Ia`8000009P3oool0
0`000000oooo0?ooo`120?ooo`00@P3oool2000001H0oooo10000004001>m00300000000C_@004kd
00D004kd00<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`0:001Ia`0300000000FLL005W7
00L005W700D00000001Ia`00FLL005W70000000:0?ooo`0301T00000000000000140QP000P000005
0?ooo`0301T000000000R00001`0R00000@000000:`0002/0000[0000P00000S0?ooo`040000002?
0000S`0008l0008005Cg00<00000001Dm`00E?L00`000003001Lo`0300000000G?l005co008005co
0P000003001So`8000000`00Hol4000000D005SJ0P00000208l000030000003R0000hP0000@0hP00
103c00000`000000T@000940000<094000030000002A0000T@0000P0T@0000@000000?<0003L0000
00002000DO0010000000057`001Al000DO05000000l005W700<00000001Ia`00FLL02@00FLL01000
000005W7001Ia`00000U0?ooo`030000003oool0oooo0480oooo00120?ooo`8000005@3oool30000
0003001>m000000004kd00@004kd00<00000001>m000C_@01@00C_@00`00000005W7001Ia`05001I
a`0300000000FLL005W700T005W700<00000001Ia`00FLL01P00FLL00`00000005W7001Ia`03001I
a`030000003oool0oooo00L0oooo0P0I00000`000000QP0008H0000=08H000800000203oool00`0I
0000000008P0000L08P000030000002/0000000002H0oooo00@0000008l0002?0000S`000P00E?L2
000000L005co00@00000001Lo`00000000002@00Hol00`00000006So001Xo`02001Xo`@000000P00
F=X01@000000S`0008l0002?0000000000@0hP00103c00000`000000T@000940000>094000030000
002A0000T@0000L0T@0000D000000=`000000000057`00000008001Al0<000001000DO000`000000
05W7001Ia`0>001Ia`0300000000FLL005W700L005W700@00000001Ia`00FLL005W70P00000T0?oo
o`030000003oool0oooo0480oooo00120?ooo`800000503oool2000000@004kd00<00000001>m000
C_@00`00C_@00`00000004kd001>m005001>m00300000000FLL005W700@005W700<00000001Ia`00
FLL02P00FLL00`00000005W7001Ia`04001Ia`0300000000FLL005W700D005W700<000000?ooo`3o
ool01`3oool201T00003000000260000QP0000X0QP000P00000;0?ooo`0301T000000000R00001/0
R0000P00000X0?ooo`050000002?0000S`0008l0000000000P00G?l00`00000005co001Lo`04001L
o`@000001`00Hol4000000L006So0`00000408l000030000003R0000hP0000@0l`0000<000000940
002A0000402A00000`000000T@00094000060940008000000`00DO000`000000057`001Al004001A
l0<000001P00DO000`00000005W7001Ia`0>001Ia`0300000000FLL005W700D005W700<00000001I
a`00FLL00P00FLL00`00000005W70000000S0?ooo`030000003oool0oooo0480oooo00120?ooo`80
00004`3oool2000000H004kd00<00000001>m000C_@00`00C_@01@00000004kd001>m000C_@00000
00<004kd00<00000001Ia`00FLL01000FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W7
00<005W700<00000001Ia`00FLL01`00FLL00`000000oooo0?ooo`070?ooo`806@0000<0000008H0
002600001`260002000000h0oooo00<06@0000000028000060280002000002/0oooo00D000000=/0
002?0000S`0000000002001Lo`0300000000G?l005co00@000000`00Hol20000008006?o0`000004
001Xo`<000000P00J?l300000080S`0000<0000008l0002?00000P2?00000`000000l`000?<00002
0?<000030000002A0000T@000180T@0000<000000940002A0000102A0002000000D0057`00<00000
001Al000DO000`000003001Al00300000000DO00057`00@0057`00<00000001Ia`00FLL03P00FLL0
0`00000005W7001Ia`03001Ia`0300000000FLL005W700@005W700<00000001Ia`0000008P3oool0
0`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`0A0?ooo`0300000000C_@00000
00L004kd00<00000001>m000C_@00`00C_@01000000004kd001>m0000004001>m00300000000FLL0
05W700<005W700<00000001Ia`00FLL02P00FLL01@00000005W7001Ia`00FLL0000000/005W700<0
00000?ooo`3oool01`3oool201T00003000000260000QP0000D0QP0000<000000?ooo`3oool03P3o
ool00`0I0000000008P0000F08P0008000000P3oool6000002H0oooo00@000000=/0002?0000S`00
0P00G?l5000000H006?o10000009001Xo`<000001@2?00001@000000S`0008l0002?0000000000<0
l`0000<000000940002A0000502A00000`000000T@00094000020940008000001`00DO02000000H0
057`00<00000001Al000DO001@00DO000`00000005W7001Ia`0>001Ia`0500000000FLL005W7001I
a`0000001`00FLL01000000005W7001Ia`00000Q0?ooo`030000003oool0oooo0480oooo00120?oo
o`030000003oool0oooo0100oooo00D00000001>m000C_@004kd00000007001>m00300000000C_@0
04kd00<004kd00<00000001>m00000001@00C_@00`00000005W7001Ia`02001Ia`0300000000FLL0
05W700X005W700@00000001Ia`00FLL000003@00FLL00`000000oooo0?ooo`070?ooo`806@0000<0
000008H0002600000P26000200000180oooo00<06@000000002800004`28000200000080oooo0`00
000208`000<0`P0000<000000?ooo`3oool0903oool010000000f`0008l0002?0005000000D006?o
0P000004001Xo`<000000`00J?l3000000T0S`0000@0000008l0002?000000000P3c00000`000000
T@000940000F094000030000002A0000T@000080000000<0057`00000000DO000`00DO0200000003
001Al0000000057`00H0057`00<00000001Al000DO001@00DO000`00000005W7001Ia`0>001Ia`03
00000000FLL0000000T005W700@00000001Ia`00FLL00000I@3oool00180oooo1P00000Z0?ooo`03
0000003oool0oooo00l0oooo00<00000001>m000C_@00`00C_@00`00000004kd001>m005001>m003
00000000C_@004kd00<004kd0P000006001>m00300000000FLL005W7008005W700<00000001Ia`00
FLL02@00FLL00`00000005W70000000?001Ia`030000003oool0oooo00L0oooo0P0I000010000000
QP0000000000000@0?ooo`/000003@28000200000080oooo0P000000100I0000000008`0002<0005
0<8000030000003oool0oooo02@0oooo00H0000008l0002?0000S`000000003K0002001So`<00000
00<006?o00000000J?l02000J?l4000000`0S`0000<0000008l0002?00000P00000J094000<00000
0`00DO0010000000057`000000000004001Al00300000000DO00057`00D0057`00<00000001Al000
DO001@00DO000`00000005W7001Ia`0>001Ia`0300000000FLL005W700P005W700D00000001Ia`00
FLL005W70000001T0?ooo`004P3oool01P2YZJT0<S8b0?ooo`3oool0k^k^038b<RX0oooo00<00000
0?ooo`3oool03`3oool00`00000004kd001>m004001>m00300000000C_@004kd00D004kd00<00000
001>m000C_@00`00C_@00`00000004kd001>m004001>m00300000000FLL005W7008005W700<00000
001Ia`00FLL02P00FLL00`00000005W7001Ia`0>001Ia`030000003oool0oooo00P0oooo0`00000@
0?ooo`8000002@2:00020<80008000002028000300000080oooo0P00000201T000030000002<0000
S00000L0`P000P00000T0?ooo`030000003K0000S`000080S`0000<000000=/00000Hol00P00Hol4
000000H006So1000000?08l000030000002?0000000001/0T@000P000004001Al08000001`00DO00
0`000000057`001Al005001Al00300000000DO00057`00D0057`00<00000001Ia`00FLL03000FLL2
000000X005W700<00000001Ia`00FLL00P00FLL00`000000oooo0?ooo`1Q0?ooo`004`3oool00`1V
IVH0MgMg0?ooo`0N0?ooo`0509RHV000000000000000002HV9P02@3oool200000140oooo00<00000
001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00<004kd0P000006
001>m00300000000FLL005W7008005W700<00000001Ia`00FLL02000FLL20000014005W700<00000
0?ooo`3oool0603oool3000000T0RP001@3200000`000000R00008P0000308P000@0000000<0oooo
0000000000000`0I00000`000000S00008`000070<8000<0e00000<000000?ooo`3oool08P3oool0
0`000000f`0008l0000208l000040000003K00000000000000@006So0`0000001000J?l000000000
0000000B08l0008000006@2A0003000000<0057`0`0000000`00DO000000001Al007001Al0030000
0000DO00057`00D0057`00<00000001Al000DO001000DO000`00000005W7001Ia`0;001Ia`040000
0000FLL005W7000000X005W700<00000001Ia`00FLL00P00FLL00`000000oooo0?ooo`1P0?ooo`00
4`3oool00`3^k^h08B4Q0<c<c00N0?ooo`050000002HV9P0oooo09RHV00000002@3oool200000180
oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@0
04kd00<00000001>m000C_@01000C_@01@00000005W7001Ia`00FLL0000000T005W700@00000001I
a`00FLL000004@00FLL00`000000oooo0?ooo`0E0?ooo`80000000<06@000000002:0000202:0007
0<800080000000<0R0000000000000001@00000401T000030000002<0000S00000L0`P001@3D0000
0`000000oooo0?ooo`0R0?ooo`030000002?0000S`000080S`0000<000000=/0003K00000P000004
001Xo`<000004P2?0003000001P0T@000P0000030?ooo`<000001@00DO000`000000057`001Al005
001Al00300000000DO00057`00H0057`00<00000001Al000DO001000DO000`00000005W7001Ia`09
001Ia`0500000000FLL005W7001Ia`0000002P00FLL00`00000005W7001Ia`02001Ia`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0@P3oool001@0oooo00<0c<c<024Q8@3^k^h07@3oool0
1@000000oooo0?ooo`3oool0000000T0oooo0P00000C0?ooo`0300000000C_@004kd00@004kd00<0
0000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00@0
0000001Ia`00FLL000002000FLL00`00000005W7001Ia`02001Ia`0300000000FLL005W700l005W7
00<000000?ooo`3oool04P3oool2000000806@0000<0000008X0002:00001P2:00000`000000`P00
0<8000080<8000D000001P0I00000`000000S00008`000070<8000L0e00000<000000?ooo`3oool0
8P3oool00`000000S`0008l0000208l000040000003K000000000000008006So0`00000A08l000<0
00000P2A00000`000000T@000940000D0940008000001P3oool00`000000057`001Al005001Al003
00000000DO00057`00D0057`00<00000001Al000DO001P00DO000`000000057`001Al004001Al003
00000000FLL005W700L005W700<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`08001Ia`03
00000000FLL005W700<005W700<000000?ooo`3oool06P3oool00`000000oooo0?ooo`120?ooo`00
5@3oool00`1gMgL0IVIV0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000002@3oool500000140
oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@0
04kd00<00000001>m000C_@01000C_@01000000005W7001Ia`000006001Ia`0300000000FLL005W7
00@005W700<00000001Ia`00FLL03`00FLL00`000000oooo0?ooo`0?0?ooo`8000000`0I00000`00
0000RP0008X0000708X000d0`P0000<0000001T0000I00001@0I00000`000000S00008`000070<80
00L0e0000P00000U0?ooo`040000002?0000S`0008l0008000000P3D000200000180S`000P000005
094000<000004@2A0003000000T0oooo00<00000001Al000DO001@00DO000`000000057`001Al005
001Al00300000000DO00057`00D0057`00<00000001Al000DO001@00DO000`00000005W7001Ia`05
001Ia`0300000000FLL005W700@005W700<00000001Ia`00FLL02000FLL00`00000005W7001Ia`03
001Ia`030000003oool0oooo01T0oooo00<000000?ooo`3oool0@P3oool00180oooo00H0<S8b0>k^
kP3oool0oooo038b<P2YZJTL0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`0D0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd
001>m004001>m00300000000C_@004kd00@004kd00<00000001Ia`0000001@00FLL00`00000005W7
001Ia`06001Ia`0300000000FLL005W700l005W700<000000?ooo`3oool0303oool2000000@06@00
00<0000008X0002:00001`2:000?0<8000800000100I00000`000000S00008`000070<8000L0e000
00@000000=/0003K000000009@3oool00`000000S`000000000208l0008000004P2?0002000000@0
T@000`0000000`0^000000000000000?0940008000003@3oool00`000000057`001Al005001Al003
00000000DO00057`00D0057`00<00000001Al000DO001@00DO000`000000057`001Al005001Al003
00000000FLL005W700<005W700<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`08001Ia`03
00000000FLL005W700@005W700<000000?ooo`3oool0603oool00`000000oooo0?ooo`120?ooo`00
4P3oool6000001`0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo01D0
oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m08000001@00C_@00`000000
04kd001>m004001>m00300000000FLL0000000<005W700<00000001Ia`00FLL02000FLL00`000000
05W7001Ia`0?001Ia`030000003oool0oooo00T0oooo0P00000501T000030000002:0000RP0000L0
RP004P3200020000000401T000000000S00008`000L0`P001`3D00000`000000f`000=/000020=/0
00030000003oool0oooo02<0oooo0P00000408l000030000002?0000S`0000`0S`001@0000020940
0080000000L0;P000000000^0000;P000000003j0000000000/0T@000`00000@0?ooo`0300000000
DO00057`00D0057`00<00000001Al000DO001@00DO000`000000057`001Al005001Al00300000000
DO00057`00D0057`00D00000001Ia`00FLL005W700000008001Ia`0300000000FLL005W700T005W7
00<00000001Ia`00FLL01000FLL00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0480oooo
000d0?ooo`050000002HV9P0oooo09RHV00000002@3oool00`000000oooo0?ooo`0F0?ooo`030000
0000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m0030000
0000C_@004kd00@004kd0P000002001Ia`0300000000FLL005W700X005W700<00000001Ia`00FLL0
3P00FLL2000000P0oooo0P00000601T000030000002:0000RP0000L0RP004`3200020=@000030000
002<0000S00000L0`P001`3D00000`000000f`000=/000040=/000030000003oool0oooo02@0oooo
00<0000008l0002?00000P2?00000`000000S`0008l0000908l000800000103oool300000080;P00
00D0000002h0000^000000000><000020?X000030000002A0000T@0000H0T@000P00000C0?ooo`03
00000000DO00057`00H0057`00<00000001Al000DO001@00DO000`000000057`001Al005001Al003
00000000DO00057`00D0057`00<00000001Ia`0000002P00FLL00`00000005W7001Ia`08001Ia`03
00000000FLL005W700D005W700<000000?ooo`3oool05P3oool00`000000oooo0?ooo`120?ooo`00
=03oool01@2HV9P00000000000000000V9RH00T0oooo00<000000?ooo`3oool05`3oool00`000000
04kd001>m004001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01@00C_@00`000000
04kd001>m004001>m00300000000FLL0000000h005W700<00000001Ia`00FLL03000FLL00`000000
05W7000000060?ooo`8000001`0I00000`000000RP0008X0000708X001<0`P00103D00000`000000
`P000<8000050<8000L0e00000<000000=/0003K00001P3K00000`000000oooo0?ooo`0T0?ooo`03
0000002?0000S`000080S`0000<0000008l0002?00001P2?0002000000<0oooo0`00000402h00004
0000000^0000;P00000000<0h`000P3j00000`000000T@00094000030940008000005P3oool00`00
0000057`001Al006001Al00300000000DO00057`00D0057`00<00000001Al000DO001@00DO000`00
0000057`001Al004001Al1@000001000FLL00`00000005W7001Ia`06001Ia`030000003oool0oooo
05X0oooo00120?ooo`030000003oool0oooo01P0oooo00<00000001>m000C_@01000C_@00`000000
04kd001>m002001>m08000001`00C_@00`00000004kd001>m003001>m08000004000FLL00`000000
05W7001Ia`0:001Ia`0500000000FLL005W7001Ia`0000000`3oool2000000P06@0000<0000008X0
002:00001`2:000C0<8000H0e00000<000000<80003200000`3200070=@000030000003K0000f`00
0080f`0000<000000=/0003K00000`3K00000`000000oooo0?ooo`0T0?ooo`8000000`2?00000`00
0000S`0008l0000208l000<000000`3oool2000000H0;P00100000050><00080nP0000<000000940
000000000P00000C0?ooo`D0000000<0oooo00000000DO001P00DO000`000000057`001Al006001A
l00300000000DO00057`00D0057`00<00000001Al000DO000`0000000`0033H000000000000:001I
a`0300000000FLL005W700@005W72`000003001Ia`030000003oool0oooo05T0oooo00120?ooo`03
0000003oool0oooo01P0oooo00<00000001>m000C_@01@00C_@01`00000004kd001>m000C_@00000
001>m00000001`00C_@00`00000004kd0000000200000003001>m000000005W7010005W700<00000
001Ia`00FLL02000FLL00`00000005W7001Ia`03001Ia`040000003oool00000000000P06@0000<0
000008X0002:00001`2:000C0<8000P0e00000@000000<8000320000`P001`3D00000`000000f`00
0=/0000:0=/000030000003oool0oooo02D0oooo0P00000208l000040000002?0000S`00000000<0
oooo0`00000602h000<0000000<0;P000000000000001P3S00020?X000030000003oool0oooo0140
oooo1000000303P000040?ooo`000000oooo000000L0057`00<00000001Al000DO001P00DO000`00
0000057`001Al004001Al0<000000`0033H01000000005W7000000000008001Ia`0300000000FLL0
05W700X005W700<00000001Ia`00FLL00`00FLL5000005X0oooo00120?ooo`030000003oool0oooo
01T0oooo00<00000001>m000C_@01@00C_@01000000004kd001>m0000002001>m00300000000C_@0
04kd00@004kd0`000004001>m00300000000FLL005W700l005W700<00000001Ia`00FLL01P00FLL0
0`00000005W7001Ia`05001Ia`800000200I00000`000000RP0008X0000708X001<0`P002P3D0002
000000L0e00000<000000=/0003K0000303K00000`000000oooo0?ooo`0V0?ooo`@000000`3oool2
000000H0;P001000000202h000040000003K0000f`00000000H0h`000P3j000A0?ooo`8000000P0h
00001`000000>00003P0000h0000000003P0000000000P3oool00`000000057`001Al005001Al003
00000000DO00057`00H0057`00<00000001Al000DO0010000004000<=P0400000000FLL005W7001I
a`8000001`00FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W700L005W700<000000?oo
o`3oool0503oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`0J0?ooo`03
00000000C_@004kd00D004kd00<00000001>m000C_@01`00C_@4000000H004kd00<00000001Ia`00
FLL03`00FLL00`00000005W7001Ia`04001Ia`0300000000FLL005W700L005W700<0000001T0000I
00001@0I00000`000000RP0008X0000708X001<0`P003@3D00000`000000e0000=@000030=@00003
0000003K0000f`0000d0f`0000<000000?ooo`3oool0:P3oool3000000H0;P001@00000202h00003
0000003K0000f`000080f`0000<000000><0003S0000103S00020?X000h0oooo0P00000303P00003
0000000h0000>00000<0>00000<000000?/0003oool00P3oool00`000000057`001Al005001Al003
00000000DO00057`00D0057`0`000002000<=P030000000033H000`f008000`f00<00000001Ia`00
FLL00`00FLL2000000H005W700<00000001Ia`00FLL02@00FLL00`00000005W7001Ia`06001Ia`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0@P3oool00480oooo00<000000?ooo`3oool0
6`3oool00`00000004kd001>m005001>m00300000000C_@004kd00D004kd0P000003001>m0030000
0000C_@004kd00@004kd00<00000001Ia`00FLL03`00FLL00`00000005W7001Ia`02001Ia`030000
0000FLL005W700T005W700<0000001T0000I00000`0I00000`000000RP0008X0000708X001<0`P00
3`3D00001@000000e0000=@0003D000000000140f`0000<000000?ooo`3oool09`3oool2000000D0
;P00100000030016[`040000000^0000;P00000000H0f`0000<000000><0003S0000103S00020?X0
00X0oooo0`00000403P000030000000h0000>00000<0>00000@000000?/0003k0000n`000`3oool0
0`000000057`001Al005001Al00400000000DO00057`001Al0@000000`0033H00`00000000`f000<
=P02000<=P0300000000FLL005W700D005W70P000004001Ia`0300000000FLL005W700X005W700<0
0000001Ia`00FLL01@00FLL00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0480oooo0012
0?ooo`030000003oool0oooo01`0oooo00<00000001>m000C_@02P00C_@2000000H004kd00<00000
001>m000C_@01000C_@00`00000005W7001Ia`0>001Ia`0500000000FLL005W7001Ia`0000003@00
FLL01@0000006@0001T0000I0000000000T0RP004`32000A0=@000030000003D0000000001<0f`00
00<000000?ooo`3oool09@3oool200000080;P00100000060016[`040000000^0000;P00000000P0
f`0000<000000><0003S00000`3S00030?X000L0oooo0P00000603P000030000000h0000>00000@0
>00000<000000?/0003k00000P3k00030?ooo`0300000000DO00057`00D0057`0`000002000<=P05
0000000033H000`f000<=P000000100033H00`00000005W7001Ia`07001Ia`8000000`00FLL00`00
000005W7001Ia`09001Ia`0300000000FLL005W700D005W700<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`0M0?ooo`0300000000C_@004kd00L0
04kd0P0000000`00C_@00000001>m006001>m00300000000C_@004kd00@004kd00<00000001Ia`00
FLL03P00FLL00`00000005W70000000?001Ia`030000000I0000000000T0RP004`32000C0=@00003
0000003K0000f`0001<0f`0000<000000?ooo`3oool08P3oool70000008004J_00<000000016[`00
AZl00`00AZl010000000;P0002h00000000:0=/000030000003S0000h`0000<0h`000P3j00040?oo
o`<000001`0h00000`000000>00003P0000403P000030000003k0000n`0000@0n`000`3oool00`00
0000057`001Al003001Al0<000000P0033H01@00000000`f000<=P0033H0000000@000`f00<00000
001Ia`00FLL02@00FLL20000008005W700<00000001Ia`00FLL02@00FLL00`00000005W7001Ia`04
001Ia`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00480oooo00<000000?oo
o`3oool07P3oool00`00000004kd001>m002001>m00400000000C_@00000000000@004kd00<00000
001>m000C_@01@00C_@00`00000004kd001>m004001>m00300000000FLL005W700h005W700<00000
001Ia`00FLL03P00FLL6000000D0RP004`32000E0=@000030000003K0000f`0001<0f`0000<00000
0?ooo`3oool0803oool00`000000;P0000000003000000D004J_0P0000020016[`040000000^0000
;P00000000`0f`0000<000000><0003S00000`3S00020?X000030?ooo`000000000000T0>00000@0
000003P0000h0000f`00100h00000`000000n`000?/000050?/000<0oooo0P00DO0300000005000<
=P00000000`f000<=P0000000`0033H00`00000000`f000<=P02000<=P0300000000FLL005W700/0
05W70`00000;001Ia`0300000000FLL005W700@005W700<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`0O0?ooo`0400000000C_@004kd001>m080
000000<004kd00000000C_@01000C_@00`00000004kd001>m005001>m00300000000C_@004kd00@0
04kd00<00000001Ia`00FLL03000FLL00`00000005W70000000@001Ia`03000000220000PP000080
PP001@00000B0<8001L0e00000<000000=/0003K00004`3K00000`000000oooo0?ooo`0N0?ooo`03
0000000^00000000008000002@00AZl200000080;P0000<000000=/0003K0000303K00000`000000
h`000><000030><00080nP002P0h00000`000000>00003P0000503P000030000003S0000n`0000L0
n`000`3oool01@00000000`f000<=P0033H00000008000`f00D00000000<=P0033H000`f00000004
000<=P0300000000FLL005W700d005W70P00000;001Ia`0300000000FLL005W700<005W700<00000
0?ooo`3oool0G`3oool00480oooo00<000000?ooo`3oool0803oool01000000004kd000000000003
001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01@00C_@00`00000004kd001>m004
001>m00300000000FLL005W700X005W700D00000001Ia`00FLL005W70000000@001Ia`0300000022
0000PP0000H0PP000P00000?0<8001L0e0000P00000F0=/000030000003oool0oooo01`0oooo0`00
000<0016[`040000003K0000;P0000000100f`0000<000000><0003S00000`3S00020?X000P0>000
00<0000003P0000h00001@0h000010000000h`000><0003S00080?/00080oooo00@00000000<=P00
33H000000P0033H01@00000000`f000<=P0033H0000000@000`f00<00000001Ia`00FLL03P00FLL2
000000/005W700<00000001Ia`00FLL00P00FLL00`000000oooo0?ooo`1P0?ooo`00@P3oool30000
0240oooo00<00000001>m00000001000C_@00`00000004kd001>m003001>m00300000000C_@004kd
00D004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`08001Ia`0300000000FLL005W7
00<005W700<00000001Ia`00FLL03P00FLL00`000000PP000880000708800003000000320000`P00
00/0`P005`3D000010000000f`000=/00000000F0=/000030000003oool0oooo01P0oooo1@00000<
0016[`040000003K0000;P0000000180f`0000<000000><0003S00000`3S00020?X000H0>00000<0
000003P0003K00001@0h00000`000000h`000><000030><000P0n`0000@00000000<=P0033H00000
0P0033H01@00000000`f000<=P0033H0000000@000`f00<00000001Ia`00FLL03P00FLL010000000
05W7000000000009001Ia`0300000000FLL005W7008005W700<000000?ooo`3oool0H@3oool00480
oooo00<000000?ooo`3oool08@3oool00`00000004kd00000005001>m00300000000C_@004kd00<0
04kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000FLL005W700L0
05W700<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`0>001Ia`03000000220000PP0000L0
PP000P00000:0<8001L0e00000<000000=/0003K00000P3K00000`000000f`000=/0000C0=/00003
0000003oool0oooo01D0oooo10000002000<6@8000002`00AZl010000000f`0002h00000000C0=/0
00030000003S0000h`0000@0h`000P3j000403P000030000000h0000f`0000D0>00000<000000><0
003S00001@3S00080?/00005000<=P00000000`f000<=P0000000`0033H00`00000000`f000<=P02
000<=P0300000000FLL005W700h005W700@00000001Ia`00FLL005W70P000008001Ia`0500000000
FLL005W7001Ia`000000I03oool00480oooo00<000000?ooo`3oool08P3oool2000000H004kd00<0
0000001>m000C_@00`00C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<0
0000001Ia`00FLL01@00FLL00`00000005W7001Ia`07001Ia`0300000000FLL005W700h005W700<0
000008800022000020220002000000L0`P005`3D00000`000000f`000=/000040=/000030000003K
0000f`0001<0f`0000<000000?ooo`3oool04`3oool30000008000`I0`0000000`00AZl000000000
00080016[`040000003K0000;P00000001D0f`0000<000000><0003S0000103S00020?X00080>000
00<0000003P0000h00001P0h00000`000000h`000><000060><000L0n`0000@00000000<=P0033H0
00000`0033H00`00000000`f000<=P030000010005W700<00000001Ia`00FLL00`00FLL2000000L0
05W700@00000001Ia`00FLL00000803oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000
oooo0?ooo`0S0?ooo`0300000000C_@004kd00D004kd00<00000001>m000C_@00`00C_@00`000000
04kd001>m004001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL00`00FLL00`000000
05W7001Ia`09001Ia`0300000000FLL005W700h005W700<000000880002200002@2200000`000000
`P000<8000030<8001L0e00000<000000=/0003K00001P3K00000`000000f`000=/0000C0=/00003
0000003oool0oooo0100oooo2@0000040016[`0300000000AZl004J_00@004J_00@000000=/0000^
000000005`3K00000`000000h`000><000030><000<0nP000P00000703P000030000003S0000h`00
00P0h`001`3k00000`0033H00000000<=P02000<=P@0000000<000`f00000000FLL03`00FLL00`00
000005W7001Ia`05001Ia`8000001@00FLL01000000005W7001Ia`00000Q0?ooo`030000003oool0
oooo0480oooo00120?ooo`030000003oool0oooo02@0oooo00<00000001>m000C_@01@00C_@00`00
000004kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@01@00
000005W7001Ia`00FLL0000000d005W700<00000001Ia`00FLL03@00FLL2000000/0PP000P000002
0<8001L0e00000<000000=/0003K0000203K00000`000000f`000=/0000C0=/000030000003oool0
oooo00d0oooo1P000002000<@P8000001P00AZl2000000<004J_00@000000=/0000^000000006@3K
00000`000000h`000><000030><000<0nP0000<0000003P0000h0000100h00000`000000h`000><0
00090><000P0n`000`0033H2000000<000`f00<00000001Ia`0000003P00FLL00`00000005W7001I
a`07001Ia`0300000000FLL005W700<005W700<00000001Ia`0000008P3oool00`000000oooo0?oo
o`120?ooo`00@P3oool00`000000oooo0?ooo`0U0?ooo`0300000000C_@004kd00D004kd00<00000
001>m000C_@00`00C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000
001Ia`0000003`00FLL00`00000005W7001Ia`0;001Ia`0400000000FLL00000000000`0PP000P00
000F0=@000030000003K0000f`0000X0f`0000<000000=/0003K00004`3K00000`000000oooo0?oo
o`0;0?ooo`@0000000<000a20000000034800`0000090016[`<0000000<0f`0002h0000000006`3K
00000`000000h`000><000030><00080nP0000<0000003P0000h00000`0h00000`000000h`000><0
000;0><000P0n`000P000004000<=P0500000000FLL005W7001Ia`0000003000FLL00`00000005W7
001Ia`09001Ia`0700000000FLL005W7001Ia`00000005W70000000S0?ooo`030000003oool0oooo
0480oooo00120?ooo`030000003oool0oooo02H0oooo00<00000001>m000C_@01000C_@00`000000
04kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@200000140
05W700<00000001Ia`00FLL02@00FLL01@00000005W7001Ia`00FLL0000000h0PP0000<000000=@0
003D00004P3D00000`000000f`000=/0000<0=/000030000003K0000f`0001<0f`0000<000000?oo
o`3oool02@3oool30000008000a20`0000000`00374000000000000:0016[`040000003K0000;P00
000001d0f`0000<000000><0003S00000`3S000010000000>00003P0000h0003000000l0h`00203k
0004000<=P0300000000FLL005W700<005W700<00000001Ia`00FLL02000FLL00`00000005W7001I
a`0;001Ia`0300000000FLL005W700800000903oool00`000000oooo0?ooo`120?ooo`00@P3oool0
0`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000001P00C_@00`00000004kd001>
m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00P000002001>m00300000000
FLL005W700h005W700<00000001Ia`00FLL02000FLL00`00000005W7001Ia`03001Ia`0300000022
0000PP0000`0PP0000<000000=@0003D0000403D00000`000000f`000=/0000=0=/000030000003K
0000f`0001@0f`0000<000000?ooo`3oool01`3oool2000000<000a20P000002000<L@8000002P00
AZl010000000f`0002h00000000O0=/000060000003S0000h`000><000000000>0001P00000@0><0
00P0n`000P0033H00`00000005W7001Ia`05001Ia`0300000000FLL005W700H005W700<00000001I
a`00FLL03@00FLL00`00000005W70000000U0?ooo`030000003oool0oooo0480oooo00120?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00000004kd001>m004001>m003
00000000C_@004kd00<004kd00<00000001>m000C_@01@00C_@2000000D004kd00<00000001Ia`00
FLL03P00FLL00`00000005W7001Ia`06001Ia`0300000000FLL005W700D005W700<0000008800022
0000302200000`000000e0000=@0000>0=@000030000003K0000f`0000l0f`0000<000000=/0003K
0000503K00000`000000oooo0?ooo`060?ooo`0300000000348000a2008000000`0037400`000000
00aa000000090016[`040000003K0000;P0000000240f`0000<000000><0000000000`00000203P0
00040000003K0000f`0000000100h`00203k00000`00000005W7001Ia`07001Ia`0300000000FLL0
05W700@005W700<00000001Ia`00FLL03`00FLL00`000000oooo0?ooo`1Y0?ooo`00@P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<00000001>m000C_@01000C_@00`00
000004kd001>m003001>m00300000000C_@004kd008004kd0P0000000`00C_@00000001>m005001>
m00300000000FLL005W700h005W700<00000001Ia`00FLL01000FLL00`00000005W7001Ia`07001I
a`03000000220000PP0000`0PP0000<000000=@0003D0000303D00000`000000f`000=/0000A0=/0
00030000003K0000f`0001<0f`0000<000000?ooo`3oool01@3oool400000003000<L@00000000aa
008000aa0P0000090016[`040000003K0000;P00000002<0f`000P00000403P000030000003K0000
f`000080f`0000<000000><0003S00003P3S00080?/000X005W700<00000001Ia`00FLL00P00FLL0
0`00000005W7001Ia`0@001Ia`030000003oool0oooo06T0oooo00120?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool00`3oool00`00000004kd001>m005001>m00300000000C_@004kd
00<004kd00@00000001>m000000000000`00C_@00`00000004kd001>m004001>m00300000000FLL0
05W700l005W700<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`09001Ia`03000000220000
PP0000`0PP000P00000;0=@000030000003K0000f`0001<0f`0000<000000=/0003K00004`3K0000
0`000000oooo0?ooo`030?ooo`8000000`0037400`00000000aa000<L@05000000L004J_00@00000
0=/0000^00000000903K000503P000030000003K0000f`0000@0f`0000<000000><0003S00003@3S
00090?/0000300000000FLL005W700H005W700D00000001Ia`00FLL005W70000000B001Ia`030000
003oool0oooo06X0oooo00120?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103o
ool00`00000004kd001>m005001>m00300000000C_@004kd008004kd0P000006001>m00300000000
C_@004kd00@004kd00<00000001Ia`00FLL03`00FLL01000000005W7001Ia`00000=001Ia`030000
00220000PP0000d0PP0000<000000=@0003D00001`3D00000`000000f`000=/0000E0=/000030000
003K0000f`0001<0f`0000@000000?ooo`3oool0oooo0P000004000<L@D0000000<001V=00000000
AZl00P0000040016[`040000003K0000;P00000002@0f`0000<0000003P0000h00000P0h00000`00
0000f`000=/000060=/000030000003S0000h`0000d0h`00203k00000`00000005W7001Ia`07001I
a`0300000000FLL00000018005W700<000000?ooo`3oool0J`3oool00480oooo00<000000?ooo`3o
ool0:`3oool00`00000004kd001>m005001>m00400000000C_@000000000008004kd00<00000001>
m000C_@01000C_@00`00000004kd001>m004001>m00300000000FLL005W700l005W70P00000?001I
a`03000000220000PP0000d0PP0000<000000=@0003D00001@3D00000`000000f`000=/0000G0=/0
00030000003K0000f`0001<0f`0000@000000?ooo`3oool000000`00374500000004000IS@000000
01V=000000<004J_0P0000001@00AZl000000=/0000^0000000002@0f`0000<0000003P0000h0000
0P0h00000`000000f`000=/000080=/000030000003S0000h`0000d0h`001P3k00000`00000005W7
001Ia`09001Ia`0300000000FLL005W7010005W700<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`110?ooo`00@P3oool00`000000oooo0?ooo`0/0?ooo`0300000000C_@004kd00<004kd0`00
0005001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001I
a`0>001Ia`8000003`00FLL6000000/0PP0000<000000=@0003D00000`3D00000`000000f`000=/0
000I0=/000030000003K0000f`0001<0f`000`0000000`003740000000000002000000<001V=00<0
0000000IS@0000001P00AZl010000000;P0002h00000000T0=/000030000000h0000>0000080>000
00<000000=/0003K00002P3K00000`000000h`000><0000=0><000D0n`0000<00000001Ia`00FLL0
2000FLL00`00000005W70000000@001Ia`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
@@3oool00480oooo0`00000]0?ooo`0300000000C_@004kd008000000`00C_@00`00000004kd001>
m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001I
a`0<001Ia`0400000000FLL005W7000000l005W700<000000880002200000P2200000`000000PP00
08800009088000050000003D0000e0000=@0000000007@3K00000`000000f`000=/0000C0=/000@0
000000<001V=000000006Hd00`006Hd00`00000001V=000000050016[`040000000^0000;P000000
02@0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000<0=/000030000003S0000h`00
00d0h`000`3k00000`00000005W7001Ia`08001Ia`0500000000FLL005W7001Ia`0000003P00FLL0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0440oooo00110?ooo`800000<03oool20000
00D004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd
00@004kd00<00000001Ia`00FLL02P00FLL01@00000005W7001Ia`00FLL00000010005W700<00000
0880002200000P2200000`000000PP0008800009088000030000003D0000000001h0f`0000<00000
0=/0003K0000503K00001@00000001V=000IS@006Hd0000000@001V=0`0000040016[`040000000^
0000;P00000002@0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000>0=/000030000
003S0000h`0000d0h`000P3k00000`00000005W7001Ia`07001Ia`0300000000FLL005W700<005W7
00<00000001Ia`00FLL02P00FLL00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0440oooo
00110?ooo`8000009@3oool00`000000oooo0?ooo`090?ooo`0300000000C_@004kd00@004kd00<0
0000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<0
0000001Ia`00FLL02000FLL00`00000005W7001Ia`03001Ia`0300000000FLL005W700h005W700<0
00000880002200000P220002000000T0PP000P00000P0=/000030000003K0000f`0001@0f`0000<0
0000000IS@0000000`006Hd300000003000QW@00AZl004J_008004J_00@0000002h0000^00000000
903K00000`000000>00003P0000203P000030000003K0000f`000100f`0000<000000><0003S0000
3@3S00000`00000005W7001Ia`07001Ia`0300000000FLL005W700@005W700<00000001Ia`00FLL0
2@00FLL00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0440oooo00110?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool02P3oool00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000
FLL005W700H005W700<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`0>001Ia`0300000022
0000PP0000<0PP0000<000000880002200000`22000300000003088000000000f`000200f`0000<0
00000=/0003K00004P3K000200000003000IS@00000000000080000000@0026M000000008Id0026M
0`00AZl4000002@0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000A0=/000030000
003S0000h`0000d0h`0000<00000001Ia`00FLL01P00FLL00`00000005W7001Ia`06001Ia`030000
0000FLL005W700L005W700<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`110?ooo`00@@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00/0oooo00<00000001>m000C_@01000
C_@00`00000004kd001>m004001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01@00
C_@00`00000005W7001Ia`04001Ia`0300000000FLL005W700L005W700<00000001Ia`00FLL03P00
FLL00`000000PP0008800003088000030000002200000000008000001@2200000`000000f`000=/0
000O0=/000030000003K0000f`000100f`0000<000000>80003R00000P000004000QW@0500000000
8Id0026M00000000AZl00P0000000`0^000000000000000S0=/000030000000h0000>0000080>000
00<000000=/0003K00004`3K00000`000000h`000><0000;0><0000300000000FLL005W700H005W7
00<00000001Ia`00FLL02000FLL00`00000005W7001Ia`05001Ia`030000003oool0oooo0780oooo
00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`00000004kd001>
m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>
m005001>m00300000000FLL005W7008005W700<00000001Ia`00FLL02@00FLL00`00000005W7001I
a`0>001Ia`03000000220000PP000080PP000P000009088000030000003K0000f`0001l0f`0000<0
00000=/0003K00003P3K00000`000000hP000>8000020>800004000000008Id0026M000QW@800000
0P008Id30000000502h000000000e0000=@0000000008@3K00000`000000>00003P0000203P00003
0000003K0000f`0001D0f`0000<000000><0003S00002@3S00000`00000005W7001Ia`06001Ia`03
00000000FLL005W700X005W700<00000001Ia`00FLL00`00FLL00`000000oooo0?ooo`1c0?ooo`00
@@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<00000001>m000C_@0
1@00C_@00`00000004kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@0
1000C_@01@00000005W7001Ia`00FLL0000000d005W700<00000001Ia`00FLL03P00FLL200000004
088000000000PP00000000X0PP0000<000000=/0003K00007`3K00000`000000f`000=/0000<0=/0
00030000003R0000hP0000@0hP0000D00000000QW@008Id00000000QW@040000000302h000000000
e00000<0e00000<000000=/0003K00007@3K00000`000000>00003P0000203P000030000003K0000
f`0001L0f`0000<000000><0003S00001`3S00000`00000005W7001Ia`07001Ia`0300000000FLL0
05W700/005W700D00000001Ia`00FLL005W70000001f0?ooo`00@@3oool2000002D0oooo00<00000
0?ooo`3oool03@3oool00`00000004kd001>m005001>m00300000000C_@004kd00<004kd00<00000
001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000FLL0000000l005W700<00000
001Ia`00FLL03000FLL4000000<0PP0000<00000088000220000202200000`000000f`000=/0000O
0=/000030000003K0000f`0000X0f`0000<000000>80003R00001@3R00000`000000026M00000007
000000H0e00000<000000=/0003K00006`3K00000`000000>00003P0000203P000030000003K0000
f`0001T0f`0000<000000><0003S00001@3S0002000000P005W700<00000001Ia`00FLL03@00FLL0
0`00000005W70000001g0?ooo`00@@3oool2000003H0oooo00<00000001>m000C_@01@00C_@00`00
000004kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@30000
00l005W700<00000001Ia`00FLL02`00FLL01@00000005W700000000FLL0000000@0PP0000<00000
088000220000202200000`000000f`000=/0000O0=/000030000003K0000f`0000P0f`0000<00000
0>80003R00001@3R00000`3c000000000000000200000080;P000P0000000`360000e0000=@00006
0=@000030000003K0000f`0001T0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000K
0=/000030000003S0000h`0000<0h`0000@00000001Ia`00FLL000001P00FLL00`00000005W7001I
a`0?001Ia`030000003oool0oooo0380oooo00<000000?ooo`3oool0@@3oool00440oooo0P00000g
0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004
001>m00300000000C_@004kd008000000P00C_@00`00000005W7001Ia`0>001Ia`0300000000FLL0
05W700T005W700@00000001Ia`00FLL000000P00FLL00`000000PP00088000020880000300000022
0000PP0000P0PP0000<000000=/0003K00007P3K00000`000000f`000=/000070=/000030000003R
0000f`0000@0hP0000D000000?<0003c0000l`000000000302h0008000000`3600080=@000030000
003K0000f`0001L0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000M0=/000050000
003S0000h`000><0000000001000FLL00`00000005W7001Ia`02001Ia`0300000000FLL005W700l0
05W700<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`110?ooo`00@@3oool2000003P0oooo
00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd
0P000005001>m00300000000FLL005W700h005W700<00000001Ia`00FLL01`00FLL01@00000005W7
001Ia`00FLL0000000<005W700<000000880002200000P2200000`000000PP000880000808800003
0000003K0000f`0001h0f`0000<000000=/0003K00001@3K00000`000000hP000>8000050>8000@0
l`0000<0000002h0000^00000P0000050<H000P0e00000<000000=/0003K00005@3K00000`000000
>00003P0000203P000030000003K0000f`0001l0f`0000<000000><0000000001P00FLL010000000
05W7001Ia`00000A001Ia`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@@3oool00440
oooo0P00000i0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`000000
04kd001>m002001>m00300000000C_@0000000H004kd00<00000001Ia`00FLL03P00FLL00`000000
05W7001Ia`05001Ia`0300000000FLL005W7008005W700<00000001Ia`00FLL00P00FLL00`000000
PP000880000208800003000000220000PP0000L0PP0000<000000=/0003K00007`3K00000`000000
f`000=/000030=/000030000003R0000hP0000D0hP00103c00001@000000;P0002h000000000[000
00L0aP001`3D0002000001D0f`0000<0000003P0000h00000P0h00000`000000f`000=/0000Q0=/0
000300000000FLL005W700H005W70P00000A001Ia`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0@@3oool00440oooo0P00000U0?ooo`030000003oool0oooo0180oooo00<00000001>m000
C_@01000C_@00`00000004kd001>m004001>m0@000000`00C_@00`00000004kd001>m004001>m003
00000000FLL005W700h005W700<00000001Ia`00FLL00`00FLL00`00000005W7001Ia`03001Ia`03
00000000FLL005W700<005W700<000000880002200000P2200000`000000PP000880000708800003
0000003K0000f`0001l0f`0000D000000=/0003K0000f`00000000070>8000@0l`00100000030:`0
00L0aP001`3D00000`000000f`000=/0000B0=/000030000000h0000>0000080>00000<000000=/0
003K00008P3K00000`00000005W7001Ia`06001Ia`8000004000FLL00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0440oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool04`3oool00`00000004kd001>m004001>m00300000000C_@004kd00<004kd0P000006001>m003
00000000C_@004kd00@004kd00<00000001Ia`00FLL03P00FLL01@00000005W7001Ia`00FLL00000
00H005W700<00000001Ia`00FLL01000FLL00`000000PP000880000208800003000000220000PP00
00L0PP0000<000000=/0003K00007`3K00000`000000f`00000000070>8000@0l`0000D000000=/0
00000000R000000000040:`000L0aP001`3D00000`000000f`000=/0000@0=/000030000000h0000
>0000080>00000<000000=/0003K00008P3K00000`00000005W7001Ia`06001Ia`0300000000FLL0
000000l005W700<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`110?ooo`00@@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<00000001>m000C_@01000C_@00`00
000004kd000000020000008004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>
m00300000000FLL005W700h005W700<00000001Ia`0000001`00FLL00`00000005W7001Ia`04001I
a`800000102200000`000000PP0008800007088000030000003K0000f`0001l0f`0000@000000>80
003R0000f`00103R00040?<000030000003K0000R00000<0R00000<000000:`0002/00000P2/0007
0<H000L0e00000<000000=/0003K00003P3K00000`000000>00003P0000203P000030000003K0000
f`000280f`0000<00000001Ia`00FLL01P00FLL01@00000005W7001Ia`00FLL0000000d005W700<0
00000?ooo`3oool0O03oool00440oooo1000000S0?ooo`030000003oool0oooo01@0oooo00<00000
001>m000C_@01000C_@2000000H004kd00<00000001>m000C_@01000C_@00`00000004kd001>m003
001>m00300000000FLL005W700l005W70`000006001Ia`0300000000FLL005W7008005W70P000000
0`00FLL000000000000408800003000000220000PP0000L0PP0000<000000=/0003K00007`3K0000
0`000000hP000>8000030>8000@0l`0000<000000=/0002800001@2800000`000000[0000:`00002
0:`000L0aP001`3D00000`000000f`000=/0000<0=/000030000000h0000>0000080>00000<00000
0=/0003K00008P3K00000`00000005W7001Ia`06001Ia`0300000000FLL005W700<005W700<00000
001Ia`00FLL02@00FLL01@000000oooo0?ooo`3oool0000007/0oooo00110?ooo`8000009@3oool0
0`000000oooo0?ooo`0E0?ooo`0300000000C_@004kd00<000000P00C_@00`00000004kd001>m004
001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`0=
001Ia`0400000000FLL005W7001Ia`<000000`00FLL00`00000005W7001Ia`02000000@005W70P00
000408800003000000220000PP0000L0PP0000<000000=/0003K00007`3K000010000000hP000>80
003R00040?<000030000003K0000R00000L0R00000<000000:`0002/00000P2/00070<H000L0e000
00<000000=/0003K00002P3K00000`000000>00003P0000203P000030000003K0000f`000280f`00
00<00000001Ia`00FLL01`00FLL00`00000005W7001Ia`04001Ia`0300000000FLL005W700P005W7
00D000000?ooo`3oool0oooo0000001k0?ooo`00@@3oool2000002D0oooo00<000000?ooo`3oool0
5P3oool2000000H004kd00<00000001>m000C_@00`00C_@00`00000004kd001>m004001>m0030000
0000C_@004kd00@004kd00<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`05001Ia`H00000
1`00FLL2000000<0PP0000<00000088000220000202200000`000000f`000=/0000M0=/000800000
0P3R00040?<000030000003K0000R00000T0R00000<000000:`0002/00000P2/00070<H000H0e000
0P00000:0=/000030000000h0000>0000080>00000<000000=/0003K00008P3K00000`00000005W7
001Ia`07001Ia`0300000000FLL005W700H005W700<00000001Ia`00FLL01P00FLL00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3oool00440oooo0P00
000o0?ooo`0300000000C_@004kd00D004kd00<00000001>m000C_@00`00C_@00`00000004kd001>
m004001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL02@00FLL00`00000005W7001I
a`09001Ia`0300000000FLL005W700P005W700<000000880002200000P2200000`000000PP000880
0008088000030000003K0000f`0001/0f`0000@000000>80003R00000000103c00000`000000f`00
08P0000;08P000030000002/0000[0000080[0001P3600070=@000800000203K00000`000000>000
03P0000203P000030000003K0000f`000280f`0000<00000001Ia`00FLL01`00FLL00`00000005W7
001Ia`08001Ia`0300000000FLL005W700@005W700<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0440oooo00110?ooo`800000@03oool00`00000004kd001>
m005001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000004kd001>
m004001>m00300000000FLL005W700L005W700<00000001Ia`00FLL02P00FLL00`00000005W7001I
a`09001Ia`03000000220000PP000080PP0000<000000880002200001`2200000`000000f`000=/0
000J0=/000030000003R0000hP000080hP0000D000000?<0003c000000000=/0000>08P000030000
002/0000[0000080[0001P3600070=@0008000001P3K00000`000000>00003P0000203P000030000
003K0000f`000280f`0000<00000001Ia`00FLL01`00FLL00`00000005W7001Ia`0:001Ia`030000
0000FLL005W7008005W700<000000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0440oooo00110?ooo`800000@@3oool00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000
FLL005W700D005W700<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`0:001Ia`0300000022
0000PP000080PP0000<000000880002200001`2200000`000000f`000=/0000H0=/000030000003R
0000hP0000<0hP0000@000000?<000000000f`00402800000`000000[0000:`000020:`000H0aP00
1`3D00000`000000f`000=/000030=/000030000000h0000>00000<00000903K00000`00000005W7
001Ia`07001Ia`0300000000FLL005W700`005W700@00000001Ia`00FLL000001`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0440oooo00110?ooo`800000@P3oool00`00000004kd
001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd
001>m004001>m00300000000FLL005W700<005W700<00000001Ia`00FLL03000FLL00`00000005W7
001Ia`0;001Ia`03000000220000PP000080PP0000<000000880002200001`2200000`000000f`00
0=/0000F0=/000030000003R0000hP0000D0hP0000<000000=/000280000402800000`2/00000000
0:`000020:`000L0aP001`3D000010000000f`000=/0003K0005000000030=@000000000f`000280
f`0000<00000001Ia`0000001`00FLL00`00000005W7001Ia`0>001Ia`800000@03oool00`000000
oooo0?ooo`110?ooo`00@@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01/0oooo
00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd
00<00000001>m000C_@01000C_@01@00000005W7001Ia`00FLL0000000l005W700<00000001Ia`00
FLL03000FLL00`000000PP000880000208800003000000220000PP0000L0PP0000<000000=/0003K
0000503K00000`000000hP000>8000070>800003000000280000R0000100R00000<0[0000000002/
00000P2/00070<H000L0e00000<000000=/0000000000P0000000`0h000000000=@000020=@00003
0000003K0000f`0001l0f`0000D00000001Ia`00FLL005W700000005001Ia`0300000000FLL005W7
00l005W700<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`110?ooo`00@@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01`0oooo00<00000001>m000C_@01000C_@00`000000
04kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`000000
05W70000000@001Ia`0300000000FLL005W700`005W70P00000408800003000000220000PP0000L0
PP0000<000000=/0003K00004P3K00000`000000hP000>8000090>800003000000280000R0000100
R00000<000000:`0002/00000P2/00070<H000H0e0000P00000303P000030000003D0000e00000<0
e00000<000000=/0003K00007@3K00000`00000005W7001Ia`03001Ia`0500000000FLL005W7001I
a`0000004@00FLL00`000000oooo0?ooo`240?ooo`00@@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01d0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m003
00000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@30000010005W700<00000001Ia`00
FLL02P00FLL200000003001Ia`000000000000@0PP0000<000000880002200001`2200000`000000
f`000=/0000@0=/000030000003R0000hP0000X0hP0000<0000008P0002800004@2800000`000000
[0000:`000020:`000L0aP00103D00000`000000>00003P0000203P000030000003D0000e00000D0
e00000<000000=/0003K00006`3K00000`00000005W7001Ia`05001Ia`0300000000FLL000000140
05W700<000000?ooo`3oool0Q@3oool00440oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0M0?ooo`0300000000C_@004kd00D004kd00<00000001>m000C_@01000C_@00`00000004kd
001>m004001>m00300000000C_@000000080000000<004kd00000000FLL00`00000=001Ia`030000
0000FLL005W700P005W70`0000000`00FLL00000001Ia`02000000@0PP0000<00000088000220000
1`2200000`000000f`000=/0000>0=/000030000003R0000hP0000`0hP0000<0000008P000280000
4@2800000`000000[0000:`000020:`000L0aP000P3D00000`000000>00003P0000203P000030000
003D0000e00000L0e00000<000000=/0003K00006@3K0002000000H005W70`00000A001Ia`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0N@3oool00440oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0N0?ooo`0300000000C_@004kd00D004kd00<00000001>m000C_@01000
C_@00`00000004kd001>m003001>m08000001@00C_@01000000005W7001Ia`00FLL2000000/005W7
00<00000001Ia`00FLL01P00FLL200000004001Ia`00000005W7000000<005W70P00000408800003
000000220000PP0000L0PP0000<000000=/0003K0000303K00000`000000hP000>80000>0>800003
000000280000R0000140R00000<000000:`0002/00000P2/00060<H000800000100h00000`000000
e0000=@000090=@000030000003K0000f`0001L0f`000`0000000`00FLL000000000000300000080
05W700<00000001Ia`00FLL03P00FLL00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07T0
oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`00000004kd
001>m005001>m00300000000C_@004kd00@004kd00<00000001>m00000000P0000000`00C_@00000
001>m005001>m00300000000FLL005W7008005W70`000008001Ia`0300000000FLL005W700@005W7
0P000002001Ia`0400000000FLL005W7000000@005W70P00000308800003000000220000PP0000L0
PP0000<000000=/0003K00002`3K00000`000000hP000>80000?0>800003000000280000R0000180
R00000<000000:`0002/00000P2/00040<H000030000000h0000>00000<0>00000<000000=@0003D
00002`3D00000`000000f`000=/0000E0=/0000300000000FLL005W7008000002000FLL00`000000
05W7001Ia`0<001Ia`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`110?ooo`00@@3oool00`000000oooo0?ooo`170?ooo`0300000000C_@004kd00D004kd
00<00000001>m000C_@00`00C_@2000000D004kd00<00000001>m000C_@01000C_@00`00000005W7
001Ia`04001Ia`<000001@00FLL00`00000005W7001Ia`02001Ia`8000000`00FLL01000000005W7
001Ia`000006001Ia`8000000`2200000`000000PP0008800007088000030000003K0000f`0000T0
f`0000<000000>80003R00004@3R00000`000000R00008P0000B08P000030000002/0000[0000080
[0000P3600000`000000>00003P0000303P000030000003D0000e00000d0e00000<000000=/0003K
00004`3K00001@00000005W7001Ia`00FLL0000000X005W700<00000001Ia`00FLL02P00FLL00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3oool00440
oooo00<000000?ooo`3oool0B03oool00`00000004kd001>m005001>m00300000000C_@000000080
000000<004kd00000000C_@01@00C_@00`00000004kd001>m004001>m00300000000FLL005W700H0
05W70P000003001Ia`0300000000FLL005W7008000001000FLL01@00000005W7001Ia`00FLL00000
00L005W700<000000880002200000P2200000`000000PP0008800007088000030000003K0000f`00
00L0f`0000<000000>80003R00004`3R00000`000000R00008P0000A08P000030:`000000000[000
0080[0000P00000503P000030000003D0000e00000l0e00000<000000=/0003K00004@3K00000`00
000005W7001Ia`02001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL02000FLL00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3oool00440
oooo0`0000190?ooo`0300000000C_@004kd00@004kd0P000005001>m00300000000C_@004kd00@0
04kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`07001Ia`H000001@00FLL01@000000
05W7001Ia`00FLL0000000T005W700<000000880002200000P2200000`000000PP00088000070880
00030000003K0000f`0000D0f`0000<000000>80003R0000503R00000`000000R00008P0000B08P0
00040:`000000000[000000000H0>00000<000000=@0003D00004@3D00000`000000f`000=/0000?
0=/0000300000000FLL005W700<005W700<00000001Ia`00FLL02P00FLL00`00000005W7001Ia`06
001Ia`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`11
0?ooo`00@@3oool00`000000oooo0?ooo`1:0?ooo`0400000000C_@004kd001>m080000000<004kd
00000000C_@01@00C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000
001Ia`00FLL02@00FLL00`00000005W7001Ia`04001Ia`0500000000FLL005W7001Ia`0000002`00
FLL00`000000PP000880000208800003000000220000PP0000L0PP0000<000000=/0003K00000`3K
00000`000000hP000>80000D0>8000030?<000000000R00001@0R0000P00000503P0008000005@3D
00000`000000f`000=/0000=0=/0000300000000FLL005W700@005W700<00000001Ia`00FLL02P00
FLL00`00000005W7001Ia`05001Ia`030000003oool0oooo04P0oooo00<000000?ooo`3oool0@@3o
ool00440oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`0300000000C_@0
000000@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@0
04kd00@004kd00<00000001Ia`00FLL02000FLL00`00000005W7001Ia`03001Ia`0300000000FLL0
05W7008005W700<00000001Ia`00FLL02@00FLL2000000@0PP0000<000000880002200001`220000
1@000000f`000=/0003K0000000001H0hP000`3c00000`000000R00008P0000?08P000@000001@0h
00000`000000aP000=@0000F0=@000030000003K0000f`0000/0f`0000<00000001Ia`00FLL01@00
FLL00`00000005W7001Ia`0;001Ia`0300000000FLL005W700<005W700<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`110?ooo`00@@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02D0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@0
04kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`07001Ia`0300000000FLL0
05W7008005W700<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`09001Ia`0400000000FLL0
0000000000@0PP0000<000000880002200001`2200000`000000f`000000000F0>8000@0l`0000<0
000008P0002800003028000300000080>00000@0000003P0000h000000000P0h000010000000aP00
0<H00036000G0=@000030000003K0000f`0000T0f`0000<00000001Ia`00FLL01P00FLL00`000000
05W7001Ia`0<001Ia`0500000000FLL005W7001Ia`000000T03oool00440oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`0300000000C_@004kd00D004kd00<00000001>m000
C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00<004kd00<00000001Ia`00
FLL01`00FLL01@00000005W7001Ia`00FLL0000000D005W700<00000001Ia`00FLL02@00FLL00`00
000005W7001Ia`02000000@0PP0000<000000880002200001P220002000001H0hP001@3c00000`00
0000R00008P0000908P000<00000100h00000`000000>00003P0000203P0008000001@36000G0=@0
00030000003K0000f`0000L0f`0000@00000001Ia`00000000001P00FLL00`00000005W7001Ia`0=
001Ia`0300000000FLL000000940oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool09P3oool00`00000004kd001>m005001>m00300000000C_@004kd00@004kd00<00000001>
m000C_@01000C_@00`00000004kd001>m003001>m00300000000FLL005W700H005W700@00000001I
a`00FLL000001@00FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W7008005W70P000004
08800003000000220000PP000080PP000`0000000`22000000000>80000D0>8000L0l`0000<00000
08P0002800001P280002000000H0>00000<0000003P0000h00000P0h00000`000000aP000<H00006
0<H001L0e00000<000000=/0003K00001@3K0002000000<005W70P000004001Ia`0300000000FLL0
05W700`005W70`00000F0?ooo`030000003oool0oooo07T0oooo00110?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool09`3oool00`00000004kd001>m005001>m00300000000C_@004kd
00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>m004001>m00300000000FLL005W7
00D005W700<00000001Ia`0000001@00FLL00`00000005W7001Ia`0:001Ia`0300000000FLL005W7
00<005W70P00000308800080000000<0PP000000000000001@2200000`000000hP000>80000A0>80
00P0l`0000<0000008P0002800000`280003000000L0>00000<0000003P0000h00000P0h00000`00
0000aP000<H000080<H001L0e00000<000000=/0003K00000`3K00001000000005W7001Ia`000004
001Ia`0500000000FLL005W7001Ia`0000002P00FLL40000008005W700<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`1i0?ooo`00@@3oool00`000000oooo0?ooo`1?0?ooo`0300000000C_@0
04kd00D004kd00<00000001>m000C_@01000C_@00`00000004kd001>m003001>m00300000000C_@0
04kd00@004kd00<00000001Ia`00FLL01000FLL2000000H005W700<00000001Ia`00FLL02@00FLL0
0`00000005W7001Ia`05001Ia`8000000P220003000000P0PP0000<000000>80003R00003`3R0009
0?<00003000000280000R00000<000002@0h000010000000>00003P0000h0002000000`0aP005`3D
00001`000000f`000=/0003K00000000001Ia`0000000P00FLL00`00000005W7001Ia`02001Ia`80
000000<005W700000000FLL01000FLL5000000D005W700<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0440oooo00110?ooo`030000003oool0oooo0500oooo
00<00000001>m000C_@01@00C_@00`00000004kd001>m003001>m00300000000C_@004kd00@004kd
00<00000001>m000C_@01000C_@00`00000005W7001Ia`03001Ia`h000001P00FLL00`00000005W7
001Ia`06001Ia`<000000P2200000`000000PP0008800006088000030000003R0000hP0000h0hP00
2`3c0002000000/0>00000D0000003P0000h0000>0000000000?0<H001L0e00000<000000=/00000
00000P00FLL01@00000005W7001Ia`00FLL0000000D005W70P0000000`00FLL00000000000020000
00T005W700<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0440oooo00110?ooo`030000003oool0oooo0540oooo00<00000001>m000C_@01@00C_@00`000000
04kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@01@000000
05W7001Ia`00FLL0000000L005W700<00000001Ia`00FLL01000FLL<000000@005W70P0000030880
0003000000220000PP0000H0PP0000<000000>80003R0000303R000<0?<000030000000h0000>000
00T0>00000D0000003P0000h0000>0000000000A0<H001L0e00000<00000001Ia`00FLL00P00FLL0
1000000005W7001Ia`000006001Ia`8000003000FLL00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0DP3oool0
0`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@0
0`00000004kd001>m004001>m00300000000FLL0000000P005W700<00000001Ia`00FLL02@00FLL0
0`00000005W7001Ia`04001Ia`H00000102200000`000000PP0008800006088000030000003R0000
hP0000X0hP003@3c00000`000000>00003P0000803P000030000000h0000>000008000004`36000E
0=@0000300000000FLL005W700<005W700D00000001Ia`00FLL005W700000005001Ia`0300000000
FLL005W700X005W700<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0440oooo00110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool0
0`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@0
0`00000004kd001>m003001>m08000002P00FLL00`00000005W7001Ia`08001Ia`0300000000FLL0
05W700P005W70P00000508800003000000220000PP0000H0PP0000<000000>80003R0000203R000=
0?<00003000000280000>00000P0>00000D0000003P00000000000000:/0000E0<H001<0e00000<0
0000001Ia`00FLL01@00FLL01@00000005W7001Ia`00FLL0000000@005W700<00000001Ia`00FLL0
2@00FLL00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0440oooo000Y0?ooo`<0000000<0
oooo09RHV00000000P0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo00L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0]0?ooo`0300000000C_@004kd00@004kd00<0
0000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@000000080000000<0
04kd00000000FLL02@00FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W700H005W700@0
0000001Ia`00FLL00000102200000`000000PP0008800006088000030000003R0000hP0000L0hP00
3P3c00000`000000>00003P0000703P000<00000102[000D0<H00180e00000<00000001Ia`00FLL0
1P00FLL00`00000005W7001Ia`02001Ia`0500000000FLL005W7001Ia`0000002P00FLL00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0440oooo000Z0?ooo`0>0000003oool0oooo0000002H
V9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV00000090?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0;P3oool00`00000004kd001>m004001>m00300000000C_@004kd00@0
04kd00<00000001>m000C_@00`00C_@2000000D004kd00<00000001Ia`00FLL01`00FLL00`000000
05W7001Ia`09001Ia`0300000000FLL005W700D005W700<00000001Ia`00FLL00P00FLL01@000000
PP00088000220000000000T0PP0000<000000>80003R00001@3R000>0?<000030=`000000000>000
0080>00000<0R00003P0000h00000P0h0002000000L0Z`005036000@0=@0000300000000FLL005W7
00L005W700<00000001Ia`00FLL00`00FLL01000000005W7001Ia`000009001Ia`030000003oool0
oooo09L0oooo000Z0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool0
0`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m00000000P000000
0`00C_@00000001>m005001>m00300000000FLL005W700H005W700<00000001Ia`00FLL02@00FLL0
0`00000005W7001Ia`04001Ia`0300000000FLL005W700@005W700D00000088000220000PP000000
0009088000030000003R0000hP0000<0hP003P3c0002000000P0>00000<0000003P0002[0000202[
000D0<H000h0e0000P00000:001Ia`0300000000FLL005W700<005W700<00000001Ia`0000002000
FLL00`000000oooo0?ooo`2H0?ooo`00:P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01`3oool4000002<0oooo00<000000?ooo`3oool0<03o
ool00`00000004kd001>m004001>m00300000000C_@004kd00<004kd0P000005001>m00300000000
C_@004kd00@004kd00<00000001Ia`00FLL01P00FLL00`00000005W7001Ia`09001Ia`0300000000
FLL005W7008005W700<00000001Ia`00FLL01P00FLL010000000PP00088000000009088000030000
003R0000hP000080hP003P3c00000`3L0000000003P0000603P000800000302[000D0<H000`0e000
2P000003001Ia`0300000000FLL005W700@005W70P000007001Ia`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0N03oool002X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0a0?ooo`0300000000C_@004kd00@004kd00<00000001>m00000000P0000000`00C_@00000
001>m005001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL01@00FLL00`00000005W7
001Ia`09001Ia`0500000000FLL005W7001Ia`0000002P00FLL00`000000PP000880000:08800003
0000003R0000hP0000h0l`0000<0g0000000000h0000100h00030000000308H000000000Z`0000`0
Z`005036000:0=@0000500000000FLL005W7001Ia`0000001P00FLL<000000H005W700<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1h0?ooo`00:P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?oo
o`0300000000C_@004kd00<004kd0P000005001>m00300000000C_@004kd00@004kd00<00000001>
m000C_@01000C_@00`00000005W7001Ia`04001Ia`0300000000FLL005W700T005W700@00000001I
a`00FLL000003000FLL00`000000PP000880000:088000030000003c0000l`0000`0l`0000<0g000
0000000h00000P0h0003000000D0QP0000<000000:/0002[00002`2[000D0<H000P0e00000<00000
001Ia`00FLL00P00FLL00`00000005W7001Ia`08001Ia`0300000000FLL005W700@005W700<00000
001Ia`00FLL00`00FLL00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0@@3oool002X0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0
000009RHV03oool0V9RH000000T0oooo00<000000?ooo`3oool0FP3oool00`00000004kd00000002
00000003001>m000000004kd00D004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004
001>m00300000000FLL005W700<005W700<00000001Ia`00FLL02P00FLL2000000d005W700<00000
0880002200002P2200000`000000l`000?<0000;0?<000030=`000000000>00000<000001`260000
0`000000QP000000000=0:/001@0aP001P3D00000`00000005W7001Ia`02001Ia`0300000000FLL0
05W700T005W700<00000001Ia`00FLL01@00FLL01@00000005W7001Ia`00FLL0000002<0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`110?ooo`00:@3oool01@0Q8B4000000?ooo`3o
ool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`070?ooo`030000003o
ool0oooo05/0oooo00<00000001>m000C_@00`00C_@00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`03001Ia`0300000000
FLL005W700P005W70P00000?001Ia`03000000220000PP0000X0PP0000<000000?<0003c00002@3c
0000103L0000000000000000000=08H000030000002[0000Z`0000/0Z`00503600040=@000030000
0000FLL005W700<005W700<00000001Ia`00FLL02000FLL00`00000005W7001Ia`07001Ia`030000
0000FLL0000002@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`110?ooo`00@@3o
ool00`000000oooo0?ooo`1K0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@01000
C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL00P00
FLL00`00000005W7001Ia`07001Ia`0300000000FLL00000010005W700<000000880002200002@22
00000`000000l`000?<000080?<000030=`00000000000000100QP0000<000000:/0002[00002`2[
000D0<H00080e0000P000005001Ia`0300000000FLL005W700P005W700<00000001Ia`00FLL02000
FLL00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03o
ool00440oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0f0?ooo`0300000000C_@0
04kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@0
04kd00<004kd00<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`06001Ia`0500000000FLL0
05W7001Ia`0000004000FLL00`000000PP0008800008088000030000003c0000l`0000L0l`0000<0
g0000000002600004P2600000`000000Z`000:/0000:0:/001@0aP000P000002001Ia`0300000000
FLL005W7008005W700<00000001Ia`00FLL02000FLL00`00000005W7001Ia`07001Ia`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0@03oool00440oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0g0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@0
0`00000004kd001>m004001>m00300000000C_@004kd00<004kd00D00000001Ia`00FLL005W70000
0007001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL03P00FLL00`000000PP000880
0008088000030000003c0000l`0000D0l`0000<0g000000000260000502600000`000000Z`000:/0
000:0:/00180aP0000<00000001Ia`00FLL00`00FLL01@00000005W7001Ia`00FLL0000000X005W7
00<00000001Ia`00FLL01P00FLL00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0400oooo
00110?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>03oool00`00000004kd001>
m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>
m004001>m00500000000FLL005W7001Ia`0000001@00FLL00`00000005W7001Ia`05001Ia`030000
0000FLL005W700h005W700<000000880002200001`2200000`000000l`000?<000040?<000030=`0
00000000QP0001H0QP0000<000000:/0002[00002P2[000@0<H0000300000000FLL005W700D005W7
00<00000001Ia`0000002`00FLL00`00000005W7001Ia`05001Ia`030000003oool0oooo0:40oooo
00110?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>@3oool00`00000004kd001>
m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>
m004001>m00400000000FLL005W7000000@005W700<00000001Ia`00FLL01`00FLL00`00000005W7
001Ia`0>001Ia`03000000220000PP0000L0PP0000<000000?<0003c00000P3c00000`3L00000000
08H0000H08H000030000002[0000Z`0000X0Z`003@360002000000T005W70P00000:001Ia`030000
0000FLL005W700D005W700<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1h0?ooo`00@@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03X0oooo00<00000001>m000C_@01000
C_@00`00000004kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000
C_@00`00000005W700000003001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL03P00
FLL00`000000PP0008800006088000060000003c0000l`000?<0003L000000006`2600000`000000
Z`000:/0000:0:/000/0aP0000<00000001Ia`00FLL02P00FLL00`00000005W7001Ia`08001Ia`03
00000000FLL005W700@005W700<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1h0?ooo`00
@03oool2000002D0oooo00<000000?ooo`3oool0>`3oool00`00000004kd001>m004001>m0030000
0000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m0800000
0P00FLL00`00000005W7001Ia`0;001Ia`0300000000FLL005W700h005W700<00000088000220000
1@2200001@000000l`000?<0003L0000000001`0QP0000<000000:/0002[00002`2[00090<H00003
00000000FLL005W700X005W700<00000001Ia`0000002@00FLL00`00000005W7001Ia`03001Ia`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0N03oool00400oooo0P00001T0?ooo`030000
0000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m0030000
0000C_@004kd00<004kd1000000>001Ia`0300000000FLL005W700d005W700<00000001Ia`000000
1`2200001@000000g0000000000I0000000001`0QP0000<000000:/0002[00002`2[00060<H00080
00003000FLL01@00000005W7001Ia`00FLL0000000P005W700<00000001Ia`00FLL00P00FLL00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00400
oooo0P00001U0?ooo`0300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`000000
04kd001>m004001>m00300000000C_@004kd00<004kd0P00000@001Ia`0300000000FLL005W700/0
05W700D00000001Ia`00FLL005W70000000608800080000000@0oooo01T0000I0000000070260000
0`000000Z`000:/0000;0:/000@0aP0000<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`03
001Ia`0300000000FLL005W700@005W700<00000001Ia`00FLL00P00FLL00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00400oooo1000001S0?oo
o`0300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>
m00300000000C_@000000080000000<004kd00000000FLL04000FLL00`00000005W7001Ia`09001I
a`0300000000FLL005W700<005W700<000000880002200000P220002000000<0oooo0P0I00000`00
0000QP0008H0000J08H000030000002[0000Z`0000/0Z`000P3600000`00000005W7001Ia`0;001I
a`0300000000FLL005W700D005W700<00000001Ia`00FLL00`00FLL01@00000005W7001Ia`00FLL0
000002h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`100?ooo`00@03oool20000
06H0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd
00<004kd0P000005001>m00300000000FLL005W700l005W700<00000001Ia`00FLL01`00FLL00`00
000005W7001Ia`04001Ia`8000000P220002000000D0oooo0P0I00000`000000QP0008H0000J08H0
00030000002[0000Z`0000X0Z`000P00000=001Ia`0300000000FLL005W700L005W700<00000001I
a`00FLL00P00FLL01000000005W7001Ia`00001W0?ooo`030000003oool0oooo0400oooo00100?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?`3oool00`00000004kd001>m004001>
m00300000000C_@004kd00@004kd00<00000001>m00000000P0000000`00C_@00000001>m005001>
m00300000000FLL005W700l005W700<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`06001I
a`80000000<0PP000000003oool01P3oool201T00003000000260000QP0001X0QP0000<000000:/0
002[00001`2[0002000000h005W700<00000001Ia`00FLL02@00FLL01`00000005W7001Ia`00FLL0
0000001Ia`000000J03oool00`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0400oooo00<00000001>m000C_@01000C_@00`00000004kd001>m003
001>m08000001@00C_@00`00000004kd001>m004001>m00300000000FLL005W700l005W700<00000
001Ia`00FLL00`00FLL00`00000005W7001Ia`08001Ia`8000002@3oool201T00003000000260000
QP0001@0QP0000<0000008H0000000000`2600000`000000Z`000:/000040:/00080000000<005W7
00000000FLL03000FLL00`00000005W7001Ia`0;001Ia`0300000000FLL005W700800000[03oool0
0400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`110?ooo`0300000000C_@004kd
00@004kd1@0000000`00C_@00000001>m005001>m00300000000C_@004kd00@004kd00<00000001I
a`00FLL03`00FLL01@00000005W7001Ia`00FLL0000000`005W700<000000?ooo`3oool01`3oool3
01T00003000000260000QP0001X0QP0000<000000:/0002[00000P2[00000`00000005W7001Ia`02
001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL03@00FLL300000:d0oooo00100?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`00000004kd001>m003001>
m08000001@00C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001I
a`00FLL03`00FLL00`00000005W70000000>001Ia`030000003oool0oooo00L0oooo0P0I00000`00
0000QP0008H0000K08H000040000002[00000000000000H005W700<00000001Ia`00FLL01`00FLL0
0`00000005W7001Ia`0?001Ia`030000003oool0oooo0340oooo00<000000?ooo`3oool0N03oool0
0400oooo0P00000U0?ooo`030000003oool0oooo04<0oooo00<00000001>m00000000P0000000`00
C_@00000001>m005001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00
000005W7001Ia`0?001Ia`0300000000FLL005W700h005W700<000000?ooo`3oool01`3oool201T0
0003000000260000QP0001T0QP000`000009001Ia`0300000000FLL005W700D005W700<00000001I
a`00FLL04000FLL00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo07P0oooo00100?ooo`80
00009@3oool00`000000oooo0?ooo`140?ooo`0300000000C_@004kd00<004kd00<00000001>m000
C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001Ia`00
FLL03@00FLL00`00000005W70000000@001Ia`030000003oool0oooo00L0oooo0P0I00000`000000
QP0008H0000D08H000@0000000<000`f00000000FLL02P00FLL00`00000005W7001Ia`03001Ia`03
00000000FLL005W7010005W700<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0400oooo00100?ooo`800000K03oool00`00000004kd001>m004001>m0030000
0000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m0030000
0000FLL005W700/005W700D00000001Ia`00FLL005W70000000@001Ia`030000003oool0oooo00L0
oooo0P0I00000`000000QP0008H0000?08H000@0000000D005W7000<=P0033H000`f0000000=001I
a`0500000000FLL005W7001Ia`0000004P00FLL00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0@03oool00400oooo0P00001]0?ooo`0300000000C_@004kd
00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd
00@004kd00<00000001Ia`00FLL02@00FLL00`00000005W7001Ia`03001Ia`0300000000FLL005W7
00h005W700<000000?ooo`3oool01`3oool201T00003000000260000QP0000/0QP000`000002000<
=P0300000000FLL000`f008000`f00<00000001Ia`00FLL03@00FLL00`00000005W70000000B001I
a`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`100?oo
o`00@03oool2000006h0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m003
00000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`07001Ia`03
00000000FLL005W700D005W700<00000001Ia`00FLL03@00FLL00`000000oooo0?ooo`080?ooo`80
6@000P00000808H000<00000100033H00`00000000`f000<=P02000<=P0300000000FLL005W700l0
05W700<00000001Ia`00FLL04000FLL00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0@03oool00400oooo0P00001_0?ooo`0300000000C_@004kd00@004kd
00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd
00<00000001Ia`00FLL01@00FLL00`00000005W7001Ia`07001Ia`0300000000FLL005W700d005W7
00<000000?ooo`3oool0203oool201T00003000000260000QP0000<0QP000`000003000<=P040000
000033H000`f000000@000`f00<00000001Ia`00FLL03`00FLL00`00000005W70000000@001Ia`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`180?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@0
1000C_@00`00000004kd001>m004001>m00300000000C_@004kd00<004kd00<00000001Ia`00FLL0
1000FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W700d005W70P0000090?ooo`<00000
00H0QP000000000000000000000<=P000006000<=P030000000033H005W7008000`f00<00000001I
a`00FLL03`00FLL01000000005W7001Ia`00000?001Ia`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`190?oo
o`0300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>m004001>
m00300000000C_@004kd00@004kd00<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`0:001I
a`0300000000FLL005W700h005W700<000000?ooo`3oool02P3oool01@00000000`f000<=P0033H0
000000L000`f00<00000001Ia`0033H00P00000A001Ia`0300000000FLL005W7008005W700<00000
001Ia`00FLL02`00FLL00`000000oooo0?ooo`2c0?ooo`00@03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo04X0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m003001>
m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@01000000005W7001Ia`00000>
001Ia`0300000000FLL005W700`005W700<00000001Ia`0000002P3oool20000008000`f00<00000
000<=P0033H01@0033H00`00000000`f000000020000014005W700<00000001Ia`00FLL01000FLL0
0`00000005W7001Ia`09001Ia`030000003oool0oooo0;@0oooo00100?ooo`<00000903oool00`00
0000oooo0?ooo`1;0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00
000004kd001>m004001>m00300000000C_@004kd00@004kd0P00000@001Ia`0300000000FLL005W7
00X005W700D00000001Ia`00FLL005W7000000090?ooo`040000000033H000`f000000H000`f1000
00000`0033H000000000000@001Ia`0300000000FLL005W700H005W700<00000001Ia`00FLL01`00
FLL00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07P0oooo00100?ooo`8000009@3oool0
0`000000oooo0?ooo`1<0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@0
0`00000004kd001>m004001>m00300000000C_@004kd00<0000000<004kd00000000FLL04000FLL0
0`00000005W7001Ia`08001Ia`0300000000FLL005W700<005W700<000000?ooo`3oool01@3oool0
1000000000`f000<=P000003000<=PD000000`0033H01000000005W7001Ia`00000>001Ia`030000
0000FLL005W700P005W700<00000001Ia`00FLL01@00FLL00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo07P0oooo00100?ooo`800000M03oool00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001>m000C_@00`00C_@3000000D004kd00<00000001Ia`00FLL03`00
FLL00`00000005W7001Ia`06001Ia`0300000000FLL005W700D005W700<000000?ooo`3oool00`3o
ool01@00000000`f000<=P00000000`f00<000000`0033H01@00000000`f001Ia`0033H0000000@0
05W700<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`09001Ia`0300000000FLL005W700<0
05W700<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0400
oooo00100?ooo`800000M@3oool00`00000004kd001>m004001>m00300000000C_@004kd00@004kd
1@000002001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL03`00FLL00`00000005W7
001Ia`04001Ia`0300000000FLL005W700L005W700D000000?ooo`3oool0oooo00000002000<=P<0
00001@0033H01@00000000`f000<=P0033H0000000H005W700<00000001Ia`00FLL02@00FLL00`00
000005W7001Ia`0;001Ia`0500000000FLL005W7001Ia`000000?`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo07D0oooo00<00000001>
m000C_@01000C_@00`00000004kd001>m002001>m0<000001P00C_@00`00000004kd001>m004001>
m00300000000FLL005W700l005W700<00000001Ia`00FLL00P00FLL00`00000005W7001Ia`09001I
a`030000003oool0000000<000001`0033H01@00000000`f000<=P0033H0000000P005W700<00000
001Ia`00FLL01`00FLL00`00000005W7001Ia`0=001Ia`<00000@03oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo07H0oooo00<00000001>
m000C_@01000C_@4000000<004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>
m00300000000FLL005W700l005W700@00000001Ia`00FLL000003000FLL300000003000<=P000000
00`f00H000`f00D00000000<=P0033H000`f0000000:001Ia`0300000000FLL005W700D005W700<0
0000001Ia`00FLL03`00FLL00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1@
0?ooo`0300000000C_@004kd00<0000000<004kd00000000C_@01@00C_@00`00000004kd001>m004
001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL03P00FLL00`00000005W70000000>
001Ia`030000000033H0000000L000`f00D00000000<=P0033H005W70000000<001Ia`0300000000
FLL005W700<005W700<00000001Ia`00FLL03`00FLL00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo0400oooo00100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D@3oool2
000000D004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@0
04kd00@004kd00<00000001Ia`00FLL03P00FLL00`00000005W7001Ia`0>001Ia`030000000033H0
00`f00D000`f00D00000000<=P0033H000`f0000000>001Ia`0500000000FLL005W7001Ia`000000
4@00FLL00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0DP3oool00`00000004kd001>m004001>m00300000000
C_@004kd00<004kd00<00000001>m000C_@01@00C_@00`00000004kd001>m004001>m00300000000
FLL005W700`005W700<00000001Ia`0000004000FLL00`00000000`f000<=P03000<=P0500000000
33H000`f000<=P0000004000FLL00`00000005W70000000A001Ia`030000003oool0oooo0;d0oooo
00100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D`3oool00`00000004kd001>
m004001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000004kd001>
m004001>m00300000000FLL005W700/005W700D00000001Ia`00FLL005W70000000@001Ia`050000
000033H000`f000<=P0000000`0033H00`00000005W7001Ia`0@001Ia`0300000000FLL005W700l0
05W700<000000?ooo`3oool0_P3oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`1D0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd
001>m004001>m00300000000C_@004kd00@004kd00<00000001Ia`00FLL02@00FLL00`00000005W7
001Ia`03001Ia`0300000000FLL005W700h005W700<00000000<=P0000000`0033H00`00000005W7
001Ia`0@001Ia`8000004000FLL00`000000oooo0?ooo`140?ooo`030000003oool0oooo07P0oooo
00100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0E03oool00`00000004kd001>
m005001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000004kd001>
m004001>m00300000000FLL005W700L005W700<00000001Ia`00FLL01@00FLL00`00000005W7001I
a`0>001Ia`050000000033H000`f000<=P0000004P00FLL01000000005W7001Ia`00000>001Ia`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0N03oool00400oooo00<000000?ooo`3oool0
O03oool00`00000004kd001>m005001>m00300000000C_@004kd00<004kd00<00000001>m000C_@0
1000C_@00`00000004kd001>m004001>m00300000000FLL005W700D005W700<00000001Ia`00FLL0
1`00FLL00`00000005W7001Ia`0>001Ia`030000000033H00000018005W700<00000001Ia`00FLL0
0P00FLL00`00000005W7001Ia`0:001Ia`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo0?ooo`1m0?ooo`0300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001Ia`00FLL00`00FLL00`00000005W7001Ia`09001Ia`0300000000
FLL005W700h005W700<00000001Ia`00FLL04000FLL00`00000005W7001Ia`04001Ia`0300000000
FLL005W700T005W700<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0400oooo00100?ooo`030000003oool0oooo07h0oooo00<00000001>m000C_@01000C_@0
0`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@0
1@00000005W7001Ia`00FLL0000000d005W700<00000001Ia`00FLL03000FLL20000014005W700<0
0000001Ia`00FLL01P00FLL00`00000005W7001Ia`07001Ia`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`100?ooo`00@03oool3000007l0oooo00<00000
001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd0P000005
001>m0<000003P00FLL00`00000005W7001Ia`0;001Ia`0400000000FLL00000000000l005W700<0
0000001Ia`00FLL02000FLL00`00000005W7001Ia`05001Ia`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo05T0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004
001>m00300000000C_@004kd00@004kd00<00000001>m000C_@00P00C_@30000010005W700<00000
001Ia`00FLL02@00FLL01P00000005W7001Ia`00000005W7000000d005W700<00000001Ia`00FLL0
2P00FLL00`00000005W7001Ia`03001Ia`030000003oool0oooo0840oooo00<000000?ooo`3oool0
@03oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1J0?ooo`0300000000
C_@004kd00@004kd00<00000001>m000C_@00`00C_@00`00000004kd001>m004001>m0D000000`00
C_@00`00000005W7001Ia`0>001Ia`0300000000FLL005W700L005W700D00000001Ia`00FLL005W7
00000002001Ia`0300000000FLL005W700T005W700<00000001Ia`00FLL03000FLL01@00000005W7
001Ia`00FLL0000008@0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1K0?ooo`0300000000C_@004kd00@004kd00<00000001>m000C_@0
0`00C_@01000000004kd001>m000C_@4000000L004kd00<00000001Ia`00FLL03P00FLL00`000000
05W7001Ia`05001Ia`0300000000FLL005W7008005W700D00000001Ia`00FLL005W700000009001I
a`0300000000FLL005W700h005W70`0000380?ooo`00@03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo05`0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m002001>m0@0
00001000C_@00`00000004kd001>m005001>m00300000000FLL005W700h005W700<00000001Ia`00
FLL00`00FLL00`00000005W7001Ia`03001Ia`0300000000FLL005W7008005W700<00000001Ia`00
FLL01@00FLL00`00000005W7001Ia`0@001Ia`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0N03oool00400oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1M0?ooo`030000
0000C_@004kd00@004kd10000002001>m00300000000C_@004kd00@004kd00<00000001>m000C_@0
1000C_@00`00000005W7001Ia`0?001Ia`0500000000FLL005W7001Ia`0000001P00FLL00`000000
05W7001Ia`03001Ia`0300000000FLL005W700<005W700<00000001Ia`00FLL04000FLL00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo07P0oooo00100?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0G@3oool01000000004kd001>m000C_@4000000H004kd00<00000001>m000
C_@01000C_@00`00000004kd001>m004001>m00300000000FLL005W700l005W700<00000001Ia`00
00001`00FLL00`00000005W7001Ia`04001Ia`0500000000FLL005W7001Ia`0000004P00FLL00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo07P0oooo00100?ooo`030000003oool0oooo08D0
oooo0`000004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`000000
04kd001>m004001>m00300000000FLL005W700l005W70P000007001Ia`0300000000FLL005W700D0
05W700<00000001Ia`0000004P00FLL00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0QP3oool00`00000004kd
001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd
001>m004001>m00300000000FLL005W700d005W700<00000001Ia`00FLL00P000005001Ia`030000
0000FLL005W700D005W70P00000B001Ia`030000003oool0oooo0500oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo0?ooo`270?ooo`0300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001Ia`00FLL02`00FLL00`00000005W7001Ia`03001Ia`8000000`00
FLL00`00000005W7001Ia`03001Ia`80000000<005W700000000FLL04000FLL00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00400oooo00<00000
0?ooo`3oool0R03oool00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000
001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000FLL005W700T005W700<00000
001Ia`00FLL01P00FLL01000000005W7001Ia`000002001Ia`<000001000FLL00`00000005W7001I
a`0=001Ia`030000003oool0oooo08X0oooo00<000000?ooo`3oool0@03oool00400oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`1R0?ooo`0300000000C_@004kd00@004kd00<00000
001>m000C_@01000C_@00`00000004kd001>m003001>m00300000000C_@004kd00D004kd00<00000
001Ia`00FLL01`00FLL00`00000005W7001Ia`08001Ia`D000002000FLL00`00000005W7001Ia`0;
001Ia`030000003oool0oooo08/0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1S0?ooo`0300000000C_@004kd00@004kd00<00000001>
m000C_@00`00C_@00`00000004kd001>m004001>m00300000000C_@004kd00D004kd00<00000001I
a`00FLL01@00FLL00`00000005W7001Ia`0;001Ia`0300000000FLL005W700T005W700<00000001I
a`00FLL02@00FLL00`000000oooo0?ooo`3?0?ooo`00@03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo06@0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m003001>m003
00000000C_@004kd00@004kd00<00000001>m000C_@01@00C_@00`00000005W7001Ia`03001Ia`03
00000000FLL005W700`005W700<00000001Ia`00FLL02P00FLL00`00000005W7001Ia`07001Ia`03
0000003oool0oooo0=00oooo00100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
I@3oool00`00000004kd001>m003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@0
1000C_@00`00000004kd001>m005001>m00500000000FLL005W7001Ia`0000003`00FLL00`000000
05W7001Ia`0;001Ia`0300000000FLL005W700D005W700<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`1h0?ooo`00@03oool3000002@0oooo00<000000?ooo`3oool0I@3oool00`00000004kd
001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd
001>m005001>m00300000000FLL00000010005W700<00000001Ia`00FLL03000FLL00`00000005W7
001Ia`03001Ia`030000003oool0oooo05L0oooo00<000000?ooo`3oool0N03oool00400oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`1V0?ooo`0300000000C_@004kd00@004kd00<0
0000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd0`00
000@001Ia`0300000000FLL005W700d005W700D00000001Ia`00FLL005W70000001J0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0SP3o
ool00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01000
C_@00`00000004kd001>m00300000003001>m000000005W7008000003P00FLL00`00000005W7001I
a`0>001Ia`0300000000FLL0000005/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`100?ooo`00@03oool00`000000oooo0?ooo`2?0?ooo`0300000000C_@004kd00@004kd00<00000
001>m000C_@01000C_@00`00000004kd001>m003001>m0<000001@00C_@00`00000005W7001Ia`02
000000`005W700<00000001Ia`00FLL03P00FLL2000005`0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo0?ooo`2@0?ooo`0300000000C_@004kd
00@004kd00<00000001>m000C_@01000C_@00`00000004kd0000000200000003001>m000000004kd
00H004kd00@00000001Ia`00FLL005W70P00000:001Ia`0300000000FLL005W700/005W70`000000
0`00FLL000000?ooo`1K0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0?`3oool0
0400oooo00<000000?ooo`3oool0T@3oool00`00000004kd001>m004001>m00400000000C_@004kd
001>m0@000001@00C_@00`00000004kd001>m005001>m00300000000FLL005W7008005W70P000008
001Ia`0300000000FLL005W700T005W70P000003001Ia`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0?`3oool003l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1[0?oo
o`H004kd10000003001>m00300000000C_@004kd00@004kd00<00000001>m000C_@01@00C_@00`00
000005W7001Ia`03001Ia`8000001P00FLL00`00000005W7001Ia`06001Ia`<000001000FLL00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo03l0oooo000o0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0K03oool2001>m0<0000000<004kd00000000C_@01@00C_@00`000000
04kd001>m004001>m00300000000C_@004kd00D004kd00<00000001Ia`00FLL01000FLL2000000@0
05W700<00000001Ia`00FLL00`00FLL3000000H005W700<000000?ooo`3oool0f03oool003l0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1]0?ooo`0300000000C_@004kd00<004kd
00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00D004kd
00<00000001Ia`00FLL01@00FLL20000008005W700@00000001Ia`00FLL005W70P000008001Ia`03
0000003oool0oooo0=T0oooo000o0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
K@3oool00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000C_@0
1000C_@00`00000004kd001>m004001>m00300000000FLL005W700L005W71P000009001Ia`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0N03oool003l0oooo0P00000V0?ooo`030000003o
ool0oooo06h0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000
C_@004kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`08001Ia`0300000000
FLL005W700T005W700<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1h0?ooo`00?`3oool2
000009P0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000C_@0
04kd00@004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`07001Ia`0300000000FLL0
05W700P005W700<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03l0oooo000o0?ooo`800000V@3oool00`00000004kd001>m004001>m00300000000C_@004kd
00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m004001>m00300000000FLL005W7
00H005W700<00000001Ia`00FLL01`00FLL00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0?`3oool002H0oooo100000000`2j^[X0oooo09RHV00300000003
09RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool01P3oool2000009X0oooo00<00000001>m000
C_@01000C_@00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000001>m000
C_@01000C_@00`00000005W7001Ia`05001Ia`0300000000FLL005W700H005W700<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03l0oooo000V0?ooo`0A0<c<
c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RH
V0000000203oool2000009/0oooo00<00000001>m000C_@01000C_@00`00000004kd001>m004001>
m00300000000C_@004kd00<004kd00<00000001>m000C_@01@00C_@00`00000005W7001Ia`04001I
a`0300000000FLL005W700D005W700<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03l0oooo000W0?ooo`030<c<c03^k^h0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool5000002<0oooo00<00000
0?ooo`3oool0L`3oool00`00000004kd001>m004001>m00300000000C_@004kd00@004kd00<00000
001>m000C_@00`00C_@00`00000004kd001>m005001>m00300000000FLL005W700<005W700<00000
001Ia`00FLL01000FLL00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo03l0oooo000X0?oo
o`050:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1d0?ooo`0300000000C_@0
04kd00@004kd00<00000001>m000C_@01000C_@00`00000004kd001>m003001>m00300000000C_@0
04kd00@004kd00<00000001Ia`00FLL00`00FLL00`00000005W7001Ia`03001Ia`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0?`3oool002P0oooo00D0gMgM06IVIP3oool0oooo00000003
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo07D0oooo00<00000001>m000C_@00`00C_@00`00000004kd001>m005
001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@00`00000005W7001Ia`02
001Ia`0300000000FLL005W7008005W700<000000?ooo`3oool0hP3oool002H0oooo00@0MgMg0?oo
o`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0M`3oool00`00000004kd
001>m003001>m00300000000C_@004kd00D004kd00<00000001>m000C_@00`00C_@00`00000004kd
001>m004001>m00500000000FLL005W7001Ia`0000000`00FLL00`000000oooo0?ooo`3S0?ooo`00
9P3oool010000000V9RH09RHV00000020?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002H
V9P0oooo09RHV0000000203oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07L0oooo
00<00000001>m000C_@01000C_@00`00000004kd001>m005001>m00300000000C_@004kd00<004kd
00<00000001>m000C_@01000C_@01000000005W7001Ia`000002001Ia`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0M`3oool002H0oooo00@0V9RH000000000000V9RH0P3oool01`2HV9P0
0000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`060?ooo`8000009@3oool0
10000000oooo0?ooo`3oool4000007<0oooo00<00000001>m000C_@01000C_@00`00000004kd001>
m005001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000C_@01@00000005W70000
0000FLL0000006d0oooo00<000000?ooo`3oool0M`3oool003l0oooo0P00000T0?ooo`030000003o
ool0oooo00H0oooo0P0000040?ooo`H00000103oool5000005l0oooo00<00000001>m000C_@01000
C_@00`00000004kd001>m005001>m00300000000C_@004kd00<004kd00<00000001>m000C_@01000
C_@3000006h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0o0?ooo`00?`3oool2
000001h0oooo0P00000V0?ooo`H00000103oool6000000@0oooo1P0000120?ooo`0300000000C_@0
04kd00@004kd00<00000001>m000C_@01@00C_@00`00000004kd001>m003001>m00400000000C_@0
04kd001>m0@00000K`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03l0oooo000o
0?ooo`8000006`3oool3000004H0oooo1@0000040?ooo`H00000103oool4000002P0oooo00<00000
001>m000C_@01000C_@00`00000004kd001>m005001>m00400000000C_@004kd001>m0D00000L`3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03l0oooo000o0?ooo`8000006P3oool0
0`000000oooo0?ooo`1N0?ooo`800000103oool6000000@0oooo1P00000C0?ooo`0300000000C_@0
04kd00@004kd00<00000001>m000C_@01000C_@4000007P0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0o0?ooo`00?`3oool2000001D0oooo0P00001m0?ooo`H00000103oool60000
00040?ooo`00000004kd001>m0H0000000@004kd0000000000000000]03oool00`000000oooo0?oo
o`0o0?ooo`00?`3oool00`000000oooo0?ooo`0A0?ooo`<00000T@3oool01000000004kd001>m000
C_@5000000<0oooo1P0000030?ooo`H00000103oool4000009d0oooo00<000000?ooo`3oool0?`3o
ool003l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2C0?ooo`<000007`3oool2
000000@0oooo1P0000040?ooo`H00000b@3oool003l0oooo00<000000?ooo`3oool02@3oool30000
0=D0oooo1P0000040?ooo`H00000103oool600000380oooo00<000000?ooo`3oool0M`3oool003l0
oooo00<000000?ooo`3oool01`3oool200000?H0oooo1P0000030?ooo`H00000103oool4000001L0
oooo00<000000?ooo`3oool0M`3oool003l0oooo0`00003o0?oooaL0oooo0P0000040?ooo`H00000
103oool6000000030?ooo`000000oooo07P0oooo000o0?ooo`030000003oool0oooo00<00000o`3o
ool[0?ooo`030000003oool0000000D00000103oool6000000@0oooo1P00000J0?ooo`030000003o
ool000000440oooo000o0?ooo`H00000o`3oool[0?ooo`030000003oool0oooo01d0oooo1P000003
0?ooo`L000000`3oool4000000030?ooo`000000oooo0400oooo00190?ooo`H00000103oool60000
00@0oooo1P00003o0?ooo`d0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000<00000@@3oool006H0oooo1P0000040?ooo`H00000103oool40000
0?l0oooo5`3oool010000000oooo0?ooo`0000030?ooo`X00000A03oool007h0oooo0P0000040?oo
o`H000000`3oool6000000@0oooo1000003_0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo00000005000004X0oooo002K0?ooo`800000103oool60000
00@0oooo1P0000030?ooo`@00000dP3oool010000000oooo0?ooo`0000030?ooo`P00000D03oool0
0;P0oooo0P0000040?ooo`H00000103oool6000000@0oooo1000002^0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01P00001F0?ooo`00eP3oool2000000<0oooo1P0000040?oo
o`H00000Q03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`L00000F`3oool00>l0oooo1P0000040?ooo`H00000103oool50000
06L0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00D00000H@3oool00?l0oooo3@3oool6000000@0oooo1P0000040?ooo`H00000B@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P00001V
0?ooo`00o`3oool[0?ooo`D00000103oool6000000@0oooo1000000^0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool02000001Z0?ooo`00o`3ooom20?ooo`800000103oool6000000@0
oooo1@0000040?ooo`@000004@3oool00`000000oooo0000000600000740oooo003o0?oooel0oooo
0P0000040?ooo`H00000103oool4000007L0oooo003o0?ooonX0oooo003o0?ooonX0oooo003o0?oo
oiH0oooo00L0410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0A`3o
ool00?l0ooooV@3oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000B@3oool00?l0oooo
VP3oool00`000000oooo000000030?ooo`030000003oool0oooo04L0oooo003o0?ooohP0oooo00D0
V9RH000000000000000009RHV00=0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
A`3oool00?l0ooooR03oool01@000000V9RH0?ooo`2HV9P0000000`0oooo00@0V9RH0000003oool0
00000`3oool00`000000oooo0?ooo`170?ooo`00o`3ooon80?ooo`050000003oool0oooo0?ooo`00
00002@3oool40000000309RHV03oool0000000<0oooo00<000000?ooo`3oool0A`3oool00?l0oooo
N@3oool01`0@41000000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`1gMgL0EEEE0?ooo`030?ooo`050000002HV9P0
oooo09RHV0000000B@3oool00?l0ooooO03oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P0
0000103oool01@000000oooo0?ooo`3oool0000000X0oooo00H0410@000000000000<S8b0?ooo`2H
V9P30000000309RHV03oool0oooo04L0oooo003o0?ooogd0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000G@3oool00?l0ooooLP3oool7
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000002HV9P0
oooo09RHV0000000G@3oool00?l0ooooO03oool0102HV9P000000?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00D0V9RH000000000000000009RHV01M0?ooo`00o`3ooomi0?ooo`@0000000<0
V9RH0?ooo`0000000`3oool00`000000oooo0?ooo`1T0?ooo`00o`3ooomi0?ooo`0307MgM`1EEED0
oooo00<0oooo00D0000009RHV03oool0V9RH0000001V0?ooo`00o`3ooomj0?ooo`06010@40000000
0000038b<P3oool0V9RH0`0000000`2HV9P0oooo0?ooo`1T0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ
0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooooZ0?ooo`00o`3ooon60?ooo`<0000000<0
oooo07MgM`0000000P00001L0?ooo`00o`3ooon70?ooo`0609RHV01gMgL0oooo0?ooo`0Q8B40ZJVY
G@3oool00?l0ooooR03oool0101EEED0V9RH07MgM`1VIVIN0?ooo`00o`3ooon80?ooo`030>k^kP0Q
8B40<S8b05l0oooo003o0?ooohP0oooo00<0k^k^010@400b<S80G`3oool00?l0ooooR03oool0101V
IVH0MgMg0:VYZ@1VIVIN0?ooo`00o`3ooon70?ooo`040:VYZ@0Q8B40oooo0?ooo`80V9RH00<0k^k^
0?ooo`3oool0FP3oool00?l0ooooQP3oool30000000307MgM`3oool0<S8b0080000000<0^[Zj0?oo
o`3oool0F@3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool0
0?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool0
0?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool0
0?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool0
0?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool00?l0oooojP3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 488}, {488, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.0020492, 0.0020492}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Saving the Magnetic field data  into a text file", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In this example, one save the data in  bz1 (generated in the section \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "Magnetic Field Plots",
  StyleBox[
  "\") into a tab delimited text file ready for postcprocessing in a \
spreadsheet software fro example. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ In\ Mathematic\ 3.0\ \ *) \[IndentingNewLine]\(tab = 
        bz1;\)\), "\n", 
    \(\(tmp = 
        OpenWrite["\<file.dta\>", FormatType \[Rule] OutputForm];\)\), "\n", 
    \(\(Do[
        Write[tmp, 
          CForm[tab\[LeftDoubleBracket]i, 1\[RightDoubleBracket]], "\<\t\>", 
          CForm[tab\[LeftDoubleBracket]i, 2\[RightDoubleBracket]]], {i, 
          Length[tab]}];\)\), "\n", 
    \(Close[tmp]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      In\ Mathematic\ 4.0\  : \ 
        Use\ the\ new\ "\<Export\>"\ function\ \ *) \)}], "Input"],

Cell[BoxData[
    \("file.dta"\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Exporting the geometry to a DXF File", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To check carefully the geometry with CAD software, it may be usefull to \
export in the DXF Format. Here is the method. The file ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "\"file.dxf\"",
  StyleBox[
  " is created in the default directory. All styles, axes and boxes are lost. \
",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(<< Utilities`DXF`; \)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"WriteDXF", "[", 
        RowBox[{"\"\<file.dxf\>\"", ",", 
          RowBox[{"Graphics3D", "[", 
            RowBox[{
              StyleBox["radObjDrw",
                FontColor->RGBColor[1, 0, 0]], "[", "g", "]"}], "]"}]}], 
        "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the pole shape...", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
A loop of computation is made for a varying value of the \
hyperbolicity figure hyp. As expected, the dodecapole coefficient crosses \
zero for an almost exact hyperbolic shape of the poles. Try increasing  the \
segmentation parameters (be carefull on the CPU time )  to check if the \
result is stable or not. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(radius = 
        34;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ 
      radius\ of\ circle\ *) \t\t\t\t\t\), "\[IndentingNewLine]", 
    \(\(width = 
        60;\)\t\t\t\t\ \  (*\ \ pole\ width\ *) \), "\[IndentingNewLine]", 
    \(\(heigh = 80;\)\t\t\t\t (*\ 
      height\ of\ iron\ in\ coil\ *) \), "\[IndentingNewLine]", 
    \(\(length = 80;\)\t\t\t\t (*\ 
      length\ \ along\ beam\ *) \), "\[IndentingNewLine]", 
    \(\(chamfer = 
        8;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ chamfer\ of\ the\ pole\ *) \), "\[IndentingNewLine]", 
    \(\(curden = 5;\)\t\t\t\t (*\ 
      current\ density\ A/
          mm2\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(nx = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ beam\ *) \), \
"\[IndentingNewLine]", 
    \(\(ny = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ width\ *) \
\), "\[IndentingNewLine]", 
    \(\(nz = 
        4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ height\ *) \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nb = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ return\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(na = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ angular\ segmentation\ in\ the\ \
corner\ *) \[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(rmin = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
      minimum\ radius\ of\ the\ coil\ windings\ *) \), "\[IndentingNewLine]", 
  
    \(\(offset = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ 
      Vert . \ recess\ betw . \ 1  st\ and\ 2  
        nd\ coils*) \), "\[IndentingNewLine]", 
    \(\(hyp = {0.9, 0.95, 1, 1.05, 
          1.1};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ pole\ profile\ 0.1 < \ hyp\  < 2, \ 
      1 : \ hyperbolic*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ironcolor = {0, 0.5, 
          1};\)\ \ \ \ \  (*\ \ Color\ of\ the\ yoke\ \ *) \), "\
\[IndentingNewLine]", 
    \(\(coilcolor = {1, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \  (*\ \ Color\ of\ the\ coil\ \ *) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(iron\  = RadMatSteel37[];\)\ \ \ \ \  (*\ 
      Material\ of\ the\ Yoke\ *) \), "\[IndentingNewLine]", 
    \(\(nseg = seg[nx, ny, nz, nb, na];\)\), "\[IndentingNewLine]", 
    \(\(res = 
        quad[radius, length, width, heigh, chamfer, hyp, nseg, curden, 
          iron];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(dodecapole = \(Transpose[
          Re[\((IntMultipole /. 
                res)\)]]\)[\([6]\)]\), "\[IndentingNewLine]", 
    \(quadrupole = \(Transpose[
          Re[\((IntMultipole /. 
                res)\)]]\)[\([2]\)]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(ListPlot[
        Transpose[{hyp, dodecapole}], \[IndentingNewLine]PlotJoined \[Rule] 
          True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integrated Dodecapole \
vs Hyperbolicity\>"];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ListPlot[
        Transpose[{hyp, quadrupole}], \[IndentingNewLine]PlotJoined \[Rule] 
          True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integrated Quadrupole \
vs Hyperbolicity\>"];\)\)}], "Input"],

Cell[BoxData[
    \({6.107520444664783`*^-8, 3.442705670542168`*^-8, 
      7.305871607687919`*^-9, \(-1.9992723979123107`*^-8\), \
\(-5.326744708794573`*^-8\)}\)], "Output"],

Cell[BoxData[
    \({1.7519073558689757`, 1.7724108411489585`, 1.79202385366026`, 
      1.8095500037678562`, 1.810405316053021`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-4.2619 4.7619 0.288921 5.14772e+06 [
[.02381 -0.0125 -9.5 -14 ]
[.02381 -0.0125 9.5 0 ]
[.2619 -0.0125 -12.5 -14 ]
[.2619 -0.0125 12.5 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -12.5 -14 ]
[.7381 -0.0125 12.5 0 ]
[.97619 -0.0125 -9.5 -14 ]
[.97619 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08301 -52.75 -7.90625 ]
[-0.0125 .08301 0 7.90625 ]
[-0.0125 .18597 -52.75 -7.90625 ]
[-0.0125 .18597 0 7.90625 ]
[-0.0125 .28892 -10 -7 ]
[-0.0125 .28892 0 7 ]
[-0.0125 .39188 -44.5 -7.90625 ]
[-0.0125 .39188 0 7.90625 ]
[-0.0125 .49483 -44.5 -7.90625 ]
[-0.0125 .49483 0 7.90625 ]
[-0.0125 .59778 -44.5 -7.90625 ]
[-0.0125 .59778 0 7.90625 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -97.8438 0 ]
[.5 .63053 97.8438 14 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .08301 m
1 .08301 L
s
0 .18597 m
1 .18597 L
s
0 .28892 m
1 .28892 L
s
0 .39188 m
1 .39188 L
s
0 .49483 m
1 .49483 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08301 m
.00625 .08301 L
s
gsave
-0.0125 .08301 -113.75 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
79.000 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
88.438 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
100.438 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
106.188 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .18597 m
.00625 .18597 L
s
gsave
-0.0125 .18597 -113.75 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
79.000 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
88.438 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
100.438 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
106.188 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .28892 m
.00625 .28892 L
s
gsave
-0.0125 .28892 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .39188 m
.00625 .39188 L
s
gsave
-0.0125 .39188 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .49483 m
.00625 .49483 L
s
gsave
-0.0125 .49483 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .59778 m
.00625 .59778 L
s
gsave
-0.0125 .59778 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10875 m
.00375 .10875 L
s
0 .13449 m
.00375 .13449 L
s
0 .16023 m
.00375 .16023 L
s
0 .21171 m
.00375 .21171 L
s
0 .23744 m
.00375 .23744 L
s
0 .26318 m
.00375 .26318 L
s
0 .31466 m
.00375 .31466 L
s
0 .3404 m
.00375 .3404 L
s
0 .36614 m
.00375 .36614 L
s
0 .41761 m
.00375 .41761 L
s
0 .44335 m
.00375 .44335 L
s
0 .46909 m
.00375 .46909 L
s
0 .52057 m
.00375 .52057 L
s
0 .54631 m
.00375 .54631 L
s
0 .57205 m
.00375 .57205 L
s
0 .05727 m
.00375 .05727 L
s
0 .03153 m
.00375 .03153 L
s
0 .0058 m
.00375 .0058 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08301 m
1 .08301 L
s
.99375 .18597 m
1 .18597 L
s
.99375 .28892 m
1 .28892 L
s
.99375 .39188 m
1 .39188 L
s
.99375 .49483 m
1 .49483 L
s
.99375 .59778 m
1 .59778 L
s
.125 Mabswid
.99625 .10875 m
1 .10875 L
s
.99625 .13449 m
1 .13449 L
s
.99625 .16023 m
1 .16023 L
s
.99625 .21171 m
1 .21171 L
s
.99625 .23744 m
1 .23744 L
s
.99625 .26318 m
1 .26318 L
s
.99625 .31466 m
1 .31466 L
s
.99625 .3404 m
1 .3404 L
s
.99625 .36614 m
1 .36614 L
s
.99625 .41761 m
1 .41761 L
s
.99625 .44335 m
1 .44335 L
s
.99625 .46909 m
1 .46909 L
s
.99625 .52057 m
1 .52057 L
s
.99625 .54631 m
1 .54631 L
s
.99625 .57205 m
1 .57205 L
s
.99625 .05727 m
1 .05727 L
s
.99625 .03153 m
1 .03153 L
s
.99625 .0058 m
1 .0058 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .28892 m
1 .28892 L
s
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -158.844 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integrated) show
114.438 14.000 moveto
(Dodecapole) show
174.625 14.000 moveto
(vs) show
188.250 14.000 moveto
(Hyperbolicity) show
254.688 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .60332 m
.2619 .46614 L
.5 .32653 L
.7381 .186 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00=@3oool01@2HV9P00000000000000000V9RH0080oooo00D0<S8b0?ooo`0b<S80<S8b09RH
V00W0?ooo`0509RHV000000000000000002HV9P00P3oool01@0b<S80oooo038b<P0b<S80V9RH00<0
oooo00D0410@000000000000000009RHV00/0?ooo`<00000:`3oool300000080oooo00<0<S8b0?oo
o`2HV9P00`0000000`2HV9P0oooo010@40030000000309RHV03oool0oooo02H0oooo0`0000020?oo
o`04038b<P3oool0oooo0?ooo`<00000103oool003D0oooo00D0000009RHV03oool0V9RH00000004
0?ooo`040>k^kP2HV9P0410@05EEEBH0oooo00D0000009RHV03oool0V9RH000000040?ooo`040>k^
kP2HV9P0410@05EEE@D0oooo00<0V9RH0000003oool0;03oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00<0oooo00D0000009RHV03oool0V9RH000000040?ooo`0309RHV0000000oooo
02P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`00=@3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<0k^k^010@402HV9P09@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<0k^k^010@402HV9P01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo000e
0?ooo`050000003oool0oooo0?ooo`000000103oool01@2HV9P000000000001EEED08B4Q02D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`0509RHV0000000000005EEE@0Q8B401@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo000e0?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000V9RH0?ooo`3<c<`0000002D0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
002HV9P0oooo0<c<c0000000103oool00`2HV9P000000?ooo`0/0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0V9RH0000
003oool0:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo000e0?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000002D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`060000003oool0oooo0?ooo`000000oooo100000000`2HV9P0
oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool01P000000
oooo0?ooo`3oool000000?ooo`@0000000<0V9RH0?ooo`3oool09`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo000e0?ooo`050000002HV9P0oooo09RHV0000000103oool0
1@000000V9RH0?ooo`2HV9P0000002D0oooo00D0000009RHV03oool0V9RH000000040?ooo`080000
002HV9P0oooo09RHV0000000oooo07MgM`1EEED`0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool00`3oool020000000V9RH0?ooo`2HV9P000000?ooo`1gMgL0EEEE;03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo000e0?ooo`0509RHV000000000000000002H
V9P0103oool01@2HV9P00000000000000000V9RH02D0oooo00D0V9RH000000000000000009RHV004
0?ooo`0509RHV000000000000000002HV9P00P3oool0100@410000000000000b<S8/0?ooo`03024Q
8@000000oooo02/0oooo00<08B4Q0000003oool0103oool01@2HV9P00000000000000000V9RH0080
oooo00@0410@000000000000<S8b:03oool00`0Q8B4000000?ooo`060?ooo`03024Q8@000000oooo
00@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000g0?oo
on@000001@3oool003L0oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo0380oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0;P3oool2000000P0
oooo00<000000?ooo`3oool00`3oool003L0oooo0P0000040?ooo`030000003oool0oooo03<0oooo
00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo02d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo02/0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo000g
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?oo
o`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo000g0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool09`3oool2000000l0oooo00<000000?ooo`3o
ool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0V0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool003L0oooo0P0000040?ooo`030000003o
ool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo02@0oooo0P00000B0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool08P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo000=0?ooo`030000003oool0oooo00<0
oooo00H0EEEE0>k^kP3oool0oooo0>k^kP1EEED40?ooo`<0000000<0oooo09RHV00000000P000000
0`2HV9P0oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0803oool2
000001H0oooo00<000000?ooo`3oool00`3oool000d0oooo00<000000?ooo`3oool00`3oool01P3^
k^h0EEEE0>k^kP3^k^h0EEEE0>k^kPD0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH0000
0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00`3oool000X0oooo1P0000040?ooo`040>k^kP1EEED0EEEE0>k^
kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00<0oooo00030?ooo`L0000000@0A4A409RHV03oool000001P3oool0103^k^h0EEEE05EEE@3^
k^h60?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool3000000<0001o
00<000000000O`0007l0_P0007l2000001T0001o0P0000050?ooo`002P3oool0103^k^h0410@0=gM
g@0000050?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0k^k^1@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0K
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool000/0oooo00<0ZJVY038b
<P0000001@3oool01P1EEED0k^k^0?ooo`3oool0k^k^05EEE@D0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo01T0oooo0P00000M0?ooo`030000003oool0oooo00<0oooo000<0?ooo`0306IVIP00
0000oooo00l0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000000L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo01P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`00303oool00`3^k^h0410@0?ooo`0>0?oo
o`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`04000000050?ooo`000000
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo01L0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00;P3oool2000000L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0E0?ooo`8000008@3oool00`000000oooo0?ooo`03
0?ooo`00;@3oool010000000oooo0?ooo`0000060?ooo`800000103oool00`000000oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0D
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool002h0oooo0P0000070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool04P3oool2000002@0oooo00<000000?oo
o`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
0`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0>0?ooo`800000:03o
ool00`000000oooo0?ooo`030?ooo`00=`3oool2000000@0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool03@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool02P3oool2000002`0
oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00`3oool003L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`070?ooo`800000;`3oool00`000000oooo0?oo
o`030?ooo`00=`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`030?ooo`00=`3oool2000000@0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?oo
o`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo000g0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool00`3oool2000003<0oooo00<000000?ooo`3o
ool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`020?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool000X0oooo100000000`2j^[X0oooo0?oo
o`020?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE103oool3000000030?ooo`2HV9P000000080
000000<0V9RH0?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo0080
0000=P3oool00`000000oooo0?ooo`030?ooo`002P3oool01@3<c<`0k^k^0?ooo`3<c<`0EEEE00@0
oooo00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`080000003oool0oooo0000002HV9P0oooo
09RHV000000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`000000>03oool00`000000
oooo0?ooo`030?ooo`002`3oool00`3<c<`0k^k^0?ooo`060?ooo`040>k^kP1EEED0EEEE0>k^kPH0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0000003oool0>03oool00`000000oooo0?ooo`030?ooo`000`3oool700000080
oooo00<0ZJVY0>k^kP3oool01@3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool03`3oool3000000<0001o00<000000000O`0007l0WP0007l2
000003T0001o0P0000050?ooo`00303oool00`3MgMd0IVIV0?ooo`040?ooo`060>k^kP1EEED0k^k^
0>k^kP1EEED0k^k^1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo
00<0001o0?ooo`3oool0<03oool2000000030?ooo`0007l0oooo03T0oooo00<000000?ooo`3oool0
0`3oool000X0oooo00@0MgMg0?ooo`3oool000001@3oool01P1EEED0k^k^0?ooo`3oool0k^k^05EE
E@D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`8000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0007l0>P3oool00`000000oooo0?oo
o`030?ooo`002P3oool010000000V9RH09RHV000000@0?ooo`080000003oool0oooo0000002HV9P0
oooo09RHV00000070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0;@3oool2
000000@0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`002P3oool0102H
V9P000000000002HV9P?0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?oo
o`04000000050?ooo`000000oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0[0?ooo`800000
1P3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000^0?ooo`8000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0>03o
ool00`000000oooo0?ooo`030?ooo`00;@3oool010000000oooo0?ooo`0000060?ooo`800000103o
ool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0:03o
ool2000000T0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00;P3oool2
000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool09P3oool2000000/0oooo00<0001o0?ooo`3oool0>03oool0
0`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo
00/0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0S0?ooo`8000003P3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0
oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo0240oooo0P00000@0?ooo`030000O`3oool0oooo03P0oooo
00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?oo
o`0@0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo0P000004
0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0N
0?ooo`8000004`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo01`0oooo0P00000E0?ooo`030000O`3oool0oooo03P0oooo00<000000?oo
o`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`03
0000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
6@3oool2000001P0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0G0?ooo`8000006P3oool00`0007l0oooo0?ooo`0h0?ooo`030000003o
ool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo01D0oooo0P00000L0?ooo`030000O`3oool0
oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo0P0000040?ooo`030000003oool0oooo
03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0B0?ooo`8000007`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0
oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo0100oooo0P00000Q0?ooo`030000O`3oool0oooo03P0oooo
00<000000?ooo`3oool00`3oool002`0oooo00D0V9RH000000000000000009RHV0060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00<0oooo000/0?ooo`050000002HV9P0oooo09RHV00000001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0=0?ooo`800000903oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo
000/0?ooo`050000003oool0oooo0?ooo`0000001P3ooooT000000D0oooo000/0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo
00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo
00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00;03oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0203oool2000002T0oooo00<0001o0?ooo`3oool0
>03oool00`000000oooo0?ooo`030?ooo`00;03oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo
00<0001o0?ooo`3oool01P3oool2000002/0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo
0?ooo`030?ooo`00;03oool01@000000V9RH0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0[0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
0`3oool002`0oooo00D0V9RH000000000000000009RHV0060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00<0oooo
0P00000^0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo0P00
00040?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool0100007l0oooo0?oo
o`3oool200000300oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3o
ool0100007l0oooo0?ooo`00000b0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
0`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o000000000000<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003o
ool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0b0?ooo`800000=@3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0
oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0`0?ooo`80000000<0oooo0000O`3oool0=03oool00`0007l0oooo0?ooo`0h0?oo
o`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0007l0=@3oool00`00
07l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g0?ooo`800000103oool00`000000
oooo0?ooo`0c0?ooo`030000O`3oool0oooo02d0oooo0P0000040?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0:`3oool2000000H0oooo
00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo
000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0Z0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0h0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0X0?ooo`8000002@3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo02H0oooo0P00000;0?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?oo
o`00=`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3o
ool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool2000000@0oooo00<000000?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0S0?ooo`8000003P3oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo0240oooo0P00000@0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0803oool0
0`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool0
0`000000oooo0?ooo`030?ooo`002P3oool4000000030;Zj^P3oool0oooo0080oooo00H0EEEE0>k^
kP3oool0oooo0>k^kP1EEED40?ooo`<0000000<0oooo09RHV00000000P0000000`2HV9P0oooo0?oo
o`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0N0?ooo`8000004`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<0
00000?ooo`3oool00`3oool000X0oooo00D0c<c<0>k^kP3oool0c<c<05EEE@040?ooo`060>k^kP1E
EED0k^k^0>k^kP1EEED0k^k^1@3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P000004@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0703o
ool2000001D0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003o
ool0oooo00<0oooo000;0?ooo`030<c<c03^k^h0oooo00H0oooo00@0k^k^05EEE@1EEED0k^k^1P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0
5@3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
0`3oool000`0oooo00<0ZJVY0>k^kP3oool01@3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool3000000<0001o00<000000000O`00
07l0C`0007l2000008P0001o0P0000050?ooo`00303oool00`3MgMd0IVIV0?ooo`040?ooo`060>k^
kP1EEED0k^k^0>k^kP1EEED0k^k^1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo01L0oooo0P00000J0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool0
0`000000oooo0?ooo`030?ooo`002P3oool0101gMgL0oooo0?ooo`0000050?ooo`0605EEE@3^k^h0
oooo0?ooo`3^k^h0EEEE1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0
oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`0E0?ooo`800000703oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool000X0oooo00@0000009RHV02HV9P00000403oool020000000
oooo0?ooo`000000V9RH0?ooo`2HV9P000001`3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0D0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00<0oooo000:0?ooo`0409RHV0000000000009RHV0l0oooo00D08B4Q0000003oool0
oooo09RHV0030000000309RHV03oool0oooo00@0000000D0oooo0000003oool0oooo000000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0B0?oo
o`8000007`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?oo
o`3oool00`3oool002h0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0@0?ooo`8000008@3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool002d0oooo00@000000?ooo`3oool0
00001P3oool2000000@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000003oool0oooo0240oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo00<0oooo000^0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo03<0oooo00<0001o0?ooo`3oool03@3oool2000002@0oooo00<0001o0?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0;0?ooo`8000009P3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3o
ool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo00X0oooo00<000000?ooo`3oool09P3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0c0?ooo`030000O`3oool0oooo00P0oooo0P00000Y0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool2000002/0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0
oooo000g0?ooo`800000103oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo
00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo00<0oooo0P00000^0?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03<0oooo00@0001o0?ooo`3oool0oooo0P00000`0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00@0001o0?ooo`3oool00000<P3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3o
ool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000O`000000
000003<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0
oooo00<0oooo000g0?ooo`800000103oool00`000000oooo0?ooo`0b0?ooo`800000=@3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`80000000<0oooo0000O`3o
ool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3o
ool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`050000
003oool0oooo0?ooo`0007l0=@3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool000d0oooo00<000000?ooo`3oool00`3oool01P1EEED0k^k^
0?ooo`3oool0k^k^05EEE@@0oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0oooo
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`800000103oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`030?ooo`003@3oool00`000000oooo0?ooo`030?ooo`060>k^kP1EEED0k^k^0>k^
kP1EEED0k^k^1@3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P000004@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo0P0000060?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0
oooo000:0?ooo`H00000103oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02T0oooo0P0000080?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000:0?ooo`0404A4A02HV9P0oooo0000
00H0oooo00@0k^k^05EEE@1EEED0k^k^1P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00l0oooo0`0000030000O`030000000007l0001o02P0001o00<000000000O`0007l0[P00
07l2000000D0oooo000:0?ooo`040>k^kP0@4100gMgM000000D0oooo00H0k^k^05EEE@3^k^h0k^k^
05EEE@3^k^h50?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo0P00000;0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo
00<0oooo000;0?ooo`030:VYZ@0b<S80000000D0oooo00H0EEEE0>k^kP3oool0oooo0>k^kP1EEED5
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3oool2000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`8000003@3oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?oo
o`030?ooo`00303oool00`1VIVH000000?ooo`0?0?ooo`080000003oool0oooo0000002HV9P0oooo
09RHV00000070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0R0?ooo`8000003`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00303oool00`3^k^h0
410@0?ooo`0>0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`040000
00050?ooo`000000oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00;P3oool20000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`8000004P3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`030?ooo`00;@3oool010000000oooo0?ooo`0000060?ooo`800000103oool00`00
0000oooo0?ooo`0M0?ooo`800000503oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00;P3oool2000000L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`8000005P3oool00`0007l0
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000
oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool05P3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo
00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01P0oooo0P00000I0?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool2000001/0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<00000
0?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool00`3oool003L0oooo0P0000040?ooo`03
0000003oool0oooo01<0oooo0P00000N0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool200000200oooo00<0001o0?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
0`3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`8000008P3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0>03o
ool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`00=`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P00000U0?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo
00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool2000002L0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool003L0oooo0P0000040?ooo`030000003oool0oooo00P0oooo
0P00000Y0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo000g
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000002`0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<00000
0?ooo`3oool00`3oool000X0oooo00D0V9RH000000000000000009RHV0040?ooo`0605EEE@3^k^h0
oooo0?ooo`3^k^h0EEEE103oool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000^0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00<0oooo000:0?ooo`050000002HV9P0oooo09RHV0000000103oool01P3^k^h0EEEE
0>k^kP3^k^h0EEEE0>k^kPD0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH00000140oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000300oooo00<0001o0?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3o
ool00`3oool000X0oooo00D000000?ooo`3oool0oooo000000050?ooo`040>k^kP1EEED0EEEE0>k^
kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool00000<P3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`002P3oool0
1@000000c<c<0?ooo`2HV9P0000000D0oooo00@0k^k^05EEE@1EEED0k^k^1P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00l0oooo0`0000030?ooo`<00000<`3oool00`0007l0
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=`3oool2000000D0
oooo000:0?ooo`05010@401EEED000000000002HV9P0103oool01P3^k^h0EEEE0>k^kP3^k^h0EEEE
0>k^kPD0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`002P3oool0
0`1gMgL0A4A40?ooo`060?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE1@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`030?ooo`002`3oool00`1EEED0MgMg
0?ooo`0@0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV00000070?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00303oool0
0`2HV9P0A4A408N7Q`0>0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?oo
o`04000000050?ooo`000000oooo0?ooo`0000001P3ooooT000000D0oooo000^0?ooo`800000l03o
ool002d0oooo00@000000?ooo`3oool00000k`3oool002h0oooo0P00003`0?ooo`00o`3ooolQ0?oo
o`00F`3oool01P2HV9P0410@0000000@4100MgMg0>k^kSl0oooo0`00000/0?ooo`03010@40000000
c<c<00<0oooo0`00000Y0?ooo`03010@40000000c<c<01`0oooo001K0?ooo`060000002j^[X0oooo
0>k^kP27QhL0<S8b@03oool00`000000oooo0?ooo`0/0?ooo`030>k^kP0Q8B40oooo00<0oooo00<0
00000?ooo`3oool0:@3oool00`3^k^h08B4Q0?ooo`0K0?ooo`00F`3oool01P1gMgL0k^k^0?ooo`3o
ool0gMgM00000400oooo00<000000?ooo`3oool0;@3oool00`1VIVH0V9RH0?ooo`020?ooo`030000
003oool0oooo02X0oooo00<0IVIV09RHV03oool06P3oool004T0oooo0`0000001@3oool000000000
00000000oooo0080000000T0oooo0:VYZ@0b<S80V9RH0000000@4100c<c<0?ooo`1gMgL00`000000
0`0@4100QhN7000000020000000?0?ooo`2HV9P0000009RHV00Q8B40EEEE0?ooo`2YZJT0<S8b09RH
V0000000410@0<c<c03oool0V9RH0080000000<0MgMg000000000000103oool60000000409RHV03o
ool0oooo09RHV0<0000000<0V9RH0?ooo`2HV9P00P0000006@1gMgL000000000002HV9P00000010@
403<c<`0oooo09RHV0000000410@0<c<c03oool0V9RH0000002HV9P08B4Q05EEE@3oool0000004A4
A0000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo000000020000000409RHV0000000410@0<c<
c0L0oooo00P0gMgM0000003MgMd0oooo0000001EEED0000009RHV0@0oooo0`0000020?ooo`<00000
0`3oool00`2HV9P08B4Q0?ooo`020?ooo`0:00000014A4@0000009RHV03oool0V9RH0000000@4100
c<c<0?ooo`<000000P3oool01P0b<S8000000000002HV9P0oooo09RHV0<0000000<0V9RH0?ooo`00
00001@0000001@2HV9P00000010@403<c<`0oooo00<0000000<0oooo0:VYZ@0b<S800P3oool00`2H
V9P08B4Q0?ooo`0J0?ooo`00BP3oool01@000000oooo0?ooo`3oool000000080oooo00`000000?oo
o`3oool000000?ooo`000000V9RH0;Zj^P0@4100oooo038b<P3MgMd50?ooo`0E0000003oool0oooo
0000002HV9P0gMgM0000003^k^h0oooo0000003oool0000009RHV02j^[X0410@0?ooo`000000V9RH
0?ooo`3<c<`0000000H0oooo02h000000?ooo`3oool0oooo09RHV0000000V9RH0?ooo`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`3<c<`000000?ooo`000000V9RH0;Zj^P0@4100oooo
0000002HV9P0^[Zj038b<P3oool0000009RHV03MgMd000000>k^kP3oool000000<c<c02HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P000000P3oool01P000000oooo0000002HV9P0^[Zj010@40L0oooo
00P0QhN700000027QhL0oooo024Q8@3^k^h0V9RH000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`03038b<P000000c<c<0080oooo00T000000<c<c02HV9P000000?oo
o`000000V9RH0;Zj^P0@41000P3oool03P000000oooo0?ooo`3oool000000>k^kP2HV9P000000?oo
o`000000V9RH0?ooo`2HV9P000000P3oool02@000000oooo0?ooo`000000oooo0000002HV9P0^[Zj
038b<P020?ooo`040000003oool0oooo000000<0oooo00<0<S8b0000003<c<`06P3oool004X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool00000103oool0
1@3MgMd08B4Q0000000@4100ZJVY0080oooo00L000000?ooo`3oool0000009RHV03oool000000080
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool00P3oool0102HV9P000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000002HV9P0oooo00000080oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`060000003oool0oooo0000003oool000002P3oool0
0`0Q8B40MgMg024Q8@020?ooo`030<c<c014A4@0A4A400D0oooo00<000000?ooo`3oool00P3oool0
20000000oooo0?ooo`3oool0^[Zj038b<P2HV9P0EEEE0P3oool01P000000oooo0?ooo`000000oooo
000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`040000003oool0oooo00000080
oooo00@0^[Zj038b<P2HV9P0EEEE6P3oool004X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0000003oool0100000001P3oool08B4Q08N7Q`3oool0gMgM00000080oooo
00@000000?ooo`3oool0V9RH0`0000020?ooo`030000003oool0000000<0000000<0oooo0000003o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000030?ooo`030000003oool0000000<0000000<0oooo0000003o
ool00`3oool0102HV9P000000000000000020?ooo`060000003oool0oooo0000003oool000000`3o
ool01@000000oooo0?ooo`000000oooo00@000001P3oool0203MgMd000000?ooo`0@4100gMgM08N7
Q`0b<S80V9RH1P3oool00`000000oooo0?ooo`020?ooo`0;0000003oool0oooo0?ooo`0b<S80^[Zj
0>k^kP0@4100k^k^0?ooo`0000000P3oool00`000000oooo0000000300000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00D0<S8b0;Zj^P3^k^h0
410@0>k^kP0I0?ooo`00BP3oool020000000oooo0?ooo`3oool000000<c<c02HV9P000000P3oool0
0`000000oooo0000000209RHV0070000003oool000000<c<c03oool0QhN7000000020?ooo`030000
003^k^h0oooo0080oooo00L0V9RH0000003oool0oooo0000003oool000000080V9RH00L000000?oo
o`000000V9RH0?ooo`2j^[X0000000H0oooo00<000000?ooo`3oool00`3oool03`000000oooo0000
002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo0;Zj^P000000oooo0000000209RHV0060000
003oool0000009RHV03MgMd0410@0`3oool03P2HV9P000000?ooo`3oool000000;Zj^P2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P000000P3oool00`000000oooo0000000209RHV0030000003oool0
oooo00@0oooo00T0MgMg05EEE@3oool0MgMg06IVIP000000V9RH0>k^kP0Q8B401@3oool600000080
oooo00d0ZJVY010@403oool0oooo04A4A027QhL0oooo0000002j^[X0V9RH0000003oool000000080
V9RH00D000000?ooo`3oool000000>k^kP020?ooo`0:0000003<c<`0V9RH0000003oool0000009RH
V03oool0V9RH00000080oooo00T000000?ooo`3oool000000?ooo`000000V9RH0=gMg@0@41000P3o
ool01`000000oooo0?ooo`000000oooo0:VYZ@0@41000P3oool00`14A4@0QhN70?ooo`0H0?ooo`00
BP3oool00`000000oooo0?ooo`020000000409RHV0000000V9RH0?ooo`<0000000/0V9RH00000000
0000V9RH0?ooo`3<c<`0410@00000014A4@0k^k^0?ooo`020000000309RHV00Q8B40A4A400800000
00<0V9RH0?ooo`0000000P0000001P2HV9P000000000002HV9P0oooo09RHV080000000<0IVIV0000
003oool01@3oool00`000000oooo0?ooo`020?ooo`0409RHV0000000oooo09RHV0<0000000<0V9RH
0?ooo`2HV9P00P000000101VIVH000000?ooo`2HV9P20000000309RHV03oool0V9RH0080000000<0
EEEE0?ooo`14A4@00P0000002@2HV9P0oooo000000000000V9RH0000002HV9P0oooo09RHV0030000
000609RHV03oool0oooo0000003oool0V9RH0P0000000`2HV9P0oooo0?ooo`040?ooo`80000000L0
oooo000000000000V9RH0000001EEED0000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020000000307MgM`2j^[X0000000<0000000D0V9RH0000002HV9P0oooo09RHV0020000
000=09RHV03oool000000000002HV9P08B4Q0?ooo`000000IVIV0000002HV9P0oooo09RHV0030000
000509RHV03oool0oooo0000003oool00P0000001P3oool0V9RH000000000000EEEE0?ooo`800000
00<0oooo0000000000000`000000101gMgL0^[Zj00000000000I0?ooo`00BP3oool00`000000oooo
0?ooo`060?ooo`0308N7Q`000000oooo01@0oooo00<0QhN70000003oool02@3oool00`000000oooo
0?ooo`040?ooo`070000003oool0oooo0?ooo`2HV9P0000009RHV00;0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`0308N7Q`000000oooo
01l0oooo00190?ooo`<00000203oool00`0b<S80oooo0?ooo`0D0?ooo`03038b<P3oool0oooo00L0
oooo0P0000050?ooo`H0000000<0V9RH0?ooo`3oool02@3oool2000001`0oooo0P00000H0?ooo`<0
00000P3oool3000001H0oooo0P00000:0?ooo`8000000P3oool00`0b<S80oooo0?ooo`050?ooo`04
038b<P3oool0oooo038b<R00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.843643, -7.16997*^-8, \
0.000923814, 8.54574*^-10}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-4.2619 4.7619 -17.6129 10.062 [
[.02381 -0.0125 -9.5 -14 ]
[.02381 -0.0125 9.5 0 ]
[.2619 -0.0125 -12.5 -14 ]
[.2619 -0.0125 12.5 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -12.5 -14 ]
[.7381 -0.0125 12.5 0 ]
[.97619 -0.0125 -9.5 -14 ]
[.97619 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09614 -25 -7 ]
[-0.0125 .09614 0 7 ]
[-0.0125 .19676 -25 -7 ]
[-0.0125 .19676 0 7 ]
[-0.0125 .29738 -25 -7 ]
[-0.0125 .29738 0 7 ]
[-0.0125 .398 -25 -7 ]
[-0.0125 .398 0 7 ]
[-0.0125 .49862 -19 -7 ]
[-0.0125 .49862 0 7 ]
[-0.0125 .59924 -25 -7 ]
[-0.0125 .59924 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -97.5 0 ]
[.5 .63053 97.5 14 ]
[ -0.0005 -0.00498 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .09614 m
1 .09614 L
s
0 .19676 m
1 .19676 L
s
0 .29738 m
1 .29738 L
s
0 .398 m
1 .398 L
s
0 .49862 m
1 .49862 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09614 m
.00625 .09614 L
s
gsave
-0.0125 .09614 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.76) show
1.000 setlinewidth
grestore
0 .19676 m
.00625 .19676 L
s
gsave
-0.0125 .19676 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.77) show
1.000 setlinewidth
grestore
0 .29738 m
.00625 .29738 L
s
gsave
-0.0125 .29738 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.78) show
1.000 setlinewidth
grestore
0 .398 m
.00625 .398 L
s
gsave
-0.0125 .398 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.79) show
1.000 setlinewidth
grestore
0 .49862 m
.00625 .49862 L
s
gsave
-0.0125 .49862 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .59924 m
.00625 .59924 L
s
gsave
-0.0125 .59924 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.81) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01565 m
.00375 .01565 L
s
0 .03577 m
.00375 .03577 L
s
0 .0559 m
.00375 .0559 L
s
0 .07602 m
.00375 .07602 L
s
0 .11627 m
.00375 .11627 L
s
0 .13639 m
.00375 .13639 L
s
0 .15651 m
.00375 .15651 L
s
0 .17664 m
.00375 .17664 L
s
0 .21689 m
.00375 .21689 L
s
0 .23701 m
.00375 .23701 L
s
0 .25713 m
.00375 .25713 L
s
0 .27726 m
.00375 .27726 L
s
0 .31751 m
.00375 .31751 L
s
0 .33763 m
.00375 .33763 L
s
0 .35775 m
.00375 .35775 L
s
0 .37788 m
.00375 .37788 L
s
0 .41813 m
.00375 .41813 L
s
0 .43825 m
.00375 .43825 L
s
0 .45837 m
.00375 .45837 L
s
0 .4785 m
.00375 .4785 L
s
0 .51874 m
.00375 .51874 L
s
0 .53887 m
.00375 .53887 L
s
0 .55899 m
.00375 .55899 L
s
0 .57912 m
.00375 .57912 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09614 m
1 .09614 L
s
.99375 .19676 m
1 .19676 L
s
.99375 .29738 m
1 .29738 L
s
.99375 .398 m
1 .398 L
s
.99375 .49862 m
1 .49862 L
s
.99375 .59924 m
1 .59924 L
s
.125 Mabswid
.99625 .01565 m
1 .01565 L
s
.99625 .03577 m
1 .03577 L
s
.99625 .0559 m
1 .0559 L
s
.99625 .07602 m
1 .07602 L
s
.99625 .11627 m
1 .11627 L
s
.99625 .13639 m
1 .13639 L
s
.99625 .15651 m
1 .15651 L
s
.99625 .17664 m
1 .17664 L
s
.99625 .21689 m
1 .21689 L
s
.99625 .23701 m
1 .23701 L
s
.99625 .25713 m
1 .25713 L
s
.99625 .27726 m
1 .27726 L
s
.99625 .31751 m
1 .31751 L
s
.99625 .33763 m
1 .33763 L
s
.99625 .35775 m
1 .35775 L
s
.99625 .37788 m
1 .37788 L
s
.99625 .41813 m
1 .41813 L
s
.99625 .43825 m
1 .43825 L
s
.99625 .45837 m
1 .45837 L
s
.99625 .4785 m
1 .4785 L
s
.99625 .51874 m
1 .51874 L
s
.99625 .53887 m
1 .53887 L
s
.99625 .55899 m
1 .55899 L
s
.99625 .57912 m
1 .57912 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 -0.00448 m
1 -0.00448 L
s
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -158.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integrated) show
114.438 14.000 moveto
(Quadrupole) show
173.938 14.000 moveto
(vs) show
187.562 14.000 moveto
(Hyperbolicity) show
254.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01472 m
.2619 .22102 L
.5 .41837 L
.7381 .59471 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3oool0
1@2HV9P00000000000000000V9RH0080oooo00D0<S8b0?ooo`0b<S80<S8b09RHV00X0?ooo`0509RH
V000000000000000002HV9P00P3oool01@0b<S80oooo038b<P0b<S80V9RH00<0oooo00D0410@0000
00000000000009RHV00]0?ooo`<00000;@3oool300000080oooo00<0<S8b0?ooo`2HV9P00`000000
0`2HV9P0oooo010@40030000000309RHV03oool0oooo02H0oooo0`0000020?ooo`04038b<P3oool0
oooo0?ooo`<00000403oool002D0oooo00D0000009RHV03oool0V9RH000000040?ooo`040>k^kP2H
V9P0410@05EEEBL0oooo00D0000009RHV03oool0V9RH000000040?ooo`040>k^kP2HV9P0410@05EE
E@D0oooo00<0V9RH0000003oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00<0oooo00D0000009RHV03oool0V9RH000000040?ooo`0309RHV0000000oooo02P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`009@3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<0k^k^010@402HV9P09P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
k^k^010@402HV9P01@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000U0?ooo`050000003o
ool0oooo0?ooo`000000103oool01@2HV9P000000000001EEED08B4Q02H0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`0509RHV0000000000005EEE@0Q8B401@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00l0oooo000U0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000V9RH0?oo
o`3<c<`0000002H0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000002HV9P0oooo0<c<
c0000000103oool00`2HV9P000000?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0V9RH0000003oool0:03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000U0?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000002H0oooo00D000000?ooo`3oool0oooo
000000040?ooo`060000003oool0oooo0?ooo`000000oooo100000000`2HV9P0oooo0?ooo`0/0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`3oool0
00000?ooo`@0000000<0V9RH0?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00l0oooo000U0?ooo`050000002HV9P0oooo09RHV0000000103oool01@000000V9RH0?oo
o`2HV9P0000002H0oooo00D0000009RHV03oool0V9RH000000040?ooo`080000002HV9P0oooo09RH
V0000000oooo07MgM`1EEEDa0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3o
ool020000000V9RH0?ooo`2HV9P000000?ooo`1gMgL0EEEE;03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00l0oooo000U0?ooo`0509RHV000000000000000002HV9P0103oool01@2H
V9P00000000000000000V9RH02H0oooo00D0V9RH000000000000000009RHV0040?ooo`0509RHV000
000000000000002HV9P00P3oool0100@410000000000000b<S8]0?ooo`03024Q8@000000oooo02d0
oooo00<08B4Q0000003oool0103oool01@2HV9P00000000000000000V9RH0080oooo00@0410@0000
00000000<S8b:03oool00`0Q8B4000000?ooo`060?ooo`03024Q8@000000oooo0100oooo003o0?oo
ob40oooo003o0?ooob40oooo000W0?ooonT00000403oool002L0ooooj@00000@0?ooo`009`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000
oooo0?ooo`0>0?ooo`009`3oool2000000@0oooo0P00000e0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0i0?ooo`800000403oool002L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0000000d0?ooo`030000O`3oool0oooo03@0oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000<`3oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000<P3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool20000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0i0?ooo`800000403oool002L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0
oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`800000;@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`0>0?ooo`009`3oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0i
0?ooo`800000403oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3o
ool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3o
ool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo02H0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3o
ool002L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo0P00000U0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0i0?ooo`800000403oool0
02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00<0001o0?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool000l0oooo
0`0000020?ooo`05038b<P3oool0oooo09RHV014A4@00`3oool01@2HV9P00000000000000000V9RH
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool00`3^k^h0
00000>k^kP020?ooo`050000002HV9P0oooo09RHV00000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?oo
o`00403oool00`000000oooo0?ooo`050?ooo`0504A4A02YZJT0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`<000000`0007l00`000000001o0000O`0C0000O`030000000007l0001o
0<L0001o0`00000@0?ooo`00403oool00`000000oooo0?ooo`050?ooo`0909RHV01EEED0oooo0?oo
o`000000c<c<0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool00100oooo00<00000
0?ooo`3oool01@3oool01P3^k^h000000?ooo`3oool0410@05EEE@80000000<0V9RH0?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo0P00000M0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000
003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00H0oooo00D08B4Q0:VYZ@3oool0MgMg
04A4A0090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0J0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00<0oooo00D0
8B4Q0;Zj^P3oool0QhN705EEE@020?ooo`0305EEE@1gMgL0oooo00L0oooo0P0000040?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000?0?ooo`03024Q8@00
0000oooo00@0oooo00D0MgMg0000000000000000010@40030?ooo`0309RHV014A4@0QhN700H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo
00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo
00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<00000
0?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?oo
o`8000005P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?oo
o`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool2000000@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0=03oool00`0007l0oooo0?ooo`0i0?ooo`800000403oool002L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool0
3P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0140oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0=03oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool0
02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool002L0oooo0P0000040?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0
oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0903oool2000000h0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<0
00000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo0P0000040?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`03
0000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000?0?ooo`<000000P3o
ool01@0b<S80oooo0?ooo`2HV9P0A4A400@0oooo00<0V9RH04A4A03oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo
0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`040?ooo`030>k^kP000000k^k^00<0oooo00<0
k^k^0000003^k^h01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo0P00
00060?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0j0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00D0oooo00<0A4A4
0:VYZ@3oool00`3oool00`14A4@0ZJVY0?ooo`060?ooo`<000000`0007l00`000000001o0000O`0^
0000O`030000000007l0001o0:`0001o0`00000@0?ooo`00403oool00`000000oooo0?ooo`050?oo
o`0309RHV01EEED0oooo00<0oooo00<0V9RH05EEE@3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?oo
o`00403oool00`000000oooo0?ooo`050?ooo`030>k^kP000000oooo00<0oooo00<0k^k^0000003o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo00D000000?ooo`3o
ool0oooo0000O`0f0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`060?ooo`03024Q8@2YZJT0oooo00<0
oooo00<08B4Q0:VYZ@3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340
oooo00@000000?ooo`3oool0001o=P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool02`0Q8B40
^[Zj0?ooo`27QhL0EEEE0?ooo`0Q8B40^[Zj0?ooo`27QhL0EEEE00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0001o03H0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000?0?ooo`03024Q8@00
0000oooo00@0oooo00L0MgMg0000000000000000010@403oool0MgMg00<0000000<0410@0?ooo`3o
ool0103oool2000000@0oooo00<000000?ooo`3oool0<`3oool00`000000001o0?ooo`0e0?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool2000003D0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0000000d0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00@0001o0?ooo`3oool00000<`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3o
ool002L0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00D0001o0?ooo`3oool0oooo0000
000b0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`02
0?ooo`800000<03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<00000
0?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?oo
o`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3o
ool0;03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3o
ool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000
O`3oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo0P0000040?ooo`030000003o
ool0oooo03@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`080?ooo`800000:P3oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool0
02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo
00X0oooo00<000000?ooo`3oool09`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0d0?ooo`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00`0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo
00<000000?ooo`3oool03P3oool002L0oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0
001o0?ooo`3oool03@3oool2000002D0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0i0?ooo`800000403oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d
0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool000l0oooo0`0000020?oo
o`05038b<P3oool0oooo09RHV014A4@00`3oool01@2HV9P00000000000000000V9RH00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo0100oooo00<0
00000?ooo`3oool08@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<0
00000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool00`3^k^h000000>k^kP02
0?ooo`050000002HV9P0oooo09RHV00000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03@0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`00403oool0
0`000000oooo0?ooo`050?ooo`0504A4A02YZJT0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`<000000`0007l00`000000001o0000O`190000O`030000000007l0001o0940001o0`00
000@0?ooo`00403oool00`000000oooo0?ooo`050?ooo`0909RHV01EEED0oooo0?ooo`2HV9P0MgMg
0;Zj^P2YZJT0EEEE00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo01<0oooo0P00000O0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`050?ooo`080>k^
kP000000oooo0?ooo`3MgMd08B4Q04A4A00b<S870?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000@0?oo
o`030000003oool0oooo00H0oooo00P08B4Q0:VYZ@3oool08B4Q0:VYZ@3oool0gMgM038b<PH0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo01H0oooo
00<000000?ooo`3oool06`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo
00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool02`0Q8B40^[Zj0?oo
o`27QhL0EEEE0?ooo`000000V9RH0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool06P3oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool0
00l0oooo00<08B4Q0000003oool0103oool01`1gMgL00000000000000000410@0?ooo`2HV9P00`00
00000`2HV9P0oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo01P0oooo0P00000J0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3o
ool200000100oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool0
0`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0=03oool0
0`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo
01H0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo
00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01@0oooo
00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo
000W0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo01h0oooo0P00
000D0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0P
0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j
0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0R0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`03
0000003oool0oooo00h0oooo000W0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000
O`3oool0oooo02<0oooo0P00000?0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
>@3oool200000100oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0
oooo00/0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0
oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0
oooo000W0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo02T0oooo
0P0000090?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0>@3oool200000100oooo
000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0[0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000?0?oo
o`<000000P3oool01@0b<S80oooo0?ooo`2HV9P0A4A400<0oooo0P0b<S800`2HV9P0oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0]
0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0j
0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00@0oooo00<0k^k^0000
003^k^h00P3oool0103^k^h0V9RH010@401EEED70?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0^0?ooo`800000103oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?oo
o`3oool01@3oool00`14A4@0ZJVY0?ooo`030?ooo`030>k^kP0@4100V9RH00H0oooo0`0000030000
O`030000000007l0001o06L0001o00<000000000O`0007l0L`0007l300000100oooo000@0?ooo`03
0000003oool0oooo00D0oooo00D0V9RH05EEE@3oool0oooo09RHV0020000000305EEE@0Q8B40oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo
0340oooo00@000000?ooo`3oool0001o=P3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0
oooo00h0oooo000@0?ooo`030000003oool0oooo00D0oooo00T0k^k^0000003oool0oooo0000002H
V9P0oooo0<c<c00000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo
00<0001o0?ooo`3oool0<P3oool00`000000oooo0000O`0f0?ooo`030000O`3oool0oooo03X0oooo
00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool01P3oool0100Q8B40ZJVY0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<000000000O`3oool0=@3oool00`0007l0oooo
0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00<0oooo00/0
8B4Q0;Zj^P3oool0QhN705EEE@3oool0000009RHV03oool0V9RH000000060?ooo`800000103oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo0P00000e0?ooo`030000O`3oool0
oooo03T0oooo0P00000@0?ooo`003`3oool00`0Q8B4000000?ooo`040?ooo`0707MgM`0000000000
0000000@4100oooo09RHV0030000000309RHV03oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`000000=03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`040000O`3oool0
oooo000003<0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool0
100007l0oooo0?ooo`3oool200000340oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo00<0001o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool2000000@0oooo00<000000?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo00@0oooo00<000000?oo
o`3oool0;@3oool00`0007l0oooo0?ooo`0i0?ooo`800000403oool002L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool01@3oool2000002d0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`00
9`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0
>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`080?ooo`030000003o
ool0oooo02T0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool0
0`0007l0oooo0?ooo`090?ooo`800000:@3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0
oooo00h0oooo000W0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo
03T0oooo0P00000@0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo02D0
oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0=0?ooo`8000009@3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo
000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`800000103oool00`000000oooo0?ooo`0d
0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`030000O`3oool0oooo03T0oooo0P00000@0?ooo`009`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0A0?oo
o`8000008@3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0j0?ooo`03
0000003oool0oooo00h0oooo000E0?ooo`<000000P3oool00`0b<S80oooo09RHV0030000000309RH
V03oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool001H0oooo00<000000?ooo`3oool00`3o
ool01@000000V9RH0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool05@3oool2000001d0oooo
00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000<0001o00<000000000O`0007l0
Q@0007l00`000000001o0000O`1E0000O`<00000403oool001H0oooo00<000000?ooo`3oool00`3o
ool01@2HV9P0MgMg0;Zj^P2YZJT0EEEE00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0603oool2000001X0oooo
00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?oo
o`030?ooo`040=gMg@0Q8B40A4A4038b<PL0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo
0?ooo`0G0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool03P3oool001H0oooo00<0
00000?ooo`3oool00`3oool01@0Q8B40ZJVY0?ooo`3MgMd0<S8b00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool0
3P3oool001H0oooo00<000000?ooo`3oool00`3oool01@000000V9RH0?ooo`2HV9P0000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0703oool2000001H0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo
0?ooo`0>0?ooo`005@3oool00`0Q8B4000000?ooo`040?ooo`0509RHV000000000000000002HV9P0
1P3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0i0?ooo`800000
403oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo03X0oooo00<000000?ooo`3oool03P3oool002L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0803oool2
00000180oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0R0?ooo`030000003oool0oooo00l0oooo00<0001o0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0>0?ooo`009`3oool2000000@0oooo00<000000?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0i0?ooo`800000403oool002L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool2000000h0oooo
00<0001o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0V0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<0001o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0X0?oo
o`8000002P3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`80
0000103oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0:P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03T0oooo0P00000@0?ooo`00
9`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0
>P3oool00`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0/0?ooo`8000001P3o
ool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo02h0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0
oooo00h0oooo000W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`00
07l0oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000W0?ooo`800000103oool00`000000
oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<03oool200000080
oooo00<0001o0?ooo`3oool0>@3oool200000100oooo000W0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0380oooo
00<000000?ooo`0007l0?03oool00`000000oooo0?ooo`0>0?ooo`003`3oool300000080oooo00<0
<S8b0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
<`3oool00`000000001o0?ooo`0k0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003o
ool0oooo00<0oooo00D0000009RHV03oool0V9RH000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0=03oool?000002h0oooo00<000000?ooo`3oool03P3oool00100oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1@3oool3000000<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0303ooolK00000140oooo0`00000@0?ooo`00403o
ool00`000000oooo0?ooo`030?ooo`0509RHV01gMgL0^[Zj0:VYZ@1EEED0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool09`3oool>000000D0oooo
00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool0103MgMd08B4Q04A4
A00b<S850?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0j0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00<0oooo00D0
8B4Q0:VYZ@3oool0gMgM038b<P040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool00100oooo00<000000?ooo`3oool00`3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
000?0?ooo`03024Q8@000000oooo00@0oooo00D0V9RH000000000000000009RHV0030?ooo`03024Q
8@000000oooo00H0ooooj@00000@0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00CP3oool01P2HV9P0410@0000000@4100MgMg0>k^kSl0oooo0`00000[0?ooo`03010@40000000
c<c<00<0oooo0`00000Y0?ooo`03010@40000000c<c<02X0oooo001>0?ooo`060000002j^[X0oooo
0>k^kP27QhL0<S8b7`3oool0102YZJT0A4A4024Q8@1VIVHM0?ooo`030000003oool0oooo02/0oooo
00<0k^k^024Q8@3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030>k^kP0Q8B40oooo02T0oooo
001>0?ooo`0607MgM`3^k^h0oooo0?ooo`3MgMd000007P3oool00`2HV9P000000;Zj^P0O0?ooo`03
0000003oool0oooo02`0oooo00<0IVIV09RHV03oool00P3oool00`000000oooo0?ooo`0Z0?ooo`03
06IVIP2HV9P0oooo02P0oooo000l0?ooo`<0000000D0oooo00000000000000000?ooo`0200000009
0?ooo`2YZJT0<S8b09RHV0000000410@0<c<c03oool0MgMg00<0000000<0410@08N7Q`0000000P00
00003`3oool0V9RH0000002HV9P08B4Q05EEE@3oool0ZJVY038b<P2HV9P00000010@403<c<`0oooo
09RHV0020000000307MgM`000000000000D0oooo00<0k^k^05EEE@0000000P0000001`2HV9P0oooo
0?ooo`3oool0V9RH0000002HV9P00P0000001P2HV9P0000009RHV00Q8B40EEEE09RHV080000000<0
MgMg0000000000000`0000020?ooo`0309RHV0000000V9RH0080000000L0oooo00000014A4@00000
09RHV03oool0V9RH00<0000000<0V9RH0?ooo`0000000P000000102HV9P00000010@403<c<`50?oo
o`080=gMg@000000gMgM0?ooo`000000EEEE0000002HV9P50?ooo`<000000P3oool3000000<0oooo
00<0V9RH024Q8@3oool00P3oool02P000000A4A40000002HV9P0oooo09RHV0000000410@0<c<c03o
ool300000080oooo00H0<S8b000000000000V9RH0?ooo`2HV9P30000000309RHV03oool0000000D0
000000D0V9RH0000000@4100c<c<0?ooo`03000000030?ooo`2YZJT0<S8b0080oooo00<0V9RH024Q
8@3oool0:03oool003d0oooo00D000000?ooo`3oool0oooo000000020?ooo`0<0000003oool0oooo
0000003oool0000009RHV02j^[X0410@0?ooo`0b<S80gMgM1@3oool05@000000oooo0?ooo`000000
V9RH0=gMg@000000k^k^0?ooo`000000oooo0000002HV9P0^[Zj010@403oool0000009RHV03oool0
c<c<000000050?ooo`030<c<c00Q8B40V9RH0080oooo00<0V9RH0000002HV9P00P3oool03`000000
V9RH0<c<c0000000oooo0000002HV9P0gMgM0000003^k^h0000009RHV03oool0c<c<000000020?oo
o`080000003oool0oooo0?ooo`000000V9RH0<c<c00000020?ooo`0:0000003<c<`0V9RH0000003o
ool0000009RHV03oool0V9RH00000080oooo00H000000?ooo`000000V9RH0;Zj^P0@41050?ooo`08
08N7Q`000000QhN70?ooo`0Q8B40k^k^09RHV00000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`0b<S8000000<c<c0020?ooo`090000003<c<`0V9RH0000003oool0
000009RHV02j^[X0410@0080oooo00h000000?ooo`3oool0oooo0000003^k^h0V9RH0000003oool0
000009RHV03oool0V9RH00000080oooo00T000000?ooo`3oool000000?ooo`000000V9RH0;Zj^P0b
<S800P3oool010000000oooo0?ooo`0000030?ooo`03038b<P000000c<c<02P0oooo000m0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00D0
gMgM024Q8@000000410@0:VYZ@020?ooo`070000003oool0oooo0000002HV9P0oooo000000020?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000002HV9P0
oooo00<0oooo00D0V9RH0000003oool0oooo000000020?ooo`080000003oool0000009RHV03oool0
00000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00H000000?ooo`3oool000000?ooo`000008
0?ooo`03024Q8@1gMgL08B4Q0080oooo00<0c<c<04A4A014A4@01P3oool00`000000oooo0?ooo`02
0?ooo`080000003oool0oooo0?ooo`2j^[X0<S8b09RHV01EEED20?ooo`060000003oool0oooo0000
003oool000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0
00000P3oool0102j^[X0<S8b09RHV01EEEDX0?ooo`00?@3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool000000?ooo`04000000060?ooo`0Q8B40QhN70?ooo`3MgMd00000
0P3oool010000000oooo0?ooo`2HV9P300000080oooo00<000000?ooo`0000000`0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`0000020?ooo`030000003oool0V9RH00<0000000<0oooo0000003oool00P3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`050000003oool0oooo0000003oool0100000040?ooo`080=gMg@000000oooo
010@403MgMd0QhN7038b<P2HV9P70?ooo`030000003oool0oooo0080oooo00/000000?ooo`3oool0
oooo038b<P2j^[X0k^k^010@403^k^h0oooo000000020?ooo`030000003oool0000000<000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool01@0b
<S80^[Zj0>k^kP0@4100k^k^02L0oooo000m0?ooo`080000003oool0oooo0?ooo`000000c<c<09RH
V00000020?ooo`030000003oool000000080V9RH00L000000?ooo`000000c<c<0?ooo`27QhL00000
0080oooo00<000000>k^kP3oool00P3oool01`2HV9P000000?ooo`3oool000000?ooo`0000000P2H
V9P01`000000oooo0000002HV9P0oooo0;Zj^P0000001@3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo00`000000?ooo`3oool0oooo09RHV0000000oooo0000002HV9P0
oooo0;Zj^P0000020?ooo`050000003^k^h0oooo0?ooo`0000000P3oool03@000000oooo0?ooo`00
0000^[Zj09RHV0000000oooo0000002HV9P0oooo09RHV00000000P3oool00`000000oooo00000002
09RHV0030000003oool0oooo0080oooo00T0MgMg05EEE@3oool0MgMg06IVIP000000V9RH0>k^kP0Q
8B401P3oool600000080oooo00d0ZJVY010@403oool0oooo04A4A027QhL0oooo0000002j^[X0V9RH
0000003oool000000080V9RH00D000000?ooo`3oool000000>k^kP020?ooo`0:0000003<c<`0V9RH
0000003oool0000009RHV03oool0V9RH00000080oooo00T000000?ooo`3oool000000?ooo`000000
V9RH0=gMg@0@41000P3oool01`000000oooo0?ooo`000000oooo0:VYZ@0@41000P3oool00`14A4@0
QhN70?ooo`0V0?ooo`00?@3oool00`000000oooo0?ooo`020000000409RHV0000000V9RH0?ooo`<0
000000/0V9RH000000000000V9RH0?ooo`3<c<`0410@00000014A4@0k^k^0?ooo`020000000309RH
V00Q8B40A4A40080000000<0V9RH0?ooo`0000000P0000001P2HV9P000000000002HV9P0oooo09RH
V080000000<0IVIV0000003oool0103oool00`000000V9RH0?ooo`030?ooo`0309RHV0000000oooo
0080000000D0oooo000000000000oooo04A4A0020000000309RHV03oool0V9RH0080000000<0IVIV
0000003oool00P0000001@2HV9P08B4Q000000000000oooo0080000000P0oooo000000000000V9RH
0000002HV9P0oooo09RHV0<0000000H0V9RH0?ooo`3oool000000?ooo`2HV9P20000000309RHV03o
ool0oooo0080oooo0P0000001`3oool000000000002HV9P0000005EEE@0000001P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080000000<0MgMg0;Zj^P0000000`0000001@2HV9P0
000009RHV03oool0V9RH0080000000d0V9RH0?ooo`000000000009RHV00Q8B40oooo0000001VIVH0
000009RHV03oool0V9RH00<0000000D0V9RH0?ooo`3oool000000?ooo`02000000060?ooo`2HV9P0
00000000001EEED0oooo0P0000000`3oool00000000000030000000407MgM`2j^[X00000000002L0
oooo000m0?ooo`030000003oool0oooo00H0oooo00<0QhN70000003oool0503oool00`27QhL00000
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0V9RH0000002HV9P00P3oool00`2HV9P00000
09RHV00@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`0308N7Q`000000oooo02d0oooo000l0?ooo`<00000203oool00`0b<S80oooo0?oo
o`0D0?ooo`03038b<P3oool0oooo00L0oooo0P0000060?ooo`0309RHV000000000000080000000<0
V9RH0?ooo`3oool03P3oool2000001L0oooo0P00000G0?ooo`<000000P3oool3000001H0oooo0P00
000:0?ooo`8000000P3oool00`0b<S80oooo0?ooo`050?ooo`04038b<P3oool0oooo038b<Rh0oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.859053, 1.74319, \
0.000906674, 0.000429089}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the  quadrupole length ...", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The integrated quadrupole is plotted as a function of the length of \
the quadrupole \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(radius = 
        34;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ 
      radius\ of\ circle\ *) \t\t\t\t\t\), "\[IndentingNewLine]", 
    \(\(width = 
        60;\)\t\t\t\t\ \  (*\ \ pole\ width\ *) \), "\[IndentingNewLine]", 
    \(\(heigh = 80;\)\t\t\t\t (*\ 
      height\ of\ iron\ in\ coil\ *) \), "\[IndentingNewLine]", 
    \(\(length = {20, 40, 50, 60, 80};\)\t\t\t\t (*\ 
      length\ \ along\ beam\ *) \), "\[IndentingNewLine]", 
    \(\(chamfer = 
        7;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ chamfer\ of\ the\ pole\ *) \), "\[IndentingNewLine]", 
    \(\(curden = 5;\)\t\t\t\t (*\ 
      current\ density\ A/
          mm2\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(nx = 
        length/10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ beam\ \
*) \), "\[IndentingNewLine]", 
    \(\(ny = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ width\ *) \
\), "\[IndentingNewLine]", 
    \(\(nz = 
        4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ height\ *) \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nb = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ return\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(na = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ angular\ segmentation\ in\ the\ \
corner\ *) \[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(rmin = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
      minimum\ radius\ of\ the\ coil\ windings\ *) \), "\[IndentingNewLine]", \

    \(\(offset = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ 
      Vert . \ recess\ betw . \ 1  st\ and\ 2  
        nd\ coils*) \), "\[IndentingNewLine]", 
    \(\(hyp = 
        1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ pole\ profile\ 0.1 < \ hyp\  < 2, \ 
      1 : \ hyperbolic*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ironcolor = {0, 0.5, 
          1};\)\ \ \ \ \  (*\ \ Color\ of\ the\ yoke\ \ *) \), "\
\[IndentingNewLine]", 
    \(\(coilcolor = {1, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \  (*\ \ Color\ of\ the\ coil\ \ *) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(iron\  = RadMatSteel37[];\)\ \ \ \ \  (*\ 
      Material\ of\ the\ Yoke\ *) \), "\[IndentingNewLine]", 
    \(\(nseg = seg[nx, ny, nz, nb, na];\)\), "\[IndentingNewLine]", 
    \(\(res = 
        quad[radius, length, width, heigh, chamfer, hyp, nseg, curden, 
          iron];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(iq = 
      Re[\(Transpose[
            IntMultipole /. res]\)[\([2]\)]]\), "\[IndentingNewLine]", 
    \(\(tab = Transpose[{length, iq}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[tab, 
        PlotJoined \[Rule] True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integrated Quadrupole \
vs Quad Length\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(Fit[tab, {1, x}, x]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(iq = 
      Re[\(Transpose[
            IntMultipole /. res]\)[\([6]\)]]\), "\[IndentingNewLine]", 
    \(\(tab = Transpose[{length, iq}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[tab, 
        PlotJoined \[Rule] True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integrated Dodecapole \
vs Quad Length\>"];\)\), "\[IndentingNewLine]", 
    \(Fit[tab, {1, x}, x]\)}], "Input"],

Cell[BoxData[
    \({0.5294716612358847`, 0.972192678292432`, 1.1835567743711226`, 
      1.3899100617932558`, 1.7914973641422218`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.293651 0.015873 -0.232228 0.466396 [
[.02381 -0.0125 -8 -14 ]
[.02381 -0.0125 8 0 ]
[.18254 -0.0125 -8 -14 ]
[.18254 -0.0125 8 0 ]
[.34127 -0.0125 -8 -14 ]
[.34127 -0.0125 8 0 ]
[.5 -0.0125 -8 -14 ]
[.5 -0.0125 8 0 ]
[.65873 -0.0125 -8 -14 ]
[.65873 -0.0125 8 0 ]
[.81746 -0.0125 -8 -14 ]
[.81746 -0.0125 8 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04761 -19 -7 ]
[-0.0125 .04761 0 7 ]
[-0.0125 .14089 -19 -7 ]
[-0.0125 .14089 0 7 ]
[-0.0125 .23417 -10 -7 ]
[-0.0125 .23417 0 7 ]
[-0.0125 .32745 -19 -7 ]
[-0.0125 .32745 0 7 ]
[-0.0125 .42073 -19 -7 ]
[-0.0125 .42073 0 7 ]
[-0.0125 .51401 -19 -7 ]
[-0.0125 .51401 0 7 ]
[-0.0125 .60728 -19 -7 ]
[-0.0125 .60728 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -95.7188 0 ]
[.5 .63053 95.7188 14 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .04761 m
1 .04761 L
s
0 .14089 m
1 .14089 L
s
0 .23417 m
1 .23417 L
s
0 .32745 m
1 .32745 L
s
0 .42073 m
1 .42073 L
s
0 .51401 m
1 .51401 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04761 m
.00625 .04761 L
s
gsave
-0.0125 .04761 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .14089 m
.00625 .14089 L
s
gsave
-0.0125 .14089 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .23417 m
.00625 .23417 L
s
gsave
-0.0125 .23417 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .32745 m
.00625 .32745 L
s
gsave
-0.0125 .32745 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .42073 m
.00625 .42073 L
s
gsave
-0.0125 .42073 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .51401 m
.00625 .51401 L
s
gsave
-0.0125 .51401 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .60728 m
.00625 .60728 L
s
gsave
-0.0125 .60728 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07093 m
.00375 .07093 L
s
0 .09425 m
.00375 .09425 L
s
0 .11757 m
.00375 .11757 L
s
0 .16421 m
.00375 .16421 L
s
0 .18753 m
.00375 .18753 L
s
0 .21085 m
.00375 .21085 L
s
0 .25749 m
.00375 .25749 L
s
0 .28081 m
.00375 .28081 L
s
0 .30413 m
.00375 .30413 L
s
0 .35077 m
.00375 .35077 L
s
0 .37409 m
.00375 .37409 L
s
0 .39741 m
.00375 .39741 L
s
0 .44405 m
.00375 .44405 L
s
0 .46737 m
.00375 .46737 L
s
0 .49069 m
.00375 .49069 L
s
0 .53733 m
.00375 .53733 L
s
0 .56064 m
.00375 .56064 L
s
0 .58396 m
.00375 .58396 L
s
0 .02429 m
.00375 .02429 L
s
0 .00097 m
.00375 .00097 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04761 m
1 .04761 L
s
.99375 .14089 m
1 .14089 L
s
.99375 .23417 m
1 .23417 L
s
.99375 .32745 m
1 .32745 L
s
.99375 .42073 m
1 .42073 L
s
.99375 .51401 m
1 .51401 L
s
.99375 .60728 m
1 .60728 L
s
.125 Mabswid
.99625 .07093 m
1 .07093 L
s
.99625 .09425 m
1 .09425 L
s
.99625 .11757 m
1 .11757 L
s
.99625 .16421 m
1 .16421 L
s
.99625 .18753 m
1 .18753 L
s
.99625 .21085 m
1 .21085 L
s
.99625 .25749 m
1 .25749 L
s
.99625 .28081 m
1 .28081 L
s
.99625 .30413 m
1 .30413 L
s
.99625 .35077 m
1 .35077 L
s
.99625 .37409 m
1 .37409 L
s
.99625 .39741 m
1 .39741 L
s
.99625 .44405 m
1 .44405 L
s
.99625 .46737 m
1 .46737 L
s
.99625 .49069 m
1 .49069 L
s
.99625 .53733 m
1 .53733 L
s
.99625 .56064 m
1 .56064 L
s
.99625 .58396 m
1 .58396 L
s
.99625 .02429 m
1 .02429 L
s
.99625 .00097 m
1 .00097 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .04761 m
1 .04761 L
s
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -156.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integrated) show
114.438 14.000 moveto
(Quadrupole) show
173.938 14.000 moveto
(vs) show
187.562 14.000 moveto
(Quad) show
216.500 14.000 moveto
(Length) show
250.438 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01472 m
.34127 .2212 L
.5 .31978 L
.65873 .41602 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00903oool4
000000030;Zj^P3oool0V9RH00<0000000<0V9RH0?ooo`3oool0603oool0100@41000000010@401g
MgL20?ooo`0509RHV000000000000000002HV9P07@3oool010000000oooo0?ooo`2HV9P300000003
09RHV03oool0oooo01P0oooo00L0410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool05`3oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo
0?ooo`0I0?ooo`0309RHV014A4@0oooo0080oooo00D0V9RH000000000000000009RHV00J0?ooo`07
09RHV000000000000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo0180oooo000T0?oo
o`0;0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV00000007@3oool0201gMgL0
IVIV0?ooo`000000V9RH0?ooo`2HV9P000007@3oool020000000oooo0?ooo`000000V9RH0?ooo`2H
V9P000007@3oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P000006@3oool02`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000001/0oooo00<0k^k^0000003^k^h00P3o
ool01@000000V9RH0?ooo`2HV9P0000001X0oooo00/0000009RHV03oool0V9RH0000003oool00000
09RHV03oool0V9RH0000000D0?ooo`009@3oool00`3<c<`0k^k^0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000007P3oool00`000000oooo000000030?ooo`030000003oool0oooo01P0oooo1`00
00030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0G0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo01X0
oooo00D0A4A40:VYZ@3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool04P3oool002H0oooo00D0ZJVY
0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo01X0oooo00D0gMgM08N7Q`000000oooo
000000030?ooo`030000003oool0oooo01P0oooo00@0A4A409RHV03oool000000P3oool01@000000
oooo0?ooo`3oool0000001h0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0G0?oo
o`070000003<c<`0oooo09RHV0000000oooo000000030?ooo`030000003oool0oooo01X0oooo00D0
V9RH05EEE@3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00L0V9RH07MgM`2j^[X0
ZJVY05EEE@3oool0000000<0oooo00<000000?ooo`3oool04P3oool002H0oooo00D0gMgM06IVIP3o
ool0oooo000000030?ooo`030000003oool0oooo01T0oooo00H0EEEE010@40000000V9RH0?ooo`00
00030?ooo`030000003oool0oooo01P0oooo00@0k^k^010@403MgMd000000P3oool01@000000oooo
0?ooo`3oool0000001d0oooo00@0V9RH0000003oool000000`3oool00`000000oooo0?ooo`0G0?oo
o`07010@401EEED000000000002HV9P0oooo000000030?ooo`030000003oool0oooo01X0oooo00D0
k^k^0000003oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00@0gMgM024Q8@14A4@0
<S8b0P3oool01@000000oooo0?ooo`3oool0000001@0oooo000T0?ooo`0407MgM`3oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo0000000M0?ooo`040;Zj^P2HV9P0oooo000000<0oooo00<0
00000?ooo`3oool06@3oool00`2YZJT0<S8b000000020?ooo`050000003oool0oooo0?ooo`000000
6P3oool40000000309RHV03oool0000000<0oooo00<000000?ooo`3oool05`3oool00`1gMgL0A4A4
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000007@3oool0100Q8B40ZJVY0?ooo`0000030?oo
o`030000003oool0oooo01P0oooo00L08B4Q0:VYZ@3oool0gMgM038b<P3oool0000000<0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00@0000009RHV02HV9P000000P3oool01@000000V9RH0?oo
o`2HV9P0000001X0oooo00/0A4A40;Zj^P3oool0^[Zj0000003oool0000009RHV03oool0V9RH0000
000L0?ooo`0906IVIP000000oooo0?ooo`000000V9RH0?ooo`2HV9P0000001X0oooo00<0MgMg05EE
E@3oool00`3oool01@000000V9RH0?ooo`2HV9P0000001X0oooo00<0EEEE07MgM`3oool00P3oool0
1@000000V9RH0?ooo`2HV9P0000001X0oooo00/08B4Q0;Zj^P3oool0QhN705EEE@3oool0000009RH
V03oool0V9RH0000000J0?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RH
V0000000503oool002@0oooo00@0V9RH000000000000V9RH0P3oool01@2HV9P00000000000000000
V9RH01X0oooo00L0k^k^04A4A0000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0
6P3oool01@3^k^h0410@0?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool06@3oool01P0@4100
00000000000b<S80oooo09RHV0<0000000<0V9RH0?ooo`3oool06@3oool01@2HV9P0A4A408N7Q`3o
ool0V9RH00<0000000<0V9RH0?ooo`3oool0603oool01`1gMgL00000000000000000410@0?ooo`2H
V9P00`0000000`2HV9P0oooo0?ooo`0H0?ooo`0709RHV000000000000000002HV9P0oooo09RHV003
0000000309RHV03oool0oooo0180oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000U0?ooonT000004P3oool002D0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000B
0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00
9@3oool00`000000oooo0?ooo`020?ooo`8000008`3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool2000000<0oooo00<000000?ooo`3oool00P00000P
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool200000180oooo000U0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?oo
o`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00000M0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00
4@3oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2HV9P0
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0J0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000
oooo0?ooo`0@0?ooo`004@3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D0000009RHV03o
ool0V9RH000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool20000
01X0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo
0100oooo000A0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000H0ooooj@00000B0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0<c<c03oool0V9RH000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0@0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
410@05EEE@000000000009RHV0060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool2000001D0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000
003oool0oooo0100oooo000A0?ooo`050000003oool0oooo0?ooo`000000103oool00`1gMgL0A4A4
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0B0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo
0?ooo`0@0?ooo`004@3oool01@000000V9RH0?ooo`2HV9P0000000D0oooo00<0EEEE07MgM`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0P00000B0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`004@3o
ool01@2HV9P00000000000000000V9RH00H0oooo00<0V9RH04A4A027QhL01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P00
00030?ooo`030000003oool0oooo0140oooo0P00000?0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool09`3oool200000180oooo000U0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01@0oooo0P00000<0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`8000002@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P0000030?ooo`030000003o
ool0oooo01T0oooo0P0000070?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3o
ool200000180oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`040?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool0
0`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo0P0000040?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0
oooo00D000000?ooo`3oool0oooo0000O`0T0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?oo
o`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`80
000000<0oooo0000O`3oool08`3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100
oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000001o
0?ooo`0S0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P00
00030?ooo`030000003oool0oooo0280oooo0P00000S0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo0P00
000B0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`0000008P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000U0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`020000
0200oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`004@3oool01@2HV9P0
0000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`020?oo
o`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?oo
o`004@3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00D0000009RHV03oool0V9RH00000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`03
0?ooo`8000007@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000A0?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000H0oooo0P00
00030000O`030000000007l0001o02X0001o00<000000000O`0007l0/@0007l300000180oooo000A
0?ooo`050000003oool0oooo0?ooo`000000103oool01@2HV9P0MgMg0;Zj^P2YZJT0EEEE00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo00H0oooo
0P00000J0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool00140oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040=gMg@0Q8B40A4A4038b<PL0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo00P0oooo0P00000H0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool00140oooo00D000000?ooo`3oool0
oooo000000040?ooo`05024Q8@2YZJT0oooo0=gMg@0b<S801P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool00140oooo00D0000009RHV03o
ool0V9RH000000040?ooo`050000002HV9P0oooo09RHV00000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool02`3oool2000001D0oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`004@3oool01@2HV9P00000000000000000
V9RH00@0oooo00D0V9RH000000000000000009RHV0060?ooo`8000000`3oool00`000000oooo0?oo
o`0R0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0W0?ooo`8000004P3oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R
0?ooo`030000O`3oool0oooo00h0oooo0P00000B0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<00000
0?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?oo
o`030000003oool0oooo0100oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0A0?ooo`8000003`3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`03
0000003oool0oooo0100oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool0503oool2000000`0oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool2000000<0oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool2
00000180oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0G0?ooo`8000002@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo
0100oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0I0?ooo`8000001`3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100
oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo
0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0
001o0?ooo`3oool0703oool2000000@0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?oo
o`0@0?ooo`009@3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0N
0?ooo`050000003oool0oooo0?ooo`0007l0903oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool09`3oool200000180oooo000U0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0O0?ooo`80000000<0oooo
0000O`3oool08`3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`000000001o0?ooo`0S0?oo
o`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?oo
o`030000003oool0oooo0100oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`8000008`3oool00`0007l0oooo0?ooo`0Q0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00
703oool3000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`0000008P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`007@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00800000803oool00`0007l0oooo0?oo
o`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?oo
o`0@0?ooo`007@3oool00`000000oooo0?ooo`050?ooo`8000000`0007l00`000000001o0000O`1<
0000O`800000T00007l300000180oooo000M0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000O`3oool0oooo0240oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000M0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool01@3oool2000001/0oooo00<0001o0?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3o
ool0403oool001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo01P0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool001d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`080?ooo`800000603oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00703oool0
0`0Q8B4000000?ooo`060?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool02P3oool2000001H0oooo00<0001o0?ooo`3oool08@3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo0P00000B0?ooo`009@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool08@3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool03@3oool2000001<0oooo00<0001o0?ooo`3oool08@3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool03`3oool200000140oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo0240oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000U
0?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool04P3oool2000000h0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo02L0oooo0P00000B0?ooo`009@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0D0?oo
o`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool05@3oool2000000/0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
5`3oool2000000T0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000U0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo01X0oooo0P0000060?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000U0?ooo`8000000`3oool00`00
0000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0703oool00`00
0000oooo0?ooo`030?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0W0?ooo`8000004P3oool002D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool07@3oool2000000<0
oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool07`3oool2000000030?oo
o`0007l0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000
003oool0oooo0100oooo000C0?ooo`<000000P3oool00`0b<S80oooo00000003000000030;Zj^P3o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`000000001o0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00503oool0
0`000000oooo0?ooo`030?ooo`050<c<c03^k^h0oooo0<c<c01EEED01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`8000008P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<0
00000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool0103oool00`3<c<`0k^k^0?ooo`07
0?ooo`8000000`0007l00`000000001o0000O`1^0000O`030000000007l0001o06d0001o0`00000B
0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030:VYZ@3^k^h0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`02000001l0oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000D0?ooo`030000003oool0oooo00D0
oooo00<0gMgM06IVIP3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0080
oooo0P00000M0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000
oooo0?ooo`0@0?ooo`00503oool00`000000oooo0?ooo`030?ooo`0407MgM`3oool0oooo000000L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo01X0
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100
oooo000D0?ooo`030000003oool0oooo00<0oooo00@0000009RHV02HV9P000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo00D0oooo0P00000J0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`004`3oool00`0Q8B400000
0?ooo`040?ooo`0409RHV0000000000009RHV0L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`070?ooo`800000603oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool0403oool002D0oooo0P0000030?ooo`030000003oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00T0oooo
00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo
0P00000B0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00X0oooo0P00
000E0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?oo
o`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00`0oooo0P00000C
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@
0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00h0oooo00<000000?oo
o`3oool0403oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?oo
o`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0?0?ooo`80
0000403oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3o
ool0403oool002D0oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0
3@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo0P00000B0?ooo`009@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0180oooo0P00000=0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01@0oooo0P00000;0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0G0?ooo`800000203oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0I0?ooo`8000001P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P00
00030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo02L0oooo0P00000B0?ooo`009@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo01`0oooo0P0000030?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo01h0oooo0P0000000`3oool0001o0?ooo`0S0?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool0403oool001<0oooo0`0000020?ooo`03038b<P3oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0200
oooo00<000000000O`3oool08`3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100
oooo000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo0P00000S0?ooo`030000O`3oool0oooo02P0oooo
00<000000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool00`3oool6000000D0oooo0P00
00030000O`030000000007l0001o0980001o0P00001:0000O`<000004P3oool001@0oooo00<00000
0?ooo`3oool00`3oool01014A4@0V9RH0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08@3oool01@0007l0oooo0?ooo`3oool000000200oooo00<0001o0?ooo`3oool0
:03oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000oooo0?ooo`030?ooo`040>k^kP0@
4100gMgM000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo0080oooo0P00000N0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0
403oool001@0oooo00<000000?ooo`3oool0103oool00`2YZJT0<S8b000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`040?ooo`800000703o
ool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000D0?ooo`030000003oool0
oooo00D0oooo00<0IVIV0000003oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0240oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000O`3oool0
oooo02P0oooo00<000000?ooo`3oool0403oool001<0oooo00<08B4Q0000003oool01P3oool00`3^
k^h0410@0?ooo`060?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
00L0oooo0P00000I0?ooo`030000O`3oool0oooo02L0oooo0P00000B0?ooo`009@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool02@3oool2000001L0
oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool02`3oool2000001D0oooo
00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool03@3oool00`000000oooo0?oo
o`0B0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo00h0oooo0P00000B
0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0100oooo0P00000@0?oo
o`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P0000030?ooo`03
0000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0240oooo00<0001o0?ooo`3oool04P3oool2000000h0oooo00<0001o0?ooo`3o
ool09`3oool200000180oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
8@3oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0
:03oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0240oooo00<0001o0?ooo`3oool05@3oool2000000/0oooo00<0001o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0240oooo00<0001o0?ooo`3oool05`3oool2000000T0oooo00<0001o0?ooo`3oool0:03oool0
0`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0240oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool0403oool002D0oooo0P0000030?ooo`030000003oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240
oooo00<0001o0?ooo`3oool06P3oool2000000H0oooo00<0001o0?ooo`3oool09`3oool200000180
oooo000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0L0?ooo`800000103oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo
000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?oo
o`0N0?ooo`8000000P3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo000U
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0P
0?ooo`030000003oool0001o02X0oooo00<000000?ooo`3oool0403oool001<0oooo0`0000020?oo
o`03038b<P3oool0V9RH00<0000000<0V9RH0?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08@3oool2000002X0oooo00<000000?oo
o`3oool0403oool001@0oooo00<000000?ooo`3oool00`3oool01@000000V9RH0?ooo`2HV9P00000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
0280oooo00<0001o000000000000:03oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000<0001o00<000000000
O`0007l0^00007l00`000000001o0000O`0S0000O`<000004P3oool001@0oooo00<000000?ooo`3o
ool00`3oool01@000000c<c<0?ooo`2HV9P0000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00@0001o0?ooo`3oool0oooo0P00000U
0?ooo`030000003oool0oooo0100oooo000D0?ooo`030000003oool0oooo00<0oooo00D0410@05EE
E@000000000009RHV0060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00<0oooo0P00000S0?ooo`030000003oool0
oooo0100oooo000D0?ooo`030000003oool0oooo00<0oooo00<0MgMg04A4A03oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`050?ooo`8000008@3oool00`000000oooo0?ooo`0@0?ooo`00503oool00`000000
oooo0?ooo`040?ooo`0305EEE@1gMgL0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0100oooo000C0?ooo`03024Q8@000000oooo00H0oooo
00<0V9RH04A4A027QhL01P3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo00P0oooo0P00000M0?ooo`8000004P3oool002D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool02P3oool2000001`0oooo00<000000?ooo`3oool0403oool002D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo000U0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo00d0oooo0P00000I0?ooo`030000003oool0oooo0100oooo000U0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo00l0oooo0P00000G0?ooo`030000003oool0oooo0100oooo000U0?ooo`800000
0`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
4@3oool2000001@0oooo0P00000B0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0C0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0503oool2
00000180oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool05P3oool20000
0100oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0603oool2000000h0
oooo00<000000?ooo`3oool0403oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0100oooo000U0?ooo`8000000`3oool00`000000oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06`3oool2000000X0oooo0P00
000B0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0M0?ooo`8000002@3oool00`000000oooo0?ooo`0@
0?ooo`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0403oool001<0oooo0`0000020?ooo`03038b<P3oool0V9RH00<0000000<0V9RH0?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0P0?ooo`8000001P3oool00`000000oooo0?ooo`0@0?ooo`00
503oool00`000000oooo0?ooo`030?ooo`050000002HV9P0oooo09RHV00000001P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool001@0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000030?ooo`03
0000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`<0
00004P3oool001@0oooo00<000000?ooo`3oool00`3oool01@2HV9P0MgMg0;Zj^P2YZJT0EEEE00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo000D0?ooo`030000003oool0oooo00<0oooo00@0gMgM024Q8@14A4@0<S8b1`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool001@0oooo
00<000000?ooo`3oool00`3oool01@0Q8B40ZJVY0?ooo`3MgMd0<S8b00H0ooooj@00000B0?ooo`00
503oool00`000000oooo0?ooo`030?ooo`050000002HV9P0oooo09RHV0000000o`3oool20?ooo`00
4`3oool00`0Q8B4000000?ooo`040?ooo`0509RHV000000000000000002HV9P0o`3oool20?ooo`00
o`3ooolQ0?ooo`00C@3oool01P2HV9P0410@0000000@4100MgMg0>k^kSl0oooo0`00001B0?ooo`06
09RHV00@41000000010@401gMgL0k^k^<`3oool004d0oooo00H000000;Zj^P3oool0k^k^08N7Q`0b
<S8O0?ooo`040:VYZ@14A4@08B4Q06IVIQd0oooo00<000000?ooo`3oool09P3oool0102YZJT0A4A4
024Q8@1VIVHW0?ooo`060000002j^[X0oooo0>k^kP27QhL0<S8b<`3oool004d0oooo00H0MgMg0>k^
kP3oool0oooo0=gMg@00000N0?ooo`0309RHV0000000^[Zj01l0oooo00<000000?ooo`3oool09@3o
ool00`2HV9P000000;Zj^P0Y0?ooo`0607MgM`3^k^h0oooo0?ooo`3MgMd00000<`3oool003/0oooo
0`0000001@3oool00000000000000000oooo0080000000T0oooo0:VYZ@0b<S80V9RH0000000@4100
c<c<0?ooo`1gMgL00`0000000`0@4100QhN7000000020000000?0?ooo`2HV9P0000009RHV00Q8B40
EEEE0?ooo`2YZJT0<S8b09RHV0000000410@0<c<c03oool0V9RH0080000000<0MgMg000000000000
1@3oool00`3^k^h0EEEE000000020000000709RHV03oool0oooo0?ooo`2HV9P0000009RHV0020000
000609RHV0000000V9RH024Q8@1EEED0V9RH0P0000000`1gMgL000000000000300000080oooo00<0
V9RH0000002HV9P00P0000001`3oool0000004A4A0000000V9RH0?ooo`2HV9P00`0000000`2HV9P0
oooo000000020000000409RHV0000000410@0<c<c0H0oooo00P0gMgM0000003MgMd0oooo0000001E
EED0000009RHV0H0oooo00<0k^k^05EEE@0000000P0000001`2HV9P0oooo0?ooo`3oool0V9RH0000
002HV9P00P0000001P2HV9P0000009RHV00Q8B40EEEE09RHV080000000<0MgMg0000000000000`3o
ool60000000606IVIP2HV9P00000010@403<c<`0oooo0`000000103oool000000000001gMgL30000
0005010@4027QhL0oooo0:VYZ@0b<S800`0000000`3oool000000000000Z0?ooo`00?03oool01@00
0000oooo0?ooo`3oool000000080oooo00`000000?ooo`3oool000000?ooo`000000V9RH0;Zj^P0@
4100oooo038b<P3MgMd50?ooo`0E0000003oool0oooo0000002HV9P0gMgM0000003^k^h0oooo0000
003oool0000009RHV02j^[X0410@0?ooo`000000V9RH0?ooo`3<c<`0000000D0oooo00<0c<c<024Q
8@2HV9P00P3oool00`2HV9P0000009RHV0020?ooo`0?0000002HV9P0c<c<0000003oool0000009RH
V03MgMd000000>k^kP000000V9RH0?ooo`3<c<`000000080oooo00P000000?ooo`3oool0oooo0000
002HV9P0c<c<00000080oooo00X000000<c<c02HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
0P3oool01P000000oooo0000002HV9P0^[Zj010@40H0oooo00P0QhN700000027QhL0oooo024Q8@3^
k^h0V9RH000000D0oooo00<0c<c<024Q8@2HV9P00P3oool00`2HV9P0000009RHV0020?ooo`0?0000
002HV9P0c<c<0000003oool0000009RHV03MgMd000000>k^kP000000V9RH0?ooo`3<c<`0000000D0
oooo00X000000>k^kP3oool0oooo0<c<c014A4@0000009RHV02j^[X0410@0P3oool01`000000oooo
0?ooo`000000oooo038b<P3MgMd01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02T0oooo000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`00
0000oooo000000@0oooo00D0gMgM024Q8@000000410@0:VYZ@020?ooo`070000003oool0oooo0000
002HV9P0oooo000000020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000002HV9P0oooo00<0oooo00D0V9RH0000003oool0oooo000000020?ooo`080000
003oool0000009RHV03oool000000?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00H000000?oo
o`3oool000000?ooo`0000090?ooo`03024Q8@1gMgL08B4Q0080oooo00<0c<c<04A4A014A4@01@3o
ool00`000000V9RH0?ooo`030?ooo`0509RHV0000000oooo0?ooo`0000000P3oool020000000oooo
0000002HV9P0oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool02P000000oooo0?ooo`000000oooo0=gMg@0Q8B40
0000010@402YZJT20?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool0
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0000003oool01000
00001P3oool08B4Q08N7Q`3oool0gMgM00000080oooo00@000000?ooo`3oool0V9RH0`0000020?oo
o`030000003oool0000000<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo09RHV003
000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`000000
oooo00@000001@3oool0203MgMd000000?ooo`0@4100gMgM08N7Q`0b<S80V9RH1P3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`2HV9P00`0000000`3o
ool000000?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool40000
0080oooo00X000000?ooo`3oool000000?ooo`0Q8B40QhN70?ooo`3MgMd000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo000l0?ooo`080000003oool0oooo0?oo
o`000000c<c<09RHV00000020?ooo`030000003oool000000080V9RH00L000000?ooo`000000c<c<
0?ooo`27QhL000000080oooo00<000000>k^kP3oool00P3oool01`2HV9P000000?ooo`3oool00000
0?ooo`0000000P2HV9P01`000000oooo0000002HV9P0oooo0;Zj^P0000001@3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00`000000?ooo`3oool0oooo09RHV0000000
oooo0000002HV9P0oooo0;Zj^P0000020?ooo`050000003^k^h0oooo0?ooo`0000000P3oool03@00
0000oooo0?ooo`000000^[Zj09RHV0000000oooo0000002HV9P0oooo09RHV00000000P3oool00`00
0000oooo0000000209RHV0030000003oool0oooo00<0oooo00T0MgMg05EEE@3oool0MgMg06IVIP00
0000V9RH0>k^kP0Q8B401@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080
oooo00`000000?ooo`3oool0oooo09RHV0000000oooo0000002HV9P0oooo0;Zj^P0000050?ooo`03
0000003oool0oooo00<0oooo00@0000009RHV02HV9P000000P3oool02P000000c<c<09RHV0000000
oooo0000003<c<`0oooo08N7Q`0000020?ooo`070000003oool0oooo0000003<c<`0V9RH0000000[
0?ooo`00?03oool00`000000oooo0?ooo`020000000409RHV0000000V9RH0?ooo`<0000000/0V9RH
000000000000V9RH0?ooo`3<c<`0410@00000014A4@0k^k^0?ooo`020000000309RHV00Q8B40A4A4
0080000000<0V9RH0?ooo`0000000P0000001P2HV9P000000000002HV9P0oooo09RHV080000000<0
IVIV0000003oool0103oool00`000000V9RH0?ooo`030?ooo`0309RHV0000000oooo0080000000D0
oooo000000000000oooo04A4A0020000000309RHV03oool0V9RH0080000000<0IVIV0000003oool0
0P0000001@2HV9P08B4Q000000000000oooo0080000000P0oooo000000000000V9RH0000002HV9P0
oooo09RHV0<0000000H0V9RH0?ooo`3oool000000?ooo`2HV9P20000000309RHV03oool0oooo00<0
oooo0P0000001`3oool000000000002HV9P0000005EEE@0000001@3oool00`000000V9RH0?ooo`03
0?ooo`0309RHV0000000oooo0080000000D0oooo000000000000oooo04A4A0020000000309RHV03o
ool0V9RH0080000000<0IVIV0000003oool0103oool00`000000oooo0?ooo`030?ooo`0509RHV000
0000000009RHV03oool00P0000002P2HV9P0000009RHV03oool0c<c<010@40000000A4A40>k^kP3o
ool3000000050?ooo`000000V9RH0000002HV9P0:`3oool003`0oooo00<000000?ooo`3oool01P3o
ool00`27QhL000000?ooo`0D0?ooo`0308N7Q`000000oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`2HV9P0000009RHV0020?ooo`0309RHV0000000V9RH0100oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0F0?ooo`0309RHV0000000V9RH0080oooo00<0V9RH0000002HV9P0403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D0QhN70000003oool0oooo
0000000^0?ooo`00>`3oool3000000P0oooo00<0<S8b0?ooo`3oool0503oool00`0b<S80oooo0?oo
o`070?ooo`8000001P3oool00`2HV9P00000000000020000000309RHV03oool0oooo00h0oooo0P00
000G0?ooo`8000006@3oool00`2HV9P00000000000020000000309RHV03oool0oooo00h0oooo0P00
00040?ooo`<000005P3oool0100b<S80oooo00000000000^0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {8.32796, 0.341512, 0.272002, \
0.00925714}}],

Cell[BoxData[
    \(\(\(0.12237708491202418`\)\(\[InvisibleSpace]\)\) + 
      0.021018972461099166`\ x\)], "Output"],

Cell[BoxData[
    \({2.834114309208102`*^-9, 4.089264072498766`*^-9, 
      5.449096632248462`*^-9, 6.962696073864461`*^-9, 
      1.0281870509165625`*^-8}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.293651 0.015873 -0.209268 7.9031e+07 [
[.02381 -0.0125 -8 -14 ]
[.02381 -0.0125 8 0 ]
[.18254 -0.0125 -8 -14 ]
[.18254 -0.0125 8 0 ]
[.34127 -0.0125 -8 -14 ]
[.34127 -0.0125 8 0 ]
[.5 -0.0125 -8 -14 ]
[.5 -0.0125 8 0 ]
[.65873 -0.0125 -8 -14 ]
[.65873 -0.0125 8 0 ]
[.81746 -0.0125 -8 -14 ]
[.81746 -0.0125 8 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02783 -44.5 -7.90625 ]
[-0.0125 .02783 0 7.90625 ]
[-0.0125 .10686 -44.5 -7.90625 ]
[-0.0125 .10686 0 7.90625 ]
[-0.0125 .18589 -44.5 -7.90625 ]
[-0.0125 .18589 0 7.90625 ]
[-0.0125 .26492 -44.5 -7.90625 ]
[-0.0125 .26492 0 7.90625 ]
[-0.0125 .34395 -44.5 -7.90625 ]
[-0.0125 .34395 0 7.90625 ]
[-0.0125 .42298 -44.5 -7.90625 ]
[-0.0125 .42298 0 7.90625 ]
[-0.0125 .50201 -44.5 -7.90625 ]
[-0.0125 .50201 0 7.90625 ]
[-0.0125 .58104 -44.5 -7.90625 ]
[-0.0125 .58104 0 7.90625 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -96.0625 0 ]
[.5 .63053 96.0625 14 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .02783 m
1 .02783 L
s
0 .10686 m
1 .10686 L
s
0 .18589 m
1 .18589 L
s
0 .26492 m
1 .26492 L
s
0 .34395 m
1 .34395 L
s
0 .42298 m
1 .42298 L
s
0 .50201 m
1 .50201 L
s
0 .58104 m
1 .58104 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02783 m
.00625 .02783 L
s
gsave
-0.0125 .02783 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .10686 m
.00625 .10686 L
s
gsave
-0.0125 .10686 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .18589 m
.00625 .18589 L
s
gsave
-0.0125 .18589 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .26492 m
.00625 .26492 L
s
gsave
-0.0125 .26492 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .34395 m
.00625 .34395 L
s
gsave
-0.0125 .34395 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .42298 m
.00625 .42298 L
s
gsave
-0.0125 .42298 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .50201 m
.00625 .50201 L
s
gsave
-0.0125 .50201 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
0 .58104 m
.00625 .58104 L
s
gsave
-0.0125 .58104 -105.5 -11.9062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.8125 translate 1 -1 scale
63.000 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.750 15.812 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
80.188 15.812 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
92.188 11.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
97.938 11.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04363 m
.00375 .04363 L
s
0 .05944 m
.00375 .05944 L
s
0 .07524 m
.00375 .07524 L
s
0 .09105 m
.00375 .09105 L
s
0 .12266 m
.00375 .12266 L
s
0 .13847 m
.00375 .13847 L
s
0 .15427 m
.00375 .15427 L
s
0 .17008 m
.00375 .17008 L
s
0 .20169 m
.00375 .20169 L
s
0 .2175 m
.00375 .2175 L
s
0 .23331 m
.00375 .23331 L
s
0 .24911 m
.00375 .24911 L
s
0 .28072 m
.00375 .28072 L
s
0 .29653 m
.00375 .29653 L
s
0 .31234 m
.00375 .31234 L
s
0 .32814 m
.00375 .32814 L
s
0 .35976 m
.00375 .35976 L
s
0 .37556 m
.00375 .37556 L
s
0 .39137 m
.00375 .39137 L
s
0 .40717 m
.00375 .40717 L
s
0 .43879 m
.00375 .43879 L
s
0 .45459 m
.00375 .45459 L
s
0 .4704 m
.00375 .4704 L
s
0 .48621 m
.00375 .48621 L
s
0 .51782 m
.00375 .51782 L
s
0 .53362 m
.00375 .53362 L
s
0 .54943 m
.00375 .54943 L
s
0 .56524 m
.00375 .56524 L
s
0 .01202 m
.00375 .01202 L
s
0 .59685 m
.00375 .59685 L
s
0 .61265 m
.00375 .61265 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02783 m
1 .02783 L
s
.99375 .10686 m
1 .10686 L
s
.99375 .18589 m
1 .18589 L
s
.99375 .26492 m
1 .26492 L
s
.99375 .34395 m
1 .34395 L
s
.99375 .42298 m
1 .42298 L
s
.99375 .50201 m
1 .50201 L
s
.99375 .58104 m
1 .58104 L
s
.125 Mabswid
.99625 .04363 m
1 .04363 L
s
.99625 .05944 m
1 .05944 L
s
.99625 .07524 m
1 .07524 L
s
.99625 .09105 m
1 .09105 L
s
.99625 .12266 m
1 .12266 L
s
.99625 .13847 m
1 .13847 L
s
.99625 .15427 m
1 .15427 L
s
.99625 .17008 m
1 .17008 L
s
.99625 .20169 m
1 .20169 L
s
.99625 .2175 m
1 .2175 L
s
.99625 .23331 m
1 .23331 L
s
.99625 .24911 m
1 .24911 L
s
.99625 .28072 m
1 .28072 L
s
.99625 .29653 m
1 .29653 L
s
.99625 .31234 m
1 .31234 L
s
.99625 .32814 m
1 .32814 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .37556 m
1 .37556 L
s
.99625 .39137 m
1 .39137 L
s
.99625 .40717 m
1 .40717 L
s
.99625 .43879 m
1 .43879 L
s
.99625 .45459 m
1 .45459 L
s
.99625 .4704 m
1 .4704 L
s
.99625 .48621 m
1 .48621 L
s
.99625 .51782 m
1 .51782 L
s
.99625 .53362 m
1 .53362 L
s
.99625 .54943 m
1 .54943 L
s
.99625 .56524 m
1 .56524 L
s
.99625 .01202 m
1 .01202 L
s
.99625 .59685 m
1 .59685 L
s
.99625 .61265 m
1 .61265 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .02783 m
1 .02783 L
s
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -157.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integrated) show
114.438 14.000 moveto
(Dodecapole) show
174.625 14.000 moveto
(vs) show
188.250 14.000 moveto
(Quad) show
217.188 14.000 moveto
(Length) show
251.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01472 m
.34127 .11391 L
.5 .22138 L
.65873 .341 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool4
000000030;Zj^P3oool0V9RH00<0000000<0V9RH0?ooo`3oool0603oool0100@41000000010@401g
MgL20?ooo`0509RHV000000000000000002HV9P07@3oool010000000oooo0?ooo`2HV9P300000003
09RHV03oool0oooo01L0oooo00L0410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH
0?ooo`3oool0603oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo
0?ooo`0I0?ooo`0309RHV014A4@0oooo0080oooo00D0V9RH000000000000000009RHV00J0?ooo`07
09RHV000000000000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo00D0oooo000a0?oo
o`0;0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV00000007@3oool0201gMgL0
IVIV0?ooo`000000V9RH0?ooo`2HV9P000007@3oool020000000oooo0?ooo`000000V9RH0?ooo`2H
V9P00000703oool0202HV9P000000?ooo`000000V9RH0?ooo`2HV9P000006P3oool02`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000001/0oooo00<0k^k^0000003^k^h00P3o
ool01@000000V9RH0?ooo`2HV9P0000001X0oooo00/0000009RHV03oool0V9RH0000003oool00000
09RHV03oool0V9RH000000070?ooo`00<P3oool00`3<c<`0k^k^0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000007P3oool00`000000oooo000000030?ooo`030000003oool0oooo01P0oooo1`00
00030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0H0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo01X0
oooo00D0A4A40:VYZ@3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool003<0oooo00D0ZJVY
0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo01X0oooo00D0gMgM08N7Q`000000oooo
000000030?ooo`030000003oool0oooo01P0oooo00@0A4A409RHV03oool000000P3oool01@000000
oooo0?ooo`3oool0000001d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0H0?oo
o`070000003<c<`0oooo09RHV0000000oooo000000030?ooo`030000003oool0oooo01X0oooo00D0
V9RH05EEE@3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00L0V9RH07MgM`2j^[X0
ZJVY05EEE@3oool0000000<0oooo00<000000?ooo`3oool01@3oool003<0oooo00D0gMgM06IVIP3o
ool0oooo000000030?ooo`030000003oool0oooo01T0oooo00H0EEEE010@40000000V9RH0?ooo`00
00030?ooo`030000003oool0oooo01P0oooo00@0k^k^010@403MgMd000000P3oool01@000000oooo
0?ooo`3oool0000001`0oooo00@0V9RH0000003oool000000`3oool00`000000oooo0?ooo`0H0?oo
o`07010@401EEED000000000002HV9P0oooo000000030?ooo`030000003oool0oooo01X0oooo00D0
k^k^0000003oool0oooo000000030?ooo`030000003oool0oooo01P0oooo00@0gMgM024Q8@14A4@0
<S8b0P3oool01@000000oooo0?ooo`3oool0000000L0oooo000a0?ooo`0407MgM`3oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo0000000M0?ooo`040;Zj^P2HV9P0oooo000000<0oooo00<0
00000?ooo`3oool06@3oool00`2YZJT0<S8b000000020?ooo`050000003oool0oooo0?ooo`000000
6@3oool40000000309RHV03oool0000000<0oooo00<000000?ooo`3oool0603oool00`1gMgL0A4A4
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000007@3oool0100Q8B40ZJVY0?ooo`0000030?oo
o`030000003oool0oooo01P0oooo00L08B4Q0:VYZ@3oool0gMgM038b<P3oool0000000<0oooo00<0
00000?ooo`3oool01@3oool00340oooo00@0000009RHV02HV9P000000P3oool01@000000V9RH0?oo
o`2HV9P0000001X0oooo00/0A4A40;Zj^P3oool0^[Zj0000003oool0000009RHV03oool0V9RH0000
000L0?ooo`0906IVIP000000oooo0?ooo`000000V9RH0?ooo`2HV9P0000001T0oooo00<0MgMg05EE
E@3oool00`3oool01@000000V9RH0?ooo`2HV9P0000001/0oooo00<0EEEE07MgM`3oool00P3oool0
1@000000V9RH0?ooo`2HV9P0000001X0oooo00/08B4Q0;Zj^P3oool0QhN705EEE@3oool0000009RH
V03oool0V9RH0000000J0?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RH
V00000001`3oool00340oooo00@0V9RH000000000000V9RH0P3oool01@2HV9P00000000000000000
V9RH01X0oooo00L0k^k^04A4A0000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0
6P3oool01@3^k^h0410@0?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool0603oool01P0@4100
00000000000b<S80oooo09RHV0<0000000<0V9RH0?ooo`3oool06P3oool01@2HV9P0A4A408N7Q`3o
ool0V9RH00<0000000<0V9RH0?ooo`3oool0603oool01`1gMgL00000000000000000410@0?ooo`2H
V9P00`0000000`2HV9P0oooo0?ooo`0H0?ooo`0709RHV000000000000000002HV9P0oooo09RHV003
0000000309RHV03oool0oooo00D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000b0?ooonP000001P3oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`00<P3oool2000000<0oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02H0oooo0P0000060?ooo`00
103oool0100@41000000010@401gMgL50?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE103oool3
000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`<000008P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo00<00000
0?ooo`3oool0103oool000L0oooo00<0MgMg06IVIP3oool00`3oool01P3^k^h0EEEE0>k^kP3^k^h0
EEEE0>k^kPD0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH00000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`03000001l0oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo00080?ooo`030000003oool0oooo00<0
oooo00@0k^k^05EEE@1EEED0k^k^1P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`<00000703oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<0gMgM08N7Q`0000001@3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0403ooooX000000H0oooo00050?ooo`0405EEE@0@4100
000009RHV0@0oooo00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo0`00000F0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`040?ooo`001`3oool00`2j^[X0V9RH0?ooo`030?ooo`0605EEE@3^k^h0oooo0?oo
o`3^k^h0EEEE1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo0P00
00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool400000180oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo0004
0?ooo`0504A4A02j^[X0oooo0;Zj^P0000003`3oool020000000oooo0?ooo`000000V9RH0?ooo`2H
V9P000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool3000000l0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?oo
o`030000003oool0oooo00@0oooo00040?ooo`050>k^kP14A4@000000000002HV9P03P3oool01@0Q
8B4000000?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool0100000020?ooo`<000001`3oool2
000000<0oooo00<000000?ooo`3oool04`3oool3000000`0oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0V0?ooo`8000001P3oool002L0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo0`0000090?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`009`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool4
000000D0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0
oooo00@0oooo000X0?ooo`800000203oool2000000<0oooo00<000000?ooo`3oool07@3oool30000
0080oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool00380
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`<00000903oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool0100007l0000000000000000Q0?ooo`030000O`3oool0oooo0240
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0
oooo00<000000?ooo`3oool0103oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0R0?ooo`040000O`3oool0oooo0?ooo`<000007P3oool00`0007l0oooo0?ooo`0Q0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo00@0oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo00@0oooo1000000J0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02H0oooo0P0000060?ooo`00<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0203o
ool3000001L0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool02`3oool3
000001@0oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool03P3oool30000
0140oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000
oooo0?ooo`030?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE103oool3000000030?ooo`2HV9P0
00000080000000<0V9RH0?ooo`3oool0403oool2000000<0oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0A0?ooo`@000003@3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool0
00L0oooo00<000000?ooo`3oool00`3oool01P3^k^h0EEEE0>k^kP3^k^h0EEEE0>k^kPD0oooo00P0
00000?ooo`3oool0000009RHV03oool0V9RH00000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0R0?ooo`030000O`3oool0oooo01D0oooo0`00000:0?ooo`030000O`3oool0oooo
0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
02L0oooo00<000000?ooo`3oool0103oool000@0oooo1P0000040?ooo`040>k^kP1EEED0EEEE0>k^
kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0H0?ooo`<000001`3oool0
0`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo00040?ooo`0404A4A02HV9P0oooo
000000H0oooo00@0k^k^05EEE@1EEED0k^k^1P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0100oooo0P0000030000O`030000000007l0001o0400001o0`00002K0000O`800000
1P3oool000@0oooo00@0k^k^010@403MgMd000001@3oool01P3^k^h0EEEE0>k^kP3^k^h0EEEE0>k^
kPD0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0N0?ooo`<0000000<0oooo
0000O`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`2YZJT0<S8b000000050?oo
o`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE1@3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0Q0?ooo`<000008P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`1VIVH000000?ooo`0?0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`0000008@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`3^k^h0410@0?ooo`0>0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2H
V9P0oooo0?ooo`0400000080oooo0`0000070?ooo`8000000`3oool00`000000oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool00P00000O0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool002L0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
02L0oooo00<000000?ooo`3oool0103oool002L0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool002P0
oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo00@0oooo0P00000K0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0
oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool00380oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool01`3oool2000001P0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000b0?oo
o`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool02P3oool2000001D0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo02H0oooo0P0000060?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000003oool0oooo0180oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
3@3oool200000180oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000b0?ooo`8000000`3oool0
0`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0403oool0
0`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0V0?ooo`8000001P3oool000@0oooo00D0410@000000000000000009RHV004
0?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE103oool3000000030?ooo`2HV9P0000000800000
00<0V9RH0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0A0?ooo`8000003P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo
0?ooo`040?ooo`001`3oool00`2HV9P000000?ooo`030?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0
k^k^1@3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool000P0oooo00<00000
0?ooo`3oool00`3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0D0?ooo`8000002`3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo
0?ooo`040?ooo`00203oool00`000000oooo0?ooo`030?ooo`040>k^kP1EEED0EEEE0>k^kPH0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?ooo`8000000`0007l00`000000
001o0000O`1P0000O`030000000007l0001o07/0001o0P0000060?ooo`001`3oool00`2HV9P00000
0?ooo`030?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0k^k^1@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01L0oooo0P000008
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W
0?ooo`030000003oool0oooo00@0oooo00040?ooo`@0000000<0V9RH0?ooo`3oool00P3oool01P1E
EED0k^k^0?ooo`3oool0k^k^05EEE@D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06@3oool00`000000oooo
0?ooo`050?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0W0?ooo`030000003oool0oooo00@0oooo00040?ooo`0307MgM`1EEED0oooo0140oooo00P0
00000?ooo`3oool0000009RHV03oool0V9RH00000080oooo100000020?ooo`<000001`3oool20000
00<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
01X0oooo0P0000050?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0V0?ooo`8000001P3oool000D0oooo00@0410@000000000000<S8b3P3oool01@0Q
8B4000000?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool01@3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?oo
o`040?ooo`009`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01d0oooo00D0
00000?ooo`3oool0oooo0000O`0T0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
9`3oool00`000000oooo0?ooo`040?ooo`00:03oool2000000P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool07P3o
ool2000000030?ooo`0007l0oooo02<0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0W0?ooo`030000003oool0oooo00@0oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0R
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0803oool00`000000001o0?ooo`0S
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo000b0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0240oooo0P00000S0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`03
0000O`3oool000000280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo00@0oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool0100007l0oooo0?ooo`00000Q0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo000b0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0240oooo00@0001o0?ooo`3oool0oooo0P00000O0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0Q0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`040?ooo`800000703oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo0P000003
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q
0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo02H0oooo0P0000060?ooo`00103oool01@2HV9P00000000000000000
V9RH00@0oooo00H0EEEE0>k^kP3oool0oooo0>k^kP1EEED40?ooo`<0000000<0oooo09RHV0000000
0P0000000`2HV9P0oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
9`3oool00`000000oooo0?ooo`040?ooo`00103oool01@000000V9RH0?ooo`2HV9P0000000@0oooo
00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`080000003oool0oooo0000002HV9P0oooo09RH
V000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool0203oool2000001P0oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo
00040?ooo`050000003oool0oooo0?ooo`0000001@3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool000@0oooo00D000000<c<c03o
ool0V9RH000000050?ooo`040>k^kP1EEED0EEEE0>k^kPH0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0@0?ooo`8000000`0007l00`000000001o0000O`1i0000O`0300000000
07l0001o0680001o0P0000060?ooo`00103oool01@0@4100EEEE000000000000V9RH00@0oooo00H0
k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo00`0oooo0P00000D0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?oo
o`00103oool00`1gMgL0A4A40?ooo`060?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE1@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0240oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`001@3oool0
0`1EEED0MgMg0?ooo`0@0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000:0?ooo`03
0000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo00l0oooo0P00000A0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo00060?ooo`0309RH
V014A4@0QhN700h0oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0oooo00@0
00000P3oool3000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00h0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo00@0oooo000W0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000W0?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0C0?ooo`80
00003@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3o
ool0103oool002P0oooo0P0000080?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0E0?ooo`030000
003oool0oooo00X0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`800000
1P3oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003o
ool0oooo00T0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003o
ool0oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool05`3oool2
000000T0oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0
oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`040?ooo`00<P3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool06P3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09P3oool2000000H0
oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool06`3oool2000000D0oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo
000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?oo
o`020?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?oo
o`040?ooo`00<P3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool07P3oool200000080oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool000D0oooo00<0V9RH04A4
A03oool01@3oool01P1EEED0k^k^0?ooo`3oool0k^k^05EEE@@0oooo0`0000000`3oool0V9RH0000
00020000000309RHV03oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?oo
o`0P0?ooo`030000003oool0001o02@0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?oo
o`040?ooo`001@3oool00`3^k^h000000>k^kP050?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0k^k^
1@3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P000004P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q
0?ooo`030000O`3oool0oooo0240oooo00<000000000O`3oool08`3oool00`0007l0oooo0?ooo`0W
0?ooo`030000003oool0oooo00@0oooo00060?ooo`0304A4A02YZJT0oooo00D0oooo00@0k^k^05EE
E@1EEED0k^k^1P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`8000008`3oool00`0007l0oooo0?oo
o`0W0?ooo`030000003oool0oooo00@0oooo00060?ooo`0309RHV01EEED0oooo00D0oooo00@0k^k^
05EEE@1EEED0k^k^1P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo
0P0000030000O`030000000007l0001o0980001o00<000000000O`0007l0B@0007l2000000H0oooo
00060?ooo`030>k^kP000000oooo00@0oooo00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo0280oooo00@0001o0?ooo`3oool000008@3oool00`0007l0oooo0?ooo`0W
0?ooo`030000003oool0oooo00@0oooo00070?ooo`03024Q8@2YZJT0oooo00<0oooo00H0EEEE0>k^
kP3oool0oooo0>k^kP1EEED50?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1P3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`050000
O`3oool0oooo0?ooo`000000803oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0
oooo00040?ooo`05024Q8@2j^[X0oooo08N7Q`1EEED03`3oool020000000oooo0?ooo`000000V9RH
0?ooo`2HV9P000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<0
001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00103oool01@1gMgL0000000000000
0000410@00h0oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0oooo00@00000
0P3oool3000000L0oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
0`3oool2000001d0oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo000W0?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`0007l0oooo0?ooo`0W0?ooo`030000
003oool0oooo00@0oooo000W0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
8@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0
6@3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000203o
ool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo01P0oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo000b0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`080?ooo`800000603oool0
0`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000b0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo
01D0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool02`3oool00`000000
oooo0?ooo`0D0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo
0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0303oool00`000000oooo
0?ooo`0C0?ooo`030000O`3oool0oooo02H0oooo0P0000060?ooo`00<P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool03@3oool00`000000oooo0?oo
o`0B0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00h0oooo0P00000B
0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0103oool00380oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000b0?ooo`80
00000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0V0?ooo`8000001P3oool000@0oooo00D0V9RH000000000000
000009RHV0040?ooo`0605EEE@3^k^h0oooo0?ooo`3^k^h0EEEE103oool3000000030?ooo`2HV9P0
00000080000000<0V9RH0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0
oooo02L0oooo00<000000?ooo`3oool0103oool000@0oooo00D0000009RHV03oool0V9RH00000004
0?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0k^k^1@3oool020000000oooo0?ooo`000000V9RH0?oo
o`2HV9P000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02L0oooo00<00000
0?ooo`3oool0103oool000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`040>k^kP1EEED0
EEEE0>k^kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?ooo`800000
0`0007l00`000000001o0000O`2W0000O`800000=@0007l2000000H0oooo00040?ooo`0509RHV01g
MgL0^[Zj0:VYZ@1EEED01@3oool0103^k^h0EEEE05EEE@3^k^h60?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo
02L0oooo00<000000?ooo`3oool0103oool000@0oooo00@0gMgM024Q8@14A4@0<S8b1@3oool01P3^
k^h0EEEE0>k^kP3^k^h0EEEE0>k^kPD0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02L0oooo
00<000000?ooo`3oool0103oool000@0oooo00D08B4Q0:VYZ@3oool0gMgM038b<P040?ooo`0605EE
E@3^k^h0oooo0?ooo`3^k^h0EEEE1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo02L0oooo00<000000?ooo`3oool0103oool000@0oooo00D0000009RHV03oool0V9RH0000000?
0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV00000020?ooo`@000000P3oool3000000L0
oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06@3oool2000000L0
oooo00<0001o0?ooo`3oool09P3oool2000000H0oooo00040?ooo`0509RHV000000000000000002H
V9P03P3oool01@0Q8B4000000?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool01@3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`040?ooo`009`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00:03oool20000
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
01d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo
00@0oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280
oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01h0
oooo00D000000?ooo`3oool0oooo0000O`0X0?ooo`8000001P3oool00380oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01l0oooo0P0000000`3oool0
001o0?ooo`0X0?ooo`030000003oool0oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000000007l0oooo02P0oooo
00<000000?ooo`3oool0103oool00380oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0
001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0V0?ooo`8000001P3oool00380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o
0000003oool09`3oool00`000000oooo0?ooo`040?ooo`00<P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0000000W0?oo
o`030000003oool0oooo00@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo008000009@3oool00`000000
oooo0?ooo`040?ooo`00<P3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool08@3oool2000000H0oooo
00040?ooo`80<S8b00<0V9RH0?ooo`3oool0103oool01P1EEED0k^k^0?ooo`3oool0k^k^05EEE@@0
oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00040?ooo`040>k^
kP2HV9P0410@05EEE@D0oooo00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`080000003oool0
oooo0000002HV9P0oooo09RHV000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`040?ooo`001P3oool00`3^k^h0410@09RHV0050?ooo`040>k^
kP1EEED0EEEE0>k^kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?oo
o`00103oool01@2HV9P000000000001EEED08B4Q00D0oooo00@0k^k^05EEE@1EEED0k^k^1P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo0P0000030000O`0300000000
07l0001o0;h0001o0P00000N0000O`8000001P3oool000@0oooo00D0000009RHV03oool0c<c<0000
00040?ooo`060>k^kP1EEED0k^k^0>k^kP1EEED0k^k^1@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00@0oooo00040?ooo`050000003oool0oooo0?ooo`000000103oool01P1E
EED0k^k^0?ooo`3oool0k^k^05EEE@D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo
00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0103oool000@0oooo00D0000009RHV03oool0V9RH0000000?0?ooo`080000
003oool0oooo0000002HV9P0oooo09RHV000000:0?ooo`030000003oool0oooo00D0oooo0P000003
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q
0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0:
0?ooo`030000003oool0oooo01T0oooo0P0000060?ooo`00103oool01@2HV9P00000000000000000
V9RH00h0oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0oooo00@000000P3o
ool3000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool02`3oool2000001X0oooo00<000000?ooo`3oool0103o
ool002L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3o
ool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0103oool002L0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103o
ool002P0oooo0P0000080?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0
oooo0280oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`8000001P3oool0
0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00@0oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0
oooo0?ooo`0R0?ooo`030000O`3oool0oooo0140oooo0P00000D0?ooo`030000003oool0oooo00@0
oooo000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo
0?ooo`0R0?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`00<P3oool2000000<0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool03`3oool2000000H0oooo000b
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00380oooo0P0000030?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0G0?ooo`8000003@3oool2000000H0oooo00060?ooo`<00000
103oool01P1EEED0k^k^0?ooo`3oool0k^k^05EEE@@0oooo0`0000000`3oool0V9RH000000020000
000309RHV03oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool08@3oool00`0007l0oooo0?ooo`0R0?oo
o`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo00070?ooo`030000003oool0oooo00<0oooo00H0k^k^05EEE@3^
k^h0k^k^05EEE@3^k^h50?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000B0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`03
0000O`3oool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`00
1`3oool00`000000oooo0?ooo`040?ooo`040>k^kP1EEED0EEEE0>k^kPH0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?oo
o`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo01/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000oooo0?ooo`040?ooo`04
0>k^kP1EEED0EEEE0>k^kPH0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0@
0?ooo`8000000`0007l00`000000001o0000O`3D0000O`800000200007l2000000H0oooo00070?oo
o`030000003oool0oooo00<0oooo00H0k^k^05EEE@3^k^h0k^k^05EEE@3^k^h50?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0N0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000L0oooo00<000000?ooo`3oool00`3o
ool01P1EEED0k^k^0?ooo`3oool0k^k^05EEE@D0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool000L0oooo00<000000?ooo`3oool03P3oool020000000
oooo0?ooo`000000V9RH0?ooo`2HV9P000001`3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0240oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
O`3oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`0Q8B4000000?ooo`0>0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo
0?ooo`04000000050?ooo`000000oooo0?ooo`0000001`3oool2000000<0oooo00<000000?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<0001o0?ooo`3o
ool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool00P3oool2000000H0oooo000X0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo0280oooo00<0001o0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0R0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool002L0oooo00@000000?ooo`3oool00000
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000O`3oool0oooo0280oooo00<0001o0?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000203o
ool2000000<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0280oooo00@000000?ooo`3oool0oooo0P0000060?ooo`00<P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00380ooooj0000006
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00F@3oool01P2HV9P0410@0000
000@4100MgMg0>k^kT00oooo0`00001B0?ooo`0609RHV00@41000000010@401gMgL0k^k^9P3oool0
05T0oooo00H000000;Zj^P3oool0k^k^08N7Q`0b<S910?ooo`030000003oool0oooo02H0oooo00@0
ZJVY04A4A00Q8B40IVIV9`3oool01P000000^[Zj0?ooo`3^k^h0QhN7038b<RH0oooo001I0?ooo`06
07MgM`3^k^h0oooo0?ooo`3MgMd00000@@3oool00`000000oooo0?ooo`0U0?ooo`0309RHV0000000
^[Zj02T0oooo00H0MgMg0>k^kP3oool0oooo0=gMg@00000V0?ooo`00A`3oool3000000050?ooo`00
000000000000003oool00P0000002@3oool0ZJVY038b<P2HV9P00000010@403<c<`0oooo07MgM`03
00000003010@4027QhL000000080000000l0oooo09RHV0000000V9RH024Q8@1EEED0oooo0:VYZ@0b
<S80V9RH0000000@4100c<c<0?ooo`2HV9P00P0000000`1gMgL00000000000050?ooo`H0000000@0
V9RH0?ooo`3oool0V9RH0`0000000`2HV9P0oooo09RHV0020000000I07MgM`000000000009RHV000
0000410@0<c<c03oool0V9RH0000000@4100c<c<0?ooo`2HV9P0000009RHV00Q8B40EEEE0?ooo`00
0000A4A40000002HV9P0oooo09RHV0030000000309RHV03oool000000080000000@0V9RH0000000@
4100c<c<1P3oool0203MgMd000000=gMg@3oool0000005EEE@000000V9RH1P3oool00`3^k^h0EEEE
000000020000000709RHV03oool0oooo0?ooo`2HV9P0000009RHV0020000000609RHV0000000V9RH
024Q8@1EEED0V9RH0P0000000`1gMgL00000000000030?ooo`H0000000H0IVIV09RHV0000000410@
0<c<c03oool3000000040?ooo`000000000007MgM`<0000000D0410@08N7Q`3oool0ZJVY038b<P03
000000030?ooo`000000000001d0oooo00180?ooo`050000003oool0oooo0?ooo`0000000P3oool0
30000000oooo0?ooo`000000oooo0000002HV9P0^[Zj010@403oool0<S8b0=gMg@D0oooo01D00000
0?ooo`3oool0000009RHV03MgMd000000>k^kP3oool000000?ooo`000000V9RH0;Zj^P0@4100oooo
0000002HV9P0oooo0<c<c00000001`3oool0;P000000oooo0?ooo`3oool0V9RH0000002HV9P0oooo
0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo0<c<c0000000oooo0000002HV9P0^[Zj
010@403oool0000009RHV02j^[X0<S8b0?ooo`000000V9RH0=gMg@000000k^k^0?ooo`000000c<c<
09RHV0000000oooo0000002HV9P0oooo09RHV00000020?ooo`060000003oool0000009RHV02j^[X0
410@1P3oool02027QhL0000008N7Q`3oool08B4Q0>k^kP2HV9P000001@3oool00`3<c<`08B4Q09RH
V0020?ooo`0309RHV0000000V9RH0080oooo00l0000009RHV03<c<`000000?ooo`000000V9RH0=gM
g@000000k^k^0000002HV9P0oooo0<c<c00000001@3oool02P000000k^k^0?ooo`3oool0c<c<04A4
A0000000V9RH0;Zj^P0@41020?ooo`070000003oool0oooo0000003oool0<S8b0=gMg@050?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool004P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`060000003oool0oooo0000003oool00000103oool01@3MgMd08B4Q0000
000@4100ZJVY0080oooo00L000000?ooo`3oool0000009RHV03oool000000080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool0
102HV9P000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`040000002HV9P0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`060000003oool0oooo0000003oool000002@3oool00`0Q8B40MgMg024Q
8@020?ooo`030<c<c014A4@0A4A400D0oooo00<0000009RHV03oool00`3oool01@2HV9P000000?oo
o`3oool000000080oooo00P000000?ooo`000000V9RH0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00X00000
0?ooo`3oool000000?ooo`3MgMd08B4Q0000000@4100ZJVY0P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo01`0oooo00180?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`000000oooo00@0000000H0oooo024Q8@27QhL0oooo0=gMg@0000020?ooo`04
0000003oool0oooo09RHV0<000000P3oool00`000000oooo00000003000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo00000003000000030?ooo`000000oooo
00<0oooo00@0V9RH00000000000000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00D000000?ooo`3oool000000?ooo`04000000D0oooo00P0gMgM0000003oool0410@0=gMg@27QhL0
<S8b09RHV0H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000
003oool0V9RH00<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo100000020?ooo`0:0000003oool0oooo0000003oool08B4Q08N7Q`3oool0
gMgM00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`00B03o
ool020000000oooo0?ooo`3oool000000<c<c02HV9P000000P3oool00`000000oooo0000000209RH
V0070000003oool000000<c<c03oool0QhN7000000020?ooo`030000003^k^h0oooo0080oooo00L0
V9RH0000003oool0oooo0000003oool000000080V9RH00L000000?ooo`000000V9RH0?ooo`2j^[X0
000000L0oooo00<000000?ooo`3oool00`3oool03`000000oooo0000002HV9P0oooo09RHV0000000
oooo0000002HV9P0oooo0;Zj^P000000oooo0000000209RHV0060000003oool0000009RHV03MgMd0
410@0`3oool03P2HV9P000000?ooo`3oool000000;Zj^P2HV9P000000?ooo`000000V9RH0?ooo`2H
V9P000000P3oool00`000000oooo0000000209RHV0030000003oool0oooo00<0oooo00T0MgMg05EE
E@3oool0MgMg06IVIP000000V9RH0>k^kP0Q8B401@3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000080oooo00`000000?ooo`3oool0oooo09RHV0000000oooo0000002HV9P0oooo
0;Zj^P0000050?ooo`030000003oool0oooo00<0oooo00@0000009RHV02HV9P000000P3oool02P00
0000c<c<09RHV0000000oooo0000003<c<`0oooo08N7Q`0000020?ooo`070000003oool0oooo0000
003<c<`0V9RH0000000N0?ooo`00B03oool00`000000oooo0?ooo`020000000409RHV0000000V9RH
0?ooo`<0000000/0V9RH000000000000V9RH0?ooo`3<c<`0410@00000014A4@0k^k^0?ooo`020000
000309RHV00Q8B40A4A40080000000<0V9RH0?ooo`0000000P0000001P2HV9P000000000002HV9P0
oooo09RHV080000000<0IVIV0000003oool01P3oool00`000000oooo0?ooo`020?ooo`0409RHV000
0000oooo09RHV0<0000000<0V9RH0?ooo`2HV9P00P000000101VIVH000000?ooo`2HV9P200000003
09RHV03oool0V9RH0080000000<0EEEE0?ooo`14A4@00P0000002@2HV9P0oooo000000000000V9RH
0000002HV9P0oooo09RHV0030000000609RHV03oool0oooo0000003oool0V9RH0P0000000`2HV9P0
oooo0?ooo`030?ooo`80000000L0oooo000000000000V9RH0000001EEED0000000D0oooo00<00000
09RHV03oool00`3oool00`2HV9P000000?ooo`02000000050?ooo`00000000000?ooo`14A4@00P00
00000`2HV9P0oooo09RHV0020000000306IVIP000000oooo00@0oooo00<000000?ooo`3oool00`3o
ool01@2HV9P000000000002HV9P0oooo0080000000X0V9RH0000002HV9P0oooo0<c<c00@41000000
04A4A03^k^h0oooo0`0000001@3oool0000009RHV0000000V9RH01h0oooo00180?ooo`030000003o
ool0oooo00H0oooo00<0QhN70000003oool0503oool00`27QhL000000?ooo`090?ooo`030000003o
ool0oooo00D0oooo00L000000?ooo`3oool0oooo09RHV0000000V9RH00/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0F0?ooo`0309RHV0000000V9RH0080oooo00<0V9RH0000002H
V9P0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D0QhN70000003o
ool0oooo0000000Q0?ooo`00A`3oool3000000P0oooo00<0<S8b0?ooo`3oool0503oool00`0b<S80
oooo0?ooo`070?ooo`8000001P3oool60000000309RHV03oool0oooo00T0oooo0P00000L0?ooo`80
00006@3oool00`2HV9P00000000000020000000309RHV03oool0oooo00h0oooo0P0000040?ooo`<0
00005P3oool0100b<S80oooo00000000000Q0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {4.85993, 1.72489*^-9, \
0.272002, 5.46304*^-11}}],

Cell[BoxData[
    \(\(-3.8076683091248404`*^-10\) + 1.2608350300619143`*^-10\ x\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the  current  ...", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The integrated quadrupole is plotted as a function of the current \
density in the coil\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(radius = 
        34;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ 
      radius\ of\ circle\ *) \t\t\t\t\t\), "\[IndentingNewLine]", 
    \(\(width = 
        60;\)\t\t\t\t\ \  (*\ \ pole\ width\ *) \), "\[IndentingNewLine]", 
    \(\(heigh = 80;\)\t\t\t\t (*\ 
      height\ of\ iron\ in\ coil\ *) \), "\[IndentingNewLine]", 
    \(\(length = 80;\)\t\t\t\t (*\ 
      length\ \ along\ beam\ *) \), "\[IndentingNewLine]", 
    \(\(chamfer = 
        8;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ chamfer\ of\ the\ pole\ *) \), "\[IndentingNewLine]", 
    \(\(curden = {0.1, 2, 4, 6, 10};\)\t\t\t\t (*\ 
      current\ density\ A/
          mm2\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(nx = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ beam\ *) \), \
"\[IndentingNewLine]", 
    \(\(ny = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ width\ *) \
\), "\[IndentingNewLine]", 
    \(\(nz = 
        4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ height\ *) \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nb = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ return\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(na = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ angular\ segmentation\ in\ the\ \
corner\ *) \[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(rmin = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
      minimum\ radius\ of\ the\ coil\ windings\ *) \), "\[IndentingNewLine]", \

    \(\(offset = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ 
      Vert . \ recess\ betw . \ 1  st\ and\ 2  
        nd\ coils*) \), "\[IndentingNewLine]", 
    \(\(hyp = 
        1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ pole\ profile\ 0.1 < \ hyp\  < 2, \ 
      1 : \ hyperbolic*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ironcolor = {0, 0.5, 
          1};\)\ \ \ \ \  (*\ \ Color\ of\ the\ yoke\ \ *) \), "\
\[IndentingNewLine]", 
    \(\(coilcolor = {1, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \  (*\ \ Color\ of\ the\ coil\ \ *) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(iron\  = RadMatSteel37[];\)\ \ \ \ \  (*\ 
      Material\ of\ the\ Yoke\ *) \), "\[IndentingNewLine]", 
    \(\(nseg = seg[nx, ny, nz, nb, na];\)\), "\[IndentingNewLine]", 
    \(\(res = 
        quad[radius, length, width, heigh, chamfer, hyp, nseg, curden, 
          iron];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(iq = IntQuad /. res\), "\[IndentingNewLine]", 
    \(\(tab = Transpose[{curden, iq}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[tab, 
        PlotJoined \[Rule] True, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Integrated Quadrupole \
vs Current Density\>"];\)\), "\[IndentingNewLine]", 
    \(Fit[tab, {x, x^2, x^3}, x]\)}], "Input"],

Cell[BoxData[
    \({0.04011922809468128`, 0.8020045465843788`, 1.5426448890818532`, 
      1.9667768668429473`, 2.328025821785802`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0141895 0.0962001 0.00439373 0.257267 [
[.01419 -0.0125 -5 -14 ]
[.01419 -0.0125 5 0 ]
[.20659 -0.0125 -5 -14 ]
[.20659 -0.0125 5 0 ]
[.39899 -0.0125 -5 -14 ]
[.39899 -0.0125 5 0 ]
[.59139 -0.0125 -5 -14 ]
[.59139 -0.0125 5 0 ]
[.78379 -0.0125 -5 -14 ]
[.78379 -0.0125 5 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00439 -10 -7 ]
[-0.0125 .00439 0 7 ]
[-0.0125 .13303 -19 -7 ]
[-0.0125 .13303 0 7 ]
[-0.0125 .26166 -10 -7 ]
[-0.0125 .26166 0 7 ]
[-0.0125 .39029 -19 -7 ]
[-0.0125 .39029 0 7 ]
[-0.0125 .51893 -10 -7 ]
[-0.0125 .51893 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -102.625 0 ]
[.5 .63053 102.625 14 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.20659 0 m
.20659 .61803 L
s
.39899 0 m
.39899 .61803 L
s
.59139 0 m
.59139 .61803 L
s
.78379 0 m
.78379 .61803 L
s
0 .13303 m
1 .13303 L
s
0 .26166 m
1 .26166 L
s
0 .39029 m
1 .39029 L
s
0 .51893 m
1 .51893 L
s
0 g
.01419 0 m
.01419 .00625 L
s
gsave
.01419 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20659 0 m
.20659 .00625 L
s
gsave
.20659 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.39899 0 m
.39899 .00625 L
s
gsave
.39899 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59139 0 m
.59139 .00625 L
s
gsave
.59139 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78379 0 m
.78379 .00625 L
s
gsave
.78379 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06229 0 m
.06229 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.15849 0 m
.15849 .00375 L
s
.25469 0 m
.25469 .00375 L
s
.30279 0 m
.30279 .00375 L
s
.35089 0 m
.35089 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.49519 0 m
.49519 .00375 L
s
.54329 0 m
.54329 .00375 L
s
.63949 0 m
.63949 .00375 L
s
.68759 0 m
.68759 .00375 L
s
.73569 0 m
.73569 .00375 L
s
.83189 0 m
.83189 .00375 L
s
.87999 0 m
.87999 .00375 L
s
.92809 0 m
.92809 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00439 m
.00625 .00439 L
s
gsave
-0.0125 .00439 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13303 m
.00625 .13303 L
s
gsave
-0.0125 .13303 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .26166 m
.00625 .26166 L
s
gsave
-0.0125 .26166 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .39029 m
.00625 .39029 L
s
gsave
-0.0125 .39029 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .51893 m
.00625 .51893 L
s
gsave
-0.0125 .51893 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03012 m
.00375 .03012 L
s
0 .05585 m
.00375 .05585 L
s
0 .08157 m
.00375 .08157 L
s
0 .1073 m
.00375 .1073 L
s
0 .15875 m
.00375 .15875 L
s
0 .18448 m
.00375 .18448 L
s
0 .21021 m
.00375 .21021 L
s
0 .23593 m
.00375 .23593 L
s
0 .28739 m
.00375 .28739 L
s
0 .31311 m
.00375 .31311 L
s
0 .33884 m
.00375 .33884 L
s
0 .36457 m
.00375 .36457 L
s
0 .41602 m
.00375 .41602 L
s
0 .44175 m
.00375 .44175 L
s
0 .46748 m
.00375 .46748 L
s
0 .4932 m
.00375 .4932 L
s
0 .54466 m
.00375 .54466 L
s
0 .57038 m
.00375 .57038 L
s
0 .59611 m
.00375 .59611 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01419 .61178 m
.01419 .61803 L
s
.20659 .61178 m
.20659 .61803 L
s
.39899 .61178 m
.39899 .61803 L
s
.59139 .61178 m
.59139 .61803 L
s
.78379 .61178 m
.78379 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06229 .61428 m
.06229 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.15849 .61428 m
.15849 .61803 L
s
.25469 .61428 m
.25469 .61803 L
s
.30279 .61428 m
.30279 .61803 L
s
.35089 .61428 m
.35089 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.49519 .61428 m
.49519 .61803 L
s
.54329 .61428 m
.54329 .61803 L
s
.63949 .61428 m
.63949 .61803 L
s
.68759 .61428 m
.68759 .61803 L
s
.73569 .61428 m
.73569 .61803 L
s
.83189 .61428 m
.83189 .61803 L
s
.87999 .61428 m
.87999 .61803 L
s
.92809 .61428 m
.92809 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00439 m
1 .00439 L
s
.99375 .13303 m
1 .13303 L
s
.99375 .26166 m
1 .26166 L
s
.99375 .39029 m
1 .39029 L
s
.99375 .51893 m
1 .51893 L
s
.125 Mabswid
.99625 .03012 m
1 .03012 L
s
.99625 .05585 m
1 .05585 L
s
.99625 .08157 m
1 .08157 L
s
.99625 .1073 m
1 .1073 L
s
.99625 .15875 m
1 .15875 L
s
.99625 .18448 m
1 .18448 L
s
.99625 .21021 m
1 .21021 L
s
.99625 .23593 m
1 .23593 L
s
.99625 .28739 m
1 .28739 L
s
.99625 .31311 m
1 .31311 L
s
.99625 .33884 m
1 .33884 L
s
.99625 .36457 m
1 .36457 L
s
.99625 .41602 m
1 .41602 L
s
.99625 .44175 m
1 .44175 L
s
.99625 .46748 m
1 .46748 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .54466 m
1 .54466 L
s
.99625 .57038 m
1 .57038 L
s
.99625 .59611 m
1 .59611 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .00439 m
1 .00439 L
s
.01419 0 m
.01419 .61803 L
s
gsave
.5 .63053 -163.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integrated) show
114.438 14.000 moveto
(Quadrupole) show
173.938 14.000 moveto
(vs) show
187.562 14.000 moveto
(Current) show
227.062 14.000 moveto
(Density) show
264.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01472 m
.20659 .21072 L
.39899 .40127 L
.59139 .51038 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3oool0
1@2HV9P00000000000000000V9RH02P0oooo100000000`2j^[X0oooo0?ooo`0X0?ooo`030000003o
ool0oooo02L0oooo00D0V9RH000000000000000009RHV00W0?ooo`0509RHV000000000000000002H
V9P09`3oool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3oool04P3oool002D0oooo
00D0000009RHV03oool0V9RH0000000X0?ooo`050<c<c03^k^h0oooo0<c<c01EEED0:P3oool00`00
0000oooo0?ooo`0W0?ooo`050000002HV9P0oooo09RHV00000009`3oool01@000000V9RH0?ooo`2H
V9P0000002P0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000001@0oooo000U0?ooo`05
0000003oool0oooo0?ooo`000000:@3oool00`3<c<`0k^k^0?ooo`0X0?ooo`H000009`3oool01@00
0000oooo0?ooo`3oool0000002L0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool04P3oool002D0oooo00D000000?ooo`3oool0oooo
0000000Z0?ooo`030:VYZ@3^k^h0oooo02L0oooo00@0A4A409RHV03oool00000:@3oool01@000000
c<c<0?ooo`2HV9P0000002L0oooo00D0V9RH07MgM`2j^[X0ZJVY05EEE@0X0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool04P3oool002D0oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`030=gMg@1VIVH0oooo02L0oooo00@0k^k^010@403MgMd00000:@3oool01@0@4100EEEE
000000000000V9RH02L0oooo00@0gMgM024Q8@14A4@0<S8b:@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0180oooo000U0?ooo`050000003oool0oooo0?ooo`000000:03oool0
101gMgL0oooo0?ooo`00000Y0?ooo`030:VYZ@0b<S80000002T0oooo00<0MgMg04A4A03oool0:@3o
ool01@0Q8B40ZJVY0?ooo`3MgMd0<S8b02P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0B0?ooo`009@3oool01@000000V9RH0?ooo`2HV9P0000002P0oooo00@0000009RHV02H
V9P00000:P3oool00`1VIVH000000?ooo`0Y0?ooo`0305EEE@1gMgL0oooo02P0oooo00D0000009RH
V03oool0V9RH0000000X0?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000D0?ooo`00
9@3oool01@2HV9P00000000000000000V9RH02P0oooo00@0V9RH000000000000V9RH:P3oool00`3^
k^h0410@0?ooo`0Z0?ooo`0309RHV014A4@0QhN702L0oooo00D0V9RH000000000000000009RHV00W
0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0B0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`006P3oool01@2HV9P00000000000000000V9RH0?l0oooo0P3oool001X0
oooo00D0000009RHV03oool0V9RH000000060?ooonT000004P3oool001X0oooo00D000000?ooo`3o
ool0oooo000000060?ooonT000004P3oool001X0oooo00D000000?ooo`3oool0oooo000000060?oo
o`040000003oool0oooo000002`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo000J0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
10000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403o
ool001X0oooo00D000000?ooo`3oool0oooo000000060?ooo`060000003oool0oooo0000003oool0
0000:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000J0?ooo`050000
002HV9P0oooo09RHV00000001P3oool01P000000oooo0?ooo`000000oooo000002X0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`006P3oool01@2HV9P00000000000000000
V9RH00H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0W0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo0P0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0;`3oool200000180oooo000U0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`
0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`
0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool08P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`
0?ooo`030000003oool0oooo0100oooo000U0?ooo`80000000<0oooo0000003oool0203oool00`00
0000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02l0oooo0P00000B0?ooo`009@3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01l0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
01h0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000
oooo0?ooo`00000<0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo00h0oooo00<000000?ooo`3o
ool06P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0?ooo`0I0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0H0?ooo`03
0000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0?ooo`0G0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo0P0000000`3oool000000?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0;`3oool200000180oooo000U0?ooo`040000003oool0oooo000001H0oooo
00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000U0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000001L0oooo
00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000A0?ooo`0509RHV000000000000000002HV9P00P3oool00`0b<S80oooo010@40030000000309RH
V03oool0oooo00@0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0A0?ooo`03
0000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool00140oooo00D0000009RHV03oool0
V9RH000000070?ooo`0309RHV0000000oooo00D0oooo00@000000?ooo`3oool000006@3oool00`00
0000oooo0?ooo`0@0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool00140
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo0P0000000`00
07l000000000O`0I0000O`030000000007l0001o0<D0001o0`00000B0?ooo`004@3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000K
0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@
0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0V9RH0000003oool01@3oool0
10000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo1000
00000`2HV9P0oooo0?ooo`040?ooo`040000003oool0oooo000001d0oooo00<000000?ooo`3oool0
303oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0
:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000A0?ooo`050000002H
V9P0oooo09RHV0000000103oool00`1gMgL0EEEE0?ooo`080?ooo`040000003oool0oooo000001h0
oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0
oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100
oooo000A0?ooo`0509RHV000000000000000002HV9P01@3oool0100@410000000000000b<S860?oo
o`040000003oool0oooo000001l0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`
0?ooo`030000003oool0oooo0100oooo000U0?ooo`80000000<0oooo0000003oool07`3oool00`00
0000oooo0?ooo`090?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02l0oooo0P00000B0?ooo`009@3oool010000000
oooo0?ooo`00000Q0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000R0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000
oooo0?ooo`00000S0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo
00D0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000
oooo0?ooo`00000U0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo02D0oooo00<000000?ooo`3o
ool00`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool0
00009`3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool0001o
02/0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo
0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool00000:@3oool01000
0000oooo0?ooo`0007l[0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool0
0`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo
000002X0oooo00<000000?ooo`0007l0:`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0
oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool01000
0000oooo0?ooo`00000[0?ooo`030000000007l0oooo02X0oooo00<0001o0?ooo`3oool0:P3oool0
0`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool0
02D0oooo0P0000000`3oool000000?ooo`0[0?ooo`030000003oool0oooo02T0oooo00<0001o0?oo
o`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02l0oooo0P00000B0?oo
o`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`000000oooo02T0oooo00<0001o0?oo
o`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?oo
o`3oool0403oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0000000Y0?oo
o`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?oo
o`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo00@0001o0?oo
o`3oool00000:03oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o
0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/
0?ooo`050000O`3oool0oooo0?ooo`0000009`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool0
10000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo02/0oooo00<0001o
0?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02X0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?oo
o`3oool00000;03oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<00000
0?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?oo
o`3oool00000;03oool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo0200oooo00<0001o
0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<00000
0?ooo`3oool0403oool001`0oooo0`0000060?ooo`040000003oool0oooo000002`0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000O`3oool0oooo02X0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000M0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`08
0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool001d0oooo00<000000?oo
o`3oool01@3oool2000000030000O`000000001o03L0001o00<000000000O`0007l0Y`0007l30000
0180oooo000M0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000;03oool00`00
07l0oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0:P3oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool001d0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo
00/0oooo00<000000?ooo`3oool06`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo
02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`007@3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0303oool00`00
0000oooo0?ooo`0J0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`00
07l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000M0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo
01T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo
0300oooo00<000000?ooo`3oool0403oool001`0oooo00<08B4Q0000003oool01P3oool010000000
oooo0?ooo`00000/0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`00
07l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo02/0oooo00<0001o0?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool0
0000;03oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool0
0000;03oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool0
0000;03oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo0P0000000`3oool000000?ooo`0[0?ooo`030000O`3oool0oooo01D0oooo
00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0;`3oool200000180oooo000U0?ooo`040000003oool0oooo000002`0oooo
00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0?0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo
00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo
0?ooo`0=0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo
00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000U0?ooo`80000000<0oooo0000003oool0:`3oool00`0007l0oooo0?ooo`0K0?ooo`030000003o
ool0oooo00/0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo02l0oooo0P00000B0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3o
ool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool0
10000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool02@3o
ool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3o
ool0oooo01h0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool0
10000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3o
ool0oooo0200oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool2
000000030?ooo`000000oooo02/0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`05
0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0_
0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0R
0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?oo
o`3oool00000;03oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<0001o
0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<00000
0?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0T
0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool001<0oooo0`0000020?oo
o`03038b<P3oool0410@00<0000000<0V9RH0?ooo`3oool0103oool010000000oooo0?ooo`00000/
0?ooo`030000O`3oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000O`0/0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`00503oool0
0`000000oooo0?ooo`060?ooo`0309RHV0000000oooo00D0oooo00@000000?ooo`3oool00000;03o
ool00`0007l0oooo0?ooo`0V0?ooo`040000003oool0oooo0000Ob`0oooo00<0001o0?ooo`3oool0
:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000D0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool2000000030000O`000000001o05D0001o00<0
00000000O`0007l0R@0007l300000180oooo000D0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02P0oooo00<0
00000000O`3oool0:`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<0
00000?ooo`3oool0403oool001@0oooo00<000000?ooo`3oool01P3oool00`2HV9P000000?ooo`05
0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool2000002/0oooo00<0
001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000D
0?ooo`030000003oool0oooo00<0oooo100000000`2HV9P0oooo0?ooo`040?ooo`040000003oool0
oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool0100007l0oooo00000000000Y0?ooo`030000
O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`00503o
ool00`000000oooo0?ooo`030?ooo`0307MgM`1EEED0oooo00P0oooo00@000000?ooo`3oool00000
;03oool00`0007l0oooo0?ooo`0Y0?ooo`050000O`3oool0oooo0?ooo`000000:03oool00`0007l0
oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool001<0oooo
00<08B4Q0000003oool01@3oool0100@410000000000000b<S860?ooo`040000003oool0oooo0000
02`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`020?ooo`8000009P3oool00`00
07l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0
oooo0P0000000`3oool000000?ooo`0[0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0103oool2000002@0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0_0?ooo`80
00004P3oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo00H0oooo0P00000R0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`03
0000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`03
0000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`00
9@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool02@3oool2000001l0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`03
0000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0;0?ooo`8000007@3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool0
0000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3o
ool06P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool0403oool002D0oooo0P0000000`3oool000000?ooo`0[0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool03P3oool2000001X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo0100oooo0P00000H0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo0?oo
o`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool04P3oool2000001H0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo
000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0E0?ooo`8000004`3oool00`0007l0oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@0
00000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01L0oooo
0P00000A0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo
0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo02/0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0I0?ooo`8000003`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo02l0oooo0P00000B0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool0
10000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0703o
ool2000000`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003o
ool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0N0?ooo`8000002P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo0300oooo00<000000?ooo`3oool0403oool002D0oooo00@000000?ooo`3oool00000;03o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403o
ool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo0240oooo0P0000070?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`009@3oool2000000030?ooo`000000oooo02/0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0S0?ooo`8000001@3oool00`0007l0oooo0?ooo`0Y
0?ooo`030000O`3oool0oooo02l0oooo0P00000B0?ooo`009@3oool010000000oooo0?ooo`00000/
0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool09@3oool2000000<0oooo00<0001o
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000U0?oo
o`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0W
0?ooo`040000003oool0oooo0000Ob/0oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?oo
o`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0
001o0?ooo`3oool0:03oool2000000030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`006P3oool4000000030;Zj^P3oool0oooo00@0oooo00@00000
0?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo0`00
000Y0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403oool001X0oooo00D0c<c<
0>k^kP3oool0c<c<05EEE@060?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0
:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo00@000009@3oool00`0007l0oooo
0?ooo`0`0?ooo`030000003oool0oooo0100oooo000K0?ooo`030<c<c03^k^h0oooo00L0oooo0P00
00000`0007l000000000O`2;0000O`D00000D@0007l300000180oooo000L0?ooo`030:VYZ@3^k^h0
oooo00H0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo02X0oooo00<0001o0?ooo`3oool02@3oool4000001`0oooo00<0001o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0@0?ooo`00703oool00`3MgMd0IVIV0?ooo`060?ooo`040000003oool0
oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo00d0oooo1000000H0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0403o
ool001X0oooo00@0MgMg0?ooo`3oool000001`3oool010000000oooo0?ooo`00000/0?ooo`030000
O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0A0?ooo`@00000
503oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo000J0?ooo`040000002H
V9P0V9RH000000L0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool05@3oool5000000l0oooo00<0001o0?ooo`3o
ool0<03oool00`000000oooo0?ooo`0@0?ooo`006P3oool0102HV9P000000000002HV9P70?ooo`04
0000003oool0oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?oo
o`030000O`3oool0oooo01X0oooo1000000;0?ooo`030000O`3oool0oooo0300oooo00<000000?oo
o`3oool0403oool002D0oooo0P0000000`3oool000000?ooo`0[0?ooo`030000O`3oool0oooo02T0
oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0N0?ooo`@000001`3oool00`0007l0
oooo0?ooo`0_0?ooo`8000004P3oool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0
oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool08P3oool4000000<0
oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo
0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0
oooo0?ooo`0V0?ooo`D00000<@3oool00`000000oooo0?ooo`0@0?ooo`009@3oool010000000oooo
0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0
oooo0?ooo`0Y0?ooo`030000O`3oool0000000<00000;@3oool00`000000oooo0?ooo`0@0?ooo`00
9@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00<0oooo1000000Y0?ooo`03
0000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo00<0001o0?ooo`3o
ool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3o
ool01`3oool4000002D0oooo00<000000?ooo`3oool0403oool002D0oooo0P0000000`3oool00000
0?ooo`0[0?ooo`030000O`3oool0oooo02T0oooo00<0001o0?ooo`3oool0:P3oool00`0007l0oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo00/0oooo1000000P0?ooo`8000004P3oool002D0oooo00@0
00000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0?0?ooo`D00000703oool00`000000oooo
0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo01@0oooo
1000000H0?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0603oool4000001@0oooo00<000000?ooo`3oool0403oool002D0oooo00@0
00000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo
00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0L0?ooo`@00000403oool00`000000oooo
0?ooo`0@0?ooo`009@3oool010000000oooo0?ooo`00000/0?ooo`030000O`3oool0oooo02T0oooo
00<0001o0?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo0200oooo
1@00000;0?ooo`030000003oool0oooo0100oooo000U0?ooo`80000000<0oooo0000003oool0:`3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`0U0?ooo`@000001P3oool200000180oooo000U0?ooo`040000003oool0
oooo000002`0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000O`3o
ool0oooo02T0oooo00<0001o0?ooo`3oool0:@3oool2000000D0oooo00<000000?ooo`3oool0403o
ool002D0oooo00@000000?ooo`3oool00000;03oool00`0007l0oooo0?ooo`0Y0?ooo`030000O`3o
ool0oooo02X0oooo00<0001o0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003o
ool0oooo0100oooo000U0?ooo`040000003oool0oooo000002`0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000U0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0100oooo000U0?ooonT000004P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool004H0oooo00H0V9RH010@40000000410@07MgM`3^k^i00?ooo`<00000J03oool00`0@4100
00000<c<c00V0?ooo`00AP3oool01P000000^[Zj0?ooo`3^k^h0QhN7038b<R00oooo00@0ZJVY04A4
A00Q8B40IVIV7@3oool00`000000oooo0?ooo`1X0?ooo`030>k^kP0Q8B40oooo02D0oooo00160?oo
o`0607MgM`3^k^h0oooo0?ooo`3MgMd000007`3oool00`2HV9P000000;Zj^P0O0?ooo`030000003o
ool0oooo06T0oooo00<0IVIV09RHV03oool0903oool003@0oooo0`0000001@3oool0000000000000
0000oooo0080000000T0oooo0:VYZ@0b<S80V9RH0000000@4100c<c<0?ooo`1gMgL00`0000000`0@
4100QhN7000000020000000?0?ooo`2HV9P0000009RHV00Q8B40EEEE0?ooo`2YZJT0<S8b09RHV000
0000410@0<c<c03oool0V9RH0080000000<0MgMg0000000000001P3oool00`3^k^h0EEEE00000002
0000000709RHV03oool0oooo0?ooo`2HV9P0000009RHV0020000000609RHV0000000V9RH024Q8@1E
EED0V9RH0P0000000`1gMgL000000000000300000080oooo00<0V9RH0000002HV9P00P0000001`3o
ool0000004A4A0000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo000000020000000409RHV000
0000410@0<c<c0D0oooo00P0gMgM0000003MgMd0oooo0000001EEED0000009RHV0H0oooo00H0V9RH
000000000000000006IVIP3^k^h20?ooo`0309RHV0000000V9RH00D0000000X0oooo000000000000
00000?ooo`2HV9P00000010@403<c<`0oooo0`0000001P3oool000000000003oool0ZJVY038b<P<0
oooo1P000000202HV9P0oooo0?ooo`2HV9P00000010@403<c<`0oooo0`000000203oool000000000
00000000EEEE0000002HV9P0oooo0`0000000`3oool0ZJVY038b<P020?ooo`0309RHV00Q8B40oooo
02@0oooo000e0?ooo`050000003oool0oooo0?ooo`0000000P3oool030000000oooo0?ooo`000000
oooo0000002HV9P0^[Zj010@403oool0<S8b0=gMg@D0oooo01D000000?ooo`3oool0000009RHV03M
gMd000000>k^kP3oool000000?ooo`000000V9RH0;Zj^P0@4100oooo0000002HV9P0oooo0<c<c000
00001P3oool00`3<c<`08B4Q09RHV0020?ooo`0309RHV0000000V9RH0080oooo00l0000009RHV03<
c<`000000?ooo`000000V9RH0=gMg@000000k^k^0000002HV9P0oooo0<c<c00000000P3oool02000
0000oooo0?ooo`3oool0000009RHV03<c<`000000P3oool02P000000c<c<09RHV0000000oooo0000
002HV9P0oooo09RHV00000020?ooo`060000003oool0000009RHV02j^[X0410@1@3oool02027QhL0
000008N7Q`3oool08B4Q0>k^kP2HV9P000001@3oool01`2HV9P0000009RHV03oool0k^k^08N7Q`0b
<S800P3oool010000000V9RH0<c<c00000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000V9RH0;Zj^P0@41020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`3oool030000000oooo0?ooo`3oool0V9RH0000002HV9P0oooo0000002HV9P0^[Zj010@4080oooo
00T000000?ooo`3oool000000?ooo`0Q8B40k^k^09RHV00000000P3oool010000000oooo0?ooo`00
00030?ooo`03038b<P000000c<c<02@0oooo000e0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01P000000oooo0?ooo`000000oooo000000@0oooo00D0gMgM024Q8@000000410@0:VYZ@020?oo
o`070000003oool0oooo0000002HV9P0oooo000000020?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000002HV9P0oooo00<0oooo00D0V9RH0000003oool0
oooo000000020?ooo`080000003oool0000009RHV03oool000000?ooo`0000030?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`03024Q8@1gMgL08B4Q0080oooo
00<0c<c<04A4A014A4@01@3oool00`000000V9RH0?ooo`030?ooo`0409RHV03oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0409RHV000
0000oooo000000D0oooo00@000000?ooo`3oool000000P3oool00`3<c<`0A4A404A4A0020?ooo`04
0000003oool0oooo00000080oooo00@0^[Zj038b<P2HV9P0EEEE903oool003D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0000003oool0100000001P3oool08B4Q08N7
Q`3oool0gMgM00000080oooo00@000000?ooo`3oool0V9RH0`0000020?ooo`030000003oool00000
00<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo09RHV003000000030?ooo`000000
oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool01@000000oooo0?ooo`000000oooo00@00000103oool0
203MgMd000000?ooo`0@4100gMgM08N7Q`0b<S80V9RH1P3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`@000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000000300000080oooo00P000000?ooo`3oool000000?ooo`27QhL0<S8b09RH
V0<0oooo00@000000?ooo`3oool000000P3oool01@0b<S80^[Zj0>k^kP0@4100k^k^02<0oooo000e
0?ooo`080000003oool0oooo0?ooo`000000c<c<09RHV00000020?ooo`030000003oool000000080
V9RH00L000000?ooo`000000c<c<0?ooo`27QhL000000080oooo00<000000>k^kP3oool00P3oool0
1`2HV9P000000?ooo`3oool000000?ooo`0000000P2HV9P01`000000oooo0000002HV9P0oooo0;Zj
^P0000001P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00`00000
0?ooo`3oool0oooo09RHV0000000oooo0000002HV9P0oooo0;Zj^P0000020?ooo`050000003^k^h0
oooo0?ooo`0000000P3oool03@000000oooo0?ooo`000000^[Zj09RHV0000000oooo0000002HV9P0
oooo09RHV00000000P3oool00`000000oooo0000000209RHV0030000003oool0oooo0080oooo00T0
MgMg05EEE@3oool0MgMg06IVIP000000V9RH0>k^kP0Q8B401@3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo00000080oooo00P000000>k^kP3oool0oooo0000003^k^h0oooo00000080
V9RH00L000000?ooo`3oool000000<c<c02HV9P000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080V9RH00`000000?ooo`3oool000000<c<
c02HV9P000000?ooo`000000V9RH0>k^kP0Q8B420?ooo`070000003oool0oooo0000003oool0ZJVY
010@40020?ooo`0304A4A027QhL0oooo0280oooo000e0?ooo`030000003oool0oooo0080000000@0
V9RH0000002HV9P0oooo0`0000002`2HV9P000000000002HV9P0oooo0<c<c00@4100000004A4A03^
k^h0oooo0080000000<0V9RH024Q8@14A4@00P0000000`2HV9P0oooo000000020000000609RHV000
0000000009RHV03oool0V9RH0P0000000`1VIVH000000?ooo`050?ooo`030000002HV9P0oooo00<0
oooo00<0V9RH0000003oool00P0000001@3oool000000000003oool0A4A40080000000<0V9RH0?oo
o`2HV9P00P0000000`1VIVH000000?ooo`020000000509RHV00Q8B4000000000003oool00P000000
203oool000000000002HV9P0000009RHV03oool0V9RH0`0000001P2HV9P0oooo0?ooo`000000oooo
09RHV080000000<0V9RH0?ooo`3oool00P3oool2000000070?ooo`000000000009RHV0000000EEEE
000000050?ooo`030000002HV9P0oooo00<0oooo00D0<S8b0?ooo`00000000000?ooo`0200000005
0?ooo`000000000009RHV00Q8B400P0000000`2HV9P08B4Q09RHV0020000000809RHV03oool00000
0000002HV9P0000009RHV03oool3000000@0oooo00<000000?ooo`3oool00P3oool0102HV9P00000
0?ooo`2HV9P20000000=09RHV03oool000000000002HV9P0000009RHV03oool0V9RH0000001EEED0
00000?ooo`02000000030?ooo`000000000000<0000000@0MgMg0;Zj^P00000000008`3oool003D0
oooo00<000000?ooo`3oool01P3oool00`27QhL000000?ooo`0D0?ooo`0308N7Q`000000oooo00T0
oooo00<000000?ooo`3oool0103oool00`2HV9P0000009RHV0020?ooo`0309RHV0000000V9RH0100
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`0709RHV0000000V9RH0?oo
o`3^k^h0MgMg0000000J0?ooo`0308N7Q`000000oooo00@0oooo00L000000?ooo`3oool0oooo09RH
V0000000V9RH01@0oooo00<0QhN70000003oool0:@3oool003@0oooo0`0000080?ooo`03038b<P3o
ool0oooo01@0oooo00<0<S8b0?ooo`3oool01`3oool2000000L0oooo00<0V9RH0000000000000P00
00000`2HV9P0oooo0?ooo`0>0?ooo`8000005`3oool2000001P0oooo00H0V9RH000000000000410@
06IVIP00000K0?ooo`03038b<P3oool0oooo0080oooo1P0000000`2HV9P0oooo0?ooo`0A0?ooo`04
038b<P3oool0oooo038b<RX0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.82589, -0.300629, \
0.0448803, 0.0167821}}],

Cell[BoxData[
    \(0.45347352460612145`\ x - 0.017802759516147668`\ x\^2 - 
      0.00042850211619741935`\ x\^3\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying the chamfer ...", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The effect of the chamfer on the integrated gradient vs position is \
studied. The segmentation has been set for a short CPU time. Increasing the \
segmentation may change the optimum value of the chamfer. The optimum value \
of the chamfer is such that the gradient is as uniform as possible vs \
position. As seen below, the optimum value of the chamfer depends slightly on \
the saturation of the yoke and therefore the current.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(radius = 
        34;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ 
      radius\ of\ circle\ *) \t\t\t\t\t\), "\[IndentingNewLine]", 
    \(\(width = 
        60;\)\t\t\t\t\ \  (*\ \ pole\ width\ *) \), "\[IndentingNewLine]", 
    \(\(heigh = 80;\)\t\t\t\t (*\ 
      height\ of\ iron\ in\ coil\ *) \), "\[IndentingNewLine]", 
    \(\(length = 80;\)\t\t\t\t (*\ 
      length\ \ along\ beam\ *) \[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(nx = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ beam\ *) \), \
"\[IndentingNewLine]", 
    \(\(ny = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ width\ *) \
\), "\[IndentingNewLine]", 
    \(\(nz = 
        4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ pole\ height\ *) \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nb = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ segmentation\ along\ return\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(na = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ angular\ segmentation\ in\ the\ \
corner\ *) \), "\[IndentingNewLine]", 
    \(\(nseg = 
        seg[nx, ny, nz, nb, 
          na];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(rmin = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \  (*\ 
      minimum\ radius\ of\ the\ coil\ windings\ *) \), "\[IndentingNewLine]", \

    \(\(offset = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ 
      Vert . \ recess\ betw . \ 1  st\ and\ 2  
        nd\ coils*) \), "\[IndentingNewLine]", 
    \(\(hyp = 
        1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ pole\ profile\ 0.1 < \ hyp\  < 2, \ 
      1 : \ hyperbolic*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ironcolor = {0, 0.5, 
          1};\)\ \ \ \ \  (*\ \ Color\ of\ the\ yoke\ \ *) \), "\
\[IndentingNewLine]", 
    \(\(coilcolor = {1, 0, 
          0};\)\ \ \ \ \ \ \ \ \ \ \  (*\ \ Color\ of\ the\ coil\ \ *) \
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ff[chamf_] := 
        Module[{grad, tt, 
            res}, \[IndentingNewLine]radUtiDelAll[]; \[IndentingNewLine]iron\ \
 = RadMatSteel37[]; \ \ \[IndentingNewLine]grad[t_, y_] := 
            Module[{}, 
              eps = 1; \(\(-\((radFldInt[
                          t, "\<inf\>", "\<ibz\>", {\(-1\), y - eps, 0}, {1, 
                            y - eps, 0}] - 
                        radFldInt[
                          t, "\<inf\>", "\<ibz\>", {\(-1\), y + eps, 0}, {1, 
                            y + eps, 0}])\)\)/2\)/
                eps]; \ \ \[IndentingNewLine]res = 
            quad[radius, length, width, heigh, chamf, hyp, nseg, curden, 
              iron]; \[IndentingNewLine]tt = 
            Table[{y, grad[AllObject /. res, y]}, {y, 0, radius, 
                radius/20}]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[ff, 
        Listable];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      necessary\ to\ tune\ the\ randomization\ beceause\ the\ default\ \
settings\ gives\ random\ jump\ in\ the\ computed\ gradient\ vs\ position\ *) \
\), "\[IndentingNewLine]", 
    \(\(rel = 10^\(-10\);\)\), "\[IndentingNewLine]", 
    \(\(radFldLenTol[10*rel, rel, 10*rel];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(curden = 5;\)\t\), "\[IndentingNewLine]", 
    \(\(chamfer = {2, 4, 6, 8, 10};\)\), "\[IndentingNewLine]", 
    \(\(pp = ff[chamfer];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, 
          PlotJoined \[Rule] True, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, Frame \[Rule] True, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, 
          PlotLabel \[Rule] "\<Int Gradient[T] vs Position [mm]\>", \
\(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(MultipleListPlot @@ pp;\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0280112 -8.03625 4.71214 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16387 -0.0125 -3 -9 ]
[.16387 -0.0125 3 0 ]
[.30392 -0.0125 -6 -9 ]
[.30392 -0.0125 6 0 ]
[.44398 -0.0125 -6 -9 ]
[.44398 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.72409 -0.0125 -6 -9 ]
[.72409 -0.0125 6 0 ]
[.86415 -0.0125 -6 -9 ]
[.86415 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06864 -24 -4.5 ]
[-0.0125 .06864 0 4.5 ]
[-0.0125 .16288 -24 -4.5 ]
[-0.0125 .16288 0 4.5 ]
[-0.0125 .25712 -24 -4.5 ]
[-0.0125 .25712 0 4.5 ]
[-0.0125 .35137 -24 -4.5 ]
[-0.0125 .35137 0 4.5 ]
[-0.0125 .44561 -18 -4.5 ]
[-0.0125 .44561 0 4.5 ]
[-0.0125 .53985 -24 -4.5 ]
[-0.0125 .53985 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16387 0 m
.16387 .00625 L
s
[(5)] .16387 -0.0125 0 1 Mshowa
.30392 0 m
.30392 .00625 L
s
[(10)] .30392 -0.0125 0 1 Mshowa
.44398 0 m
.44398 .00625 L
s
[(15)] .44398 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(20)] .58403 -0.0125 0 1 Mshowa
.72409 0 m
.72409 .00625 L
s
[(25)] .72409 -0.0125 0 1 Mshowa
.86415 0 m
.86415 .00625 L
s
[(30)] .86415 -0.0125 0 1 Mshowa
.125 Mabswid
.05182 0 m
.05182 .00375 L
s
.07983 0 m
.07983 .00375 L
s
.10784 0 m
.10784 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.19188 0 m
.19188 .00375 L
s
.21989 0 m
.21989 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.27591 0 m
.27591 .00375 L
s
.33193 0 m
.33193 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.38796 0 m
.38796 .00375 L
s
.41597 0 m
.41597 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.5 0 m
.5 .00375 L
s
.52801 0 m
.52801 .00375 L
s
.55602 0 m
.55602 .00375 L
s
.61204 0 m
.61204 .00375 L
s
.64006 0 m
.64006 .00375 L
s
.66807 0 m
.66807 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.7521 0 m
.7521 .00375 L
s
.78011 0 m
.78011 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.83613 0 m
.83613 .00375 L
s
.89216 0 m
.89216 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.94818 0 m
.94818 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06864 m
.00625 .06864 L
s
[(1.72)] -0.0125 .06864 1 0 Mshowa
0 .16288 m
.00625 .16288 L
s
[(1.74)] -0.0125 .16288 1 0 Mshowa
0 .25712 m
.00625 .25712 L
s
[(1.76)] -0.0125 .25712 1 0 Mshowa
0 .35137 m
.00625 .35137 L
s
[(1.78)] -0.0125 .35137 1 0 Mshowa
0 .44561 m
.00625 .44561 L
s
[(1.8)] -0.0125 .44561 1 0 Mshowa
0 .53985 m
.00625 .53985 L
s
[(1.82)] -0.0125 .53985 1 0 Mshowa
.125 Mabswid
0 .0922 m
.00375 .0922 L
s
0 .11576 m
.00375 .11576 L
s
0 .13932 m
.00375 .13932 L
s
0 .18644 m
.00375 .18644 L
s
0 .21 m
.00375 .21 L
s
0 .23356 m
.00375 .23356 L
s
0 .28068 m
.00375 .28068 L
s
0 .30424 m
.00375 .30424 L
s
0 .3278 m
.00375 .3278 L
s
0 .37493 m
.00375 .37493 L
s
0 .39849 m
.00375 .39849 L
s
0 .42205 m
.00375 .42205 L
s
0 .46917 m
.00375 .46917 L
s
0 .49273 m
.00375 .49273 L
s
0 .51629 m
.00375 .51629 L
s
0 .04508 m
.00375 .04508 L
s
0 .02152 m
.00375 .02152 L
s
0 .56341 m
.00375 .56341 L
s
0 .58697 m
.00375 .58697 L
s
0 .61053 m
.00375 .61053 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16387 .61178 m
.16387 .61803 L
s
.30392 .61178 m
.30392 .61803 L
s
.44398 .61178 m
.44398 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.72409 .61178 m
.72409 .61803 L
s
.86415 .61178 m
.86415 .61803 L
s
.125 Mabswid
.05182 .61428 m
.05182 .61803 L
s
.07983 .61428 m
.07983 .61803 L
s
.10784 .61428 m
.10784 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.19188 .61428 m
.19188 .61803 L
s
.21989 .61428 m
.21989 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.27591 .61428 m
.27591 .61803 L
s
.33193 .61428 m
.33193 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.38796 .61428 m
.38796 .61803 L
s
.41597 .61428 m
.41597 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52801 .61428 m
.52801 .61803 L
s
.55602 .61428 m
.55602 .61803 L
s
.61204 .61428 m
.61204 .61803 L
s
.64006 .61428 m
.64006 .61803 L
s
.66807 .61428 m
.66807 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.7521 .61428 m
.7521 .61803 L
s
.78011 .61428 m
.78011 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.83613 .61428 m
.83613 .61803 L
s
.89216 .61428 m
.89216 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.94818 .61428 m
.94818 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06864 m
1 .06864 L
s
.99375 .16288 m
1 .16288 L
s
.99375 .25712 m
1 .25712 L
s
.99375 .35137 m
1 .35137 L
s
.99375 .44561 m
1 .44561 L
s
.99375 .53985 m
1 .53985 L
s
.125 Mabswid
.99625 .0922 m
1 .0922 L
s
.99625 .11576 m
1 .11576 L
s
.99625 .13932 m
1 .13932 L
s
.99625 .18644 m
1 .18644 L
s
.99625 .21 m
1 .21 L
s
.99625 .23356 m
1 .23356 L
s
.99625 .28068 m
1 .28068 L
s
.99625 .30424 m
1 .30424 L
s
.99625 .3278 m
1 .3278 L
s
.99625 .37493 m
1 .37493 L
s
.99625 .39849 m
1 .39849 L
s
.99625 .42205 m
1 .42205 L
s
.99625 .46917 m
1 .46917 L
s
.99625 .49273 m
1 .49273 L
s
.99625 .51629 m
1 .51629 L
s
.99625 .04508 m
1 .04508 L
s
.99625 .02152 m
1 .02152 L
s
.99625 .56341 m
1 .56341 L
s
.99625 .58697 m
1 .58697 L
s
.99625 .61053 m
1 .61053 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06864 m
1 .06864 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Int) show
87.000 13.000 moveto
(Gradient) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(@) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.000 13.000 moveto
(D) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
177.000 13.000 moveto
(Position) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
231.000 13.000 moveto
(@) show
237.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
249.125 13.000 moveto
(D) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .60332 m
.07143 .60331 L
.11905 .60326 L
.16667 .60305 L
.21429 .60249 L
.2619 .60132 L
.30952 .59921 L
.35714 .59575 L
.40476 .59045 L
.45238 .58276 L
.5 .57208 L
.54762 .55777 L
.59524 .53918 L
.64286 .5157 L
.69048 .48668 L
.7381 .45129 L
.78571 .40797 L
.83333 .3535 L
.88095 .28139 L
.92857 .17989 L
.97619 .02989 L
s
.0001 w
.02381 .60332 -1.875 0 Mabsadd m
.02381 .60332 0 2.5 Mabsadd L
.02381 .60332 1.875 0 Mabsadd L
.02381 .60332 0 -2.5 Mabsadd L
.02381 .60332 -1.875 0 Mabsadd L closepath F
.07143 .60331 -1.875 0 Mabsadd m
.07143 .60331 0 2.5 Mabsadd L
.07143 .60331 1.875 0 Mabsadd L
.07143 .60331 0 -2.5 Mabsadd L
.07143 .60331 -1.875 0 Mabsadd L closepath F
.11905 .60326 -1.875 0 Mabsadd m
.11905 .60326 0 2.5 Mabsadd L
.11905 .60326 1.875 0 Mabsadd L
.11905 .60326 0 -2.5 Mabsadd L
.11905 .60326 -1.875 0 Mabsadd L closepath F
.16667 .60305 -1.875 0 Mabsadd m
.16667 .60305 0 2.5 Mabsadd L
.16667 .60305 1.875 0 Mabsadd L
.16667 .60305 0 -2.5 Mabsadd L
.16667 .60305 -1.875 0 Mabsadd L closepath F
.21429 .60249 -1.875 0 Mabsadd m
.21429 .60249 0 2.5 Mabsadd L
.21429 .60249 1.875 0 Mabsadd L
.21429 .60249 0 -2.5 Mabsadd L
.21429 .60249 -1.875 0 Mabsadd L closepath F
.2619 .60132 -1.875 0 Mabsadd m
.2619 .60132 0 2.5 Mabsadd L
.2619 .60132 1.875 0 Mabsadd L
.2619 .60132 0 -2.5 Mabsadd L
.2619 .60132 -1.875 0 Mabsadd L closepath F
.30952 .59921 -1.875 0 Mabsadd m
.30952 .59921 0 2.5 Mabsadd L
.30952 .59921 1.875 0 Mabsadd L
.30952 .59921 0 -2.5 Mabsadd L
.30952 .59921 -1.875 0 Mabsadd L closepath F
.35714 .59575 -1.875 0 Mabsadd m
.35714 .59575 0 2.5 Mabsadd L
.35714 .59575 1.875 0 Mabsadd L
.35714 .59575 0 -2.5 Mabsadd L
.35714 .59575 -1.875 0 Mabsadd L closepath F
.40476 .59045 -1.875 0 Mabsadd m
.40476 .59045 0 2.5 Mabsadd L
.40476 .59045 1.875 0 Mabsadd L
.40476 .59045 0 -2.5 Mabsadd L
.40476 .59045 -1.875 0 Mabsadd L closepath F
.45238 .58276 -1.875 0 Mabsadd m
.45238 .58276 0 2.5 Mabsadd L
.45238 .58276 1.875 0 Mabsadd L
.45238 .58276 0 -2.5 Mabsadd L
.45238 .58276 -1.875 0 Mabsadd L closepath F
.5 .57208 -1.875 0 Mabsadd m
.5 .57208 0 2.5 Mabsadd L
.5 .57208 1.875 0 Mabsadd L
.5 .57208 0 -2.5 Mabsadd L
.5 .57208 -1.875 0 Mabsadd L closepath F
.54762 .55777 -1.875 0 Mabsadd m
.54762 .55777 0 2.5 Mabsadd L
.54762 .55777 1.875 0 Mabsadd L
.54762 .55777 0 -2.5 Mabsadd L
.54762 .55777 -1.875 0 Mabsadd L closepath F
.59524 .53918 -1.875 0 Mabsadd m
.59524 .53918 0 2.5 Mabsadd L
.59524 .53918 1.875 0 Mabsadd L
.59524 .53918 0 -2.5 Mabsadd L
.59524 .53918 -1.875 0 Mabsadd L closepath F
.64286 .5157 -1.875 0 Mabsadd m
.64286 .5157 0 2.5 Mabsadd L
.64286 .5157 1.875 0 Mabsadd L
.64286 .5157 0 -2.5 Mabsadd L
.64286 .5157 -1.875 0 Mabsadd L closepath F
.69048 .48668 -1.875 0 Mabsadd m
.69048 .48668 0 2.5 Mabsadd L
.69048 .48668 1.875 0 Mabsadd L
.69048 .48668 0 -2.5 Mabsadd L
.69048 .48668 -1.875 0 Mabsadd L closepath F
.7381 .45129 -1.875 0 Mabsadd m
.7381 .45129 0 2.5 Mabsadd L
.7381 .45129 1.875 0 Mabsadd L
.7381 .45129 0 -2.5 Mabsadd L
.7381 .45129 -1.875 0 Mabsadd L closepath F
.78571 .40797 -1.875 0 Mabsadd m
.78571 .40797 0 2.5 Mabsadd L
.78571 .40797 1.875 0 Mabsadd L
.78571 .40797 0 -2.5 Mabsadd L
.78571 .40797 -1.875 0 Mabsadd L closepath F
.83333 .3535 -1.875 0 Mabsadd m
.83333 .3535 0 2.5 Mabsadd L
.83333 .3535 1.875 0 Mabsadd L
.83333 .3535 0 -2.5 Mabsadd L
.83333 .3535 -1.875 0 Mabsadd L closepath F
.88095 .28139 -1.875 0 Mabsadd m
.88095 .28139 0 2.5 Mabsadd L
.88095 .28139 1.875 0 Mabsadd L
.88095 .28139 0 -2.5 Mabsadd L
.88095 .28139 -1.875 0 Mabsadd L closepath F
.92857 .17989 -1.875 0 Mabsadd m
.92857 .17989 0 2.5 Mabsadd L
.92857 .17989 1.875 0 Mabsadd L
.92857 .17989 0 -2.5 Mabsadd L
.92857 .17989 -1.875 0 Mabsadd L closepath F
.97619 .02989 -1.875 0 Mabsadd m
.97619 .02989 0 2.5 Mabsadd L
.97619 .02989 1.875 0 Mabsadd L
.97619 .02989 0 -2.5 Mabsadd L
.97619 .02989 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .5891 m
.07143 .5891 L
.11905 .58906 L
.16667 .58892 L
.21429 .58853 L
.2619 .58771 L
.30952 .58624 L
.35714 .5838 L
.40476 .58002 L
.45238 .57444 L
.5 .56652 L
.54762 .55561 L
.59524 .54093 L
.64286 .5216 L
.69048 .49649 L
.7381 .46409 L
.78571 .42199 L
.83333 .36599 L
.88095 .28873 L
.92857 .17794 L
.97619 .01472 L
s
.0001 w
[ ] 0 setdash
.02381 .5891 0 2.5 Mabsadd m
.02381 .5891 -0.56518 .7779 Mabsadd L
.02381 .5891 -2.37764 .77254 Mabsadd L
.02381 .5891 -0.91448 -0.29713 Mabsadd L
.02381 .5891 -1.46946 -2.02254 Mabsadd L
.02381 .5891 0 -0.96154 Mabsadd L
.02381 .5891 1.46946 -2.02254 Mabsadd L
.02381 .5891 .91448 -0.29713 Mabsadd L
.02381 .5891 2.37764 .77254 Mabsadd L
.02381 .5891 .56518 .7779 Mabsadd L
.02381 .5891 0 2.5 Mabsadd L closepath F
.07143 .5891 0 2.5 Mabsadd m
.07143 .5891 -0.56518 .7779 Mabsadd L
.07143 .5891 -2.37764 .77254 Mabsadd L
.07143 .5891 -0.91448 -0.29713 Mabsadd L
.07143 .5891 -1.46946 -2.02254 Mabsadd L
.07143 .5891 0 -0.96154 Mabsadd L
.07143 .5891 1.46946 -2.02254 Mabsadd L
.07143 .5891 .91448 -0.29713 Mabsadd L
.07143 .5891 2.37764 .77254 Mabsadd L
.07143 .5891 .56518 .7779 Mabsadd L
.07143 .5891 0 2.5 Mabsadd L closepath F
.11905 .58906 0 2.5 Mabsadd m
.11905 .58906 -0.56518 .7779 Mabsadd L
.11905 .58906 -2.37764 .77254 Mabsadd L
.11905 .58906 -0.91448 -0.29713 Mabsadd L
.11905 .58906 -1.46946 -2.02254 Mabsadd L
.11905 .58906 0 -0.96154 Mabsadd L
.11905 .58906 1.46946 -2.02254 Mabsadd L
.11905 .58906 .91448 -0.29713 Mabsadd L
.11905 .58906 2.37764 .77254 Mabsadd L
.11905 .58906 .56518 .7779 Mabsadd L
.11905 .58906 0 2.5 Mabsadd L closepath F
.16667 .58892 0 2.5 Mabsadd m
.16667 .58892 -0.56518 .7779 Mabsadd L
.16667 .58892 -2.37764 .77254 Mabsadd L
.16667 .58892 -0.91448 -0.29713 Mabsadd L
.16667 .58892 -1.46946 -2.02254 Mabsadd L
.16667 .58892 0 -0.96154 Mabsadd L
.16667 .58892 1.46946 -2.02254 Mabsadd L
.16667 .58892 .91448 -0.29713 Mabsadd L
.16667 .58892 2.37764 .77254 Mabsadd L
.16667 .58892 .56518 .7779 Mabsadd L
.16667 .58892 0 2.5 Mabsadd L closepath F
.21429 .58853 0 2.5 Mabsadd m
.21429 .58853 -0.56518 .7779 Mabsadd L
.21429 .58853 -2.37764 .77254 Mabsadd L
.21429 .58853 -0.91448 -0.29713 Mabsadd L
.21429 .58853 -1.46946 -2.02254 Mabsadd L
.21429 .58853 0 -0.96154 Mabsadd L
.21429 .58853 1.46946 -2.02254 Mabsadd L
.21429 .58853 .91448 -0.29713 Mabsadd L
.21429 .58853 2.37764 .77254 Mabsadd L
.21429 .58853 .56518 .7779 Mabsadd L
.21429 .58853 0 2.5 Mabsadd L closepath F
.2619 .58771 0 2.5 Mabsadd m
.2619 .58771 -0.56518 .7779 Mabsadd L
.2619 .58771 -2.37764 .77254 Mabsadd L
.2619 .58771 -0.91448 -0.29713 Mabsadd L
.2619 .58771 -1.46946 -2.02254 Mabsadd L
.2619 .58771 0 -0.96154 Mabsadd L
.2619 .58771 1.46946 -2.02254 Mabsadd L
.2619 .58771 .91448 -0.29713 Mabsadd L
.2619 .58771 2.37764 .77254 Mabsadd L
.2619 .58771 .56518 .7779 Mabsadd L
.2619 .58771 0 2.5 Mabsadd L closepath F
.30952 .58624 0 2.5 Mabsadd m
.30952 .58624 -0.56518 .7779 Mabsadd L
.30952 .58624 -2.37764 .77254 Mabsadd L
.30952 .58624 -0.91448 -0.29713 Mabsadd L
.30952 .58624 -1.46946 -2.02254 Mabsadd L
.30952 .58624 0 -0.96154 Mabsadd L
.30952 .58624 1.46946 -2.02254 Mabsadd L
.30952 .58624 .91448 -0.29713 Mabsadd L
.30952 .58624 2.37764 .77254 Mabsadd L
.30952 .58624 .56518 .7779 Mabsadd L
.30952 .58624 0 2.5 Mabsadd L closepath F
.35714 .5838 0 2.5 Mabsadd m
.35714 .5838 -0.56518 .7779 Mabsadd L
.35714 .5838 -2.37764 .77254 Mabsadd L
.35714 .5838 -0.91448 -0.29713 Mabsadd L
.35714 .5838 -1.46946 -2.02254 Mabsadd L
.35714 .5838 0 -0.96154 Mabsadd L
.35714 .5838 1.46946 -2.02254 Mabsadd L
.35714 .5838 .91448 -0.29713 Mabsadd L
.35714 .5838 2.37764 .77254 Mabsadd L
.35714 .5838 .56518 .7779 Mabsadd L
.35714 .5838 0 2.5 Mabsadd L closepath F
.40476 .58002 0 2.5 Mabsadd m
.40476 .58002 -0.56518 .7779 Mabsadd L
.40476 .58002 -2.37764 .77254 Mabsadd L
.40476 .58002 -0.91448 -0.29713 Mabsadd L
.40476 .58002 -1.46946 -2.02254 Mabsadd L
.40476 .58002 0 -0.96154 Mabsadd L
.40476 .58002 1.46946 -2.02254 Mabsadd L
.40476 .58002 .91448 -0.29713 Mabsadd L
.40476 .58002 2.37764 .77254 Mabsadd L
.40476 .58002 .56518 .7779 Mabsadd L
.40476 .58002 0 2.5 Mabsadd L closepath F
.45238 .57444 0 2.5 Mabsadd m
.45238 .57444 -0.56518 .7779 Mabsadd L
.45238 .57444 -2.37764 .77254 Mabsadd L
.45238 .57444 -0.91448 -0.29713 Mabsadd L
.45238 .57444 -1.46946 -2.02254 Mabsadd L
.45238 .57444 0 -0.96154 Mabsadd L
.45238 .57444 1.46946 -2.02254 Mabsadd L
.45238 .57444 .91448 -0.29713 Mabsadd L
.45238 .57444 2.37764 .77254 Mabsadd L
.45238 .57444 .56518 .7779 Mabsadd L
.45238 .57444 0 2.5 Mabsadd L closepath F
.5 .56652 0 2.5 Mabsadd m
.5 .56652 -0.56518 .7779 Mabsadd L
.5 .56652 -2.37764 .77254 Mabsadd L
.5 .56652 -0.91448 -0.29713 Mabsadd L
.5 .56652 -1.46946 -2.02254 Mabsadd L
.5 .56652 0 -0.96154 Mabsadd L
.5 .56652 1.46946 -2.02254 Mabsadd L
.5 .56652 .91448 -0.29713 Mabsadd L
.5 .56652 2.37764 .77254 Mabsadd L
.5 .56652 .56518 .7779 Mabsadd L
.5 .56652 0 2.5 Mabsadd L closepath F
.54762 .55561 0 2.5 Mabsadd m
.54762 .55561 -0.56518 .7779 Mabsadd L
.54762 .55561 -2.37764 .77254 Mabsadd L
.54762 .55561 -0.91448 -0.29713 Mabsadd L
.54762 .55561 -1.46946 -2.02254 Mabsadd L
.54762 .55561 0 -0.96154 Mabsadd L
.54762 .55561 1.46946 -2.02254 Mabsadd L
.54762 .55561 .91448 -0.29713 Mabsadd L
.54762 .55561 2.37764 .77254 Mabsadd L
.54762 .55561 .56518 .7779 Mabsadd L
.54762 .55561 0 2.5 Mabsadd L closepath F
.59524 .54093 0 2.5 Mabsadd m
.59524 .54093 -0.56518 .7779 Mabsadd L
.59524 .54093 -2.37764 .77254 Mabsadd L
.59524 .54093 -0.91448 -0.29713 Mabsadd L
.59524 .54093 -1.46946 -2.02254 Mabsadd L
.59524 .54093 0 -0.96154 Mabsadd L
.59524 .54093 1.46946 -2.02254 Mabsadd L
.59524 .54093 .91448 -0.29713 Mabsadd L
.59524 .54093 2.37764 .77254 Mabsadd L
.59524 .54093 .56518 .7779 Mabsadd L
.59524 .54093 0 2.5 Mabsadd L closepath F
.64286 .5216 0 2.5 Mabsadd m
.64286 .5216 -0.56518 .7779 Mabsadd L
.64286 .5216 -2.37764 .77254 Mabsadd L
.64286 .5216 -0.91448 -0.29713 Mabsadd L
.64286 .5216 -1.46946 -2.02254 Mabsadd L
.64286 .5216 0 -0.96154 Mabsadd L
.64286 .5216 1.46946 -2.02254 Mabsadd L
.64286 .5216 .91448 -0.29713 Mabsadd L
.64286 .5216 2.37764 .77254 Mabsadd L
.64286 .5216 .56518 .7779 Mabsadd L
.64286 .5216 0 2.5 Mabsadd L closepath F
.69048 .49649 0 2.5 Mabsadd m
.69048 .49649 -0.56518 .7779 Mabsadd L
.69048 .49649 -2.37764 .77254 Mabsadd L
.69048 .49649 -0.91448 -0.29713 Mabsadd L
.69048 .49649 -1.46946 -2.02254 Mabsadd L
.69048 .49649 0 -0.96154 Mabsadd L
.69048 .49649 1.46946 -2.02254 Mabsadd L
.69048 .49649 .91448 -0.29713 Mabsadd L
.69048 .49649 2.37764 .77254 Mabsadd L
.69048 .49649 .56518 .7779 Mabsadd L
.69048 .49649 0 2.5 Mabsadd L closepath F
.7381 .46409 0 2.5 Mabsadd m
.7381 .46409 -0.56518 .7779 Mabsadd L
.7381 .46409 -2.37764 .77254 Mabsadd L
.7381 .46409 -0.91448 -0.29713 Mabsadd L
.7381 .46409 -1.46946 -2.02254 Mabsadd L
.7381 .46409 0 -0.96154 Mabsadd L
.7381 .46409 1.46946 -2.02254 Mabsadd L
.7381 .46409 .91448 -0.29713 Mabsadd L
.7381 .46409 2.37764 .77254 Mabsadd L
.7381 .46409 .56518 .7779 Mabsadd L
.7381 .46409 0 2.5 Mabsadd L closepath F
.78571 .42199 0 2.5 Mabsadd m
.78571 .42199 -0.56518 .7779 Mabsadd L
.78571 .42199 -2.37764 .77254 Mabsadd L
.78571 .42199 -0.91448 -0.29713 Mabsadd L
.78571 .42199 -1.46946 -2.02254 Mabsadd L
.78571 .42199 0 -0.96154 Mabsadd L
.78571 .42199 1.46946 -2.02254 Mabsadd L
.78571 .42199 .91448 -0.29713 Mabsadd L
.78571 .42199 2.37764 .77254 Mabsadd L
.78571 .42199 .56518 .7779 Mabsadd L
.78571 .42199 0 2.5 Mabsadd L closepath F
.83333 .36599 0 2.5 Mabsadd m
.83333 .36599 -0.56518 .7779 Mabsadd L
.83333 .36599 -2.37764 .77254 Mabsadd L
.83333 .36599 -0.91448 -0.29713 Mabsadd L
.83333 .36599 -1.46946 -2.02254 Mabsadd L
.83333 .36599 0 -0.96154 Mabsadd L
.83333 .36599 1.46946 -2.02254 Mabsadd L
.83333 .36599 .91448 -0.29713 Mabsadd L
.83333 .36599 2.37764 .77254 Mabsadd L
.83333 .36599 .56518 .7779 Mabsadd L
.83333 .36599 0 2.5 Mabsadd L closepath F
.88095 .28873 0 2.5 Mabsadd m
.88095 .28873 -0.56518 .7779 Mabsadd L
.88095 .28873 -2.37764 .77254 Mabsadd L
.88095 .28873 -0.91448 -0.29713 Mabsadd L
.88095 .28873 -1.46946 -2.02254 Mabsadd L
.88095 .28873 0 -0.96154 Mabsadd L
.88095 .28873 1.46946 -2.02254 Mabsadd L
.88095 .28873 .91448 -0.29713 Mabsadd L
.88095 .28873 2.37764 .77254 Mabsadd L
.88095 .28873 .56518 .7779 Mabsadd L
.88095 .28873 0 2.5 Mabsadd L closepath F
.92857 .17794 0 2.5 Mabsadd m
.92857 .17794 -0.56518 .7779 Mabsadd L
.92857 .17794 -2.37764 .77254 Mabsadd L
.92857 .17794 -0.91448 -0.29713 Mabsadd L
.92857 .17794 -1.46946 -2.02254 Mabsadd L
.92857 .17794 0 -0.96154 Mabsadd L
.92857 .17794 1.46946 -2.02254 Mabsadd L
.92857 .17794 .91448 -0.29713 Mabsadd L
.92857 .17794 2.37764 .77254 Mabsadd L
.92857 .17794 .56518 .7779 Mabsadd L
.92857 .17794 0 2.5 Mabsadd L closepath F
.97619 .01472 0 2.5 Mabsadd m
.97619 .01472 -0.56518 .7779 Mabsadd L
.97619 .01472 -2.37764 .77254 Mabsadd L
.97619 .01472 -0.91448 -0.29713 Mabsadd L
.97619 .01472 -1.46946 -2.02254 Mabsadd L
.97619 .01472 0 -0.96154 Mabsadd L
.97619 .01472 1.46946 -2.02254 Mabsadd L
.97619 .01472 .91448 -0.29713 Mabsadd L
.97619 .01472 2.37764 .77254 Mabsadd L
.97619 .01472 .56518 .7779 Mabsadd L
.97619 .01472 0 2.5 Mabsadd L closepath F
.001 w
[ .5 4 5 4 ] 0 Mabsdash
.02381 .50535 m
.07143 .50535 L
.11905 .50534 L
.16667 .50533 L
.21429 .50529 L
.2619 .5052 L
.30952 .50502 L
.35714 .5047 L
.40476 .50413 L
.45238 .50312 L
.5 .50141 L
.54762 .49859 L
.59524 .49409 L
.64286 .48711 L
.69048 .47658 L
.7381 .46088 L
.78571 .43743 L
.83333 .40172 L
.88095 .34595 L
.92857 .25719 L
.97619 .11561 L
s
.0001 w
[ ] 0 setdash
.02381 .50535 -2.5 2.5 Mabsadd m
.02381 .50535 2.5 2.5 Mabsadd L
.02381 .50535 2.5 -2.5 Mabsadd L
.02381 .50535 -2.5 -2.5 Mabsadd L
.02381 .50535 -2.5 2.5 Mabsadd L closepath F
.07143 .50535 -2.5 2.5 Mabsadd m
.07143 .50535 2.5 2.5 Mabsadd L
.07143 .50535 2.5 -2.5 Mabsadd L
.07143 .50535 -2.5 -2.5 Mabsadd L
.07143 .50535 -2.5 2.5 Mabsadd L closepath F
.11905 .50534 -2.5 2.5 Mabsadd m
.11905 .50534 2.5 2.5 Mabsadd L
.11905 .50534 2.5 -2.5 Mabsadd L
.11905 .50534 -2.5 -2.5 Mabsadd L
.11905 .50534 -2.5 2.5 Mabsadd L closepath F
.16667 .50533 -2.5 2.5 Mabsadd m
.16667 .50533 2.5 2.5 Mabsadd L
.16667 .50533 2.5 -2.5 Mabsadd L
.16667 .50533 -2.5 -2.5 Mabsadd L
.16667 .50533 -2.5 2.5 Mabsadd L closepath F
.21429 .50529 -2.5 2.5 Mabsadd m
.21429 .50529 2.5 2.5 Mabsadd L
.21429 .50529 2.5 -2.5 Mabsadd L
.21429 .50529 -2.5 -2.5 Mabsadd L
.21429 .50529 -2.5 2.5 Mabsadd L closepath F
.2619 .5052 -2.5 2.5 Mabsadd m
.2619 .5052 2.5 2.5 Mabsadd L
.2619 .5052 2.5 -2.5 Mabsadd L
.2619 .5052 -2.5 -2.5 Mabsadd L
.2619 .5052 -2.5 2.5 Mabsadd L closepath F
.30952 .50502 -2.5 2.5 Mabsadd m
.30952 .50502 2.5 2.5 Mabsadd L
.30952 .50502 2.5 -2.5 Mabsadd L
.30952 .50502 -2.5 -2.5 Mabsadd L
.30952 .50502 -2.5 2.5 Mabsadd L closepath F
.35714 .5047 -2.5 2.5 Mabsadd m
.35714 .5047 2.5 2.5 Mabsadd L
.35714 .5047 2.5 -2.5 Mabsadd L
.35714 .5047 -2.5 -2.5 Mabsadd L
.35714 .5047 -2.5 2.5 Mabsadd L closepath F
.40476 .50413 -2.5 2.5 Mabsadd m
.40476 .50413 2.5 2.5 Mabsadd L
.40476 .50413 2.5 -2.5 Mabsadd L
.40476 .50413 -2.5 -2.5 Mabsadd L
.40476 .50413 -2.5 2.5 Mabsadd L closepath F
.45238 .50312 -2.5 2.5 Mabsadd m
.45238 .50312 2.5 2.5 Mabsadd L
.45238 .50312 2.5 -2.5 Mabsadd L
.45238 .50312 -2.5 -2.5 Mabsadd L
.45238 .50312 -2.5 2.5 Mabsadd L closepath F
.5 .50141 -2.5 2.5 Mabsadd m
.5 .50141 2.5 2.5 Mabsadd L
.5 .50141 2.5 -2.5 Mabsadd L
.5 .50141 -2.5 -2.5 Mabsadd L
.5 .50141 -2.5 2.5 Mabsadd L closepath F
.54762 .49859 -2.5 2.5 Mabsadd m
.54762 .49859 2.5 2.5 Mabsadd L
.54762 .49859 2.5 -2.5 Mabsadd L
.54762 .49859 -2.5 -2.5 Mabsadd L
.54762 .49859 -2.5 2.5 Mabsadd L closepath F
.59524 .49409 -2.5 2.5 Mabsadd m
.59524 .49409 2.5 2.5 Mabsadd L
.59524 .49409 2.5 -2.5 Mabsadd L
.59524 .49409 -2.5 -2.5 Mabsadd L
.59524 .49409 -2.5 2.5 Mabsadd L closepath F
.64286 .48711 -2.5 2.5 Mabsadd m
.64286 .48711 2.5 2.5 Mabsadd L
.64286 .48711 2.5 -2.5 Mabsadd L
.64286 .48711 -2.5 -2.5 Mabsadd L
.64286 .48711 -2.5 2.5 Mabsadd L closepath F
.69048 .47658 -2.5 2.5 Mabsadd m
.69048 .47658 2.5 2.5 Mabsadd L
.69048 .47658 2.5 -2.5 Mabsadd L
.69048 .47658 -2.5 -2.5 Mabsadd L
.69048 .47658 -2.5 2.5 Mabsadd L closepath F
.7381 .46088 -2.5 2.5 Mabsadd m
.7381 .46088 2.5 2.5 Mabsadd L
.7381 .46088 2.5 -2.5 Mabsadd L
.7381 .46088 -2.5 -2.5 Mabsadd L
.7381 .46088 -2.5 2.5 Mabsadd L closepath F
.78571 .43743 -2.5 2.5 Mabsadd m
.78571 .43743 2.5 2.5 Mabsadd L
.78571 .43743 2.5 -2.5 Mabsadd L
.78571 .43743 -2.5 -2.5 Mabsadd L
.78571 .43743 -2.5 2.5 Mabsadd L closepath F
.83333 .40172 -2.5 2.5 Mabsadd m
.83333 .40172 2.5 2.5 Mabsadd L
.83333 .40172 2.5 -2.5 Mabsadd L
.83333 .40172 -2.5 -2.5 Mabsadd L
.83333 .40172 -2.5 2.5 Mabsadd L closepath F
.88095 .34595 -2.5 2.5 Mabsadd m
.88095 .34595 2.5 2.5 Mabsadd L
.88095 .34595 2.5 -2.5 Mabsadd L
.88095 .34595 -2.5 -2.5 Mabsadd L
.88095 .34595 -2.5 2.5 Mabsadd L closepath F
.92857 .25719 -2.5 2.5 Mabsadd m
.92857 .25719 2.5 2.5 Mabsadd L
.92857 .25719 2.5 -2.5 Mabsadd L
.92857 .25719 -2.5 -2.5 Mabsadd L
.92857 .25719 -2.5 2.5 Mabsadd L closepath F
.97619 .11561 -2.5 2.5 Mabsadd m
.97619 .11561 2.5 2.5 Mabsadd L
.97619 .11561 2.5 -2.5 Mabsadd L
.97619 .11561 -2.5 -2.5 Mabsadd L
.97619 .11561 -2.5 2.5 Mabsadd L closepath F
.001 w
[ 5 2 ] 0 Mabsdash
.02381 .40802 m
.07143 .40803 L
.11905 .40805 L
.16667 .40815 L
.21429 .40841 L
.2619 .40894 L
.30952 .40987 L
.35714 .41136 L
.40476 .41352 L
.45238 .41641 L
.5 .41996 L
.54762 .42398 L
.59524 .42804 L
.64286 .43145 L
.69048 .43318 L
.7381 .43167 L
.78571 .42438 L
.83333 .40695 L
.88095 .3718 L
.92857 .30623 L
.97619 .1905 L
s
.0001 w
[ ] 0 setdash
.02381 .40802 0 2.5 Mabsadd m
.02381 .40802 -2.165 -1.25 Mabsadd L
.02381 .40802 2.165 -1.25 Mabsadd L
.02381 .40802 0 2.5 Mabsadd L closepath F
.07143 .40803 0 2.5 Mabsadd m
.07143 .40803 -2.165 -1.25 Mabsadd L
.07143 .40803 2.165 -1.25 Mabsadd L
.07143 .40803 0 2.5 Mabsadd L closepath F
.11905 .40805 0 2.5 Mabsadd m
.11905 .40805 -2.165 -1.25 Mabsadd L
.11905 .40805 2.165 -1.25 Mabsadd L
.11905 .40805 0 2.5 Mabsadd L closepath F
.16667 .40815 0 2.5 Mabsadd m
.16667 .40815 -2.165 -1.25 Mabsadd L
.16667 .40815 2.165 -1.25 Mabsadd L
.16667 .40815 0 2.5 Mabsadd L closepath F
.21429 .40841 0 2.5 Mabsadd m
.21429 .40841 -2.165 -1.25 Mabsadd L
.21429 .40841 2.165 -1.25 Mabsadd L
.21429 .40841 0 2.5 Mabsadd L closepath F
.2619 .40894 0 2.5 Mabsadd m
.2619 .40894 -2.165 -1.25 Mabsadd L
.2619 .40894 2.165 -1.25 Mabsadd L
.2619 .40894 0 2.5 Mabsadd L closepath F
.30952 .40987 0 2.5 Mabsadd m
.30952 .40987 -2.165 -1.25 Mabsadd L
.30952 .40987 2.165 -1.25 Mabsadd L
.30952 .40987 0 2.5 Mabsadd L closepath F
.35714 .41136 0 2.5 Mabsadd m
.35714 .41136 -2.165 -1.25 Mabsadd L
.35714 .41136 2.165 -1.25 Mabsadd L
.35714 .41136 0 2.5 Mabsadd L closepath F
.40476 .41352 0 2.5 Mabsadd m
.40476 .41352 -2.165 -1.25 Mabsadd L
.40476 .41352 2.165 -1.25 Mabsadd L
.40476 .41352 0 2.5 Mabsadd L closepath F
.45238 .41641 0 2.5 Mabsadd m
.45238 .41641 -2.165 -1.25 Mabsadd L
.45238 .41641 2.165 -1.25 Mabsadd L
.45238 .41641 0 2.5 Mabsadd L closepath F
.5 .41996 0 2.5 Mabsadd m
.5 .41996 -2.165 -1.25 Mabsadd L
.5 .41996 2.165 -1.25 Mabsadd L
.5 .41996 0 2.5 Mabsadd L closepath F
.54762 .42398 0 2.5 Mabsadd m
.54762 .42398 -2.165 -1.25 Mabsadd L
.54762 .42398 2.165 -1.25 Mabsadd L
.54762 .42398 0 2.5 Mabsadd L closepath F
.59524 .42804 0 2.5 Mabsadd m
.59524 .42804 -2.165 -1.25 Mabsadd L
.59524 .42804 2.165 -1.25 Mabsadd L
.59524 .42804 0 2.5 Mabsadd L closepath F
.64286 .43145 0 2.5 Mabsadd m
.64286 .43145 -2.165 -1.25 Mabsadd L
.64286 .43145 2.165 -1.25 Mabsadd L
.64286 .43145 0 2.5 Mabsadd L closepath F
.69048 .43318 0 2.5 Mabsadd m
.69048 .43318 -2.165 -1.25 Mabsadd L
.69048 .43318 2.165 -1.25 Mabsadd L
.69048 .43318 0 2.5 Mabsadd L closepath F
.7381 .43167 0 2.5 Mabsadd m
.7381 .43167 -2.165 -1.25 Mabsadd L
.7381 .43167 2.165 -1.25 Mabsadd L
.7381 .43167 0 2.5 Mabsadd L closepath F
.78571 .42438 0 2.5 Mabsadd m
.78571 .42438 -2.165 -1.25 Mabsadd L
.78571 .42438 2.165 -1.25 Mabsadd L
.78571 .42438 0 2.5 Mabsadd L closepath F
.83333 .40695 0 2.5 Mabsadd m
.83333 .40695 -2.165 -1.25 Mabsadd L
.83333 .40695 2.165 -1.25 Mabsadd L
.83333 .40695 0 2.5 Mabsadd L closepath F
.88095 .3718 0 2.5 Mabsadd m
.88095 .3718 -2.165 -1.25 Mabsadd L
.88095 .3718 2.165 -1.25 Mabsadd L
.88095 .3718 0 2.5 Mabsadd L closepath F
.92857 .30623 0 2.5 Mabsadd m
.92857 .30623 -2.165 -1.25 Mabsadd L
.92857 .30623 2.165 -1.25 Mabsadd L
.92857 .30623 0 2.5 Mabsadd L closepath F
.97619 .1905 0 2.5 Mabsadd m
.97619 .1905 -2.165 -1.25 Mabsadd L
.97619 .1905 2.165 -1.25 Mabsadd L
.97619 .1905 0 2.5 Mabsadd L closepath F
.001 w
[ .5 4 5 4 .5 3 ] 0 Mabsdash
.02381 .29629 m
.07143 .29629 L
.11905 .29634 L
.16667 .29653 L
.21429 .29702 L
.2619 .29803 L
.30952 .29984 L
.35714 .30273 L
.40476 .307 L
.45238 .31287 L
.5 .32045 L
.54762 .32962 L
.59524 .34007 L
.64286 .35115 L
.69048 .36187 L
.7381 .3708 L
.78571 .37566 L
.83333 .3726 L
.88095 .35489 L
.92857 .31098 L
.97619 .22229 L
s
.01 w
.02381 .29629 Mdot
.07143 .29629 Mdot
.11905 .29634 Mdot
.16667 .29653 Mdot
.21429 .29702 Mdot
.2619 .29803 Mdot
.30952 .29984 Mdot
.35714 .30273 Mdot
.40476 .307 Mdot
.45238 .31287 Mdot
.5 .32045 Mdot
.54762 .32962 Mdot
.59524 .34007 Mdot
.64286 .35115 Mdot
.69048 .36187 Mdot
.7381 .3708 Mdot
.78571 .37566 Mdot
.83333 .3726 Mdot
.88095 .35489 Mdot
.92857 .31098 Mdot
.97619 .22229 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{368, 227.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005`0000hb000`400?l00000o`00003oo`3oooma
0?ooo`00;03oool2000002X0oooo0`00000V0?ooo`<00000103oool2000002@0oooo0`0000030?oo
o`<000008`3oool5000000<0oooo0P00000R0?ooo`D000000P3oool3000002@0oooo0`0000040?oo
o`800000<`3oool002/0oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool0
000002H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000T0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool0803oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000<P3oool002/0oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000903oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000S
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0300oooo000[0?ooo`040000003oool0oooo000002`0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08P3oool2000000<0oooo00@000000?ooo`3oool00000<P3oool002/0oooo00@000000?ooo`3o
ool00000:03oool4000002L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000T
0?ooo`040000003oool0oooo0?ooo`@000008`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000008@3oool01P000000oooo0?ooo`3oool000000?ooo`@000009`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0300oooo000[0?ooo`040000003oool0
oooo000002P0oooo00<000000?ooo`3oool09`3oool2000000@0oooo00@000000?ooo`3oool00000
8`3oool2000000<0oooo00<000000?ooo`3oool0903oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000008@3oool01`000000oooo0?ooo`3oool000000?ooo`0000009P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000<P3oool002`0oooo
0P00000Y0?ooo`D000009P3oool00`000000oooo0?ooo`030?ooo`8000009@3oool010000000oooo
0?ooo`3oool5000002<0oooo0`0000040?ooo`8000008`3oool300000080oooo1@00000S0?ooo`<0
0000103oool2000003<0oooo003o0?ooog40oooo003o0?ooog40oooo003o0?ooog40oooo003o0?oo
og40oooo003o0?ooog40oooo000U0?ooool00000@P00000:0?ooo`009@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`009@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030000003oool0oooo
00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo=@3oool2000000L0oooo
00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0o`3ooole0?ooo`<000001P3o
ool00`000000oooo0?ooo`080?ooo`009@3oool200000?l0oooo=P3oool2000000D0oooo0`00000:
0?ooo`009@3oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?ooo`3oool0203oool002D0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool002D0oooo00<000000?ooo`3oool0o`3ooold0?ooo`@000001P3oool00`000000oooo
0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?oooc@0oooo100000060?ooo`030000003o
ool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo<`3oool00`00
0000oooo000000080?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0
oooo<`3oool00`000000oooo000000080?ooo`030000003oool0oooo00P0oooo000U0?ooo`800000
o`3ooolf0?ooo`030000003oool0oooo00@0oooo0`00000:0?ooo`009@3oool00`000000oooo0?oo
o`3o0?oooc@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`009@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`08
0?ooo`009@3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool5000000D0oooo00<000000?ooo`3oool0o`3ooola0?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0o`3ooola0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0203oool000/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
o`000012000000X0oooo000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo<P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo<03oool3
000000/0oooo00<000000?ooo`3oool0203oool000X0oooo0P0000090?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oola0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool000/0oooo00<00000
0?ooo`3oool01`3oool500000080oooo0`0000060?ooo`030000003oool0oooo0?l0oooo<@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo
0?l0oooo;`3oool3000000`0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3o
ool0o`3ooola0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool002D0oooo
00<000000?ooo`3oool0o`3oool`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool002D0oooo0P00003o0?oooc00oooo0P00000;0?ooo`<000002P3oool002D0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0203oool0
02D0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0203oool002D0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<00000
3P3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool00P3oool5000000H0oooo00<000000?ooo`3oool0203oool0
02D0oooo0P00003o0?ooobd0oooo0`0000040?ooo`D00000103oool3000000X0oooo000U0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`030?ooo`D000001P3oool00`000000
oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0
0`3oool5000000H0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0o`3o
ool/0?ooo`8000001@3oool5000000H0oooo00<000000?ooo`3oool0203oool002D0oooo00<00000
0?ooo`3oool0o`3oool[0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo;03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo
:P3oool300000140oooo00<000000?ooo`3oool0203oool002D0oooo0P00003o0?ooob`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`<000002P3oool002D0oooo00<00000
0?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooobX0oooo0P0000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3o
ool0o`3ooolZ0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo000:0?ooo`<00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003o
ool0oooo0?l0oooo:@3oool2000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D000001@3oool300000?l0oooo:@3oool00`000000oooo0?ooo`0@0?ooo`<000002P3oool000/0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`06
0000003oool0oooo0000003oool000001P3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000:0?oo
o`8000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000060?ooo`030000003oool0
oooo0?l0oooo:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000;0?oo
o`030000003oool0oooo00L0oooo1@0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooolU0?ooo`80000000<0oooo0000003oool0503oool00`000000oooo0?ooo`080?oo
o`009@3oool00`000000oooo0?ooo`3o0?ooobH0oooo0P00000F0?ooo`030000003oool0oooo00P0
oooo000U0?ooo`030000003oool0oooo0?l0oooo9@3oool4000000H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooobH0oooo0`00
00060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool002D0oooo0P00003o
0?ooobH0oooo0`0000060?ooo`030000003oool0oooo00/0oooo0`00000:0?ooo`009@3oool00`00
0000oooo0?ooo`3o0?ooobD0oooo0P0000070?ooo`030000003oool0oooo00<0oooo100000060?oo
o`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0`0000060?ooo`030000003oool0oooo00P0
oooo000U0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0=0?ooo`800000
1`3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
00000?ooo`3oool03P3oool2000000L0oooo00<000000?ooo`3oool0203oool002D0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool002D0oooo0P00003o0?ooob<0oooo0P0000080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool3000000X0oooo000U0?ooo`030000003oool0oooo0?l0oooo
8`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool002D0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o
0?ooob40oooo0P00000B0?ooo`<000001P3oool00`000000oooo0?ooo`080?ooo`009@3oool00`00
0000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<000001P3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000
oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<000001P3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo
0?ooo`3o0?ooob00oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo
0?ooo`3o0?ooob00oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool002D0oooo0P00003o0?ooob00oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo0`00
000:0?ooo`009@3oool00`000000oooo0?ooo`3o0?oooah0oooo0P00000N0?ooo`030000003oool0
oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`009@3oool00`00
0000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`080?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3o
ool0203oool000/0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3o
ool01@3oool5000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00`3oool300000?l0oooo703oool00`000000oooo0?ooo`050?ooo`D00000103oool00`000000
oooo0?ooo`0<0?ooo`<000002P3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`04000000H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`8000001`3oool5000001D0oooo
00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000
00090?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`060?ooo`D00000103o
ool00`000000oooo0000000>0?ooo`030000003oool0oooo00P0oooo000:0?ooo`8000002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?oooa/0oooo00<000000?ooo`3oool01P3oool5000000@0oooo00<000000?ooo`0000003P3o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`070?ooo`D000000`3oool2
000000H0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo000U0?oo
o`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000
oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool000000100oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0
o`3ooolI0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool002D0oooo0P00
003o0?oooaP0oooo0`00000@0?ooo`030000003oool0oooo00l0oooo0`00000:0?ooo`009@3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo0`0000090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?oo
oaL0oooo0P0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?oooaH0oooo1000000?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0
103oool3000000`0oooo0`00000<0?ooo`<00000303oool3000000d0oooo0`00000<0?ooo`<00000
`P3oool200000140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`009@3o
ool00`000000oooo0?ooo`040?ooo`<000000P3oool6000000<0oooo1@0000030?ooo`H000000P3o
ool300000080oooo00@000000?ooo`3oool0oooo2`0000020?ooo`040000003oool0oooo0?ooo`P0
000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool6000000`0oooo0`00002b0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool2000001@0oooo00<000000?oo
o`3oool0203oool002D0oooo00<000000?ooo`3oool0103oool3000000`0oooo0`00000<0?ooo`<0
0000303oool3000000d0oooo0`00000<0?ooo`<000000`3oool200000080oooo00@000000?ooo`3o
ool0oooo1P0000030?ooo`8000001@3oool300000:80oooo0`0000090?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0203oool002D0oooo0P00001P0?ooo`<000002@3oool00`000000
oooo0?ooo`07000000P0oooo0`00002B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`<000002P3oool002D0oooo00<000000?ooo`3oool0
KP3oool3000000L0oooo0P0000020?ooo`P00000SP3oool2000000X0oooo00<000000?ooo`3oool0
0`3oool4000001D0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0O@3o
ool3000000@0oooo0P0000070?ooo`<00000P@3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo00@0oooo0`00000E0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0
oooo08T0oooo0P0000020?ooo`<00000P03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo0`00000E0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo
08d0oooo0`0000000`3oool0000000000004000007T0oooo0P00000B0?ooo`@000005@3oool00`00
0000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2J0?ooo`D00000L03oool00`000000
oooo0000000A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool002D0oooo
00<000000?ooo`3oool0W03oool3000000<0oooo1000001X0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo
000U0?ooo`030000003oool0oooo09`0oooo0`0000070?ooo`8000000`3oool300000600oooo0P00
000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`080?ooo`009@3oool200000:`0oooo0`00001O0?ooo`030000003oool0000000l0oooo0`00000I
0?ooo`<000002P3oool002D0oooo00<000000?ooo`3oool0Z`3oool5000005`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo000U0?ooo`03
0000003oool0oooo0;<0oooo0`00001F0?ooo`8000002`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000007@3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2f0?oo
o`8000000P3oool3000004h0oooo00<000000?ooo`0000002`3oool010000000oooo0?ooo`3oool2
000001h0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0^P3oool30000
04d0oooo00<000000?ooo`3oool01`3oool5000000D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`080?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`2j0?ooo`<000000P3oool00`000000
oooo0?ooo`170?ooo`030000003oool0000000P0oooo1@0000001@3oool000000?ooo`3oool00000
01l0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`330?oo
o`@000000P3oool3000003d0oooo00<000000?ooo`000000203oool600000080oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool300000<L0oooo1@00000k0?oo
o`8000002`3oool500000080oooo00<000000?ooo`3oool07@3oool3000000X0oooo000;0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0`0000060?ooo`030000003oool0oooo
0<T0oooo100000020?ooo`030000003oool0oooo03@0oooo0`0000000`3oool000000?ooo`080?oo
o`D00000903oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3@0?ooo`04
0000003oool0oooo0?ooo`@00000;@3oool5000000T0oooo00<000000?ooo`3oool00`0000000`3o
ool000000?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000:0?ooo`8000002@3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0=P0oooo1000000Z0?ooo`<000002@3oool200000080oooo0`0000000`3oool000000?ooo`0Q
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00L0oooo1@0000020?oo
o`<000001P3oool00`000000oooo0?ooo`3I0?ooo`D000009`3oool4000000H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000U0?ooo`03
0000003oool0oooo0=T0oooo0`0000040?ooo`030000003oool0oooo0240oooo00<000000?ooo`00
00000P00000?0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool002D0oooo
00<000000?ooo`3oool0i03oool7000001P0oooo00<000000?ooo`3oool01P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`009@3o
ool00`000000oooo0?ooo`3X0?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool00`3o
ool3000000P0oooo00<000000?ooo`3oool0100000070?ooo`030000003oool0oooo0080oooo1000
000T0?ooo`030000003oool0oooo00P0oooo000U0?ooo`800000j@3oool3000000X0oooo1P000003
0?ooo`80000000<0oooo0000000000000`3oool3000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000200000280oooo0`00000:0?ooo`009@3oool00`000000oooo0?ooo`3g0?oo
o`<000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo0000000U0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo
0?l0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3o0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3o
ool0oP3oool010000000oooo0?ooo`00000=0?ooo`800000;03oool00`000000oooo0?ooo`080?oo
o`009@3oool00`000000oooo0?ooo`3m0?ooo`050000003oool0oooo0?ooo`000000203oool20000
00030?ooo`000000000002h0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3o
ool0o03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0203oool002D0oooo0P00003l0?ooo`030000003oool0oooo008000001@3oool500000340oooo
0`00000:0?ooo`009@3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo00P0oooo1`00
000a0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0?P0oooo0P00000;
0?ooo`D00000<`3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`030?oo
o`P0000000<0oooo0000000000002`0000000`3oool0000000000004000000030?ooo`0000000000
00@0000000<0oooo000000000000100000000`3oool0000000000004000000/0oooo1000000;0?oo
o`@00000Y03oool300000080oooo0P0000070?ooo`D00000<`3oool00`000000oooo0?ooo`080?oo
o`009@3oool00`000000oooo0?ooo`040?ooo`<00000303oool3000000`0oooo0`00000<0?ooo`@0
000000<0oooo000000000000100000000`3oool000000000000;000000030?ooo`000000000000/0
000000<0oooo0000000000002`0000000`3oool0000000000008000008D0oooo1000000:0?ooo`H0
0000<`3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`040?ooo`800000
3@3oool2000000d0oooo0P00000>0?ooo`8000003@3oool2000000d0oooo0P00000=0?ooo`<00000
303oool6000000030?ooo`000000000000@0000000<0oooo0000000000001000001c0?ooo`030000
003oool0000000<000001P3oool300000080oooo0`00000d0?ooo`030000003oool0oooo00P0oooo
000U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`8000003@3oool400000080oooo1P00
00000`3oool0000000000004000000030?ooo`000000000000800000G`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P00000=0?ooo`<000001@3oool2000000030?oo
o`000000000000T00000D03oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool30000
00030?ooo`000000000003/0oooo00<000000?ooo`3oool0203oool002D0oooo0P0000200?ooo`03
0000003oool0oooo00/0oooo0P00000=0?ooo`<00000103oool2000000030?ooo`000000000000H0
0000A03oool010000000oooo0?ooo`3oool6000003l0oooo0`00000:0?ooo`009@3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`P0000000<0oooo00000000
00000P00000i0?ooo`040000003oool0oooo0?ooo`H0000000<0oooo000000000000?`3oool00`00
0000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00/0
oooo0P00000;0?ooo`T0000000<0oooo0000000000000P00000Y0?ooo`<0000000D0oooo00000000
000000000?ooo`0200000080oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`080?oo
o`009@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00/0oooo0`0000090?ooo`80
000000<0oooo000000000000100000000`3oool0000000000004000000030?ooo`000000000000@0
000000<0oooo000000000000100000000`3oool0000000000004000000030?ooo`00000000000080
00001@3oool600000480oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0<0?ooo`<00000303oool3000000`0oooo0`0000030?ooo`030000
003oool0oooo00D0oooo1@0000120?ooo`030000003oool0oooo00P0oooo000@0?ooo`<00000103o
ool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00/0oooo0P00000=0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool500000480oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool01`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000P0oooo1P0000120?ooo`030000003oool0oooo00P0oooo
000A0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000
j`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo1@0000100?ooo`<00000
2P3oool00140oooo00<000000?ooo`3oool0203oool3000000H0oooo00<000000?ooo`3oool0j@3o
ool2000000D0oooo0P00001;0?ooo`030000003oool0oooo00P0oooo000A0?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0>P0oooo0`00
00020?ooo`<00000C@3oool00`000000oooo0?ooo`080?ooo`00403oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0>L0oooo100000020?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool0203oool3
000000H0oooo00<000000?ooo`3oool0iP3oool500000580oooo00<000000?ooo`3oool0203oool0
02D0oooo00<000000?ooo`3oool0i@3oool700000540oooo00<000000?ooo`3oool0203oool002D0
oooo00<000000?ooo`3oool0h`3oool2000000030?ooo`000000000000<00000DP3oool00`000000
oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`3R0?ooo`T00000DP3oool00`000000oooo
0?ooo`080?ooo`009@3oool200000>40oooo0`0000030?ooo`D00000D03oool3000000X0oooo000U
0?ooo`030000003oool0oooo0=L0oooo1@0000001@3oool000000?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo0000001C0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003o
ool0oooo0=L0oooo1P0000000`3oool000000000001M0?ooo`030000003oool0oooo00P0oooo000U
0?ooo`030000003oool0oooo0=H0oooo1P0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0b03oool50000
00H0oooo0`0000000`3oool000000000000400000600oooo00<000000?ooo`3oool0203oool002D0
oooo00<000000?ooo`3oool0b03oool500000080oooo00<000000?ooo`3oool01@3oool5000000<0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo
0?ooo`2i0?ooo`D00000203oool7000000`0oooo0`00001Q0?ooo`030000003oool0oooo00P0oooo
000U0?ooo`800000^P3oool5000000@0oooo00<000000?ooo`3oool00`3oool5000000X0oooo1`00
001M0?ooo`<000002P3oool002D0oooo00<000000?ooo`3oool0ZP3oool5000000X0oooo1P000009
0?ooo`D000002@3oool00`000000oooo0?ooo`0200000680oooo00<000000?ooo`3oool0203oool0
02D0oooo00<000000?ooo`3oool0R`3oool5000000X0oooo1@00000;0?ooo`L000000`3oool20000
00<0oooo1@00000F0?ooo`8000000P3oool400000640oooo00<000000?ooo`3oool0203oool002D0
oooo00<000000?ooo`3oool00P3oool5000000/0oooo1@00000:0?ooo`D000002P3oool5000000X0
oooo1@00000:0?ooo`D000002`3oool5000000X0oooo1@00000:0?ooo`D000002P3oool5000000T0
oooo2`0000030?ooo`030000003oool0oooo00D000002P3oool5000001@0oooo0P0000030?ooo`03
0000003oool0000006<0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0
0P3oool5000000/0oooo1@00000:0?ooo`D000002P3oool5000000X0oooo1@00000:0?ooo`D00000
0`3oool010000000oooo0?ooo`3oool;000000<0oooo2P0000030?ooo`H0000000<0oooo00000000
00000`0000020?ooo`H000000P3oool;000000@0oooo1@00000;0?ooo`D000008P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203oool002D0oooo
00<000000?ooo`3oool00P3oool500000080oooo1P0000030?ooo`/000000`3oool:000000<0oooo
0P0000000`3oool0000000000006000000<0oooo00@000000?ooo`3oool0oooo1P0000030?ooo`80
00000`3oool6000000/0oooo1@00000:0?ooo`D000002P3oool5000000X0oooo1@00000:0?ooo`D0
00002`3oool500000200oooo0P0000020?ooo`800000J03oool00`000000oooo0?ooo`080?ooo`00
9@3oool00`000000oooo0?ooo`020?ooo`D000002`3oool5000000X0oooo1@00000:0?ooo`D00000
2P3oool5000000X0oooo1@00000;0?ooo`D000002P3oool5000000X0oooo1@00000:0?ooo`D00000
2P3oool5000002h0oooo0P00001^0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003o
ool0oooo0080oooo1@00000;0?ooo`D000002P3oool5000000X0oooo1@00000:0?ooo`D000002P3o
ool5000000/0oooo1@00000:0?ooo`D000002P3oool5000004X0oooo0P0000030?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0203oool002D0oooo0P00003;0?ooo`80000000<0oooo
0000003oool0K03oool3000000X0oooo000U0?ooo`030000003oool0oooo0<P0oooo100000000`3o
ool000000?ooo`1^0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo0<D0
oooo0`0000000`3oool000000000000200000700oooo00<000000?ooo`3oool0203oool002D0oooo
00<000000?ooo`3oool0``3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`310?ooo`800000NP3o
ool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo00<000000?ooo`3oool00P3oool3
00000080oooo1@0000050?ooo`030000003oool0oooo0;h0oooo0`0000020?ooo`800000N03oool0
0`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0;/0oooo0`00
00020?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0203oool000/0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2j0?ooo`@00000O`3oool00`000000oooo0?ooo`080?ooo`002`3oool0
0`000000oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`<00000]`3oool6
000007h0oooo0`00000:0?ooo`002`3oool00`000000oooo0?ooo`070?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0]@3o
ool3000000030?ooo`000000000000<00000O`3oool00`000000oooo0?ooo`080?ooo`002P3oool2
000000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2b0?ooo`<0000000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00P0oooo0`00
00030?ooo`<000001P3oool00`000000oooo0?ooo`2`0?ooo`80000000<0oooo0000003oool0R03o
ool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2[0?ooo`D00000S@3oool0
0`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool00000
00<00000SP3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`2U0?ooo`80
000000<0oooo0000000000001000002?0?ooo`030000003oool0oooo00P0oooo000U0?ooo`800000
W03oool2000000D0oooo00<000000?ooo`3oool00`0000030?ooo`<00000S@3oool3000000X0oooo
000U0?ooo`030000003oool0oooo09/0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo09D0oooo00@00000
0?ooo`3oool000000`3oool6000009/0oooo00<000000?ooo`3oool0203oool002D0oooo00<00000
0?ooo`3oool0S@3oool200000080oooo00@000000?ooo`3oool000001P3oool4000009h0oooo00<0
00000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0O@3oool2000000L0oooo0P000002
0?ooo`030000003oool0000000<000001P3oool5000000040?ooo`0000000000000009h0oooo00<0
00000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0OP3oool300000080oooo00<00000
0?ooo`3oool01`3oool200000080oooo1@0000070?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0000000<0?oo
o`030000003oool00000008000000P3oool00`000000oooo0?ooo`0200000080oooo1@00000;0?oo
o`D00000[03oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`030?ooo`80
00003P3oool00`000000oooo0000000<0?ooo`030000003oool0000000`0oooo0P00000=0?ooo`80
00003@3oool2000000/0oooo0P0000001@3oool00000000000000000oooo008000000P3oool00`00
0000oooo0?ooo`0200000080oooo1000000<0?ooo`030000003oool0oooo00H0oooo2@00002]0?oo
o`030000003oool0oooo00P0oooo000U0?ooo`8000001@3oool200000080oooo0P0000020?ooo`03
0000003oool0oooo008000000P3oool500000080oooo00<000000?ooo`3oool00P0000020?ooo`D0
00000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P0000020?ooo`03
0000003oool0oooo008000000P3oool00`000000oooo0?ooo`03000000040?ooo`000000oooo0?oo
o`8000000P3oool00`000000oooo0?ooo`0500000080oooo0P0000020?ooo`030000003oool0oooo
00<0oooo0`00000=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@0000060?oo
o`<00000Z`3oool3000000X0oooo000U0?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`<0
0000303oool4000000/0oooo1000000;0?ooo`@00000303oool3000000d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`/00000303oool00`000000oooo0?ooo`2/0?ooo`03
0000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo3`0000070?ooo`800000
_@3oool00`000000oooo0?ooo`080?ooo`009@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`l000001@3o
ool4000000h0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`080?ooo`009@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool?
000000D0oooo1000000<0?ooo`<00000c03oool00`000000oooo0?ooo`080?ooo`009@3oool00`00
0000oooo0?ooo`040?ooodH000001@3oool4000000`0oooo0`00000=0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool0203oool002D0oooo00<000000?ooo`3oool0103oool3000000`0
oooo0`00000<0?ooo`<000003@3oool2000000d0oooo0`00000<0?ooo`<000003@3oool00`000000
oooo0?ooo`3J0?ooo`030000003oool0oooo00P0oooo000U0?ooo`8000001P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0i`3oool3000000X0oooo
000U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000U0?oo
ool00000@P00000:0?ooo`00o`3oooma0?ooo`00o`3oooma0?ooo`00o`3oooma0?ooo`00o`3oooma
0?ooo`00/03oool2000000P0oooo0P00001D0?ooo`8000003P3oool2000004h0oooo002`0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo04`0oooo001U0?ooo`D0000000D0oooo00000000000000000?ooo`0200000080
oooo0P0000090?ooo`<000000P3oool3000000@0oooo100000020?ooo`@0000000<0oooo00000000
00000`0000020?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P0000050?ooo`04
0000003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
0?ooo`@00000203oool3000000@0oooo0`0000020?ooo`@000000P3oool5000000<0oooo0P000002
0?ooo`D000000P3oool300000080oooo0`0000000`3oool00000000000090?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool0oooo04`0oooo001W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
04`0oooo001W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`<000000P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`D00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`00
00000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`080?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0oooo04`0oooo001W0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<00000
00<0oooo0000000000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo000000020?ooo`030000003oool0oooo00X0oooo
0`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0>0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo04`0oooo
001W0?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000P0oooo00<000000?ooo`3oool0
0`3oool2000000030?ooo`00000000000080oooo0P0000040?ooo`<000000P3oool3000000@0oooo
0`0000020?ooo`@000000P3oool4000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`00000000000080oooo10000008
0?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`@0000000@0oooo0000000000000000
0`3oool400000080oooo0`0000040?ooo`<000000P3oool4000000/0oooo00<000000?ooo`3oool0
0P000000103oool000000?ooo`3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3o
ool0C03oool006L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0
oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo0P00000L0?ooo`040000003oool0
oooo000001@0oooo00<000000?ooo`3oool07@3oool2000000h0oooo0P00001>0?ooo`00I@3oool5
000000P0oooo00<000000?ooo`3oool02@3oool300000100oooo0P0000040?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0203oool5000001l0oooo1000000@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1f0?ooo`00o`3oooma0?oo
o`00o`3oooma0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 367}, {226.312, 0}} -> {-5.07538, 1.6968, 0.111812, \
0.000664664}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(curden = 1;\)\), "\[IndentingNewLine]", 
    \(\(chamfer = {2, 4, 6, 8, 10};\)\), "\[IndentingNewLine]", 
    \(\(pp = ff[chamfer];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, 
          PlotJoined \[Rule] True, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, Frame \[Rule] True, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(pp = 
        Insert[pp, 
          PlotLabel \[Rule] "\<Int Gradient[T] vs Position [mm]\>", \
\(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(MultipleListPlot @@ pp;\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0280112 -12.3623 31.383 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16387 -0.0125 -3 -9 ]
[.16387 -0.0125 3 0 ]
[.30392 -0.0125 -6 -9 ]
[.30392 -0.0125 6 0 ]
[.44398 -0.0125 -6 -9 ]
[.44398 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.72409 -0.0125 -6 -9 ]
[.72409 -0.0125 6 0 ]
[.86415 -0.0125 -6 -9 ]
[.86415 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03403 -30 -4.5 ]
[-0.0125 .03403 0 4.5 ]
[-0.0125 .11249 -36 -4.5 ]
[-0.0125 .11249 0 4.5 ]
[-0.0125 .19094 -18 -4.5 ]
[-0.0125 .19094 0 4.5 ]
[-0.0125 .2694 -36 -4.5 ]
[-0.0125 .2694 0 4.5 ]
[-0.0125 .34786 -30 -4.5 ]
[-0.0125 .34786 0 4.5 ]
[-0.0125 .42632 -36 -4.5 ]
[-0.0125 .42632 0 4.5 ]
[-0.0125 .50477 -24 -4.5 ]
[-0.0125 .50477 0 4.5 ]
[-0.0125 .58323 -36 -4.5 ]
[-0.0125 .58323 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16387 0 m
.16387 .00625 L
s
[(5)] .16387 -0.0125 0 1 Mshowa
.30392 0 m
.30392 .00625 L
s
[(10)] .30392 -0.0125 0 1 Mshowa
.44398 0 m
.44398 .00625 L
s
[(15)] .44398 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(20)] .58403 -0.0125 0 1 Mshowa
.72409 0 m
.72409 .00625 L
s
[(25)] .72409 -0.0125 0 1 Mshowa
.86415 0 m
.86415 .00625 L
s
[(30)] .86415 -0.0125 0 1 Mshowa
.125 Mabswid
.05182 0 m
.05182 .00375 L
s
.07983 0 m
.07983 .00375 L
s
.10784 0 m
.10784 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.19188 0 m
.19188 .00375 L
s
.21989 0 m
.21989 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.27591 0 m
.27591 .00375 L
s
.33193 0 m
.33193 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.38796 0 m
.38796 .00375 L
s
.41597 0 m
.41597 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.5 0 m
.5 .00375 L
s
.52801 0 m
.52801 .00375 L
s
.55602 0 m
.55602 .00375 L
s
.61204 0 m
.61204 .00375 L
s
.64006 0 m
.64006 .00375 L
s
.66807 0 m
.66807 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.7521 0 m
.7521 .00375 L
s
.78011 0 m
.78011 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.83613 0 m
.83613 .00375 L
s
.89216 0 m
.89216 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.94818 0 m
.94818 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03403 m
.00625 .03403 L
s
[(0.395)] -0.0125 .03403 1 0 Mshowa
0 .11249 m
.00625 .11249 L
s
[(0.3975)] -0.0125 .11249 1 0 Mshowa
0 .19094 m
.00625 .19094 L
s
[(0.4)] -0.0125 .19094 1 0 Mshowa
0 .2694 m
.00625 .2694 L
s
[(0.4025)] -0.0125 .2694 1 0 Mshowa
0 .34786 m
.00625 .34786 L
s
[(0.405)] -0.0125 .34786 1 0 Mshowa
0 .42632 m
.00625 .42632 L
s
[(0.4075)] -0.0125 .42632 1 0 Mshowa
0 .50477 m
.00625 .50477 L
s
[(0.41)] -0.0125 .50477 1 0 Mshowa
0 .58323 m
.00625 .58323 L
s
[(0.4125)] -0.0125 .58323 1 0 Mshowa
.125 Mabswid
0 .04972 m
.00375 .04972 L
s
0 .06541 m
.00375 .06541 L
s
0 .0811 m
.00375 .0811 L
s
0 .09679 m
.00375 .09679 L
s
0 .12818 m
.00375 .12818 L
s
0 .14387 m
.00375 .14387 L
s
0 .15956 m
.00375 .15956 L
s
0 .17525 m
.00375 .17525 L
s
0 .20663 m
.00375 .20663 L
s
0 .22233 m
.00375 .22233 L
s
0 .23802 m
.00375 .23802 L
s
0 .25371 m
.00375 .25371 L
s
0 .28509 m
.00375 .28509 L
s
0 .30078 m
.00375 .30078 L
s
0 .31648 m
.00375 .31648 L
s
0 .33217 m
.00375 .33217 L
s
0 .36355 m
.00375 .36355 L
s
0 .37924 m
.00375 .37924 L
s
0 .39493 m
.00375 .39493 L
s
0 .41062 m
.00375 .41062 L
s
0 .44201 m
.00375 .44201 L
s
0 .4577 m
.00375 .4577 L
s
0 .47339 m
.00375 .47339 L
s
0 .48908 m
.00375 .48908 L
s
0 .52047 m
.00375 .52047 L
s
0 .53616 m
.00375 .53616 L
s
0 .55185 m
.00375 .55185 L
s
0 .56754 m
.00375 .56754 L
s
0 .01834 m
.00375 .01834 L
s
0 .00265 m
.00375 .00265 L
s
0 .59892 m
.00375 .59892 L
s
0 .61461 m
.00375 .61461 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16387 .61178 m
.16387 .61803 L
s
.30392 .61178 m
.30392 .61803 L
s
.44398 .61178 m
.44398 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.72409 .61178 m
.72409 .61803 L
s
.86415 .61178 m
.86415 .61803 L
s
.125 Mabswid
.05182 .61428 m
.05182 .61803 L
s
.07983 .61428 m
.07983 .61803 L
s
.10784 .61428 m
.10784 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.19188 .61428 m
.19188 .61803 L
s
.21989 .61428 m
.21989 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.27591 .61428 m
.27591 .61803 L
s
.33193 .61428 m
.33193 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.38796 .61428 m
.38796 .61803 L
s
.41597 .61428 m
.41597 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52801 .61428 m
.52801 .61803 L
s
.55602 .61428 m
.55602 .61803 L
s
.61204 .61428 m
.61204 .61803 L
s
.64006 .61428 m
.64006 .61803 L
s
.66807 .61428 m
.66807 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.7521 .61428 m
.7521 .61803 L
s
.78011 .61428 m
.78011 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.83613 .61428 m
.83613 .61803 L
s
.89216 .61428 m
.89216 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.94818 .61428 m
.94818 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03403 m
1 .03403 L
s
.99375 .11249 m
1 .11249 L
s
.99375 .19094 m
1 .19094 L
s
.99375 .2694 m
1 .2694 L
s
.99375 .34786 m
1 .34786 L
s
.99375 .42632 m
1 .42632 L
s
.99375 .50477 m
1 .50477 L
s
.99375 .58323 m
1 .58323 L
s
.125 Mabswid
.99625 .04972 m
1 .04972 L
s
.99625 .06541 m
1 .06541 L
s
.99625 .0811 m
1 .0811 L
s
.99625 .09679 m
1 .09679 L
s
.99625 .12818 m
1 .12818 L
s
.99625 .14387 m
1 .14387 L
s
.99625 .15956 m
1 .15956 L
s
.99625 .17525 m
1 .17525 L
s
.99625 .20663 m
1 .20663 L
s
.99625 .22233 m
1 .22233 L
s
.99625 .23802 m
1 .23802 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .28509 m
1 .28509 L
s
.99625 .30078 m
1 .30078 L
s
.99625 .31648 m
1 .31648 L
s
.99625 .33217 m
1 .33217 L
s
.99625 .36355 m
1 .36355 L
s
.99625 .37924 m
1 .37924 L
s
.99625 .39493 m
1 .39493 L
s
.99625 .41062 m
1 .41062 L
s
.99625 .44201 m
1 .44201 L
s
.99625 .4577 m
1 .4577 L
s
.99625 .47339 m
1 .47339 L
s
.99625 .48908 m
1 .48908 L
s
.99625 .52047 m
1 .52047 L
s
.99625 .53616 m
1 .53616 L
s
.99625 .55185 m
1 .55185 L
s
.99625 .56754 m
1 .56754 L
s
.99625 .01834 m
1 .01834 L
s
.99625 .00265 m
1 .00265 L
s
.99625 .59892 m
1 .59892 L
s
.99625 .61461 m
1 .61461 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Int) show
87.000 13.000 moveto
(Gradient) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(@) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.000 13.000 moveto
(D) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
177.000 13.000 moveto
(Position) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
231.000 13.000 moveto
(@) show
237.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
249.125 13.000 moveto
(D) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .60332 m
.07143 .60331 L
.11905 .60325 L
.16667 .60301 L
.21429 .60237 L
.2619 .60106 L
.30952 .59869 L
.35714 .59486 L
.40476 .58914 L
.45238 .5811 L
.5 .57042 L
.54762 .55694 L
.59524 .54067 L
.64286 .52183 L
.69048 .50057 L
.7381 .47639 L
.78571 .44698 L
.83333 .40621 L
.88095 .34137 L
.92857 .23 L
.97619 .03723 L
s
.0001 w
.02381 .60332 -1.875 0 Mabsadd m
.02381 .60332 0 2.5 Mabsadd L
.02381 .60332 1.875 0 Mabsadd L
.02381 .60332 0 -2.5 Mabsadd L
.02381 .60332 -1.875 0 Mabsadd L closepath F
.07143 .60331 -1.875 0 Mabsadd m
.07143 .60331 0 2.5 Mabsadd L
.07143 .60331 1.875 0 Mabsadd L
.07143 .60331 0 -2.5 Mabsadd L
.07143 .60331 -1.875 0 Mabsadd L closepath F
.11905 .60325 -1.875 0 Mabsadd m
.11905 .60325 0 2.5 Mabsadd L
.11905 .60325 1.875 0 Mabsadd L
.11905 .60325 0 -2.5 Mabsadd L
.11905 .60325 -1.875 0 Mabsadd L closepath F
.16667 .60301 -1.875 0 Mabsadd m
.16667 .60301 0 2.5 Mabsadd L
.16667 .60301 1.875 0 Mabsadd L
.16667 .60301 0 -2.5 Mabsadd L
.16667 .60301 -1.875 0 Mabsadd L closepath F
.21429 .60237 -1.875 0 Mabsadd m
.21429 .60237 0 2.5 Mabsadd L
.21429 .60237 1.875 0 Mabsadd L
.21429 .60237 0 -2.5 Mabsadd L
.21429 .60237 -1.875 0 Mabsadd L closepath F
.2619 .60106 -1.875 0 Mabsadd m
.2619 .60106 0 2.5 Mabsadd L
.2619 .60106 1.875 0 Mabsadd L
.2619 .60106 0 -2.5 Mabsadd L
.2619 .60106 -1.875 0 Mabsadd L closepath F
.30952 .59869 -1.875 0 Mabsadd m
.30952 .59869 0 2.5 Mabsadd L
.30952 .59869 1.875 0 Mabsadd L
.30952 .59869 0 -2.5 Mabsadd L
.30952 .59869 -1.875 0 Mabsadd L closepath F
.35714 .59486 -1.875 0 Mabsadd m
.35714 .59486 0 2.5 Mabsadd L
.35714 .59486 1.875 0 Mabsadd L
.35714 .59486 0 -2.5 Mabsadd L
.35714 .59486 -1.875 0 Mabsadd L closepath F
.40476 .58914 -1.875 0 Mabsadd m
.40476 .58914 0 2.5 Mabsadd L
.40476 .58914 1.875 0 Mabsadd L
.40476 .58914 0 -2.5 Mabsadd L
.40476 .58914 -1.875 0 Mabsadd L closepath F
.45238 .5811 -1.875 0 Mabsadd m
.45238 .5811 0 2.5 Mabsadd L
.45238 .5811 1.875 0 Mabsadd L
.45238 .5811 0 -2.5 Mabsadd L
.45238 .5811 -1.875 0 Mabsadd L closepath F
.5 .57042 -1.875 0 Mabsadd m
.5 .57042 0 2.5 Mabsadd L
.5 .57042 1.875 0 Mabsadd L
.5 .57042 0 -2.5 Mabsadd L
.5 .57042 -1.875 0 Mabsadd L closepath F
.54762 .55694 -1.875 0 Mabsadd m
.54762 .55694 0 2.5 Mabsadd L
.54762 .55694 1.875 0 Mabsadd L
.54762 .55694 0 -2.5 Mabsadd L
.54762 .55694 -1.875 0 Mabsadd L closepath F
.59524 .54067 -1.875 0 Mabsadd m
.59524 .54067 0 2.5 Mabsadd L
.59524 .54067 1.875 0 Mabsadd L
.59524 .54067 0 -2.5 Mabsadd L
.59524 .54067 -1.875 0 Mabsadd L closepath F
.64286 .52183 -1.875 0 Mabsadd m
.64286 .52183 0 2.5 Mabsadd L
.64286 .52183 1.875 0 Mabsadd L
.64286 .52183 0 -2.5 Mabsadd L
.64286 .52183 -1.875 0 Mabsadd L closepath F
.69048 .50057 -1.875 0 Mabsadd m
.69048 .50057 0 2.5 Mabsadd L
.69048 .50057 1.875 0 Mabsadd L
.69048 .50057 0 -2.5 Mabsadd L
.69048 .50057 -1.875 0 Mabsadd L closepath F
.7381 .47639 -1.875 0 Mabsadd m
.7381 .47639 0 2.5 Mabsadd L
.7381 .47639 1.875 0 Mabsadd L
.7381 .47639 0 -2.5 Mabsadd L
.7381 .47639 -1.875 0 Mabsadd L closepath F
.78571 .44698 -1.875 0 Mabsadd m
.78571 .44698 0 2.5 Mabsadd L
.78571 .44698 1.875 0 Mabsadd L
.78571 .44698 0 -2.5 Mabsadd L
.78571 .44698 -1.875 0 Mabsadd L closepath F
.83333 .40621 -1.875 0 Mabsadd m
.83333 .40621 0 2.5 Mabsadd L
.83333 .40621 1.875 0 Mabsadd L
.83333 .40621 0 -2.5 Mabsadd L
.83333 .40621 -1.875 0 Mabsadd L closepath F
.88095 .34137 -1.875 0 Mabsadd m
.88095 .34137 0 2.5 Mabsadd L
.88095 .34137 1.875 0 Mabsadd L
.88095 .34137 0 -2.5 Mabsadd L
.88095 .34137 -1.875 0 Mabsadd L closepath F
.92857 .23 -1.875 0 Mabsadd m
.92857 .23 0 2.5 Mabsadd L
.92857 .23 1.875 0 Mabsadd L
.92857 .23 0 -2.5 Mabsadd L
.92857 .23 -1.875 0 Mabsadd L closepath F
.97619 .03723 -1.875 0 Mabsadd m
.97619 .03723 0 2.5 Mabsadd L
.97619 .03723 1.875 0 Mabsadd L
.97619 .03723 0 -2.5 Mabsadd L
.97619 .03723 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .57548 m
.07143 .57548 L
.11905 .57544 L
.16667 .5753 L
.21429 .57491 L
.2619 .57411 L
.30952 .57267 L
.35714 .57033 L
.40476 .56684 L
.45238 .56192 L
.5 .55535 L
.54762 .54697 L
.59524 .53668 L
.64286 .52431 L
.69048 .5094 L
.7381 .49047 L
.78571 .46391 L
.83333 .42209 L
.88095 .35083 L
.92857 .22668 L
.97619 .01472 L
s
.0001 w
[ ] 0 setdash
.02381 .57548 0 2.5 Mabsadd m
.02381 .57548 -0.56518 .7779 Mabsadd L
.02381 .57548 -2.37764 .77254 Mabsadd L
.02381 .57548 -0.91448 -0.29713 Mabsadd L
.02381 .57548 -1.46946 -2.02254 Mabsadd L
.02381 .57548 0 -0.96154 Mabsadd L
.02381 .57548 1.46946 -2.02254 Mabsadd L
.02381 .57548 .91448 -0.29713 Mabsadd L
.02381 .57548 2.37764 .77254 Mabsadd L
.02381 .57548 .56518 .7779 Mabsadd L
.02381 .57548 0 2.5 Mabsadd L closepath F
.07143 .57548 0 2.5 Mabsadd m
.07143 .57548 -0.56518 .7779 Mabsadd L
.07143 .57548 -2.37764 .77254 Mabsadd L
.07143 .57548 -0.91448 -0.29713 Mabsadd L
.07143 .57548 -1.46946 -2.02254 Mabsadd L
.07143 .57548 0 -0.96154 Mabsadd L
.07143 .57548 1.46946 -2.02254 Mabsadd L
.07143 .57548 .91448 -0.29713 Mabsadd L
.07143 .57548 2.37764 .77254 Mabsadd L
.07143 .57548 .56518 .7779 Mabsadd L
.07143 .57548 0 2.5 Mabsadd L closepath F
.11905 .57544 0 2.5 Mabsadd m
.11905 .57544 -0.56518 .7779 Mabsadd L
.11905 .57544 -2.37764 .77254 Mabsadd L
.11905 .57544 -0.91448 -0.29713 Mabsadd L
.11905 .57544 -1.46946 -2.02254 Mabsadd L
.11905 .57544 0 -0.96154 Mabsadd L
.11905 .57544 1.46946 -2.02254 Mabsadd L
.11905 .57544 .91448 -0.29713 Mabsadd L
.11905 .57544 2.37764 .77254 Mabsadd L
.11905 .57544 .56518 .7779 Mabsadd L
.11905 .57544 0 2.5 Mabsadd L closepath F
.16667 .5753 0 2.5 Mabsadd m
.16667 .5753 -0.56518 .7779 Mabsadd L
.16667 .5753 -2.37764 .77254 Mabsadd L
.16667 .5753 -0.91448 -0.29713 Mabsadd L
.16667 .5753 -1.46946 -2.02254 Mabsadd L
.16667 .5753 0 -0.96154 Mabsadd L
.16667 .5753 1.46946 -2.02254 Mabsadd L
.16667 .5753 .91448 -0.29713 Mabsadd L
.16667 .5753 2.37764 .77254 Mabsadd L
.16667 .5753 .56518 .7779 Mabsadd L
.16667 .5753 0 2.5 Mabsadd L closepath F
.21429 .57491 0 2.5 Mabsadd m
.21429 .57491 -0.56518 .7779 Mabsadd L
.21429 .57491 -2.37764 .77254 Mabsadd L
.21429 .57491 -0.91448 -0.29713 Mabsadd L
.21429 .57491 -1.46946 -2.02254 Mabsadd L
.21429 .57491 0 -0.96154 Mabsadd L
.21429 .57491 1.46946 -2.02254 Mabsadd L
.21429 .57491 .91448 -0.29713 Mabsadd L
.21429 .57491 2.37764 .77254 Mabsadd L
.21429 .57491 .56518 .7779 Mabsadd L
.21429 .57491 0 2.5 Mabsadd L closepath F
.2619 .57411 0 2.5 Mabsadd m
.2619 .57411 -0.56518 .7779 Mabsadd L
.2619 .57411 -2.37764 .77254 Mabsadd L
.2619 .57411 -0.91448 -0.29713 Mabsadd L
.2619 .57411 -1.46946 -2.02254 Mabsadd L
.2619 .57411 0 -0.96154 Mabsadd L
.2619 .57411 1.46946 -2.02254 Mabsadd L
.2619 .57411 .91448 -0.29713 Mabsadd L
.2619 .57411 2.37764 .77254 Mabsadd L
.2619 .57411 .56518 .7779 Mabsadd L
.2619 .57411 0 2.5 Mabsadd L closepath F
.30952 .57267 0 2.5 Mabsadd m
.30952 .57267 -0.56518 .7779 Mabsadd L
.30952 .57267 -2.37764 .77254 Mabsadd L
.30952 .57267 -0.91448 -0.29713 Mabsadd L
.30952 .57267 -1.46946 -2.02254 Mabsadd L
.30952 .57267 0 -0.96154 Mabsadd L
.30952 .57267 1.46946 -2.02254 Mabsadd L
.30952 .57267 .91448 -0.29713 Mabsadd L
.30952 .57267 2.37764 .77254 Mabsadd L
.30952 .57267 .56518 .7779 Mabsadd L
.30952 .57267 0 2.5 Mabsadd L closepath F
.35714 .57033 0 2.5 Mabsadd m
.35714 .57033 -0.56518 .7779 Mabsadd L
.35714 .57033 -2.37764 .77254 Mabsadd L
.35714 .57033 -0.91448 -0.29713 Mabsadd L
.35714 .57033 -1.46946 -2.02254 Mabsadd L
.35714 .57033 0 -0.96154 Mabsadd L
.35714 .57033 1.46946 -2.02254 Mabsadd L
.35714 .57033 .91448 -0.29713 Mabsadd L
.35714 .57033 2.37764 .77254 Mabsadd L
.35714 .57033 .56518 .7779 Mabsadd L
.35714 .57033 0 2.5 Mabsadd L closepath F
.40476 .56684 0 2.5 Mabsadd m
.40476 .56684 -0.56518 .7779 Mabsadd L
.40476 .56684 -2.37764 .77254 Mabsadd L
.40476 .56684 -0.91448 -0.29713 Mabsadd L
.40476 .56684 -1.46946 -2.02254 Mabsadd L
.40476 .56684 0 -0.96154 Mabsadd L
.40476 .56684 1.46946 -2.02254 Mabsadd L
.40476 .56684 .91448 -0.29713 Mabsadd L
.40476 .56684 2.37764 .77254 Mabsadd L
.40476 .56684 .56518 .7779 Mabsadd L
.40476 .56684 0 2.5 Mabsadd L closepath F
.45238 .56192 0 2.5 Mabsadd m
.45238 .56192 -0.56518 .7779 Mabsadd L
.45238 .56192 -2.37764 .77254 Mabsadd L
.45238 .56192 -0.91448 -0.29713 Mabsadd L
.45238 .56192 -1.46946 -2.02254 Mabsadd L
.45238 .56192 0 -0.96154 Mabsadd L
.45238 .56192 1.46946 -2.02254 Mabsadd L
.45238 .56192 .91448 -0.29713 Mabsadd L
.45238 .56192 2.37764 .77254 Mabsadd L
.45238 .56192 .56518 .7779 Mabsadd L
.45238 .56192 0 2.5 Mabsadd L closepath F
.5 .55535 0 2.5 Mabsadd m
.5 .55535 -0.56518 .7779 Mabsadd L
.5 .55535 -2.37764 .77254 Mabsadd L
.5 .55535 -0.91448 -0.29713 Mabsadd L
.5 .55535 -1.46946 -2.02254 Mabsadd L
.5 .55535 0 -0.96154 Mabsadd L
.5 .55535 1.46946 -2.02254 Mabsadd L
.5 .55535 .91448 -0.29713 Mabsadd L
.5 .55535 2.37764 .77254 Mabsadd L
.5 .55535 .56518 .7779 Mabsadd L
.5 .55535 0 2.5 Mabsadd L closepath F
.54762 .54697 0 2.5 Mabsadd m
.54762 .54697 -0.56518 .7779 Mabsadd L
.54762 .54697 -2.37764 .77254 Mabsadd L
.54762 .54697 -0.91448 -0.29713 Mabsadd L
.54762 .54697 -1.46946 -2.02254 Mabsadd L
.54762 .54697 0 -0.96154 Mabsadd L
.54762 .54697 1.46946 -2.02254 Mabsadd L
.54762 .54697 .91448 -0.29713 Mabsadd L
.54762 .54697 2.37764 .77254 Mabsadd L
.54762 .54697 .56518 .7779 Mabsadd L
.54762 .54697 0 2.5 Mabsadd L closepath F
.59524 .53668 0 2.5 Mabsadd m
.59524 .53668 -0.56518 .7779 Mabsadd L
.59524 .53668 -2.37764 .77254 Mabsadd L
.59524 .53668 -0.91448 -0.29713 Mabsadd L
.59524 .53668 -1.46946 -2.02254 Mabsadd L
.59524 .53668 0 -0.96154 Mabsadd L
.59524 .53668 1.46946 -2.02254 Mabsadd L
.59524 .53668 .91448 -0.29713 Mabsadd L
.59524 .53668 2.37764 .77254 Mabsadd L
.59524 .53668 .56518 .7779 Mabsadd L
.59524 .53668 0 2.5 Mabsadd L closepath F
.64286 .52431 0 2.5 Mabsadd m
.64286 .52431 -0.56518 .7779 Mabsadd L
.64286 .52431 -2.37764 .77254 Mabsadd L
.64286 .52431 -0.91448 -0.29713 Mabsadd L
.64286 .52431 -1.46946 -2.02254 Mabsadd L
.64286 .52431 0 -0.96154 Mabsadd L
.64286 .52431 1.46946 -2.02254 Mabsadd L
.64286 .52431 .91448 -0.29713 Mabsadd L
.64286 .52431 2.37764 .77254 Mabsadd L
.64286 .52431 .56518 .7779 Mabsadd L
.64286 .52431 0 2.5 Mabsadd L closepath F
.69048 .5094 0 2.5 Mabsadd m
.69048 .5094 -0.56518 .7779 Mabsadd L
.69048 .5094 -2.37764 .77254 Mabsadd L
.69048 .5094 -0.91448 -0.29713 Mabsadd L
.69048 .5094 -1.46946 -2.02254 Mabsadd L
.69048 .5094 0 -0.96154 Mabsadd L
.69048 .5094 1.46946 -2.02254 Mabsadd L
.69048 .5094 .91448 -0.29713 Mabsadd L
.69048 .5094 2.37764 .77254 Mabsadd L
.69048 .5094 .56518 .7779 Mabsadd L
.69048 .5094 0 2.5 Mabsadd L closepath F
.7381 .49047 0 2.5 Mabsadd m
.7381 .49047 -0.56518 .7779 Mabsadd L
.7381 .49047 -2.37764 .77254 Mabsadd L
.7381 .49047 -0.91448 -0.29713 Mabsadd L
.7381 .49047 -1.46946 -2.02254 Mabsadd L
.7381 .49047 0 -0.96154 Mabsadd L
.7381 .49047 1.46946 -2.02254 Mabsadd L
.7381 .49047 .91448 -0.29713 Mabsadd L
.7381 .49047 2.37764 .77254 Mabsadd L
.7381 .49047 .56518 .7779 Mabsadd L
.7381 .49047 0 2.5 Mabsadd L closepath F
.78571 .46391 0 2.5 Mabsadd m
.78571 .46391 -0.56518 .7779 Mabsadd L
.78571 .46391 -2.37764 .77254 Mabsadd L
.78571 .46391 -0.91448 -0.29713 Mabsadd L
.78571 .46391 -1.46946 -2.02254 Mabsadd L
.78571 .46391 0 -0.96154 Mabsadd L
.78571 .46391 1.46946 -2.02254 Mabsadd L
.78571 .46391 .91448 -0.29713 Mabsadd L
.78571 .46391 2.37764 .77254 Mabsadd L
.78571 .46391 .56518 .7779 Mabsadd L
.78571 .46391 0 2.5 Mabsadd L closepath F
.83333 .42209 0 2.5 Mabsadd m
.83333 .42209 -0.56518 .7779 Mabsadd L
.83333 .42209 -2.37764 .77254 Mabsadd L
.83333 .42209 -0.91448 -0.29713 Mabsadd L
.83333 .42209 -1.46946 -2.02254 Mabsadd L
.83333 .42209 0 -0.96154 Mabsadd L
.83333 .42209 1.46946 -2.02254 Mabsadd L
.83333 .42209 .91448 -0.29713 Mabsadd L
.83333 .42209 2.37764 .77254 Mabsadd L
.83333 .42209 .56518 .7779 Mabsadd L
.83333 .42209 0 2.5 Mabsadd L closepath F
.88095 .35083 0 2.5 Mabsadd m
.88095 .35083 -0.56518 .7779 Mabsadd L
.88095 .35083 -2.37764 .77254 Mabsadd L
.88095 .35083 -0.91448 -0.29713 Mabsadd L
.88095 .35083 -1.46946 -2.02254 Mabsadd L
.88095 .35083 0 -0.96154 Mabsadd L
.88095 .35083 1.46946 -2.02254 Mabsadd L
.88095 .35083 .91448 -0.29713 Mabsadd L
.88095 .35083 2.37764 .77254 Mabsadd L
.88095 .35083 .56518 .7779 Mabsadd L
.88095 .35083 0 2.5 Mabsadd L closepath F
.92857 .22668 0 2.5 Mabsadd m
.92857 .22668 -0.56518 .7779 Mabsadd L
.92857 .22668 -2.37764 .77254 Mabsadd L
.92857 .22668 -0.91448 -0.29713 Mabsadd L
.92857 .22668 -1.46946 -2.02254 Mabsadd L
.92857 .22668 0 -0.96154 Mabsadd L
.92857 .22668 1.46946 -2.02254 Mabsadd L
.92857 .22668 .91448 -0.29713 Mabsadd L
.92857 .22668 2.37764 .77254 Mabsadd L
.92857 .22668 .56518 .7779 Mabsadd L
.92857 .22668 0 2.5 Mabsadd L closepath F
.97619 .01472 0 2.5 Mabsadd m
.97619 .01472 -0.56518 .7779 Mabsadd L
.97619 .01472 -2.37764 .77254 Mabsadd L
.97619 .01472 -0.91448 -0.29713 Mabsadd L
.97619 .01472 -1.46946 -2.02254 Mabsadd L
.97619 .01472 0 -0.96154 Mabsadd L
.97619 .01472 1.46946 -2.02254 Mabsadd L
.97619 .01472 .91448 -0.29713 Mabsadd L
.97619 .01472 2.37764 .77254 Mabsadd L
.97619 .01472 .56518 .7779 Mabsadd L
.97619 .01472 0 2.5 Mabsadd L closepath F
.001 w
[ .5 4 5 4 ] 0 Mabsdash
.02381 .42804 m
.07143 .42804 L
.11905 .42806 L
.16667 .42812 L
.21429 .42827 L
.2619 .42861 L
.30952 .42921 L
.35714 .4302 L
.40476 .43173 L
.45238 .43396 L
.5 .4371 L
.54762 .44135 L
.59524 .44689 L
.64286 .45373 L
.69048 .4614 L
.7381 .4683 L
.78571 .47053 L
.83333 .46 L
.88095 .42189 L
.92857 .33178 L
.97619 .1534 L
s
.0001 w
[ ] 0 setdash
.02381 .42804 -2.5 2.5 Mabsadd m
.02381 .42804 2.5 2.5 Mabsadd L
.02381 .42804 2.5 -2.5 Mabsadd L
.02381 .42804 -2.5 -2.5 Mabsadd L
.02381 .42804 -2.5 2.5 Mabsadd L closepath F
.07143 .42804 -2.5 2.5 Mabsadd m
.07143 .42804 2.5 2.5 Mabsadd L
.07143 .42804 2.5 -2.5 Mabsadd L
.07143 .42804 -2.5 -2.5 Mabsadd L
.07143 .42804 -2.5 2.5 Mabsadd L closepath F
.11905 .42806 -2.5 2.5 Mabsadd m
.11905 .42806 2.5 2.5 Mabsadd L
.11905 .42806 2.5 -2.5 Mabsadd L
.11905 .42806 -2.5 -2.5 Mabsadd L
.11905 .42806 -2.5 2.5 Mabsadd L closepath F
.16667 .42812 -2.5 2.5 Mabsadd m
.16667 .42812 2.5 2.5 Mabsadd L
.16667 .42812 2.5 -2.5 Mabsadd L
.16667 .42812 -2.5 -2.5 Mabsadd L
.16667 .42812 -2.5 2.5 Mabsadd L closepath F
.21429 .42827 -2.5 2.5 Mabsadd m
.21429 .42827 2.5 2.5 Mabsadd L
.21429 .42827 2.5 -2.5 Mabsadd L
.21429 .42827 -2.5 -2.5 Mabsadd L
.21429 .42827 -2.5 2.5 Mabsadd L closepath F
.2619 .42861 -2.5 2.5 Mabsadd m
.2619 .42861 2.5 2.5 Mabsadd L
.2619 .42861 2.5 -2.5 Mabsadd L
.2619 .42861 -2.5 -2.5 Mabsadd L
.2619 .42861 -2.5 2.5 Mabsadd L closepath F
.30952 .42921 -2.5 2.5 Mabsadd m
.30952 .42921 2.5 2.5 Mabsadd L
.30952 .42921 2.5 -2.5 Mabsadd L
.30952 .42921 -2.5 -2.5 Mabsadd L
.30952 .42921 -2.5 2.5 Mabsadd L closepath F
.35714 .4302 -2.5 2.5 Mabsadd m
.35714 .4302 2.5 2.5 Mabsadd L
.35714 .4302 2.5 -2.5 Mabsadd L
.35714 .4302 -2.5 -2.5 Mabsadd L
.35714 .4302 -2.5 2.5 Mabsadd L closepath F
.40476 .43173 -2.5 2.5 Mabsadd m
.40476 .43173 2.5 2.5 Mabsadd L
.40476 .43173 2.5 -2.5 Mabsadd L
.40476 .43173 -2.5 -2.5 Mabsadd L
.40476 .43173 -2.5 2.5 Mabsadd L closepath F
.45238 .43396 -2.5 2.5 Mabsadd m
.45238 .43396 2.5 2.5 Mabsadd L
.45238 .43396 2.5 -2.5 Mabsadd L
.45238 .43396 -2.5 -2.5 Mabsadd L
.45238 .43396 -2.5 2.5 Mabsadd L closepath F
.5 .4371 -2.5 2.5 Mabsadd m
.5 .4371 2.5 2.5 Mabsadd L
.5 .4371 2.5 -2.5 Mabsadd L
.5 .4371 -2.5 -2.5 Mabsadd L
.5 .4371 -2.5 2.5 Mabsadd L closepath F
.54762 .44135 -2.5 2.5 Mabsadd m
.54762 .44135 2.5 2.5 Mabsadd L
.54762 .44135 2.5 -2.5 Mabsadd L
.54762 .44135 -2.5 -2.5 Mabsadd L
.54762 .44135 -2.5 2.5 Mabsadd L closepath F
.59524 .44689 -2.5 2.5 Mabsadd m
.59524 .44689 2.5 2.5 Mabsadd L
.59524 .44689 2.5 -2.5 Mabsadd L
.59524 .44689 -2.5 -2.5 Mabsadd L
.59524 .44689 -2.5 2.5 Mabsadd L closepath F
.64286 .45373 -2.5 2.5 Mabsadd m
.64286 .45373 2.5 2.5 Mabsadd L
.64286 .45373 2.5 -2.5 Mabsadd L
.64286 .45373 -2.5 -2.5 Mabsadd L
.64286 .45373 -2.5 2.5 Mabsadd L closepath F
.69048 .4614 -2.5 2.5 Mabsadd m
.69048 .4614 2.5 2.5 Mabsadd L
.69048 .4614 2.5 -2.5 Mabsadd L
.69048 .4614 -2.5 -2.5 Mabsadd L
.69048 .4614 -2.5 2.5 Mabsadd L closepath F
.7381 .4683 -2.5 2.5 Mabsadd m
.7381 .4683 2.5 2.5 Mabsadd L
.7381 .4683 2.5 -2.5 Mabsadd L
.7381 .4683 -2.5 -2.5 Mabsadd L
.7381 .4683 -2.5 2.5 Mabsadd L closepath F
.78571 .47053 -2.5 2.5 Mabsadd m
.78571 .47053 2.5 2.5 Mabsadd L
.78571 .47053 2.5 -2.5 Mabsadd L
.78571 .47053 -2.5 -2.5 Mabsadd L
.78571 .47053 -2.5 2.5 Mabsadd L closepath F
.83333 .46 -2.5 2.5 Mabsadd m
.83333 .46 2.5 2.5 Mabsadd L
.83333 .46 2.5 -2.5 Mabsadd L
.83333 .46 -2.5 -2.5 Mabsadd L
.83333 .46 -2.5 2.5 Mabsadd L closepath F
.88095 .42189 -2.5 2.5 Mabsadd m
.88095 .42189 2.5 2.5 Mabsadd L
.88095 .42189 2.5 -2.5 Mabsadd L
.88095 .42189 -2.5 -2.5 Mabsadd L
.88095 .42189 -2.5 2.5 Mabsadd L closepath F
.92857 .33178 -2.5 2.5 Mabsadd m
.92857 .33178 2.5 2.5 Mabsadd L
.92857 .33178 2.5 -2.5 Mabsadd L
.92857 .33178 -2.5 -2.5 Mabsadd L
.92857 .33178 -2.5 2.5 Mabsadd L closepath F
.97619 .1534 -2.5 2.5 Mabsadd m
.97619 .1534 2.5 2.5 Mabsadd L
.97619 .1534 2.5 -2.5 Mabsadd L
.97619 .1534 -2.5 -2.5 Mabsadd L
.97619 .1534 -2.5 2.5 Mabsadd L closepath F
.001 w
[ 5 2 ] 0 Mabsdash
.02381 .24987 m
.07143 .24988 L
.11905 .24993 L
.16667 .25017 L
.21429 .25077 L
.2619 .25204 L
.30952 .25431 L
.35714 .25802 L
.40476 .26363 L
.45238 .27166 L
.5 .28261 L
.54762 .29694 L
.59524 .31501 L
.64286 .33692 L
.69048 .36223 L
.7381 .38937 L
.78571 .41458 L
.83333 .43012 L
.88095 .42176 L
.92857 .3658 L
.97619 .22649 L
s
.0001 w
[ ] 0 setdash
.02381 .24987 0 2.5 Mabsadd m
.02381 .24987 -2.165 -1.25 Mabsadd L
.02381 .24987 2.165 -1.25 Mabsadd L
.02381 .24987 0 2.5 Mabsadd L closepath F
.07143 .24988 0 2.5 Mabsadd m
.07143 .24988 -2.165 -1.25 Mabsadd L
.07143 .24988 2.165 -1.25 Mabsadd L
.07143 .24988 0 2.5 Mabsadd L closepath F
.11905 .24993 0 2.5 Mabsadd m
.11905 .24993 -2.165 -1.25 Mabsadd L
.11905 .24993 2.165 -1.25 Mabsadd L
.11905 .24993 0 2.5 Mabsadd L closepath F
.16667 .25017 0 2.5 Mabsadd m
.16667 .25017 -2.165 -1.25 Mabsadd L
.16667 .25017 2.165 -1.25 Mabsadd L
.16667 .25017 0 2.5 Mabsadd L closepath F
.21429 .25077 0 2.5 Mabsadd m
.21429 .25077 -2.165 -1.25 Mabsadd L
.21429 .25077 2.165 -1.25 Mabsadd L
.21429 .25077 0 2.5 Mabsadd L closepath F
.2619 .25204 0 2.5 Mabsadd m
.2619 .25204 -2.165 -1.25 Mabsadd L
.2619 .25204 2.165 -1.25 Mabsadd L
.2619 .25204 0 2.5 Mabsadd L closepath F
.30952 .25431 0 2.5 Mabsadd m
.30952 .25431 -2.165 -1.25 Mabsadd L
.30952 .25431 2.165 -1.25 Mabsadd L
.30952 .25431 0 2.5 Mabsadd L closepath F
.35714 .25802 0 2.5 Mabsadd m
.35714 .25802 -2.165 -1.25 Mabsadd L
.35714 .25802 2.165 -1.25 Mabsadd L
.35714 .25802 0 2.5 Mabsadd L closepath F
.40476 .26363 0 2.5 Mabsadd m
.40476 .26363 -2.165 -1.25 Mabsadd L
.40476 .26363 2.165 -1.25 Mabsadd L
.40476 .26363 0 2.5 Mabsadd L closepath F
.45238 .27166 0 2.5 Mabsadd m
.45238 .27166 -2.165 -1.25 Mabsadd L
.45238 .27166 2.165 -1.25 Mabsadd L
.45238 .27166 0 2.5 Mabsadd L closepath F
.5 .28261 0 2.5 Mabsadd m
.5 .28261 -2.165 -1.25 Mabsadd L
.5 .28261 2.165 -1.25 Mabsadd L
.5 .28261 0 2.5 Mabsadd L closepath F
.54762 .29694 0 2.5 Mabsadd m
.54762 .29694 -2.165 -1.25 Mabsadd L
.54762 .29694 2.165 -1.25 Mabsadd L
.54762 .29694 0 2.5 Mabsadd L closepath F
.59524 .31501 0 2.5 Mabsadd m
.59524 .31501 -2.165 -1.25 Mabsadd L
.59524 .31501 2.165 -1.25 Mabsadd L
.59524 .31501 0 2.5 Mabsadd L closepath F
.64286 .33692 0 2.5 Mabsadd m
.64286 .33692 -2.165 -1.25 Mabsadd L
.64286 .33692 2.165 -1.25 Mabsadd L
.64286 .33692 0 2.5 Mabsadd L closepath F
.69048 .36223 0 2.5 Mabsadd m
.69048 .36223 -2.165 -1.25 Mabsadd L
.69048 .36223 2.165 -1.25 Mabsadd L
.69048 .36223 0 2.5 Mabsadd L closepath F
.7381 .38937 0 2.5 Mabsadd m
.7381 .38937 -2.165 -1.25 Mabsadd L
.7381 .38937 2.165 -1.25 Mabsadd L
.7381 .38937 0 2.5 Mabsadd L closepath F
.78571 .41458 0 2.5 Mabsadd m
.78571 .41458 -2.165 -1.25 Mabsadd L
.78571 .41458 2.165 -1.25 Mabsadd L
.78571 .41458 0 2.5 Mabsadd L closepath F
.83333 .43012 0 2.5 Mabsadd m
.83333 .43012 -2.165 -1.25 Mabsadd L
.83333 .43012 2.165 -1.25 Mabsadd L
.83333 .43012 0 2.5 Mabsadd L closepath F
.88095 .42176 0 2.5 Mabsadd m
.88095 .42176 -2.165 -1.25 Mabsadd L
.88095 .42176 2.165 -1.25 Mabsadd L
.88095 .42176 0 2.5 Mabsadd L closepath F
.92857 .3658 0 2.5 Mabsadd m
.92857 .3658 -2.165 -1.25 Mabsadd L
.92857 .3658 2.165 -1.25 Mabsadd L
.92857 .3658 0 2.5 Mabsadd L closepath F
.97619 .22649 0 2.5 Mabsadd m
.97619 .22649 -2.165 -1.25 Mabsadd L
.97619 .22649 2.165 -1.25 Mabsadd L
.97619 .22649 0 2.5 Mabsadd L closepath F
.001 w
[ .5 4 5 4 .5 3 ] 0 Mabsdash
.02381 .0407 m
.07143 .04071 L
.11905 .0408 L
.16667 .04115 L
.21429 .04208 L
.2619 .04401 L
.30952 .04748 L
.35714 .05312 L
.40476 .06162 L
.45238 .07367 L
.5 .08995 L
.54762 .111 L
.59524 .13718 L
.64286 .16854 L
.69048 .20458 L
.7381 .24385 L
.78571 .28307 L
.83333 .31552 L
.88095 .32877 L
.92857 .30156 L
.97619 .20088 L
s
.01 w
.02381 .0407 Mdot
.07143 .04071 Mdot
.11905 .0408 Mdot
.16667 .04115 Mdot
.21429 .04208 Mdot
.2619 .04401 Mdot
.30952 .04748 Mdot
.35714 .05312 Mdot
.40476 .06162 Mdot
.45238 .07367 Mdot
.5 .08995 Mdot
.54762 .111 Mdot
.59524 .13718 Mdot
.64286 .16854 Mdot
.69048 .20458 Mdot
.7381 .24385 Mdot
.78571 .28307 Mdot
.83333 .31552 Mdot
.88095 .32877 Mdot
.92857 .30156 Mdot
.97619 .20088 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{352, 217.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005P0000fB000`400?l00000o`00003oo`3ooomQ
0?ooo`00<@3oool2000002P0oooo0`00000T0?ooo`<00000103oool200000280oooo0`0000030?oo
o`<00000803oool5000000<0oooo0P00000Q0?ooo`D000000P3oool300000280oooo0`0000040?oo
o`800000:P3oool00300oooo00@000000?ooo`3oool000009P3oool01@000000oooo0?ooo`3oool0
000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000R0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000:@3oool00300oooo00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo02L0oooo000`0?ooo`040000003oool0oooo000002X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000280oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0803oool2000000<0oooo00@000000?ooo`3oool00000:@3oool00300oooo00@000000?ooo`3o
ool000009P3oool4000002D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000R
0?ooo`040000003oool0oooo0?ooo`@00000803oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000803oool01P000000oooo0?ooo`3oool000000?ooo`@000009@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0oooo000`0?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool09@3oool2000000@0oooo00@000000?ooo`3oool00000
8@3oool2000000<0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000803oool01`000000oooo0?ooo`3oool000000?ooo`000000903o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000:@3oool00340oooo
0P00000W0?ooo`D00000903oool00`000000oooo0?ooo`030?ooo`8000008`3oool010000000oooo
0?ooo`3oool500000200oooo0`0000040?ooo`8000008P3oool300000080oooo1@00000Q0?ooo`<0
0000103oool2000002X0oooo003o0?ooof40oooo003o0?ooof40oooo003o0?ooof40oooo003o0?oo
of40oooo003o0?ooof40oooo000[0?ooool00000<P0000040?ooo`00:`3oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`800000103oool002/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo000[0?oo
o`030000003oool0oooo0?l0oooo9@3oool2000000L0oooo00<000000?ooo`3oool00P3oool002/0
oooo00<000000?ooo`3oool0o`3ooolV0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`00
:`3oool200000?l0oooo9P3oool4000000@0oooo0P0000040?ooo`00:`3oool00`000000oooo0?oo
o`3o0?ooobH0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00:`3oool0
0`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`002`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P0000040?oo
o`<000001P3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo0`00003o0?ooob`0oooo0`0000040?ooo`002P3oool010000000oooo0?ooo`00
00090?ooo`8000000`3oool4000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`<00000303oool3000000/0oooo0`00000<0?ooo`<00000lP3oool3000000H0oooo00<0
00000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
00030?ooo`030000003oool0000000<000001P3oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool6000000<0oooo1@0000030?ooo`X000000P3oool2000000<0oooo1`0000020?ooo`030000003o
ool0oooo00H0oooo0`00000;0?ooo`<00000eP3oool3000000H0oooo00<000000?ooo`3oool00P3o
ool000X0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo0`00000<0?ooo`<0
00002`3oool3000000`0oooo0`0000050?ooo`8000000`3oool6000000<0oooo00<000000?ooo`3o
ool00P0000000`3oool0000000000004000000T0oooo0`0000380?ooo`8000001P3oool00`000000
oooo0?ooo`020?ooo`002`3oool2000000T0oooo0`0000030?ooo`<000000P3oool5000000D0oooo
00<000000?ooo`3oool0?@3oool3000000/0oooo0`0000030?ooo`8000000`3oool00`000000oooo
0?ooo`0400000<H0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`00:`3o
ool2000005/0oooo2@0000050?ooo`<00000^03oool00`000000oooo000000060?ooo`800000103o
ool002/0oooo00<000000?ooo`3oool0IP3oool500000;X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`1X0?ooo`<000000`3oool40000
0;<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000
oooo0?ooo`1b0?ooo`8000000`3oool300000:P0oooo0`0000080?ooo`030000003oool0oooo0080
oooo000[0?ooo`030000003oool0oooo07L0oooo0`0000000`3oool000000?ooo`2W0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool002/0oooo0P00001h0?ooo`<000001@3o
ool200000:<0oooo00<000000?ooo`3oool01@3oool2000000@0oooo000[0?ooo`030000003oool0
oooo0840oooo0`000000103oool0000000000000002J0?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0Q03oool4000009/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`250?oo
o`@00000VP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000[0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool0T`3oool00`000000oooo000000090?ooo`03
0000003oool0oooo0080oooo000[0?ooo`800000T03oool200000900oooo00<000000?ooo`000000
203oool2000000@0oooo000[0?ooo`030000003oool0oooo0940oooo1P00002;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0U03oool3
000008/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00:`3oool00`00
0000oooo0?ooo`2D0?ooo`<0000000<0oooo0000003oool0QP3oool00`000000oooo0000000:0?oo
o`030000003oool0oooo0080oooo000[0?ooo`800000V@3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00L0oooo0P0000040?ooo`00:`3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00:`3o
ool00`000000oooo0?ooo`3o0?ooob40oooo0P00000;0?ooo`030000003oool0oooo0080oooo0005
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0W`3oool2000007h0oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:40oooo
1000001l0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool000@0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000XP3oool3000007/0oooo
00<000000?ooo`3oool0203oool3000000@0oooo00040?ooo`040000003oool0oooo000000T0oooo
0P0000030?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0XP3oool3000007X0oooo0P00000<0?ooo`030000003oool0oooo0080oooo
00040?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<000001P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00103o
ool010000000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`001@3oool2000000T0oooo0`0000030?ooo`<000000P3oool5000000030?ooo`000000000000<0
00001@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0700oooo0P00000=0?ooo`03
0000003oool0oooo0080oooo000[0?ooo`800000o`3ooolP0?ooo`800000303oool2000000@0oooo
000[0?ooo`030000003oool0oooo0:h0oooo0P00001_0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0/03oool4000006T0oooo0P00000>
0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo0;40oooo0`00001Y0?oo
o`8000003P3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`2a0?ooo`<0
0000JP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000[0?ooo`800000
]`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`00:`3o
ool00`000000oooo0?ooo`3o0?oooad0oooo0P0000050?ooo`D000001@3oool00`000000oooo0?oo
o`020?ooo`00:`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool00`3oool5000000D0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?oo
o`3oool0o`3ooolN0?ooo`030000003oool0oooo00<0oooo1@0000050?ooo`030000003oool0oooo
0080oooo000[0?ooo`800000o`3ooolN0?ooo`8000001@3oool5000000@0oooo0P0000040?ooo`00
:`3oool00`000000oooo0?ooo`2l0?ooo`800000GP3oool00`000000oooo0?ooo`040?ooo`D00000
1@3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`2n0?ooo`@00000FP3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0
oooo0;l0oooo0`00001J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
02/0oooo00<000000?ooo`3oool0_`3oool3000005T0oooo0P0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool002/0oooo0P00003o0?oooad0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`800000103oool002/0oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`005`3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool3000000D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`8000001`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo000F0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0500oooo0P00
00070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool001H0oooo00@00000
0?ooo`3oool000001`3oool5000000D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`005P3oool0
10000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000H0oooo0`00003o0?oooa/0oooo
00<000000?ooo`3oool03P3oool3000000@0oooo000F0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`3:0?ooo`800000C@3oool200000180oooo
00<000000?ooo`3oool00P3oool001H0oooo00@000000?ooo`3oool000002@3oool2000000H0oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo
0`0000050?ooo`030000003oool0oooo0080oooo000G0?ooo`8000002`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0<d0oooo100000180?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`0000050?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0
oooo0<h0oooo0`0000170?ooo`8000002`3oool3000000D0oooo00<000000?ooo`3oool00P3oool0
02/0oooo0P00003?0?ooo`<00000B03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`00:`3oool00`000000oooo0?ooo`3A0?ooo`800000AP3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool002/0oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`3D0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool01P3oool00`000000oooo000000090?ooo`030000
003oool0oooo0080oooo000[0?ooo`800000e@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000203oool2000000@0oooo000[0?ooo`030000003o
ool0oooo0?l0oooo5`3oool3000000L0oooo00<000000?ooo`0000001@0000050?ooo`030000003o
ool0oooo0080oooo000[0?ooo`030000003oool0oooo0=L0oooo0P00000m0?ooo`800000203oool0
10000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool00P3oool002/0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo0?ooo`0j0?ooo`<000001P3oool00`000000oooo0?ooo`03
0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`3J0?oo
o`030000003oool0oooo03T0oooo0`0000080?ooo`040000003oool0oooo0?ooo`8000001P3oool0
0`000000oooo0?ooo`020?ooo`00:`3oool200000=`0oooo00<000000?ooo`3oool0>03oool20000
00T0oooo00<000000?ooo`3oool0203oool2000000@0oooo000[0?ooo`030000003oool0oooo0=`0
oooo0`00000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`3L0?ooo`<00000=`3oool00`000000oooo
0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
000[0?ooo`030000003oool0oooo0=`0oooo1000000e0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000[
0?ooo`030000003oool0oooo0080oooo200000000`3oool000000000000;000000030?ooo`000000
000000/0000000<0oooo000000000000100000000`3oool0000000000004000000030?ooo`000000
000000@0000000<0oooo000000000000100000000`3oool0000000000004000000030?ooo`000000
000000<00000a@3oool2000000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00:`3oool2000000@0oooo0`00000<0?ooo`<000002`3oool3000000`0oooo0`00000;0?oo
o`<000002`3oool5000000030?ooo`000000000000@0000000<0oooo000000000000100000230?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?oo
o`800000103oool002/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`80
0000303oool3000000`0oooo0`0000020?ooo`H0000000<0oooo0000000000001000001e0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000D0oooo0P0000040?ooo`030000
003oool0oooo00<0oooo0`0000030?ooo`8000000P3oool500000080oooo0`0000060?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`800000
303oool4000000030?ooo`000000000000@00000X03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool00000
2P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0:0?ooo`<000002@3oool6000006/0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00040?ooo`040000003oool0oooo000000L0oooo1@0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool02`3oool3000000030?ooo`000000000000@00000I@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo
000000L0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000007P0oooo00<000000?ooo`3oool0
1`3oool7000005h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool3000000@0oooo00040?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000`0000060?ooo`030000003oool0oooo08D0oooo2000001K0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`0000090?oo
o`8000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`250?ooo`<000001@3oool200000880oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00050?ooo`8000002`3oool0
0`000000oooo0?ooo`020?ooo`8000000`3oool300000080oooo1@0000050?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool01P3oool4000005P0oooo0`00000S0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0T`3oool50000
05<0oooo0`00000S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`00:`3oool2000009D0oooo0`000000103oool0000000000000001@0?oo
o`<000008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool02@3oool2000000@0oooo000[0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool00`3oool010000000oooo00000000001?0?ooo`800000803oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3o
ool0W`3oool3000006d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo0:40oooo1@00001<0?ooo`800000
6`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`00:`3oool200000:<0oooo0`0000000`3oool000000000
001<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool3000000030?ooo`00
0000oooo0080oooo00<000000?ooo`3oool02`3oool2000000@0oooo000[0?ooo`030000003oool0
oooo0:80oooo0P0000040?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003oool04@3oool00`000000oooo0?ooo`02
0?ooo`00:`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo00@0oooo0P00001:0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool6000000<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`2/0?ooo`<0
0000GP3oool00`000000oooo0?ooo`020?ooo`8000001@3oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0[`3oool5000004D0
oooo0`00000A0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool00P3oool002/0oooo0P00002b0?ooo`@00000A03oool30000
0100oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000l0oooo0P000004
0?ooo`00:`3oool00`000000oooo0?ooo`2a0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`<0000000<0oooo0000003oool03@3oool2000000h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0080
oooo0P0000180?ooo`@000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0^@3oool3000004T0oooo
0P0000000`3oool0000000000003000000P0oooo1@0000000`3oool000000?ooo`0@0?ooo`030000
003oool0oooo0080oooo000[0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0B@3o
ool4000000T0oooo1@0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo0080oooo000[
0?ooo`800000_P3oool3000004P0oooo100000090?ooo`H000004@3oool2000000@0oooo000[0?oo
o`030000003oool0oooo0;h0oooo100000180?ooo`030000003oool0oooo00P0oooo1P00000B0?oo
o`030000003oool0oooo0080oooo000;0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<0
00000`3oool2000000<0oooo0`0000060?ooo`030000003oool0oooo0;l0oooo100000160?ooo`80
00002P3oool600000180oooo00<000000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool0
00002P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0;l0oooo0P0000030?ooo`800000@P3oool20000
00/0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo0080oooo000:0?oo
o`040000003oool0oooo000000L0oooo1@0000020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0?P3oool3000000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`020?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`<00000a`3oool00`000000
oooo0?ooo`0n0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo0`0000040?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool000000?ooo`04000000H0oooo00<000000?ooo`3oool0b03oool01000
0000oooo00000000000k0?ooo`@000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool000002@3oool2
000000<0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool0=`3oool3000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo000;0?ooo`8000002`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool5000000D0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`00:`3oool200000<h0oooo1000000d0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool2000000@0oooo000[0?ooo`030000003oool0oooo0<h0oooo1000000b0?oo
o`<000003P3oool4000001@0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`02000002l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`<00000503oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo
0?ooo`3D0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool2000001D0oooo
00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0eP3oool2000002T0oooo00@0
00000?ooo`3oool00000403oool00`000000oooo0000000E0?ooo`030000003oool0oooo0080oooo
000[0?ooo`800000f@3oool2000002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0E0?ooo`800000103oool002/0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003o
ool0oooo0080oooo000[0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool08@3oool0
10000000oooo0?ooo`00000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3o
ool002/0oooo00<000000?ooo`3oool0f`3oool4000001l0oooo00<000000?ooo`3oool03@3oool0
10000000oooo0?ooo`00000K0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0
oooo0=`0oooo1@00000M0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000703oool0
0`000000oooo0?ooo`020?ooo`00:`3oool200000=d0oooo0P0000030?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000000L0?ooo`800000103oool0
02/0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`020?ooo`800000603oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool002/0
oooo00<000000?ooo`3oool0i03oool3000001<0oooo0P0000020?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0i`3oool00`000000oooo
0?ooo`0?0?ooo`<000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0j@3oool2000000d0oooo1000
000?0?ooo`030000003oool0000001l0oooo00<000000?ooo`3oool00P3oool002/0oooo0P00003/
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`00000?0?ooo`030000003oool0
oooo01d0oooo0P0000040?ooo`00:`3oool00`000000oooo0?ooo`3Z0?ooo`@00000203oool01`00
0000oooo0?ooo`3oool000000?ooo`0000003P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0080oooo00050?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000000`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0j`3oool3
000000030?ooo`000000000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0oooo
1@00000R0?ooo`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo000000X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool5000000T0oooo1@00000:
0?ooo`D000002@3oool500000;X0oooo00<000000?ooo`3oool00P3oool4000000@0oooo0`00000:
0?ooo`D000008P3oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`000007
0?ooo`D000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool300000080oooo1@0000090?ooo`D000002P3oool5000000T0oooo1@00
000:0?ooo`D000002@3oool5000000T0oooo1@00000:0?ooo`D00000Q`3oool2000000040?ooo`00
000000000?ooo`@000000P3oool3000000030?ooo`000000000000H00000803oool3000000@0oooo
00040?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`D000000P3oool6000000030?ooo`000000000000<0000000<0oooo0000
00000000100000030?ooo`/000000`3oool:000000<0oooo2`0000030?ooo`030000003oool00000
00L000000`3oool2000000030?ooo`000000000000H000000`3oool010000000oooo0?ooo`3oool5
000000T0oooo1@00000:0?ooo`D00000J@3oool00`000000oooo0?ooo`030?ooo`L000001`3oool5
00000280oooo00<000000?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`00
00060?ooo`030000003oool0oooo0080oooo1@0000090?ooo`D000002P3oool5000000T0oooo1@00
000:0?ooo`D000002@3oool5000000T0oooo1@00000:0?ooo`H000000`3oool2000000<0oooo1P00
00030?ooo`030000003oool0oooo00<0oooo1@0000090?ooo`D00000FP3oool00`000000oooo0?oo
o`030?ooo`030000003oool00000008000002@3oool600000280oooo00<000000?ooo`3oool00P3o
ool000@0oooo00@000000?ooo`3oool000002@3oool2000000<0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool00P3oool5000000T0
oooo1@00000:0?ooo`D000002@3oool5000000X0oooo1@0000090?ooo`D000002@3oool5000000X0
oooo1@0000090?ooo`D00000203oool700000080oooo0P0000030?ooo`L000002P3oool5000004X0
oooo00<000000?ooo`3oool01P3oool200000380oooo00<000000?ooo`3oool00P3oool000D0oooo
0P00000;0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`D0000000<0oooo000000000000
0`0000050?ooo`030000003oool0oooo03`0oooo1@0000090?ooo`D000002@3oool5000000X0oooo
1@0000090?ooo`D000002P3oool5000000T0oooo1@0000000`3oool00000000000030?ooo`T00000
B@3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0080oooo000[0?ooo`800000MP3oool5000000X0oooo1@0000090?ooo`D000002P3o
ool6000000P0oooo1@00000j0?ooo`030000003oool0oooo0100oooo0P00000Y0?ooo`800000103o
ool002/0oooo00<000000?ooo`3oool0TP3oool5000000X0oooo1@0000040?ooo`X00000>03oool2
000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`00:`3oool00`00
0000oooo0?ooo`2Q0?ooo`D000002@3oool6000000T0oooo1@00000X0?ooo`<000003`3oool20000
02h0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0[`3oool5000000@0
oooo2`00000V0?ooo`D000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0[`3oool5000000X0oooo
1@00000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`D0
0000<03oool00`000000oooo0?ooo`020?ooo`00:`3oool200000;l0oooo1@0000020?ooo`H00000
00<0oooo0000000000000`00000E0?ooo`800000403oool5000002l0oooo0P0000040?ooo`00:`3o
ool00`000000oooo0?ooo`2n0?ooo`D000002@3oool5000001<0oooo0P0000040?ooo`80000000<0
oooo0000003oool0203oool600000300oooo00<000000?ooo`3oool00P3oool002/0oooo00<00000
0?ooo`3oool0c03oool5000000030?ooo`000000000000@000000`3oool5000000<0oooo00<00000
0?ooo`3oool00`3oool5000000<0oooo0P0000030?ooo`030000003oool0000000@00000<03oool0
0`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`3<0?ooo`D000002P3oool90000
00D0oooo200000070?ooo`D00000<03oool00`000000oooo0?ooo`020?ooo`00:`3oool00`000000
oooo0?ooo`3<0?ooo`D000002P3oool6000000<0oooo0P0000000`3oool000000?ooo`05000003l0
oooo00<000000?ooo`3oool00P3oool002/0oooo0P00003L0?ooo`D000001`3oool00`000000oooo
00000004000003h0oooo0P0000040?ooo`00:`3oool00`000000oooo0?ooo`3K0?ooo`D00000103o
ool00`000000oooo0?ooo`020?ooo`D00000?`3oool00`000000oooo0?ooo`020?ooo`00:`3oool0
0`000000oooo0?ooo`3J0?ooo`D00000CP3oool00`000000oooo0?ooo`020?ooo`00:`3oool00`00
0000oooo0?ooo`3H0?ooo`8000000`3oool00`000000oooo0?ooo`02000004/0oooo00<000000?oo
o`3oool00P3oool002/0oooo00<000000?ooo`3oool0eP3oool2000000@0oooo00<000000?ooo`00
0000CP3oool00`000000oooo0?ooo`020?ooo`00:`3oool200000=D0oooo0P0000060?ooo`<00000
C@3oool2000000@0oooo000[0?ooo`030000003oool0oooo0=80oooo0P0000060?ooo`H00000C@3o
ool00`000000oooo0?ooo`020?ooo`004@3oool2000000@0oooo00<000000?ooo`3oool00`3oool3
00000080oooo0`0000060?ooo`030000003oool0oooo0<l0oooo0`0000050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`020?ooo`00403oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3>0?ooo`<00000G03oool00`000000oooo0?ooo`020?ooo`00403oool01000
0000oooo0?ooo`0000070?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`<00000b`3oool6
000000<0oooo00<000000?ooo`3oool0E03oool3000000@0oooo000@0?ooo`040000003oool0oooo
000000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0<T0oooo0P0000030?ooo`@00000F`3oool00`000000oooo0?ooo`020?ooo`00403oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`360?ooo`<00000103oool4000005`0oooo00<000000?ooo`3oool00P3o
ool00100oooo00@000000?ooo`3oool000002@3oool2000000<0oooo0P0000070?ooo`030000003o
ool0oooo0<@0oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000GP3oool00`000000oooo
0?ooo`020?ooo`004@3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0<00oooo100000020?ooo`800000I@3oool00`000000oooo0?oo
o`020?ooo`00:`3oool200000<00oooo0`0000000`3oool000000000001W0?ooo`800000103oool0
02/0oooo00<000000?ooo`3oool0_03oool6000006/0oooo00<000000?ooo`3oool00P3oool002/0
oooo00<000000?ooo`3oool0^P3oool4000000030?ooo`000000000000800000JP3oool00`000000
oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`2h0?ooo`8000001P3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo0;00oooo0P00
00030?ooo`<00000203oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo000[
0?ooo`800000/P3oool4000007L0oooo0P0000040?ooo`00:`3oool00`000000oooo0?ooo`2[0?oo
o`8000000P3oool5000007T0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo1P00001i0?ooo`03
0000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo0:80oooo100000050?ooo`<00000
0`3oool3000007T0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0500000080oooo0`0000070?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool00P3oool002/0oooo0P00002E0?ooo`040000003oool0oooo00000080oooo0P00
00070?ooo`030000003oool0000000800000Q03oool2000000@0oooo000[0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool01000000:0?ooo`@00000R03oool00`000000oooo0?ooo`02
0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`050000003oool000000?ooo`0000000P3oool2
000000H0oooo00<000000?ooo`3oool01`3oool7000008P0oooo00<000000?ooo`3oool00P3oool0
02/0oooo00<000000?ooo`3oool0MP3oool2000000L0oooo00@000000?ooo`3oool000000P3oool4
00000140oooo100000040?ooo`<00000R03oool00`000000oooo0?ooo`020?ooo`00:`3oool20000
06T0oooo00<000000?ooo`0000002@3oool2000000030?ooo`00000000000080oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000008000002@3oool0
0`000000oooo0?ooo`260?ooo`800000103oool002/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0000000;0?ooo`8000002`3oool2000000030?ooo`00000000000080oooo0P0000020?oo
o`030000003oool0oooo00<0oooo0`00000<0?ooo`030000003oool0oooo00X0oooo1000002F0?oo
o`030000003oool0oooo0080oooo000[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000303oool2000000`0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@0000020?ooo`8000000P3oool00`000000
oooo0?ooo`0500000080oooo0P0000020?ooo`030000003oool0oooo0080oooo1000000;0?ooo`03
0000003oool0oooo01@0oooo2@00002F0?ooo`030000003oool0oooo0080oooo00050?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`<000000P3oool300000080oooo1@0000020?ooo`<00000
1P3oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo0?ooo`0200000080oooo
00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00D00000
0P3oool200000080oooo00<000000?ooo`3oool01@0000020?ooo`8000001P3oool4000000/0oooo
0`00000<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@0000060?ooo`<00000
UP3oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`<000002`3oool40000
00/0oooo0`00000<0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`D00000303oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0080oooo00040?ooo`040000003oool0oooo0000
00L0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`<00000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0`0?ooo`T00000X`3oool30000
00@0oooo00040?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0000000@000001P3oool300000:D0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00@000000?ooo`3oool00000203oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000003000000H0oooo00<0
00000?ooo`3oool0M03oool6000000`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`020?ooo`00103oool010000000oooo0?ooo`0000090?ooo`8000000`3oool2000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool0J@3oool010000000
oooo0?ooo`3oool7000000<0oooo0`00002c0?ooo`030000003oool0oooo0080oooo00050?ooo`80
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D0
00001@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00@0oooo2`00000;0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool00P3oool002/0oooo0P0000050?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo3P0000060?ooo`<00000`@3oool2000000@0oooo000[0?ooo`030000003o
ool0oooo00<0ooooD@0000060?ooo`<00000303oool00`000000oooo0?ooo`310?ooo`030000003o
ool0oooo0080oooo000[0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`<000002`3oool4
000000/0oooo0`00000<0?ooo`<000002`3oool3000000d0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`020?ooo`00:`3oool00`000000oooo0?ooo`030?ooo`<00000303oool20000
00`0oooo0`00000<0?ooo`8000003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0=h0oooo00<000000?ooo`3oool00P3oool002/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool002/0oooo
0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
000[0?ooool00000<P0000040?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00o`3ooomQ0?ooo`00
o`3ooomQ0?ooo`00[P3oool2000000P0oooo0P00001D0?ooo`8000003P3oool200000400oooo002^
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo03h0oooo001S0?ooo`D0000000D0oooo00000000000000000?ooo`02
00000080oooo0P0000090?ooo`<000000P3oool3000000@0oooo100000020?ooo`@0000000<0oooo
0000000000000`0000020?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P000005
0?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo0?ooo`@00000203oool3000000@0oooo0`0000020?ooo`@000000P3oool5000000<0oooo
0P0000020?ooo`D000000P3oool300000080oooo0`0000000`3oool00000000000090?ooo`0>0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`03
0000003oool0oooo03h0oooo001U0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool0oooo03h0oooo001U0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`<000000P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?oo
o`D000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`080?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0oooo03h0oooo001U0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool00000
00<0000000<0oooo0000000000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo000000020?ooo`030000003oool0oooo
00X0oooo0`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0>0000003oool0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo
03h0oooo001U0?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000P0oooo00<000000?oo
o`3oool00`3oool2000000030?ooo`00000000000080oooo0P0000040?ooo`<000000P3oool30000
00@0oooo0`0000020?ooo`@000000P3oool4000000D0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`00000000000080oooo
100000080?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`@0000000@0oooo00000000
000000000`3oool400000080oooo0`0000040?ooo`<000000P3oool4000000/0oooo00<000000?oo
o`3oool00P000000103oool000000?ooo`3oool2000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool0?P3oool006D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00D0oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo0P00000L0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool07@3oool2000000h0oooo0P0000100?ooo`00
H`3oool5000000P0oooo00<000000?ooo`3oool02@3oool300000100oooo0P0000040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0203oool5000001l0oooo1000000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1X0?ooo`00o`3o
oomQ0?ooo`00o`3ooomQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 351}, {216.438, 0}} -> {-5.9446, 0.392575, 0.117462, \
0.000104841}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
WindowToolbars->{},
Evaluator->"Local",
CellGrouping->Manual,
WindowSize->{763, 646},
WindowMargins->{{Automatic, 119}, {Automatic, 12}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.  Make modifications to any definition using commands in the 
Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\

The following styles are useful for numbered equations, figures, etc.  They 
automatically give the cell a FrameLabel containing a reference to a 
particular counter, and also increment that counter.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help 
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 164, 4, 40, "Title",
  Evaluatable->False],
Cell[1884, 55, 123, 3, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2032, 62, 79, 2, 53, "Section",
  Evaluatable->False],
Cell[2114, 66, 1101, 18, 134, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[3252, 89, 92, 2, 33, "Section",
  Evaluatable->False],
Cell[3347, 93, 488, 15, 46, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3860, 112, 141, 6, 92, "Input"],
Cell[4004, 120, 220, 4, 22, "Print"],
Cell[4227, 126, 121, 2, 37, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4397, 134, 85, 2, 33, "Section",
  Evaluatable->False],
Cell[4485, 138, 145, 5, 26, "Text",
  Evaluatable->False],
Cell[4633, 145, 909, 15, 207, "Input"],
Cell[5545, 162, 11456, 195, 2271, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17038, 362, 100, 2, 33, "Section",
  Evaluatable->False],
Cell[17141, 366, 316, 7, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17482, 377, 3299, 66, 463, "Input"],
Cell[20784, 445, 1810, 32, 225, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22631, 482, 1154, 25, 351, "Input"],
Cell[23788, 509, 89305, 2019, 296, 15065, 1098, "GraphicsData", "PostScript", \
"Graphics"],
Cell[113096, 2530, 105227, 3353, 296, 46878, 2628, "GraphicsData", \
"PostScript", "Graphics"],
Cell[218326, 5885, 219045, 9567, 296, 168878, 8943, "GraphicsData", \
"PostScript", "Graphics"],
Cell[437374, 15454, 1932, 38, 199, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[439355, 15498, 107, 2, 33, "Section",
  Evaluatable->False],
Cell[439465, 15502, 988, 25, 90, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[440478, 15531, 213, 4, 95, "Input"],
Cell[440694, 15537, 837, 15, 99, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[441580, 15558, 88, 2, 33, "Section",
  Evaluatable->False],
Cell[441671, 15562, 98, 1, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[441794, 15567, 678, 13, 255, "Input"],
Cell[442475, 15582, 59654, 1619, 186, 17746, 1097, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[502166, 17206, 502, 10, 127, "Input"],
Cell[502671, 17218, 78064, 1883, 263, 19697, 1158, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580772, 19106, 696, 14, 143, "Input"],
Cell[581471, 19122, 57829, 1397, 186, 14135, 853, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[639349, 20525, 93, 2, 33, "Section",
  Evaluatable->False],
Cell[639445, 20529, 508, 9, 58, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[639978, 20542, 355, 6, 175, "Input"],
Cell[640336, 20550, 76283, 3038, 358, 34235, 2514, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[716656, 23593, 349, 6, 175, "Input"],
Cell[717008, 23601, 412093, 28907, 421, 317027, 27729, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1129138, 52513, 1052, 20, 431, "Input"],
Cell[1130193, 52535, 147, 3, 24, "Print"],
Cell[1130343, 52540, 115184, 2507, 671, 21568, 1347, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1245576, 55053, 87, 2, 33, "Section",
  Evaluatable->False],
Cell[1245666, 55057, 631, 18, 60, "Text",
  Evaluatable->False],
Cell[1246300, 55077, 179, 3, 79, "Input"],
Cell[1246482, 55082, 204, 4, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1246723, 55091, 144, 6, 33, "Section",
  Evaluatable->False],
Cell[1246870, 55099, 602, 13, 58, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1247497, 55116, 450, 11, 127, "Input"],
Cell[1247950, 55129, 770703, 34226, 497, 609835, 32235, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2018702, 89361, 115, 2, 33, "Section",
  Evaluatable->False],
Cell[2018820, 89365, 389, 12, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2019234, 89381, 577, 12, 143, "Input"],
Cell[2019814, 89395, 44, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2019907, 89402, 104, 2, 33, "Section",
  Evaluatable->False],
Cell[2020014, 89406, 440, 14, 42, "Text",
  Evaluatable->False],
Cell[2020457, 89422, 56, 1, 47, "Input"],
Cell[2020516, 89425, 301, 8, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2020854, 89438, 92, 2, 33, "Section",
  Evaluatable->False],
Cell[2020949, 89442, 384, 8, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2021358, 89454, 4033, 80, 655, "Input"],
Cell[2025394, 89536, 174, 3, 48, "Output"],
Cell[2025571, 89541, 143, 2, 46, "Output"],
Cell[2025717, 89545, 57849, 1438, 186, 16127, 918, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2083569, 90985, 53520, 1312, 186, 12416, 800, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2137138, 92303, 101, 2, 33, "Section",
  Evaluatable->False],
Cell[2137242, 92307, 157, 5, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2137424, 92316, 3165, 63, 431, "Input"],

Cell[CellGroupData[{
Cell[2140614, 92383, 959, 19, 255, "Input"],
Cell[2141576, 92404, 145, 2, 46, "Output"],
Cell[2141724, 92408, 63184, 1547, 186, 14903, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2204911, 93957, 117, 2, 46, "Output"],
Cell[2205031, 93961, 169, 3, 48, "Output"],
Cell[2205203, 93966, 75383, 1940, 186, 22169, 1279, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2280589, 95908, 93, 1, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2280743, 95916, 92, 2, 33, "Section",
  Evaluatable->False],
Cell[2280838, 95920, 159, 5, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2281022, 95929, 3156, 63, 431, "Input"],

Cell[CellGroupData[{
Cell[2284203, 95996, 405, 7, 127, "Input"],
Cell[2284611, 96005, 146, 2, 46, "Output"],
Cell[2284760, 96009, 50601, 1245, 186, 12144, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2335364, 97256, 126, 2, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2335551, 97265, 90, 2, 33, "Section",
  Evaluatable->False],
Cell[2335644, 97269, 503, 9, 58, "Text",
  Evaluatable->False],
Cell[2336150, 97280, 3837, 77, 591, "Input"],

Cell[CellGroupData[{
Cell[2340012, 97361, 573, 13, 143, "Input"],
Cell[2340588, 97376, 68696, 1732, 236, 29394, 1242, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2409321, 99113, 571, 13, 143, "Input"],
Cell[2409895, 99128, 70551, 1830, 226, 30349, 1329, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

